/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtcore_python.h"

#include "qdir_wrapper.h"

// Extra includes
#include <QList>
#include <QStringList>
#include <qdir.h>
#include <qfileinfo.h>



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QDir_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QDir >()))
        return -1;

    QDir* cptr = 0;
    int overloadId = -1;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);

    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 4) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QDir(): too many arguments");
        return -1;
    }

    if (!PyArg_ParseTuple(args, "|OOOO:QDir", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return -1;

    // Overloaded function decisor
    // 0: QDir(QDir)
    // 1: QDir(QString)
    // 2: QDir(QString,QString,QFlags<QDir::SortFlag>,QFlags<QDir::Filter>)
    if (numArgs == 0) {
        overloadId = 1; // QDir(QString)
    } else if (Shiboken::Converter< QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 1; // QDir(QString)
        } else if (Shiboken::Converter< QString >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 2; // QDir(QString,QString,QFlags<QDir::SortFlag>,QFlags<QDir::Filter>)
            } else if (Shiboken::Converter< ::QFlags<QDir::SortFlag> >::isConvertible(pyargs[2])) {
                if (numArgs == 3) {
                    overloadId = 2; // QDir(QString,QString,QFlags<QDir::SortFlag>,QFlags<QDir::Filter>)
                } else if (Shiboken::Converter< ::QFlags<QDir::Filter> >::isConvertible(pyargs[3])) {
                    overloadId = 2; // QDir(QString,QString,QFlags<QDir::SortFlag>,QFlags<QDir::Filter>)
                }
            }
        }
    } else if (numArgs == 1 && Shiboken::Converter< ::QDir >::isConvertible(pyargs[0])) {
        overloadId = 0; // QDir(QDir)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDir_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QDir(QDir)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QDir cppArg0 = Shiboken::Converter<QDir >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QDir(QDir)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QDir(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // QDir(QString)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "path");
                    if (value) {
                        if (pyargs[0])
                            errorArgName = "path";
                        else if (Shiboken::Converter< QString >::isConvertible(value))
                            pyargs[0] = value;
                        else
                            goto Sbk_QDir_Init_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtCore.QDir(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                QString cppArg0 = pyargs[0] ? Shiboken::Converter<QString >::toCpp(pyargs[0]) : QString();

                if(!PyErr_Occurred()) {
                    // QDir(QString)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QDir(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 2: // QDir(QString,QString,QFlags<QDir::SortFlag>,QFlags<QDir::Filter>)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "sort");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "sort";
                        else if (Shiboken::Converter< ::QFlags<QDir::SortFlag> >::isConvertible(value))
                            pyargs[2] = value;
                        else
                            goto Sbk_QDir_Init_TypeError;
                    }
                    value = PyDict_GetItemString(kwds, "filter");
                    if (value) {
                        if (pyargs[3])
                            errorArgName = "filter";
                        else if (Shiboken::Converter< ::QFlags<QDir::Filter> >::isConvertible(value))
                            pyargs[3] = value;
                        else
                            goto Sbk_QDir_Init_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtCore.QDir(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                QString cppArg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);
                QFlags<QDir::SortFlag> cppArg2 = pyargs[2] ? Shiboken::Converter<QFlags<QDir::SortFlag> >::toCpp(pyargs[2]) : QDir::SortFlags(QDir::Name |QDir:: IgnoreCase);
                QFlags<QDir::Filter> cppArg3 = pyargs[3] ? Shiboken::Converter<QFlags<QDir::Filter> >::toCpp(pyargs[3]) : QDir::AllEntries;

                if(!PyErr_Occurred()) {
                    // QDir(QString,QString,QFlags<QDir::SortFlag>,QFlags<QDir::Filter>)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QDir(cppArg0, cppArg1, cppArg2, cppArg3);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QDir >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QDir_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QDir_Init_TypeError:
        const char* overloads[] = {"PySide.QtCore.QDir", "QString = QString()", "QString, QString, PySide.QtCore.QDir.SortFlags = QDir.SortFlags(Name | IgnoreCase), PySide.QtCore.QDir.Filters = QDir.AllEntries", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QDir", overloads);
        return -1;
}

static PyObject* Sbk_QDirFunc___reduce__(PyObject* self)
{
    QDir* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDir* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // __reduce__()
                // Begin code injection

                // TEMPLATE - reduce_code - START
                pyResult = Py_BuildValue("(N(s))", PyObject_Type(self), qPrintable(cppSelf->path()));
                // TEMPLATE - reduce_code - END

                // End of code injection


            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDirFunc_absoluteFilePath(PyObject* self, PyObject* arg)
{
    QDir* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDir* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: absoluteFilePath(QString)const
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // absoluteFilePath(QString)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDirFunc_absoluteFilePath_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // absoluteFilePath(QString)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QDir*>(cppSelf)->absoluteFilePath(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QDirFunc_absoluteFilePath_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QDir.absoluteFilePath", overloads);
        return 0;
}

static PyObject* Sbk_QDirFunc_absolutePath(PyObject* self)
{
    QDir* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDir* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // absolutePath()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QDir*>(cppSelf)->absolutePath();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDirFunc_addResourceSearchPath(PyObject* self, PyObject* arg)
{
    int overloadId = -1;

    // Overloaded function decisor
    // 0: addResourceSearchPath(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // addResourceSearchPath(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDirFunc_addResourceSearchPath_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // addResourceSearchPath(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QDir::addResourceSearchPath(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QDirFunc_addResourceSearchPath_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QDir.addResourceSearchPath", overloads);
        return 0;
}

static PyObject* Sbk_QDirFunc_addSearchPath(PyObject* self, PyObject* args)
{
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "addSearchPath", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: addSearchPath(QString,QString)
    if (numArgs == 2 && Shiboken::Converter< QString >::isConvertible(pyargs[0]) && Shiboken::Converter< QString >::isConvertible(pyargs[1])) {
        overloadId = 0; // addSearchPath(QString,QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDirFunc_addSearchPath_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            QString cppArg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // addSearchPath(QString,QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QDir::addSearchPath(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QDirFunc_addSearchPath_TypeError:
        const char* overloads[] = {"QString, QString", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QDir.addSearchPath", overloads);
        return 0;
}

static PyObject* Sbk_QDirFunc_canonicalPath(PyObject* self)
{
    QDir* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDir* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // canonicalPath()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QDir*>(cppSelf)->canonicalPath();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDirFunc_cd(PyObject* self, PyObject* arg)
{
    QDir* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDir* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: cd(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // cd(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDirFunc_cd_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // cd(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->cd(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QDirFunc_cd_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QDir.cd", overloads);
        return 0;
}

static PyObject* Sbk_QDirFunc_cdUp(PyObject* self)
{
    QDir* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDir* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // cdUp()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->cdUp();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDirFunc_cleanPath(PyObject* self, PyObject* arg)
{
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: cleanPath(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // cleanPath(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDirFunc_cleanPath_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // cleanPath(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = QDir::cleanPath(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QDirFunc_cleanPath_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QDir.cleanPath", overloads);
        return 0;
}

static PyObject* Sbk_QDirFunc_convertSeparators(PyObject* self, PyObject* arg)
{
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: convertSeparators(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // convertSeparators(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDirFunc_convertSeparators_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // convertSeparators(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = QDir::convertSeparators(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QDirFunc_convertSeparators_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QDir.convertSeparators", overloads);
        return 0;
}

static PyObject* Sbk_QDirFunc_count(PyObject* self)
{
    QDir* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDir* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // count()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                uint cppResult = const_cast<const QDir*>(cppSelf)->count();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< unsigned int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDirFunc_current(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // current()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QDir cppResult = QDir::current();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QDir >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDirFunc_currentPath(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // currentPath()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = QDir::currentPath();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDirFunc_dirName(PyObject* self)
{
    QDir* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDir* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // dirName()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QDir*>(cppSelf)->dirName();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDirFunc_drives(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // drives()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QList<QFileInfo > cppResult = QDir::drives();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QList<QFileInfo > >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDirFunc_entryInfoList(PyObject* self, PyObject* args, PyObject* kwds)
{
    QDir* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDir* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QDir.entryInfoList(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOO:entryInfoList", &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: entryInfoList(QFlags<QDir::Filter>,QFlags<QDir::SortFlag>)const
    // 1: entryInfoList(QStringList,QFlags<QDir::Filter>,QFlags<QDir::SortFlag>)const
    if (numArgs == 0) {
        overloadId = 0; // entryInfoList(QFlags<QDir::Filter>,QFlags<QDir::SortFlag>)const
    } else if (Shiboken::Converter< ::QStringList >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 1; // entryInfoList(QStringList,QFlags<QDir::Filter>,QFlags<QDir::SortFlag>)const
        } else if (Shiboken::Converter< ::QFlags<QDir::Filter> >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 1; // entryInfoList(QStringList,QFlags<QDir::Filter>,QFlags<QDir::SortFlag>)const
            } else if (Shiboken::Converter< ::QFlags<QDir::SortFlag> >::isConvertible(pyargs[2])) {
                overloadId = 1; // entryInfoList(QStringList,QFlags<QDir::Filter>,QFlags<QDir::SortFlag>)const
            }
        }
    } else if (Shiboken::Converter< ::QFlags<QDir::Filter> >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // entryInfoList(QFlags<QDir::Filter>,QFlags<QDir::SortFlag>)const
        } else if (Shiboken::Converter< ::QFlags<QDir::SortFlag> >::isConvertible(pyargs[1])) {
            overloadId = 0; // entryInfoList(QFlags<QDir::Filter>,QFlags<QDir::SortFlag>)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDirFunc_entryInfoList_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // entryInfoList(QFlags<QDir::Filter>,QFlags<QDir::SortFlag>)const
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "filters");
                    if (value) {
                        if (pyargs[0])
                            errorArgName = "filters";
                        else if (Shiboken::Converter< ::QFlags<QDir::Filter> >::isConvertible(value))
                            pyargs[0] = value;
                        else
                            goto Sbk_QDirFunc_entryInfoList_TypeError;
                    }
                    value = PyDict_GetItemString(kwds, "sort");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "sort";
                        else if (Shiboken::Converter< ::QFlags<QDir::SortFlag> >::isConvertible(value))
                            pyargs[1] = value;
                        else
                            goto Sbk_QDirFunc_entryInfoList_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtCore.QDir.entryInfoList(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                QFlags<QDir::Filter> cppArg0 = pyargs[0] ? Shiboken::Converter<QFlags<QDir::Filter> >::toCpp(pyargs[0]) : QDir::NoFilter;
                QFlags<QDir::SortFlag> cppArg1 = pyargs[1] ? Shiboken::Converter<QFlags<QDir::SortFlag> >::toCpp(pyargs[1]) : QDir::NoSort;

                if(!PyErr_Occurred()) {
                    // entryInfoList(QFlags<QDir::Filter>,QFlags<QDir::SortFlag>)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QList<QFileInfo > cppResult = const_cast<const QDir*>(cppSelf)->entryInfoList(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QList<QFileInfo > >::toPython(cppResult);
                }
                break;
            }
            case 1: // entryInfoList(QStringList,QFlags<QDir::Filter>,QFlags<QDir::SortFlag>)const
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "filters");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "filters";
                        else if (Shiboken::Converter< ::QFlags<QDir::Filter> >::isConvertible(value))
                            pyargs[1] = value;
                        else
                            goto Sbk_QDirFunc_entryInfoList_TypeError;
                    }
                    value = PyDict_GetItemString(kwds, "sort");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "sort";
                        else if (Shiboken::Converter< ::QFlags<QDir::SortFlag> >::isConvertible(value))
                            pyargs[2] = value;
                        else
                            goto Sbk_QDirFunc_entryInfoList_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtCore.QDir.entryInfoList(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                QStringList cppArg0 = Shiboken::Converter<QStringList >::toCpp(pyargs[0]);
                QFlags<QDir::Filter> cppArg1 = pyargs[1] ? Shiboken::Converter<QFlags<QDir::Filter> >::toCpp(pyargs[1]) : QDir::NoFilter;
                QFlags<QDir::SortFlag> cppArg2 = pyargs[2] ? Shiboken::Converter<QFlags<QDir::SortFlag> >::toCpp(pyargs[2]) : QDir::NoSort;

                if(!PyErr_Occurred()) {
                    // entryInfoList(QStringList,QFlags<QDir::Filter>,QFlags<QDir::SortFlag>)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QList<QFileInfo > cppResult = const_cast<const QDir*>(cppSelf)->entryInfoList(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QList<QFileInfo > >::toPython(cppResult);
                }
                break;
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QDirFunc_entryInfoList_TypeError:
        const char* overloads[] = {"PySide.QtCore.QDir.Filters = QDir.NoFilter, PySide.QtCore.QDir.SortFlags = QDir.NoSort", "list, PySide.QtCore.QDir.Filters = QDir.NoFilter, PySide.QtCore.QDir.SortFlags = QDir.NoSort", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QDir.entryInfoList", overloads);
        return 0;
}

static PyObject* Sbk_QDirFunc_entryList(PyObject* self, PyObject* args, PyObject* kwds)
{
    QDir* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDir* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QDir.entryList(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOO:entryList", &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: entryList(QFlags<QDir::Filter>,QFlags<QDir::SortFlag>)const
    // 1: entryList(QStringList,QFlags<QDir::Filter>,QFlags<QDir::SortFlag>)const
    if (numArgs == 0) {
        overloadId = 0; // entryList(QFlags<QDir::Filter>,QFlags<QDir::SortFlag>)const
    } else if (Shiboken::Converter< ::QStringList >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 1; // entryList(QStringList,QFlags<QDir::Filter>,QFlags<QDir::SortFlag>)const
        } else if (Shiboken::Converter< ::QFlags<QDir::Filter> >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 1; // entryList(QStringList,QFlags<QDir::Filter>,QFlags<QDir::SortFlag>)const
            } else if (Shiboken::Converter< ::QFlags<QDir::SortFlag> >::isConvertible(pyargs[2])) {
                overloadId = 1; // entryList(QStringList,QFlags<QDir::Filter>,QFlags<QDir::SortFlag>)const
            }
        }
    } else if (Shiboken::Converter< ::QFlags<QDir::Filter> >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // entryList(QFlags<QDir::Filter>,QFlags<QDir::SortFlag>)const
        } else if (Shiboken::Converter< ::QFlags<QDir::SortFlag> >::isConvertible(pyargs[1])) {
            overloadId = 0; // entryList(QFlags<QDir::Filter>,QFlags<QDir::SortFlag>)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDirFunc_entryList_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // entryList(QFlags<QDir::Filter>,QFlags<QDir::SortFlag>)const
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "filters");
                    if (value) {
                        if (pyargs[0])
                            errorArgName = "filters";
                        else if (Shiboken::Converter< ::QFlags<QDir::Filter> >::isConvertible(value))
                            pyargs[0] = value;
                        else
                            goto Sbk_QDirFunc_entryList_TypeError;
                    }
                    value = PyDict_GetItemString(kwds, "sort");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "sort";
                        else if (Shiboken::Converter< ::QFlags<QDir::SortFlag> >::isConvertible(value))
                            pyargs[1] = value;
                        else
                            goto Sbk_QDirFunc_entryList_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtCore.QDir.entryList(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                QFlags<QDir::Filter> cppArg0 = pyargs[0] ? Shiboken::Converter<QFlags<QDir::Filter> >::toCpp(pyargs[0]) : QDir::NoFilter;
                QFlags<QDir::SortFlag> cppArg1 = pyargs[1] ? Shiboken::Converter<QFlags<QDir::SortFlag> >::toCpp(pyargs[1]) : QDir::NoSort;

                if(!PyErr_Occurred()) {
                    // entryList(QFlags<QDir::Filter>,QFlags<QDir::SortFlag>)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QStringList cppResult = const_cast<const QDir*>(cppSelf)->entryList(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QStringList >::toPython(cppResult);
                }
                break;
            }
            case 1: // entryList(QStringList,QFlags<QDir::Filter>,QFlags<QDir::SortFlag>)const
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "filters");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "filters";
                        else if (Shiboken::Converter< ::QFlags<QDir::Filter> >::isConvertible(value))
                            pyargs[1] = value;
                        else
                            goto Sbk_QDirFunc_entryList_TypeError;
                    }
                    value = PyDict_GetItemString(kwds, "sort");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "sort";
                        else if (Shiboken::Converter< ::QFlags<QDir::SortFlag> >::isConvertible(value))
                            pyargs[2] = value;
                        else
                            goto Sbk_QDirFunc_entryList_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtCore.QDir.entryList(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                QStringList cppArg0 = Shiboken::Converter<QStringList >::toCpp(pyargs[0]);
                QFlags<QDir::Filter> cppArg1 = pyargs[1] ? Shiboken::Converter<QFlags<QDir::Filter> >::toCpp(pyargs[1]) : QDir::NoFilter;
                QFlags<QDir::SortFlag> cppArg2 = pyargs[2] ? Shiboken::Converter<QFlags<QDir::SortFlag> >::toCpp(pyargs[2]) : QDir::NoSort;

                if(!PyErr_Occurred()) {
                    // entryList(QStringList,QFlags<QDir::Filter>,QFlags<QDir::SortFlag>)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QStringList cppResult = const_cast<const QDir*>(cppSelf)->entryList(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QStringList >::toPython(cppResult);
                }
                break;
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QDirFunc_entryList_TypeError:
        const char* overloads[] = {"PySide.QtCore.QDir.Filters = QDir.NoFilter, PySide.QtCore.QDir.SortFlags = QDir.NoSort", "list, PySide.QtCore.QDir.Filters = QDir.NoFilter, PySide.QtCore.QDir.SortFlags = QDir.NoSort", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QDir.entryList", overloads);
        return 0;
}

static PyObject* Sbk_QDirFunc_exists(PyObject* self, PyObject* args)
{
    QDir* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDir* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "exists", 0, 1, &(pyargs[0])))
        return 0;


    // Overloaded function decisor
    // 0: exists()const
    // 1: exists(QString)const
    if (numArgs == 0) {
        overloadId = 0; // exists()const
    } else if (numArgs == 1 && Shiboken::Converter< QString >::isConvertible(pyargs[0])) {
        overloadId = 1; // exists(QString)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDirFunc_exists_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // exists()const
            {

                if(!PyErr_Occurred()) {
                    // exists()const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    bool cppResult = const_cast<const QDir*>(cppSelf)->exists();
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< bool >::toPython(cppResult);
                }
                break;
            }
            case 1: // exists(QString)const
            {
                QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // exists(QString)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    bool cppResult = const_cast<const QDir*>(cppSelf)->exists(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< bool >::toPython(cppResult);
                }
                break;
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QDirFunc_exists_TypeError:
        const char* overloads[] = {"", "QString", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QDir.exists", overloads);
        return 0;
}

static PyObject* Sbk_QDirFunc_filePath(PyObject* self, PyObject* arg)
{
    QDir* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDir* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: filePath(QString)const
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // filePath(QString)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDirFunc_filePath_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // filePath(QString)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QDir*>(cppSelf)->filePath(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QDirFunc_filePath_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QDir.filePath", overloads);
        return 0;
}

static PyObject* Sbk_QDirFunc_filter(PyObject* self)
{
    QDir* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDir* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // filter()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QFlags<QDir::Filter> cppResult = const_cast<const QDir*>(cppSelf)->filter();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QFlags<QDir::Filter> >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDirFunc_fromNativeSeparators(PyObject* self, PyObject* arg)
{
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: fromNativeSeparators(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // fromNativeSeparators(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDirFunc_fromNativeSeparators_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // fromNativeSeparators(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = QDir::fromNativeSeparators(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QDirFunc_fromNativeSeparators_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QDir.fromNativeSeparators", overloads);
        return 0;
}

static PyObject* Sbk_QDirFunc_home(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // home()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QDir cppResult = QDir::home();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QDir >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDirFunc_homePath(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // homePath()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = QDir::homePath();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDirFunc_isAbsolute(PyObject* self)
{
    QDir* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDir* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isAbsolute()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QDir*>(cppSelf)->isAbsolute();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDirFunc_isAbsolutePath(PyObject* self, PyObject* arg)
{
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: isAbsolutePath(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // isAbsolutePath(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDirFunc_isAbsolutePath_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // isAbsolutePath(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = QDir::isAbsolutePath(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QDirFunc_isAbsolutePath_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QDir.isAbsolutePath", overloads);
        return 0;
}

static PyObject* Sbk_QDirFunc_isReadable(PyObject* self)
{
    QDir* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDir* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isReadable()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QDir*>(cppSelf)->isReadable();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDirFunc_isRelative(PyObject* self)
{
    QDir* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDir* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isRelative()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QDir*>(cppSelf)->isRelative();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDirFunc_isRelativePath(PyObject* self, PyObject* arg)
{
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: isRelativePath(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // isRelativePath(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDirFunc_isRelativePath_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // isRelativePath(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = QDir::isRelativePath(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QDirFunc_isRelativePath_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QDir.isRelativePath", overloads);
        return 0;
}

static PyObject* Sbk_QDirFunc_isRoot(PyObject* self)
{
    QDir* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDir* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isRoot()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QDir*>(cppSelf)->isRoot();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDirFunc_makeAbsolute(PyObject* self)
{
    QDir* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDir* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // makeAbsolute()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->makeAbsolute();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDirFunc_match(PyObject* self, PyObject* args)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "match", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: match(QString,QString)
    // 1: match(QStringList,QString)
    if (numArgs == 2 && Shiboken::Converter< ::QStringList >::isConvertible(pyargs[0]) && Shiboken::Converter< QString >::isConvertible(pyargs[1])) {
        overloadId = 1; // match(QStringList,QString)
    } else if (numArgs == 2 && Shiboken::Converter< QString >::isConvertible(pyargs[0]) && Shiboken::Converter< QString >::isConvertible(pyargs[1])) {
        overloadId = 0; // match(QString,QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDirFunc_match_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // match(QString,QString)
            {
                QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                QString cppArg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // match(QString,QString)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    bool cppResult = QDir::match(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< bool >::toPython(cppResult);
                }
                break;
            }
            case 1: // match(QStringList,QString)
            {
                QStringList cppArg0 = Shiboken::Converter<QStringList >::toCpp(pyargs[0]);
                QString cppArg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // match(QStringList,QString)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    bool cppResult = QDir::match(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< bool >::toPython(cppResult);
                }
                break;
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QDirFunc_match_TypeError:
        const char* overloads[] = {"QString, QString", "list, QString", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QDir.match", overloads);
        return 0;
}

static PyObject* Sbk_QDirFunc_mkdir(PyObject* self, PyObject* arg)
{
    QDir* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDir* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: mkdir(QString)const
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // mkdir(QString)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDirFunc_mkdir_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // mkdir(QString)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QDir*>(cppSelf)->mkdir(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QDirFunc_mkdir_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QDir.mkdir", overloads);
        return 0;
}

static PyObject* Sbk_QDirFunc_mkpath(PyObject* self, PyObject* arg)
{
    QDir* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDir* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: mkpath(QString)const
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // mkpath(QString)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDirFunc_mkpath_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // mkpath(QString)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QDir*>(cppSelf)->mkpath(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QDirFunc_mkpath_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QDir.mkpath", overloads);
        return 0;
}

static PyObject* Sbk_QDirFunc_nameFilters(PyObject* self)
{
    QDir* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDir* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // nameFilters()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QStringList cppResult = const_cast<const QDir*>(cppSelf)->nameFilters();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QStringList >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDirFunc_nameFiltersFromString(PyObject* self, PyObject* arg)
{
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: nameFiltersFromString(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // nameFiltersFromString(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDirFunc_nameFiltersFromString_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // nameFiltersFromString(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QStringList cppResult = QDir::nameFiltersFromString(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QStringList >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QDirFunc_nameFiltersFromString_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QDir.nameFiltersFromString", overloads);
        return 0;
}

static PyObject* Sbk_QDirFunc_path(PyObject* self)
{
    QDir* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDir* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // path()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QDir*>(cppSelf)->path();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDirFunc_refresh(PyObject* self)
{
    QDir* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDir* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // refresh()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                const_cast<const QDir*>(cppSelf)->refresh();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QDirFunc_relativeFilePath(PyObject* self, PyObject* arg)
{
    QDir* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDir* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: relativeFilePath(QString)const
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // relativeFilePath(QString)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDirFunc_relativeFilePath_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // relativeFilePath(QString)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QDir*>(cppSelf)->relativeFilePath(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QDirFunc_relativeFilePath_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QDir.relativeFilePath", overloads);
        return 0;
}

static PyObject* Sbk_QDirFunc_remove(PyObject* self, PyObject* arg)
{
    QDir* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDir* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: remove(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // remove(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDirFunc_remove_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // remove(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->remove(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QDirFunc_remove_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QDir.remove", overloads);
        return 0;
}

static PyObject* Sbk_QDirFunc_rename(PyObject* self, PyObject* args)
{
    QDir* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDir* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "rename", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: rename(QString,QString)
    if (numArgs == 2 && Shiboken::Converter< QString >::isConvertible(pyargs[0]) && Shiboken::Converter< QString >::isConvertible(pyargs[1])) {
        overloadId = 0; // rename(QString,QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDirFunc_rename_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            QString cppArg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // rename(QString,QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->rename(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QDirFunc_rename_TypeError:
        const char* overloads[] = {"QString, QString", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QDir.rename", overloads);
        return 0;
}

static PyObject* Sbk_QDirFunc_rmdir(PyObject* self, PyObject* arg)
{
    QDir* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDir* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: rmdir(QString)const
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // rmdir(QString)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDirFunc_rmdir_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // rmdir(QString)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QDir*>(cppSelf)->rmdir(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QDirFunc_rmdir_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QDir.rmdir", overloads);
        return 0;
}

static PyObject* Sbk_QDirFunc_rmpath(PyObject* self, PyObject* arg)
{
    QDir* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDir* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: rmpath(QString)const
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // rmpath(QString)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDirFunc_rmpath_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // rmpath(QString)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QDir*>(cppSelf)->rmpath(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QDirFunc_rmpath_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QDir.rmpath", overloads);
        return 0;
}

static PyObject* Sbk_QDirFunc_root(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // root()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QDir cppResult = QDir::root();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QDir >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDirFunc_rootPath(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // rootPath()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = QDir::rootPath();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDirFunc_searchPaths(PyObject* self, PyObject* arg)
{
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: searchPaths(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // searchPaths(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDirFunc_searchPaths_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // searchPaths(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QStringList cppResult = QDir::searchPaths(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QStringList >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QDirFunc_searchPaths_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QDir.searchPaths", overloads);
        return 0;
}

static PyObject* Sbk_QDirFunc_separator(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // separator()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QChar cppResult = QDir::separator();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QChar >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDirFunc_setCurrent(PyObject* self, PyObject* arg)
{
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setCurrent(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // setCurrent(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDirFunc_setCurrent_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setCurrent(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = QDir::setCurrent(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QDirFunc_setCurrent_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QDir.setCurrent", overloads);
        return 0;
}

static PyObject* Sbk_QDirFunc_setFilter(PyObject* self, PyObject* arg)
{
    QDir* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDir* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setFilter(QFlags<QDir::Filter>)
    if (Shiboken::Converter< ::QFlags<QDir::Filter> >::isConvertible(arg)) {
        overloadId = 0; // setFilter(QFlags<QDir::Filter>)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDirFunc_setFilter_TypeError;

    // Call function/method
    {
        {
            QFlags<QDir::Filter> cppArg0 = Shiboken::Converter<QFlags<QDir::Filter> >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setFilter(QFlags<QDir::Filter>)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setFilter(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QDirFunc_setFilter_TypeError:
        const char* overloads[] = {"PySide.QtCore.QDir.Filters", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QDir.setFilter", overloads);
        return 0;
}

static PyObject* Sbk_QDirFunc_setNameFilters(PyObject* self, PyObject* arg)
{
    QDir* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDir* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setNameFilters(QStringList)
    if (Shiboken::Converter< ::QStringList >::isConvertible(arg)) {
        overloadId = 0; // setNameFilters(QStringList)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDirFunc_setNameFilters_TypeError;

    // Call function/method
    {
        {
            QStringList cppArg0 = Shiboken::Converter<QStringList >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setNameFilters(QStringList)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setNameFilters(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QDirFunc_setNameFilters_TypeError:
        const char* overloads[] = {"list", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QDir.setNameFilters", overloads);
        return 0;
}

static PyObject* Sbk_QDirFunc_setPath(PyObject* self, PyObject* arg)
{
    QDir* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDir* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setPath(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // setPath(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDirFunc_setPath_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setPath(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setPath(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QDirFunc_setPath_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QDir.setPath", overloads);
        return 0;
}

static PyObject* Sbk_QDirFunc_setSearchPaths(PyObject* self, PyObject* args)
{
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setSearchPaths", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setSearchPaths(QString,QStringList)
    if (numArgs == 2 && Shiboken::Converter< QString >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QStringList >::isConvertible(pyargs[1])) {
        overloadId = 0; // setSearchPaths(QString,QStringList)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDirFunc_setSearchPaths_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            QStringList cppArg1 = Shiboken::Converter<QStringList >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // setSearchPaths(QString,QStringList)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QDir::setSearchPaths(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QDirFunc_setSearchPaths_TypeError:
        const char* overloads[] = {"QString, list", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QDir.setSearchPaths", overloads);
        return 0;
}

static PyObject* Sbk_QDirFunc_setSorting(PyObject* self, PyObject* arg)
{
    QDir* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDir* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setSorting(QFlags<QDir::SortFlag>)
    if (Shiboken::Converter< ::QFlags<QDir::SortFlag> >::isConvertible(arg)) {
        overloadId = 0; // setSorting(QFlags<QDir::SortFlag>)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDirFunc_setSorting_TypeError;

    // Call function/method
    {
        {
            QFlags<QDir::SortFlag> cppArg0 = Shiboken::Converter<QFlags<QDir::SortFlag> >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setSorting(QFlags<QDir::SortFlag>)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setSorting(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QDirFunc_setSorting_TypeError:
        const char* overloads[] = {"PySide.QtCore.QDir.SortFlags", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QDir.setSorting", overloads);
        return 0;
}

static PyObject* Sbk_QDirFunc_sorting(PyObject* self)
{
    QDir* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDir* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // sorting()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QFlags<QDir::SortFlag> cppResult = const_cast<const QDir*>(cppSelf)->sorting();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QFlags<QDir::SortFlag> >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDirFunc_temp(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // temp()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QDir cppResult = QDir::temp();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QDir >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDirFunc_tempPath(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // tempPath()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = QDir::tempPath();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDirFunc_toNativeSeparators(PyObject* self, PyObject* arg)
{
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: toNativeSeparators(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // toNativeSeparators(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDirFunc_toNativeSeparators_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // toNativeSeparators(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = QDir::toNativeSeparators(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QDirFunc_toNativeSeparators_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QDir.toNativeSeparators", overloads);
        return 0;
}

static PyObject *Sbk_QDir___copy__(PyObject *self)
{
        QDir* cppSelf = 0;
        if (!Shiboken::Object::isValid(self))
            return 0;
        cppSelf = Shiboken::Converter<QDir*>::toCpp(self);
        PyObject* pyResult = 0;
        QDir* copy = new QDir(*cppSelf);
        pyResult = Shiboken::Converter<QDir*>::toPython(copy);
        Shiboken::Object::getOwnership(pyResult);

        if (PyErr_Occurred() || !pyResult) {
            Py_XDECREF(pyResult);
            return 0;
        }
        return pyResult;
}

static PyMethodDef Sbk_QDir_methods[] = {
    {"__reduce__", (PyCFunction)Sbk_QDirFunc___reduce__, METH_NOARGS},
    {"absoluteFilePath", (PyCFunction)Sbk_QDirFunc_absoluteFilePath, METH_O},
    {"absolutePath", (PyCFunction)Sbk_QDirFunc_absolutePath, METH_NOARGS},
    {"addResourceSearchPath", (PyCFunction)Sbk_QDirFunc_addResourceSearchPath, METH_O|METH_STATIC},
    {"addSearchPath", (PyCFunction)Sbk_QDirFunc_addSearchPath, METH_VARARGS|METH_STATIC},
    {"canonicalPath", (PyCFunction)Sbk_QDirFunc_canonicalPath, METH_NOARGS},
    {"cd", (PyCFunction)Sbk_QDirFunc_cd, METH_O},
    {"cdUp", (PyCFunction)Sbk_QDirFunc_cdUp, METH_NOARGS},
    {"cleanPath", (PyCFunction)Sbk_QDirFunc_cleanPath, METH_O|METH_STATIC},
    {"convertSeparators", (PyCFunction)Sbk_QDirFunc_convertSeparators, METH_O|METH_STATIC},
    {"count", (PyCFunction)Sbk_QDirFunc_count, METH_NOARGS},
    {"current", (PyCFunction)Sbk_QDirFunc_current, METH_NOARGS|METH_STATIC},
    {"currentPath", (PyCFunction)Sbk_QDirFunc_currentPath, METH_NOARGS|METH_STATIC},
    {"dirName", (PyCFunction)Sbk_QDirFunc_dirName, METH_NOARGS},
    {"drives", (PyCFunction)Sbk_QDirFunc_drives, METH_NOARGS|METH_STATIC},
    {"entryInfoList", (PyCFunction)Sbk_QDirFunc_entryInfoList, METH_VARARGS|METH_KEYWORDS},
    {"entryList", (PyCFunction)Sbk_QDirFunc_entryList, METH_VARARGS|METH_KEYWORDS},
    {"exists", (PyCFunction)Sbk_QDirFunc_exists, METH_VARARGS},
    {"filePath", (PyCFunction)Sbk_QDirFunc_filePath, METH_O},
    {"filter", (PyCFunction)Sbk_QDirFunc_filter, METH_NOARGS},
    {"fromNativeSeparators", (PyCFunction)Sbk_QDirFunc_fromNativeSeparators, METH_O|METH_STATIC},
    {"home", (PyCFunction)Sbk_QDirFunc_home, METH_NOARGS|METH_STATIC},
    {"homePath", (PyCFunction)Sbk_QDirFunc_homePath, METH_NOARGS|METH_STATIC},
    {"isAbsolute", (PyCFunction)Sbk_QDirFunc_isAbsolute, METH_NOARGS},
    {"isAbsolutePath", (PyCFunction)Sbk_QDirFunc_isAbsolutePath, METH_O|METH_STATIC},
    {"isReadable", (PyCFunction)Sbk_QDirFunc_isReadable, METH_NOARGS},
    {"isRelative", (PyCFunction)Sbk_QDirFunc_isRelative, METH_NOARGS},
    {"isRelativePath", (PyCFunction)Sbk_QDirFunc_isRelativePath, METH_O|METH_STATIC},
    {"isRoot", (PyCFunction)Sbk_QDirFunc_isRoot, METH_NOARGS},
    {"makeAbsolute", (PyCFunction)Sbk_QDirFunc_makeAbsolute, METH_NOARGS},
    {"match", (PyCFunction)Sbk_QDirFunc_match, METH_VARARGS|METH_STATIC},
    {"mkdir", (PyCFunction)Sbk_QDirFunc_mkdir, METH_O},
    {"mkpath", (PyCFunction)Sbk_QDirFunc_mkpath, METH_O},
    {"nameFilters", (PyCFunction)Sbk_QDirFunc_nameFilters, METH_NOARGS},
    {"nameFiltersFromString", (PyCFunction)Sbk_QDirFunc_nameFiltersFromString, METH_O|METH_STATIC},
    {"path", (PyCFunction)Sbk_QDirFunc_path, METH_NOARGS},
    {"refresh", (PyCFunction)Sbk_QDirFunc_refresh, METH_NOARGS},
    {"relativeFilePath", (PyCFunction)Sbk_QDirFunc_relativeFilePath, METH_O},
    {"remove", (PyCFunction)Sbk_QDirFunc_remove, METH_O},
    {"rename", (PyCFunction)Sbk_QDirFunc_rename, METH_VARARGS},
    {"rmdir", (PyCFunction)Sbk_QDirFunc_rmdir, METH_O},
    {"rmpath", (PyCFunction)Sbk_QDirFunc_rmpath, METH_O},
    {"root", (PyCFunction)Sbk_QDirFunc_root, METH_NOARGS|METH_STATIC},
    {"rootPath", (PyCFunction)Sbk_QDirFunc_rootPath, METH_NOARGS|METH_STATIC},
    {"searchPaths", (PyCFunction)Sbk_QDirFunc_searchPaths, METH_O|METH_STATIC},
    {"separator", (PyCFunction)Sbk_QDirFunc_separator, METH_NOARGS|METH_STATIC},
    {"setCurrent", (PyCFunction)Sbk_QDirFunc_setCurrent, METH_O|METH_STATIC},
    {"setFilter", (PyCFunction)Sbk_QDirFunc_setFilter, METH_O},
    {"setNameFilters", (PyCFunction)Sbk_QDirFunc_setNameFilters, METH_O},
    {"setPath", (PyCFunction)Sbk_QDirFunc_setPath, METH_O},
    {"setSearchPaths", (PyCFunction)Sbk_QDirFunc_setSearchPaths, METH_VARARGS|METH_STATIC},
    {"setSorting", (PyCFunction)Sbk_QDirFunc_setSorting, METH_O},
    {"sorting", (PyCFunction)Sbk_QDirFunc_sorting, METH_NOARGS},
    {"temp", (PyCFunction)Sbk_QDirFunc_temp, METH_NOARGS|METH_STATIC},
    {"tempPath", (PyCFunction)Sbk_QDirFunc_tempPath, METH_NOARGS|METH_STATIC},
    {"toNativeSeparators", (PyCFunction)Sbk_QDirFunc_toNativeSeparators, METH_O|METH_STATIC},

    {"__copy__", (PyCFunction)Sbk_QDir___copy__, METH_NOARGS},
    {0} // Sentinel
};

// Rich comparison
static PyObject* Sbk_QDir_richcompare(PyObject* self, PyObject* arg, int op)
{
    PyObject* pyResult = 0;
    QDir& cppSelf = *Shiboken::Converter< QDir* >::toCpp(self);

    switch (op) {
        case Py_NE:
            if (Shiboken::Converter< ::QDir >::isConvertible(arg)) {
                // operator!=(const QDir & dir) const
                QDir cppArg0 = Shiboken::Converter< ::QDir >::toCpp(arg);
                pyResult = Shiboken::Converter< bool >::toPython(cppSelf != cppArg0);
            } else goto Sbk_QDir_RichComparison_TypeError;

            break;
        case Py_EQ:
            if (Shiboken::Converter< ::QDir >::isConvertible(arg)) {
                // operator==(const QDir & dir) const
                QDir cppArg0 = Shiboken::Converter< ::QDir >::toCpp(arg);
                pyResult = Shiboken::Converter< bool >::toPython(cppSelf == cppArg0);
            } else goto Sbk_QDir_RichComparison_TypeError;

            break;
        default:
            goto Sbk_QDir_RichComparison_TypeError;
    }

    if (pyResult && !PyErr_Occurred())
        return pyResult;
    Sbk_QDir_RichComparison_TypeError:
    PyErr_SetString(PyExc_NotImplementedError, "operator not implemented.");
    return 0;

}

} // extern "C"

extern "C"
{
static PyObject* Sbk_QDir__repr__(PyObject* pyObj)
{
    QBuffer buffer;
    buffer.open(QBuffer::ReadWrite);
    QDebug dbg(&buffer);
    dbg << Shiboken::Converter< ::QDir >::toCpp(pyObj);
    buffer.close();
    return PyString_FromFormat("<PySide.QtCore.%s at %p>", buffer.data().constData(), pyObj);
}
} // extern C

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QDir_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtCore.QDir",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Sbk_QDir__repr__,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      Sbk_QDir_richcompare,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QDir_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QDir_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern

PyObject* SbkPySide_QtCore_QDir_Filter___and__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QDir::Filters >::toPython(
        Shiboken::Converter<QDir::Filters>::toCpp(self)
        & Shiboken::Converter< QDir::Filters >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtCore_QDir_Filter___or__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QDir::Filters >::toPython(
        Shiboken::Converter<QDir::Filters>::toCpp(self)
        | Shiboken::Converter< QDir::Filters >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtCore_QDir_Filter___xor__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QDir::Filters >::toPython(
        Shiboken::Converter<QDir::Filters>::toCpp(self)
        ^ Shiboken::Converter< QDir::Filters >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtCore_QDir_Filter___invert__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QDir::Filters >::toPython(
        ~Shiboken::Converter<QDir::Filters >::toCpp(self)
    );
}


static PyNumberMethods SbkPySide_QtCore_QDir_Filter_as_number = {
    /*nb_add*/                  0,
    /*nb_subtract*/             0,
    /*nb_multiply*/             0,
    /*nb_divide*/               0,
    /*nb_remainder*/            0,
    /*nb_divmod*/               0,
    /*nb_power*/                0,
    /*nb_negative*/             0,
    /*nb_positive*/             0,
    /*nb_absolute*/             0,
    /*nb_nonzero*/              0,
    /*nb_invert*/               (unaryfunc)SbkPySide_QtCore_QDir_Filter___invert__,
    /*nb_lshift*/               0,
    /*nb_rshift*/               0,
    /*nb_and*/                  (binaryfunc)SbkPySide_QtCore_QDir_Filter___and__,
    /*nb_xor*/                  (binaryfunc)SbkPySide_QtCore_QDir_Filter___xor__,
    /*nb_or*/                   (binaryfunc)SbkPySide_QtCore_QDir_Filter___or__,
    /*nb_coerce*/               0,
    /*nb_int*/                  0,
    /*nb_long*/                 0,
    /*nb_float*/                0,
    /*nb_oct*/                  0,
    /*nb_hex*/                  0,
    /*nb_inplace_add*/          0,
    /*nb_inplace_subtract*/     0,
    /*nb_inplace_multiply*/     0,
    /*nb_inplace_divide*/       0,
    /*nb_inplace_remainder*/    0,
    /*nb_inplace_power*/        0,
    /*nb_inplace_lshift*/       0,
    /*nb_inplace_rshift*/       0,
    /*nb_inplace_and*/          0,
    /*nb_inplace_xor*/          0,
    /*nb_inplace_or*/           0,
    /*nb_floor_divide*/         0,
    /*nb_true_divide*/          0,
    /*nb_inplace_floor_divide*/ 0,
    /*nb_inplace_true_divide*/  0,
    /*nb_index*/                0
};


// forward declaration of new function
static PyTypeObject SbkPySide_QtCore_QDir_Filters_Type = {
    PyObject_HEAD_INIT(&PyType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "Filters",
    /*tp_basicsize*/        0,
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        &SbkPySide_QtCore_QDir_Filter_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT | Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              PyInt_Type.tp_new,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};


PyObject* SbkPySide_QtCore_QDir_SortFlag___and__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QDir::SortFlags >::toPython(
        Shiboken::Converter<QDir::SortFlags>::toCpp(self)
        & Shiboken::Converter< QDir::SortFlags >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtCore_QDir_SortFlag___or__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QDir::SortFlags >::toPython(
        Shiboken::Converter<QDir::SortFlags>::toCpp(self)
        | Shiboken::Converter< QDir::SortFlags >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtCore_QDir_SortFlag___xor__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QDir::SortFlags >::toPython(
        Shiboken::Converter<QDir::SortFlags>::toCpp(self)
        ^ Shiboken::Converter< QDir::SortFlags >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtCore_QDir_SortFlag___invert__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QDir::SortFlags >::toPython(
        ~Shiboken::Converter<QDir::SortFlags >::toCpp(self)
    );
}


static PyNumberMethods SbkPySide_QtCore_QDir_SortFlag_as_number = {
    /*nb_add*/                  0,
    /*nb_subtract*/             0,
    /*nb_multiply*/             0,
    /*nb_divide*/               0,
    /*nb_remainder*/            0,
    /*nb_divmod*/               0,
    /*nb_power*/                0,
    /*nb_negative*/             0,
    /*nb_positive*/             0,
    /*nb_absolute*/             0,
    /*nb_nonzero*/              0,
    /*nb_invert*/               (unaryfunc)SbkPySide_QtCore_QDir_SortFlag___invert__,
    /*nb_lshift*/               0,
    /*nb_rshift*/               0,
    /*nb_and*/                  (binaryfunc)SbkPySide_QtCore_QDir_SortFlag___and__,
    /*nb_xor*/                  (binaryfunc)SbkPySide_QtCore_QDir_SortFlag___xor__,
    /*nb_or*/                   (binaryfunc)SbkPySide_QtCore_QDir_SortFlag___or__,
    /*nb_coerce*/               0,
    /*nb_int*/                  0,
    /*nb_long*/                 0,
    /*nb_float*/                0,
    /*nb_oct*/                  0,
    /*nb_hex*/                  0,
    /*nb_inplace_add*/          0,
    /*nb_inplace_subtract*/     0,
    /*nb_inplace_multiply*/     0,
    /*nb_inplace_divide*/       0,
    /*nb_inplace_remainder*/    0,
    /*nb_inplace_power*/        0,
    /*nb_inplace_lshift*/       0,
    /*nb_inplace_rshift*/       0,
    /*nb_inplace_and*/          0,
    /*nb_inplace_xor*/          0,
    /*nb_inplace_or*/           0,
    /*nb_floor_divide*/         0,
    /*nb_true_divide*/          0,
    /*nb_inplace_floor_divide*/ 0,
    /*nb_inplace_true_divide*/  0,
    /*nb_index*/                0
};


// forward declaration of new function
static PyTypeObject SbkPySide_QtCore_QDir_SortFlags_Type = {
    PyObject_HEAD_INIT(&PyType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "SortFlags",
    /*tp_basicsize*/        0,
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        &SbkPySide_QtCore_QDir_SortFlag_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT | Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              PyInt_Type.tp_new,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};



void init_QDir(PyObject* module)
{
    SbkPySide_QtCoreTypes[SBK_QDIR_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QDir_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QDir_Type);
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QDir_Type, &Shiboken::callCppDestructor<QDir >);
    if (PyType_Ready((PyTypeObject*)&Sbk_QDir_Type) < 0)
        return;

    Shiboken::ObjectType::setOriginalName(&Sbk_QDir_Type, "QDir");
    PyModule_AddObject(module, "QDir",
        ((PyObject*)&Sbk_QDir_Type));

    // Initialize enums
    PyObject* enumItem;

    // init enum: Filter
    PyTypeObject* SbkPySide_QtCore_QDir_Filter = Shiboken::Enum::newType("PySide.QtCore.QDir.Filter");
    SbkPySide_QtCore_QDir_Filter->tp_as_number = &SbkPySide_QtCore_QDir_Filter_as_number;
    SbkPySide_QtCoreTypes[SBK_QDIR_FILTER_IDX] = SbkPySide_QtCore_QDir_Filter;
    if (PyType_Ready(SbkPySide_QtCore_QDir_Filter) < 0)
        return;
    PyDict_SetItemString(Sbk_QDir_Type.super.ht_type.tp_dict,
            "Filter",((PyObject*)SbkPySide_QtCore_QDir_Filter));

    // init flags class: QFlags<QDir::Filter>
    SbkPySide_QtCoreTypes[SBK_QFLAGS_QDIR_FILTER__IDX] = &SbkPySide_QtCore_QDir_Filters_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtCore_QDir_Filters_Type) < 0)
        return;
    PyDict_SetItemString(Sbk_QDir_Type.super.ht_type.tp_dict,
            "Filters",((PyObject*)&SbkPySide_QtCore_QDir_Filters_Type));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QDir_Filter,(long) QDir::Dirs, "Dirs");
    PyDict_SetItemString(Sbk_QDir_Type.super.ht_type.tp_dict,"Dirs", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QDir_Filter->tp_dict,"Dirs", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QDir_Filter,(long) QDir::Files, "Files");
    PyDict_SetItemString(Sbk_QDir_Type.super.ht_type.tp_dict,"Files", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QDir_Filter->tp_dict,"Files", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QDir_Filter,(long) QDir::Drives, "Drives");
    PyDict_SetItemString(Sbk_QDir_Type.super.ht_type.tp_dict,"Drives", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QDir_Filter->tp_dict,"Drives", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QDir_Filter,(long) QDir::NoSymLinks, "NoSymLinks");
    PyDict_SetItemString(Sbk_QDir_Type.super.ht_type.tp_dict,"NoSymLinks", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QDir_Filter->tp_dict,"NoSymLinks", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QDir_Filter,(long) QDir::AllEntries, "AllEntries");
    PyDict_SetItemString(Sbk_QDir_Type.super.ht_type.tp_dict,"AllEntries", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QDir_Filter->tp_dict,"AllEntries", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QDir_Filter,(long) QDir::TypeMask, "TypeMask");
    PyDict_SetItemString(Sbk_QDir_Type.super.ht_type.tp_dict,"TypeMask", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QDir_Filter->tp_dict,"TypeMask", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QDir_Filter,(long) QDir::Readable, "Readable");
    PyDict_SetItemString(Sbk_QDir_Type.super.ht_type.tp_dict,"Readable", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QDir_Filter->tp_dict,"Readable", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QDir_Filter,(long) QDir::Writable, "Writable");
    PyDict_SetItemString(Sbk_QDir_Type.super.ht_type.tp_dict,"Writable", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QDir_Filter->tp_dict,"Writable", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QDir_Filter,(long) QDir::Executable, "Executable");
    PyDict_SetItemString(Sbk_QDir_Type.super.ht_type.tp_dict,"Executable", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QDir_Filter->tp_dict,"Executable", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QDir_Filter,(long) QDir::PermissionMask, "PermissionMask");
    PyDict_SetItemString(Sbk_QDir_Type.super.ht_type.tp_dict,"PermissionMask", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QDir_Filter->tp_dict,"PermissionMask", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QDir_Filter,(long) QDir::Modified, "Modified");
    PyDict_SetItemString(Sbk_QDir_Type.super.ht_type.tp_dict,"Modified", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QDir_Filter->tp_dict,"Modified", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QDir_Filter,(long) QDir::Hidden, "Hidden");
    PyDict_SetItemString(Sbk_QDir_Type.super.ht_type.tp_dict,"Hidden", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QDir_Filter->tp_dict,"Hidden", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QDir_Filter,(long) QDir::System, "System");
    PyDict_SetItemString(Sbk_QDir_Type.super.ht_type.tp_dict,"System", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QDir_Filter->tp_dict,"System", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QDir_Filter,(long) QDir::AccessMask, "AccessMask");
    PyDict_SetItemString(Sbk_QDir_Type.super.ht_type.tp_dict,"AccessMask", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QDir_Filter->tp_dict,"AccessMask", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QDir_Filter,(long) QDir::AllDirs, "AllDirs");
    PyDict_SetItemString(Sbk_QDir_Type.super.ht_type.tp_dict,"AllDirs", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QDir_Filter->tp_dict,"AllDirs", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QDir_Filter,(long) QDir::CaseSensitive, "CaseSensitive");
    PyDict_SetItemString(Sbk_QDir_Type.super.ht_type.tp_dict,"CaseSensitive", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QDir_Filter->tp_dict,"CaseSensitive", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QDir_Filter,(long) QDir::NoDotAndDotDot, "NoDotAndDotDot");
    PyDict_SetItemString(Sbk_QDir_Type.super.ht_type.tp_dict,"NoDotAndDotDot", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QDir_Filter->tp_dict,"NoDotAndDotDot", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QDir_Filter,(long) QDir::NoDot, "NoDot");
    PyDict_SetItemString(Sbk_QDir_Type.super.ht_type.tp_dict,"NoDot", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QDir_Filter->tp_dict,"NoDot", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QDir_Filter,(long) QDir::NoDotDot, "NoDotDot");
    PyDict_SetItemString(Sbk_QDir_Type.super.ht_type.tp_dict,"NoDotDot", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QDir_Filter->tp_dict,"NoDotDot", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QDir_Filter,(long) QDir::NoFilter, "NoFilter");
    PyDict_SetItemString(Sbk_QDir_Type.super.ht_type.tp_dict,"NoFilter", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QDir_Filter->tp_dict,"NoFilter", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QDir::Filter");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::Filter");
    // end of enum Filter

    // init enum: SortFlag
    PyTypeObject* SbkPySide_QtCore_QDir_SortFlag = Shiboken::Enum::newType("PySide.QtCore.QDir.SortFlag");
    SbkPySide_QtCore_QDir_SortFlag->tp_as_number = &SbkPySide_QtCore_QDir_SortFlag_as_number;
    SbkPySide_QtCoreTypes[SBK_QDIR_SORTFLAG_IDX] = SbkPySide_QtCore_QDir_SortFlag;
    if (PyType_Ready(SbkPySide_QtCore_QDir_SortFlag) < 0)
        return;
    PyDict_SetItemString(Sbk_QDir_Type.super.ht_type.tp_dict,
            "SortFlag",((PyObject*)SbkPySide_QtCore_QDir_SortFlag));

    // init flags class: QFlags<QDir::SortFlag>
    SbkPySide_QtCoreTypes[SBK_QFLAGS_QDIR_SORTFLAG__IDX] = &SbkPySide_QtCore_QDir_SortFlags_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtCore_QDir_SortFlags_Type) < 0)
        return;
    PyDict_SetItemString(Sbk_QDir_Type.super.ht_type.tp_dict,
            "SortFlags",((PyObject*)&SbkPySide_QtCore_QDir_SortFlags_Type));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QDir_SortFlag,(long) QDir::Name, "Name");
    PyDict_SetItemString(Sbk_QDir_Type.super.ht_type.tp_dict,"Name", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QDir_SortFlag->tp_dict,"Name", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QDir_SortFlag,(long) QDir::Time, "Time");
    PyDict_SetItemString(Sbk_QDir_Type.super.ht_type.tp_dict,"Time", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QDir_SortFlag->tp_dict,"Time", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QDir_SortFlag,(long) QDir::Size, "Size");
    PyDict_SetItemString(Sbk_QDir_Type.super.ht_type.tp_dict,"Size", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QDir_SortFlag->tp_dict,"Size", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QDir_SortFlag,(long) QDir::Unsorted, "Unsorted");
    PyDict_SetItemString(Sbk_QDir_Type.super.ht_type.tp_dict,"Unsorted", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QDir_SortFlag->tp_dict,"Unsorted", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QDir_SortFlag,(long) QDir::SortByMask, "SortByMask");
    PyDict_SetItemString(Sbk_QDir_Type.super.ht_type.tp_dict,"SortByMask", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QDir_SortFlag->tp_dict,"SortByMask", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QDir_SortFlag,(long) QDir::DirsFirst, "DirsFirst");
    PyDict_SetItemString(Sbk_QDir_Type.super.ht_type.tp_dict,"DirsFirst", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QDir_SortFlag->tp_dict,"DirsFirst", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QDir_SortFlag,(long) QDir::Reversed, "Reversed");
    PyDict_SetItemString(Sbk_QDir_Type.super.ht_type.tp_dict,"Reversed", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QDir_SortFlag->tp_dict,"Reversed", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QDir_SortFlag,(long) QDir::IgnoreCase, "IgnoreCase");
    PyDict_SetItemString(Sbk_QDir_Type.super.ht_type.tp_dict,"IgnoreCase", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QDir_SortFlag->tp_dict,"IgnoreCase", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QDir_SortFlag,(long) QDir::DirsLast, "DirsLast");
    PyDict_SetItemString(Sbk_QDir_Type.super.ht_type.tp_dict,"DirsLast", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QDir_SortFlag->tp_dict,"DirsLast", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QDir_SortFlag,(long) QDir::LocaleAware, "LocaleAware");
    PyDict_SetItemString(Sbk_QDir_Type.super.ht_type.tp_dict,"LocaleAware", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QDir_SortFlag->tp_dict,"LocaleAware", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QDir_SortFlag,(long) QDir::Type, "Type");
    PyDict_SetItemString(Sbk_QDir_Type.super.ht_type.tp_dict,"Type", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QDir_SortFlag->tp_dict,"Type", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QDir_SortFlag,(long) QDir::NoSort, "NoSort");
    PyDict_SetItemString(Sbk_QDir_Type.super.ht_type.tp_dict,"NoSort", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QDir_SortFlag->tp_dict,"NoSort", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QDir::SortFlag");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::SortFlag");
    // end of enum SortFlag


    Shiboken::TypeResolver::createValueTypeResolver<QDir >("QDir");
    Shiboken::TypeResolver::createObjectTypeResolver<QDir >("QDir*");
    Shiboken::TypeResolver::createValueTypeResolver<QDir >(typeid(QDir).name());
    PySide::initQtMetaType< ::QDir >();
    qRegisterMetaType< ::QDir::Filter >("QDir::Filter");
    qRegisterMetaType< ::QDir::Filters >("QDir::Filters");
    qRegisterMetaType< ::QDir::SortFlag >("QDir::SortFlag");
    qRegisterMetaType< ::QDir::SortFlags >("QDir::SortFlags");
}

