/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtcore_python.h"

#include "qevent_wrapper.h"

// Extra includes


// Native ---------------------------------------------------------

QEventWrapper::QEventWrapper(QEvent::Type type) : QEvent(type) {
    // ... middle
}

QEventWrapper::~QEventWrapper()
{
    SbkObject* wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QEvent_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QEvent >()))
        return -1;

    QEventWrapper* cptr = 0;
    int overloadId = -1;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QEvent", 1, 1, &(pyargs[0])))
        return -1;

    // Overloaded function decisor
    // 0: QEvent(QEvent::Type)
    if (numArgs == 1 && Shiboken::Converter< ::QEvent::Type >::isConvertible(pyargs[0])) {
        overloadId = 0; // QEvent(QEvent::Type)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QEvent_Init_TypeError;

    // Call function/method
    {
        {
            QEvent::Type cppArg0 = Shiboken::Converter<QEvent::Type >::toCpp(pyargs[0]);

            if(!PyErr_Occurred()) {
                // QEvent(QEvent::Type)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new QEventWrapper(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QEvent >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QEvent_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QEvent_Init_TypeError:
        const char* overloads[] = {"PySide.QtCore.QEvent.Type", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QEvent", overloads);
        return -1;
}

static PyObject* Sbk_QEventFunc_accept(PyObject* self)
{
    QEvent* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QEvent* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // accept()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->accept();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QEventFunc_ignore(PyObject* self)
{
    QEvent* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QEvent* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // ignore()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->ignore();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QEventFunc_isAccepted(PyObject* self)
{
    QEvent* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QEvent* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isAccepted()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QEvent*>(cppSelf)->isAccepted();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QEventFunc_registerEventType(PyObject* self, PyObject* args, PyObject* kwds)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QEvent.registerEventType(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:registerEventType", &(pyargs[0])))
        return 0;


    // Overloaded function decisor
    // 0: registerEventType(int)
    if (numArgs == 0) {
        overloadId = 0; // registerEventType(int)
    } else if (SbkNumber_Check(pyargs[0])) {
        overloadId = 0; // registerEventType(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QEventFunc_registerEventType_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "hint");
                if (value) {
                    if (pyargs[0])
                        errorArgName = "hint";
                    else if (SbkNumber_Check(value))
                        pyargs[0] = value;
                    else
                        goto Sbk_QEventFunc_registerEventType_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.QEvent.registerEventType(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            int cppArg0 = pyargs[0] ? Shiboken::Converter<int >::toCpp(pyargs[0]) : -1;

            if(!PyErr_Occurred()) {
                // registerEventType(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = QEvent::registerEventType(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QEventFunc_registerEventType_TypeError:
        const char* overloads[] = {"int = -1", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QEvent.registerEventType", overloads);
        return 0;
}

static PyObject* Sbk_QEventFunc_setAccepted(PyObject* self, PyObject* arg)
{
    QEvent* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QEvent* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setAccepted(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setAccepted(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QEventFunc_setAccepted_TypeError;

    // Call function/method
    {
        {
            bool cppArg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setAccepted(bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setAccepted(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QEventFunc_setAccepted_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QEvent.setAccepted", overloads);
        return 0;
}

static PyObject* Sbk_QEventFunc_spontaneous(PyObject* self)
{
    QEvent* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QEvent* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // spontaneous()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QEvent*>(cppSelf)->spontaneous();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QEventFunc_type(PyObject* self)
{
    QEvent* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QEvent* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // type()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QEvent::Type cppResult = const_cast<const QEvent*>(cppSelf)->type();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QEvent::Type >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef Sbk_QEvent_methods[] = {
    {"accept", (PyCFunction)Sbk_QEventFunc_accept, METH_NOARGS},
    {"ignore", (PyCFunction)Sbk_QEventFunc_ignore, METH_NOARGS},
    {"isAccepted", (PyCFunction)Sbk_QEventFunc_isAccepted, METH_NOARGS},
    {"registerEventType", (PyCFunction)Sbk_QEventFunc_registerEventType, METH_VARARGS|METH_KEYWORDS|METH_STATIC},
    {"setAccepted", (PyCFunction)Sbk_QEventFunc_setAccepted, METH_O},
    {"spontaneous", (PyCFunction)Sbk_QEventFunc_spontaneous, METH_NOARGS},
    {"type", (PyCFunction)Sbk_QEventFunc_type, METH_NOARGS},

    {0} // Sentinel
};

} // extern "C"

extern "C"
{
static PyObject* Sbk_QEvent__repr__(PyObject* pyObj)
{
    QBuffer buffer;
    buffer.open(QBuffer::ReadWrite);
    QDebug dbg(&buffer);
    dbg << Shiboken::Converter< ::QEvent* >::toCpp(pyObj);
    buffer.close();
    return PyString_FromFormat("<PySide.QtCore.%s at %p>", buffer.data().constData(), pyObj);
}
} // extern C

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QEvent_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtCore.QEvent",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Sbk_QEvent__repr__,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QEvent_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QEvent_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QEvent(PyObject* module)
{
    SbkPySide_QtCoreTypes[SBK_QEVENT_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QEvent_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QEvent_Type);
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QEvent_Type, &Shiboken::callCppDestructor<QEvent >);
    if (PyType_Ready((PyTypeObject*)&Sbk_QEvent_Type) < 0)
        return;

    // Fill type discovery information

    Shiboken::ObjectType::setOriginalName(&Sbk_QEvent_Type, "QEvent*");
    PyModule_AddObject(module, "QEvent",
        ((PyObject*)&Sbk_QEvent_Type));

    // Initialize enums
    PyObject* enumItem;

    // init enum: Type
    PyTypeObject* SbkPySide_QtCore_QEvent_Type = Shiboken::Enum::newType("PySide.QtCore.QEvent.Type");
    SbkPySide_QtCoreTypes[SBK_QEVENT_TYPE_IDX] = SbkPySide_QtCore_QEvent_Type;
    if (PyType_Ready(SbkPySide_QtCore_QEvent_Type) < 0)
        return;
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,
            "Type",((PyObject*)SbkPySide_QtCore_QEvent_Type));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::None, "None");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"None", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"None", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::Timer, "Timer");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"Timer", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"Timer", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::MouseButtonPress, "MouseButtonPress");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"MouseButtonPress", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"MouseButtonPress", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::MouseButtonRelease, "MouseButtonRelease");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"MouseButtonRelease", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"MouseButtonRelease", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::MouseButtonDblClick, "MouseButtonDblClick");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"MouseButtonDblClick", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"MouseButtonDblClick", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::MouseMove, "MouseMove");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"MouseMove", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"MouseMove", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::KeyPress, "KeyPress");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"KeyPress", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"KeyPress", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::KeyRelease, "KeyRelease");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"KeyRelease", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"KeyRelease", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::FocusIn, "FocusIn");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"FocusIn", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"FocusIn", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::FocusOut, "FocusOut");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"FocusOut", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"FocusOut", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::Enter, "Enter");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"Enter", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"Enter", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::Leave, "Leave");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"Leave", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"Leave", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::Paint, "Paint");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"Paint", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"Paint", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::Move, "Move");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"Move", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"Move", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::Resize, "Resize");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"Resize", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"Resize", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::Create, "Create");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"Create", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"Create", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::Destroy, "Destroy");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"Destroy", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"Destroy", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::Show, "Show");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"Show", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"Show", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::Hide, "Hide");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"Hide", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"Hide", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::Close, "Close");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"Close", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"Close", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::Quit, "Quit");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"Quit", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"Quit", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::ParentChange, "ParentChange");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"ParentChange", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"ParentChange", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::ParentAboutToChange, "ParentAboutToChange");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"ParentAboutToChange", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"ParentAboutToChange", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::ThreadChange, "ThreadChange");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"ThreadChange", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"ThreadChange", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::WindowActivate, "WindowActivate");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"WindowActivate", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"WindowActivate", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::WindowDeactivate, "WindowDeactivate");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"WindowDeactivate", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"WindowDeactivate", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::ShowToParent, "ShowToParent");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"ShowToParent", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"ShowToParent", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::HideToParent, "HideToParent");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"HideToParent", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"HideToParent", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::Wheel, "Wheel");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"Wheel", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"Wheel", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::WindowTitleChange, "WindowTitleChange");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"WindowTitleChange", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"WindowTitleChange", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::WindowIconChange, "WindowIconChange");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"WindowIconChange", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"WindowIconChange", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::ApplicationWindowIconChange, "ApplicationWindowIconChange");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"ApplicationWindowIconChange", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"ApplicationWindowIconChange", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::ApplicationFontChange, "ApplicationFontChange");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"ApplicationFontChange", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"ApplicationFontChange", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::ApplicationLayoutDirectionChange, "ApplicationLayoutDirectionChange");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"ApplicationLayoutDirectionChange", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"ApplicationLayoutDirectionChange", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::ApplicationPaletteChange, "ApplicationPaletteChange");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"ApplicationPaletteChange", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"ApplicationPaletteChange", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::PaletteChange, "PaletteChange");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"PaletteChange", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"PaletteChange", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::Clipboard, "Clipboard");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"Clipboard", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"Clipboard", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::Speech, "Speech");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"Speech", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"Speech", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::MetaCall, "MetaCall");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"MetaCall", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"MetaCall", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::SockAct, "SockAct");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"SockAct", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"SockAct", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::WinEventAct, "WinEventAct");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"WinEventAct", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"WinEventAct", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::DeferredDelete, "DeferredDelete");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"DeferredDelete", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"DeferredDelete", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::DragEnter, "DragEnter");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"DragEnter", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"DragEnter", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::DragMove, "DragMove");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"DragMove", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"DragMove", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::DragLeave, "DragLeave");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"DragLeave", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"DragLeave", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::Drop, "Drop");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"Drop", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"Drop", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::DragResponse, "DragResponse");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"DragResponse", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"DragResponse", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::ChildAdded, "ChildAdded");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"ChildAdded", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"ChildAdded", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::ChildPolished, "ChildPolished");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"ChildPolished", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"ChildPolished", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::ChildRemoved, "ChildRemoved");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"ChildRemoved", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"ChildRemoved", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::ShowWindowRequest, "ShowWindowRequest");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"ShowWindowRequest", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"ShowWindowRequest", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::PolishRequest, "PolishRequest");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"PolishRequest", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"PolishRequest", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::Polish, "Polish");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"Polish", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"Polish", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::LayoutRequest, "LayoutRequest");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"LayoutRequest", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"LayoutRequest", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::UpdateRequest, "UpdateRequest");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"UpdateRequest", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"UpdateRequest", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::UpdateLater, "UpdateLater");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"UpdateLater", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"UpdateLater", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::EmbeddingControl, "EmbeddingControl");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"EmbeddingControl", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"EmbeddingControl", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::ActivateControl, "ActivateControl");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"ActivateControl", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"ActivateControl", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::DeactivateControl, "DeactivateControl");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"DeactivateControl", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"DeactivateControl", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::ContextMenu, "ContextMenu");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"ContextMenu", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"ContextMenu", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::InputMethod, "InputMethod");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"InputMethod", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"InputMethod", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::AccessibilityPrepare, "AccessibilityPrepare");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"AccessibilityPrepare", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"AccessibilityPrepare", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::TabletMove, "TabletMove");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"TabletMove", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"TabletMove", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::LocaleChange, "LocaleChange");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"LocaleChange", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"LocaleChange", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::LanguageChange, "LanguageChange");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"LanguageChange", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"LanguageChange", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::LayoutDirectionChange, "LayoutDirectionChange");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"LayoutDirectionChange", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"LayoutDirectionChange", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::Style, "Style");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"Style", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"Style", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::TabletPress, "TabletPress");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"TabletPress", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"TabletPress", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::TabletRelease, "TabletRelease");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"TabletRelease", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"TabletRelease", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::OkRequest, "OkRequest");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"OkRequest", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"OkRequest", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::HelpRequest, "HelpRequest");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"HelpRequest", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"HelpRequest", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::IconDrag, "IconDrag");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"IconDrag", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"IconDrag", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::FontChange, "FontChange");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"FontChange", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"FontChange", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::EnabledChange, "EnabledChange");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"EnabledChange", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"EnabledChange", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::ActivationChange, "ActivationChange");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"ActivationChange", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"ActivationChange", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::StyleChange, "StyleChange");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"StyleChange", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"StyleChange", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::IconTextChange, "IconTextChange");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"IconTextChange", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"IconTextChange", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::ModifiedChange, "ModifiedChange");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"ModifiedChange", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"ModifiedChange", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::MouseTrackingChange, "MouseTrackingChange");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"MouseTrackingChange", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"MouseTrackingChange", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::WindowBlocked, "WindowBlocked");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"WindowBlocked", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"WindowBlocked", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::WindowUnblocked, "WindowUnblocked");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"WindowUnblocked", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"WindowUnblocked", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::WindowStateChange, "WindowStateChange");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"WindowStateChange", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"WindowStateChange", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::ToolTip, "ToolTip");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"ToolTip", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"ToolTip", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::WhatsThis, "WhatsThis");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"WhatsThis", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"WhatsThis", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::StatusTip, "StatusTip");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"StatusTip", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"StatusTip", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::ActionChanged, "ActionChanged");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"ActionChanged", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"ActionChanged", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::ActionAdded, "ActionAdded");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"ActionAdded", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"ActionAdded", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::ActionRemoved, "ActionRemoved");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"ActionRemoved", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"ActionRemoved", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::FileOpen, "FileOpen");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"FileOpen", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"FileOpen", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::Shortcut, "Shortcut");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"Shortcut", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"Shortcut", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::ShortcutOverride, "ShortcutOverride");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"ShortcutOverride", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"ShortcutOverride", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::WhatsThisClicked, "WhatsThisClicked");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"WhatsThisClicked", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"WhatsThisClicked", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::ToolBarChange, "ToolBarChange");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"ToolBarChange", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"ToolBarChange", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::ApplicationActivate, "ApplicationActivate");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"ApplicationActivate", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"ApplicationActivate", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::ApplicationActivated, "ApplicationActivated");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"ApplicationActivated", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"ApplicationActivated", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::ApplicationDeactivate, "ApplicationDeactivate");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"ApplicationDeactivate", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"ApplicationDeactivate", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::ApplicationDeactivated, "ApplicationDeactivated");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"ApplicationDeactivated", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"ApplicationDeactivated", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::QueryWhatsThis, "QueryWhatsThis");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"QueryWhatsThis", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"QueryWhatsThis", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::EnterWhatsThisMode, "EnterWhatsThisMode");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"EnterWhatsThisMode", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"EnterWhatsThisMode", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::LeaveWhatsThisMode, "LeaveWhatsThisMode");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"LeaveWhatsThisMode", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"LeaveWhatsThisMode", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::ZOrderChange, "ZOrderChange");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"ZOrderChange", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"ZOrderChange", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::HoverEnter, "HoverEnter");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"HoverEnter", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"HoverEnter", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::HoverLeave, "HoverLeave");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"HoverLeave", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"HoverLeave", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::HoverMove, "HoverMove");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"HoverMove", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"HoverMove", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::AccessibilityHelp, "AccessibilityHelp");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"AccessibilityHelp", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"AccessibilityHelp", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::AccessibilityDescription, "AccessibilityDescription");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"AccessibilityDescription", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"AccessibilityDescription", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::AcceptDropsChange, "AcceptDropsChange");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"AcceptDropsChange", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"AcceptDropsChange", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::MenubarUpdated, "MenubarUpdated");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"MenubarUpdated", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"MenubarUpdated", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::ZeroTimerEvent, "ZeroTimerEvent");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"ZeroTimerEvent", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"ZeroTimerEvent", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::GraphicsSceneMouseMove, "GraphicsSceneMouseMove");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"GraphicsSceneMouseMove", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"GraphicsSceneMouseMove", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::GraphicsSceneMousePress, "GraphicsSceneMousePress");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"GraphicsSceneMousePress", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"GraphicsSceneMousePress", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::GraphicsSceneMouseRelease, "GraphicsSceneMouseRelease");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"GraphicsSceneMouseRelease", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"GraphicsSceneMouseRelease", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::GraphicsSceneMouseDoubleClick, "GraphicsSceneMouseDoubleClick");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"GraphicsSceneMouseDoubleClick", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"GraphicsSceneMouseDoubleClick", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::GraphicsSceneContextMenu, "GraphicsSceneContextMenu");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"GraphicsSceneContextMenu", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"GraphicsSceneContextMenu", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::GraphicsSceneHoverEnter, "GraphicsSceneHoverEnter");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"GraphicsSceneHoverEnter", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"GraphicsSceneHoverEnter", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::GraphicsSceneHoverMove, "GraphicsSceneHoverMove");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"GraphicsSceneHoverMove", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"GraphicsSceneHoverMove", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::GraphicsSceneHoverLeave, "GraphicsSceneHoverLeave");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"GraphicsSceneHoverLeave", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"GraphicsSceneHoverLeave", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::GraphicsSceneHelp, "GraphicsSceneHelp");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"GraphicsSceneHelp", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"GraphicsSceneHelp", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::GraphicsSceneDragEnter, "GraphicsSceneDragEnter");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"GraphicsSceneDragEnter", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"GraphicsSceneDragEnter", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::GraphicsSceneDragMove, "GraphicsSceneDragMove");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"GraphicsSceneDragMove", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"GraphicsSceneDragMove", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::GraphicsSceneDragLeave, "GraphicsSceneDragLeave");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"GraphicsSceneDragLeave", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"GraphicsSceneDragLeave", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::GraphicsSceneDrop, "GraphicsSceneDrop");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"GraphicsSceneDrop", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"GraphicsSceneDrop", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::GraphicsSceneWheel, "GraphicsSceneWheel");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"GraphicsSceneWheel", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"GraphicsSceneWheel", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::KeyboardLayoutChange, "KeyboardLayoutChange");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"KeyboardLayoutChange", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"KeyboardLayoutChange", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::DynamicPropertyChange, "DynamicPropertyChange");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"DynamicPropertyChange", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"DynamicPropertyChange", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::TabletEnterProximity, "TabletEnterProximity");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"TabletEnterProximity", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"TabletEnterProximity", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::TabletLeaveProximity, "TabletLeaveProximity");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"TabletLeaveProximity", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"TabletLeaveProximity", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::NonClientAreaMouseMove, "NonClientAreaMouseMove");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"NonClientAreaMouseMove", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"NonClientAreaMouseMove", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::NonClientAreaMouseButtonPress, "NonClientAreaMouseButtonPress");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"NonClientAreaMouseButtonPress", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"NonClientAreaMouseButtonPress", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::NonClientAreaMouseButtonRelease, "NonClientAreaMouseButtonRelease");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"NonClientAreaMouseButtonRelease", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"NonClientAreaMouseButtonRelease", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::NonClientAreaMouseButtonDblClick, "NonClientAreaMouseButtonDblClick");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"NonClientAreaMouseButtonDblClick", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"NonClientAreaMouseButtonDblClick", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::MacSizeChange, "MacSizeChange");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"MacSizeChange", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"MacSizeChange", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::ContentsRectChange, "ContentsRectChange");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"ContentsRectChange", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"ContentsRectChange", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::MacGLWindowChange, "MacGLWindowChange");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"MacGLWindowChange", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"MacGLWindowChange", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::FutureCallOut, "FutureCallOut");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"FutureCallOut", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"FutureCallOut", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::GraphicsSceneResize, "GraphicsSceneResize");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"GraphicsSceneResize", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"GraphicsSceneResize", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::GraphicsSceneMove, "GraphicsSceneMove");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"GraphicsSceneMove", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"GraphicsSceneMove", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::CursorChange, "CursorChange");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"CursorChange", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"CursorChange", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::ToolTipChange, "ToolTipChange");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"ToolTipChange", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"ToolTipChange", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::NetworkReplyUpdated, "NetworkReplyUpdated");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"NetworkReplyUpdated", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"NetworkReplyUpdated", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::GrabMouse, "GrabMouse");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"GrabMouse", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"GrabMouse", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::UngrabMouse, "UngrabMouse");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"UngrabMouse", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"UngrabMouse", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::GrabKeyboard, "GrabKeyboard");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"GrabKeyboard", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"GrabKeyboard", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::UngrabKeyboard, "UngrabKeyboard");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"UngrabKeyboard", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"UngrabKeyboard", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::MacGLClearDrawable, "MacGLClearDrawable");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"MacGLClearDrawable", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"MacGLClearDrawable", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::StateMachineSignal, "StateMachineSignal");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"StateMachineSignal", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"StateMachineSignal", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::StateMachineWrapped, "StateMachineWrapped");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"StateMachineWrapped", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"StateMachineWrapped", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::TouchBegin, "TouchBegin");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"TouchBegin", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"TouchBegin", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::TouchUpdate, "TouchUpdate");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"TouchUpdate", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"TouchUpdate", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::TouchEnd, "TouchEnd");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"TouchEnd", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"TouchEnd", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::NativeGesture, "NativeGesture");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"NativeGesture", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"NativeGesture", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::RequestSoftwareInputPanel, "RequestSoftwareInputPanel");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"RequestSoftwareInputPanel", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"RequestSoftwareInputPanel", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::CloseSoftwareInputPanel, "CloseSoftwareInputPanel");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"CloseSoftwareInputPanel", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"CloseSoftwareInputPanel", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::UpdateSoftKeys, "UpdateSoftKeys");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"UpdateSoftKeys", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"UpdateSoftKeys", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::WinIdChange, "WinIdChange");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"WinIdChange", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"WinIdChange", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::Gesture, "Gesture");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"Gesture", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"Gesture", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::GestureOverride, "GestureOverride");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"GestureOverride", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"GestureOverride", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::User, "User");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"User", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"User", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEvent_Type,(long) QEvent::MaxUser, "MaxUser");
    PyDict_SetItemString(Sbk_QEvent_Type.super.ht_type.tp_dict,"MaxUser", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEvent_Type->tp_dict,"MaxUser", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QEvent::Type");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::Type");
    // end of enum Type


    Shiboken::TypeResolver::createObjectTypeResolver<QEvent >("QEvent*");
    Shiboken::TypeResolver::createObjectTypeResolver<QEvent >(typeid(QEvent).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QEvent >(typeid(QEventWrapper).name());
    PySide::initQtMetaType< ::QEvent* >();
    qRegisterMetaType< ::QEvent::Type >("QEvent::Type");
}

