/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include "pyside_qtcore_python.h"

#include "qhistorystate_wrapper.h"

// Extra includes
#include <QList>
#include <qabstractstate.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qhistorystate.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qstate.h>
#include <qstatemachine.h>
#include <qthread.h>


// Native ---------------------------------------------------------

QHistoryStateWrapper::QHistoryStateWrapper(QHistoryState::HistoryType type, QState * parent) : QHistoryState(type, parent) {
    // ... middle
}

QHistoryStateWrapper::QHistoryStateWrapper(QState * parent) : QHistoryState(parent) {
    // ... middle
}

void QHistoryStateWrapper::childEvent(QChildEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "childEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::childEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QChildEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QHistoryStateWrapper::connectNotify(const char * signal)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "connectNotify"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QHistoryStateWrapper::customEvent(QEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "customEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::customEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QHistoryStateWrapper::disconnectNotify(const char * signal)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "disconnectNotify"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

bool QHistoryStateWrapper::event(QEvent * e)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return bool(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "event"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QHistoryState::event(e);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(e)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QHistoryState.event", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
    return cppResult;
}

bool QHistoryStateWrapper::eventFilter(QObject * arg__1, QEvent * arg__2)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return bool(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "eventFilter"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::eventFilter(arg__1, arg__2);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter< ::QObject * >::toPython(arg__1),
        Shiboken::Converter< ::QEvent * >::toPython(arg__2)
    ));
    bool invalidadeArg2 = PyTuple_GET_ITEM(pyargs, 1)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QHistoryState.eventFilter", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    if (invalidadeArg2)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 1));
    return cppResult;
}

void QHistoryStateWrapper::onEntry(QEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "onEntry"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QHistoryState::onEntry(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(event)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QHistoryStateWrapper::onExit(QEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "onExit"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QHistoryState::onExit(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(event)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QHistoryStateWrapper::timerEvent(QTimerEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "timerEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::timerEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QTimerEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

const QMetaObject* QHistoryStateWrapper::metaObject() const
{
    SbkObject* pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    return reinterpret_cast<QMetaObject*>(Shiboken::Object::getTypeUserData(pySelf));
}

int QHistoryStateWrapper::qt_metacall(QMetaObject::Call call, int id, void** args)
{
    int result = QHistoryState::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

QHistoryStateWrapper::~QHistoryStateWrapper()
{
    SbkObject* wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QHistoryState_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QHistoryState >()))
        return -1;

    QHistoryStateWrapper* cptr = 0;
    int overloadId = -1;
    const char* argNames[] = {"parent"};
    const QMetaObject* metaObject;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_ParseTuple(args, "|OO:QHistoryState", &(pyargs[0]), &(pyargs[1])))
        return -1;

    // Overloaded function decisor
    // 0: QHistoryState(QHistoryState::HistoryType,QState*)
    // 1: QHistoryState(QState*)
    if (numArgs == 0) {
        overloadId = 1; // QHistoryState(QState*)
    } else if (Shiboken::Converter< ::QState * >::isConvertible(pyargs[0])) {
        overloadId = 1; // QHistoryState(QState*)
    } else if (Shiboken::Converter< ::QHistoryState::HistoryType >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // QHistoryState(QHistoryState::HistoryType,QState*)
        } else if (Shiboken::Converter< ::QState * >::isConvertible(pyargs[1])) {
            overloadId = 0; // QHistoryState(QHistoryState::HistoryType,QState*)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QHistoryState_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QHistoryState(QHistoryState::HistoryType,QState*)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "parent");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "parent";
                        else if (Shiboken::Converter< ::QState * >::isConvertible(value))
                            pyargs[1] = value;
                        else
                            goto Sbk_QHistoryState_Init_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtCore.QHistoryState(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                QHistoryState::HistoryType cppArg0 = Shiboken::Converter<QHistoryState::HistoryType >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return -1;
                QState * cppArg1 = pyargs[1] ? Shiboken::Converter<QState * >::toCpp(pyargs[1]) : 0;

                if(!PyErr_Occurred()) {
                    // QHistoryState(QHistoryState::HistoryType,QState*)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QHistoryStateWrapper(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    Shiboken::Object::setParent(pyargs[1], self);
                }
                break;
            }
            case 1: // QHistoryState(QState*)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "parent");
                    if (value) {
                        if (pyargs[0])
                            errorArgName = "parent";
                        else if (Shiboken::Converter< ::QState * >::isConvertible(value))
                            pyargs[0] = value;
                        else
                            goto Sbk_QHistoryState_Init_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtCore.QHistoryState(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QState * cppArg0 = pyargs[0] ? Shiboken::Converter<QState * >::toCpp(pyargs[0]) : 0;

                if(!PyErr_Occurred()) {
                    // QHistoryState(QState*)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QHistoryStateWrapper(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    Shiboken::Object::setParent(pyargs[0], self);
                }
                break;
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QHistoryState >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QHistoryState_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    metaObject = cptr->metaObject(); // <- init python qt properties
    if (kwds && !PySide::fillQtProperties(self, metaObject, kwds, argNames, 1))
        return -1;


    return 1;

    Sbk_QHistoryState_Init_TypeError:
        const char* overloads[] = {"PySide.QtCore.QHistoryState.HistoryType, PySide.QtCore.QState = None", "PySide.QtCore.QState = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QHistoryState", overloads);
        return -1;
}

static PyObject* Sbk_QHistoryStateFunc_defaultState(PyObject* self)
{
    QHistoryState* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QHistoryState* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // defaultState()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QAbstractState * cppResult = const_cast<const QHistoryState*>(cppSelf)->defaultState();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QAbstractState * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QHistoryStateFunc_event(PyObject* self, PyObject* arg)
{
    QHistoryState* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QHistoryState* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: event(QEvent*)
    if (Shiboken::Converter< ::QEvent * >::isConvertible(arg)) {
        overloadId = 0; // event(QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QHistoryStateFunc_event_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QEvent * cppArg0 = Shiboken::Converter<QEvent * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // event(QEvent*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = (Shiboken::Object::isUserType(self) ? cppSelf->::QHistoryState::event(cppArg0) : cppSelf->event(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QHistoryStateFunc_event_TypeError:
        const char* overloads[] = {"PySide.QtCore.QEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QHistoryState.event", overloads);
        return 0;
}

static PyObject* Sbk_QHistoryStateFunc_historyType(PyObject* self)
{
    QHistoryState* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QHistoryState* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // historyType()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QHistoryState::HistoryType cppResult = const_cast<const QHistoryState*>(cppSelf)->historyType();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QHistoryState::HistoryType >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QHistoryStateFunc_onEntry(PyObject* self, PyObject* arg)
{
    QHistoryState* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QHistoryState* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: onEntry(QEvent*)
    if (Shiboken::Converter< ::QEvent * >::isConvertible(arg)) {
        overloadId = 0; // onEntry(QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QHistoryStateFunc_onEntry_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QEvent * cppArg0 = Shiboken::Converter<QEvent * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // onEntry(QEvent*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QHistoryState::onEntry(cppArg0) : cppSelf->onEntry(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QHistoryStateFunc_onEntry_TypeError:
        const char* overloads[] = {"PySide.QtCore.QEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QHistoryState.onEntry", overloads);
        return 0;
}

static PyObject* Sbk_QHistoryStateFunc_onExit(PyObject* self, PyObject* arg)
{
    QHistoryState* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QHistoryState* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: onExit(QEvent*)
    if (Shiboken::Converter< ::QEvent * >::isConvertible(arg)) {
        overloadId = 0; // onExit(QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QHistoryStateFunc_onExit_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QEvent * cppArg0 = Shiboken::Converter<QEvent * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // onExit(QEvent*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QHistoryState::onExit(cppArg0) : cppSelf->onExit(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QHistoryStateFunc_onExit_TypeError:
        const char* overloads[] = {"PySide.QtCore.QEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QHistoryState.onExit", overloads);
        return 0;
}

static PyObject* Sbk_QHistoryStateFunc_setDefaultState(PyObject* self, PyObject* arg)
{
    QHistoryState* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QHistoryState* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setDefaultState(QAbstractState*)
    if (Shiboken::Converter< ::QAbstractState * >::isConvertible(arg)) {
        overloadId = 0; // setDefaultState(QAbstractState*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QHistoryStateFunc_setDefaultState_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QAbstractState * cppArg0 = Shiboken::Converter<QAbstractState * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setDefaultState(QAbstractState*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setDefaultState(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QHistoryStateFunc_setDefaultState_TypeError:
        const char* overloads[] = {"PySide.QtCore.QAbstractState", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QHistoryState.setDefaultState", overloads);
        return 0;
}

static PyObject* Sbk_QHistoryStateFunc_setHistoryType(PyObject* self, PyObject* arg)
{
    QHistoryState* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QHistoryState* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setHistoryType(QHistoryState::HistoryType)
    if (Shiboken::Converter< ::QHistoryState::HistoryType >::isConvertible(arg)) {
        overloadId = 0; // setHistoryType(QHistoryState::HistoryType)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QHistoryStateFunc_setHistoryType_TypeError;

    // Call function/method
    {
        {
            QHistoryState::HistoryType cppArg0 = Shiboken::Converter<QHistoryState::HistoryType >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setHistoryType(QHistoryState::HistoryType)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setHistoryType(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QHistoryStateFunc_setHistoryType_TypeError:
        const char* overloads[] = {"PySide.QtCore.QHistoryState.HistoryType", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QHistoryState.setHistoryType", overloads);
        return 0;
}

static PyMethodDef Sbk_QHistoryState_methods[] = {
    {"defaultState", (PyCFunction)Sbk_QHistoryStateFunc_defaultState, METH_NOARGS},
    {"event", (PyCFunction)Sbk_QHistoryStateFunc_event, METH_O},
    {"historyType", (PyCFunction)Sbk_QHistoryStateFunc_historyType, METH_NOARGS},
    {"onEntry", (PyCFunction)Sbk_QHistoryStateFunc_onEntry, METH_O},
    {"onExit", (PyCFunction)Sbk_QHistoryStateFunc_onExit, METH_O},
    {"setDefaultState", (PyCFunction)Sbk_QHistoryStateFunc_setDefaultState, METH_O},
    {"setHistoryType", (PyCFunction)Sbk_QHistoryStateFunc_setHistoryType, METH_O},

    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QHistoryState_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtCore.QHistoryState",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QHistoryState_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QHistoryState_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern

static SbkObjectType* Sbk_QHistoryState_typeDiscovery(void* cptr, SbkObjectType* instanceType)
{
    if (instanceType == reinterpret_cast<SbkObjectType*>(Shiboken::SbkType<QObject >()) && dynamic_cast<QHistoryState*>(reinterpret_cast<QObject*>(cptr)))
        return &Sbk_QHistoryState_Type;
    return 0;
}


void init_QHistoryState(PyObject* module)
{
    SbkPySide_QtCoreTypes[SBK_QHISTORYSTATE_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QHistoryState_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QHistoryState_Type);
    Shiboken::ObjectType::setSubTypeInitHook(&Sbk_QHistoryState_Type, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(&Sbk_QHistoryState_Type, &QHistoryState::staticMetaObject);    Sbk_QHistoryState_Type.super.ht_type.tp_base = SbkPySide_QtCoreTypes[SBK_QABSTRACTSTATE_IDX];
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QHistoryState_Type, &Shiboken::callCppDestructor<QHistoryState >);
    if (PyType_Ready((PyTypeObject*)&Sbk_QHistoryState_Type) < 0)
        return;

    // Fill type discovery information
    Shiboken::ObjectType::setTypeDiscoveryFunction(&Sbk_QHistoryState_Type, &Sbk_QHistoryState_typeDiscovery);
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkObjectType*>(SbkPySide_QtCoreTypes[SBK_QABSTRACTSTATE_IDX]), &Sbk_QHistoryState_Type);

    Shiboken::ObjectType::setOriginalName(&Sbk_QHistoryState_Type, "QHistoryState*");
    PyModule_AddObject(module, "QHistoryState",
        ((PyObject*)&Sbk_QHistoryState_Type));

    // Initialize enums
    PyObject* enumItem;

    // init enum: HistoryType
    PyTypeObject* SbkPySide_QtCore_QHistoryState_HistoryType = Shiboken::Enum::newType("PySide.QtCore.QHistoryState.HistoryType");
    SbkPySide_QtCoreTypes[SBK_QHISTORYSTATE_HISTORYTYPE_IDX] = SbkPySide_QtCore_QHistoryState_HistoryType;
    if (PyType_Ready(SbkPySide_QtCore_QHistoryState_HistoryType) < 0)
        return;
    PyDict_SetItemString(Sbk_QHistoryState_Type.super.ht_type.tp_dict,
            "HistoryType",((PyObject*)SbkPySide_QtCore_QHistoryState_HistoryType));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QHistoryState_HistoryType,(long) QHistoryState::ShallowHistory, "ShallowHistory");
    PyDict_SetItemString(Sbk_QHistoryState_Type.super.ht_type.tp_dict,"ShallowHistory", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QHistoryState_HistoryType->tp_dict,"ShallowHistory", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QHistoryState_HistoryType,(long) QHistoryState::DeepHistory, "DeepHistory");
    PyDict_SetItemString(Sbk_QHistoryState_Type.super.ht_type.tp_dict,"DeepHistory", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QHistoryState_HistoryType->tp_dict,"DeepHistory", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QHistoryState::HistoryType");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::HistoryType");
    // end of enum HistoryType


    Shiboken::TypeResolver::createObjectTypeResolver<QHistoryState >("QHistoryState*");
    Shiboken::TypeResolver::createObjectTypeResolver<QHistoryState >(typeid(QHistoryState).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QHistoryState >(typeid(QHistoryStateWrapper).name());
    PySide::initQtMetaType< ::QHistoryState* >();
    qRegisterMetaType< ::QHistoryState::HistoryType >("QHistoryState::HistoryType");
}

