/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtcore_python.h"

#include "qresource_wrapper.h"

// Extra includes
#include <QStringList>
#include <qlocale.h>



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QResource_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QResource >()))
        return -1;

    QResource* cptr = 0;
    int overloadId = -1;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);

    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QResource(): too many arguments");
        return -1;
    }

    if (!PyArg_ParseTuple(args, "|OO:QResource", &(pyargs[0]), &(pyargs[1])))
        return -1;

    // Overloaded function decisor
    // 0: QResource(QString,QLocale)
    if (numArgs == 0) {
        overloadId = 0; // QResource(QString,QLocale)
    } else if (Shiboken::Converter< QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // QResource(QString,QLocale)
        } else if (Shiboken::Converter< ::QLocale >::isConvertible(pyargs[1])) {
            overloadId = 0; // QResource(QString,QLocale)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QResource_Init_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "file");
                if (value) {
                    if (pyargs[0])
                        errorArgName = "file";
                    else if (Shiboken::Converter< QString >::isConvertible(value))
                        pyargs[0] = value;
                    else
                        goto Sbk_QResource_Init_TypeError;
                }
                value = PyDict_GetItemString(kwds, "locale");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "locale";
                    else if (Shiboken::Converter< ::QLocale >::isConvertible(value))
                        pyargs[1] = value;
                    else
                        goto Sbk_QResource_Init_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.QResource(): got multiple values for keyword argument '%s'", errorArgName);
                    return -1;
                }
            }
            QString cppArg0 = pyargs[0] ? Shiboken::Converter<QString >::toCpp(pyargs[0]) : QString();
            if (!Shiboken::Object::isValid(pyargs[1]))
                return -1;
            QLocale cppArg1_tmp = QLocale();
            QLocale cppArg1 = pyargs[1] ? Shiboken::Converter<QLocale >::toCpp(pyargs[1]) : cppArg1_tmp;

            if(!PyErr_Occurred()) {
                // QResource(QString,QLocale)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new QResource(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QResource >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QResource_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QResource_Init_TypeError:
        const char* overloads[] = {"QString = QString(), PySide.QtCore.QLocale = QLocale()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QResource", overloads);
        return -1;
}

static PyObject* Sbk_QResourceFunc_absoluteFilePath(PyObject* self)
{
    QResource* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QResource* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // absoluteFilePath()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QResource*>(cppSelf)->absoluteFilePath();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QResourceFunc_addSearchPath(PyObject* self, PyObject* arg)
{
    int overloadId = -1;

    // Overloaded function decisor
    // 0: addSearchPath(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // addSearchPath(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QResourceFunc_addSearchPath_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // addSearchPath(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QResource::addSearchPath(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QResourceFunc_addSearchPath_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QResource.addSearchPath", overloads);
        return 0;
}

static PyObject* Sbk_QResourceFunc_children(PyObject* self)
{
    QResource* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QResource* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // children()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QStringList cppResult = const_cast<const QResource*>(cppSelf)->children();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QStringList >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QResourceFunc_data(PyObject* self)
{
    QResource* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QResource* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // data()const
                // Begin code injection

                const uchar* d = cppSelf->data();
                if (d) {
                    pyResult = PyBuffer_FromMemory(const_cast<uchar*>(d), cppSelf->size());
                } else {
                    Py_INCREF(Py_None);
                    pyResult = Py_None;
                }

                // End of code injection


            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QResourceFunc_fileName(PyObject* self)
{
    QResource* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QResource* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // fileName()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QResource*>(cppSelf)->fileName();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QResourceFunc_isCompressed(PyObject* self)
{
    QResource* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QResource* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isCompressed()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QResource*>(cppSelf)->isCompressed();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QResourceFunc_isDir(PyObject* self)
{
    QResource* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QResource* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isDir()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QResource*>(cppSelf)->isDir();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QResourceFunc_isFile(PyObject* self)
{
    QResource* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QResource* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isFile()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QResource*>(cppSelf)->isFile();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QResourceFunc_isValid(PyObject* self)
{
    QResource* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QResource* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isValid()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QResource*>(cppSelf)->isValid();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QResourceFunc_locale(PyObject* self)
{
    QResource* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QResource* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // locale()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QLocale cppResult = const_cast<const QResource*>(cppSelf)->locale();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QLocale >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QResourceFunc_registerResource(PyObject* self, PyObject* args, PyObject* kwds)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QResource.registerResource(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QResource.registerResource(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:registerResource", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: registerResource(QString,QString)
    if (Shiboken::Converter< QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // registerResource(QString,QString)
        } else if (Shiboken::Converter< QString >::isConvertible(pyargs[1])) {
            overloadId = 0; // registerResource(QString,QString)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QResourceFunc_registerResource_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "resourceRoot");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "resourceRoot";
                    else if (Shiboken::Converter< QString >::isConvertible(value))
                        pyargs[1] = value;
                    else
                        goto Sbk_QResourceFunc_registerResource_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.QResource.registerResource(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            QString cppArg1 = pyargs[1] ? Shiboken::Converter<QString >::toCpp(pyargs[1]) : QString();

            if(!PyErr_Occurred()) {
                // registerResource(QString,QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = QResource::registerResource(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QResourceFunc_registerResource_TypeError:
        const char* overloads[] = {"QString, QString = QString()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QResource.registerResource", overloads);
        return 0;
}

static PyObject* Sbk_QResourceFunc_registerResourceData(PyObject* self, PyObject* args, PyObject* kwds)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QResource.registerResourceData(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QResource.registerResourceData(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:registerResourceData", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: registerResource(const uchar*,QString)
    if (PyObject_Check(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // registerResource(const uchar*,QString)
        } else if (Shiboken::Converter< QString >::isConvertible(pyargs[1])) {
            overloadId = 0; // registerResource(const uchar*,QString)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QResourceFunc_registerResourceData_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "resourceRoot");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "resourceRoot";
                    else if (Shiboken::Converter< QString >::isConvertible(value))
                        pyargs[1] = value;
                    else
                        goto Sbk_QResourceFunc_registerResourceData_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.QResource.registerResourceData(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QString cppArg1 = pyargs[1] ? Shiboken::Converter<QString >::toCpp(pyargs[1]) : QString();

            if(!PyErr_Occurred()) {
                // registerResource(const uchar*,QString)
                // Begin code injection

                // TEMPLATE - QResource_registerResource - START
                PyTypeObject* pyType = pyargs[1-1]->ob_type;
                if (pyType->tp_as_buffer
                    && pyType->tp_as_buffer->bf_getreadbuffer
                    && pyType->tp_as_buffer->bf_getsegcount(pyargs[1-1], 0) == 1) {
                    void* ptr;
                    pyType->tp_as_buffer->bf_getreadbuffer(pyargs[1-1], 0, &ptr);
                    pyResult = Shiboken::Converter<bool >::toPython(QResource::registerResource(const_cast<const uchar*>((uchar*)ptr), cppArg1));
                } else {
                    PyErr_SetString(PyExc_TypeError, "The object must support buffer protocol with just one segment.");
                }
                // TEMPLATE - QResource_registerResource - END

                // End of code injection


            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QResourceFunc_registerResourceData_TypeError:
        const char* overloads[] = {"uchar, QString = QString()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QResource.registerResourceData", overloads);
        return 0;
}

static PyObject* Sbk_QResourceFunc_searchPaths(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // searchPaths()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QStringList cppResult = QResource::searchPaths();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QStringList >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QResourceFunc_setFileName(PyObject* self, PyObject* arg)
{
    QResource* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QResource* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setFileName(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // setFileName(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QResourceFunc_setFileName_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setFileName(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setFileName(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QResourceFunc_setFileName_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QResource.setFileName", overloads);
        return 0;
}

static PyObject* Sbk_QResourceFunc_setLocale(PyObject* self, PyObject* arg)
{
    QResource* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QResource* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setLocale(QLocale)
    if (Shiboken::Converter< ::QLocale >::isConvertible(arg)) {
        overloadId = 0; // setLocale(QLocale)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QResourceFunc_setLocale_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QLocale cppArg0 = Shiboken::Converter<QLocale >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setLocale(QLocale)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setLocale(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QResourceFunc_setLocale_TypeError:
        const char* overloads[] = {"PySide.QtCore.QLocale", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QResource.setLocale", overloads);
        return 0;
}

static PyObject* Sbk_QResourceFunc_size(PyObject* self)
{
    QResource* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QResource* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // size()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                qint64 cppResult = const_cast<const QResource*>(cppSelf)->size();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< long long >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QResourceFunc_unregisterResource(PyObject* self, PyObject* args, PyObject* kwds)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QResource.unregisterResource(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QResource.unregisterResource(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:unregisterResource", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: unregisterResource(QString,QString)
    if (Shiboken::Converter< QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // unregisterResource(QString,QString)
        } else if (Shiboken::Converter< QString >::isConvertible(pyargs[1])) {
            overloadId = 0; // unregisterResource(QString,QString)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QResourceFunc_unregisterResource_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "resourceRoot");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "resourceRoot";
                    else if (Shiboken::Converter< QString >::isConvertible(value))
                        pyargs[1] = value;
                    else
                        goto Sbk_QResourceFunc_unregisterResource_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.QResource.unregisterResource(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            QString cppArg1 = pyargs[1] ? Shiboken::Converter<QString >::toCpp(pyargs[1]) : QString();

            if(!PyErr_Occurred()) {
                // unregisterResource(QString,QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = QResource::unregisterResource(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QResourceFunc_unregisterResource_TypeError:
        const char* overloads[] = {"QString, QString = QString()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QResource.unregisterResource", overloads);
        return 0;
}

static PyObject* Sbk_QResourceFunc_unregisterResourceData(PyObject* self, PyObject* args, PyObject* kwds)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QResource.unregisterResourceData(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QResource.unregisterResourceData(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:unregisterResourceData", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: unregisterResource(const uchar*,QString)
    if (PyObject_Check(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // unregisterResource(const uchar*,QString)
        } else if (Shiboken::Converter< QString >::isConvertible(pyargs[1])) {
            overloadId = 0; // unregisterResource(const uchar*,QString)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QResourceFunc_unregisterResourceData_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "resourceRoot");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "resourceRoot";
                    else if (Shiboken::Converter< QString >::isConvertible(value))
                        pyargs[1] = value;
                    else
                        goto Sbk_QResourceFunc_unregisterResourceData_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.QResource.unregisterResourceData(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QString cppArg1 = pyargs[1] ? Shiboken::Converter<QString >::toCpp(pyargs[1]) : QString();

            if(!PyErr_Occurred()) {
                // unregisterResource(const uchar*,QString)
                // Begin code injection

                // TEMPLATE - QResource_registerResource - START
                PyTypeObject* pyType = pyargs[1-1]->ob_type;
                if (pyType->tp_as_buffer
                    && pyType->tp_as_buffer->bf_getreadbuffer
                    && pyType->tp_as_buffer->bf_getsegcount(pyargs[1-1], 0) == 1) {
                    void* ptr;
                    pyType->tp_as_buffer->bf_getreadbuffer(pyargs[1-1], 0, &ptr);
                    pyResult = Shiboken::Converter<bool >::toPython(QResource::unregisterResource(const_cast<const uchar*>((uchar*)ptr), cppArg1));
                } else {
                    PyErr_SetString(PyExc_TypeError, "The object must support buffer protocol with just one segment.");
                }
                // TEMPLATE - QResource_registerResource - END

                // End of code injection


            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QResourceFunc_unregisterResourceData_TypeError:
        const char* overloads[] = {"uchar, QString = QString()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QResource.unregisterResourceData", overloads);
        return 0;
}

static PyMethodDef Sbk_QResource_methods[] = {
    {"absoluteFilePath", (PyCFunction)Sbk_QResourceFunc_absoluteFilePath, METH_NOARGS},
    {"addSearchPath", (PyCFunction)Sbk_QResourceFunc_addSearchPath, METH_O|METH_STATIC},
    {"children", (PyCFunction)Sbk_QResourceFunc_children, METH_NOARGS},
    {"data", (PyCFunction)Sbk_QResourceFunc_data, METH_NOARGS},
    {"fileName", (PyCFunction)Sbk_QResourceFunc_fileName, METH_NOARGS},
    {"isCompressed", (PyCFunction)Sbk_QResourceFunc_isCompressed, METH_NOARGS},
    {"isDir", (PyCFunction)Sbk_QResourceFunc_isDir, METH_NOARGS},
    {"isFile", (PyCFunction)Sbk_QResourceFunc_isFile, METH_NOARGS},
    {"isValid", (PyCFunction)Sbk_QResourceFunc_isValid, METH_NOARGS},
    {"locale", (PyCFunction)Sbk_QResourceFunc_locale, METH_NOARGS},
    {"registerResource", (PyCFunction)Sbk_QResourceFunc_registerResource, METH_VARARGS|METH_KEYWORDS|METH_STATIC},
    {"registerResourceData", (PyCFunction)Sbk_QResourceFunc_registerResourceData, METH_VARARGS|METH_KEYWORDS|METH_STATIC},
    {"searchPaths", (PyCFunction)Sbk_QResourceFunc_searchPaths, METH_NOARGS|METH_STATIC},
    {"setFileName", (PyCFunction)Sbk_QResourceFunc_setFileName, METH_O},
    {"setLocale", (PyCFunction)Sbk_QResourceFunc_setLocale, METH_O},
    {"size", (PyCFunction)Sbk_QResourceFunc_size, METH_NOARGS},
    {"unregisterResource", (PyCFunction)Sbk_QResourceFunc_unregisterResource, METH_VARARGS|METH_KEYWORDS|METH_STATIC},
    {"unregisterResourceData", (PyCFunction)Sbk_QResourceFunc_unregisterResourceData, METH_VARARGS|METH_KEYWORDS|METH_STATIC},

    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QResource_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtCore.QResource",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QResource_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QResource_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QResource(PyObject* module)
{
    SbkPySide_QtCoreTypes[SBK_QRESOURCE_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QResource_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QResource_Type);
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QResource_Type, &Shiboken::callCppDestructor<QResource >);
    if (PyType_Ready((PyTypeObject*)&Sbk_QResource_Type) < 0)
        return;

    Shiboken::ObjectType::setOriginalName(&Sbk_QResource_Type, "QResource*");
    PyModule_AddObject(module, "QResource",
        ((PyObject*)&Sbk_QResource_Type));


    Shiboken::TypeResolver::createObjectTypeResolver<QResource >("QResource*");
    Shiboken::TypeResolver::createObjectTypeResolver<QResource >(typeid(QResource).name());
    PySide::initQtMetaType< ::QResource* >();
}

