/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtcore_python.h"

#include "qsize_wrapper.h"

// Extra includes
#include <qsize.h>


// Begin code injection

namespace PySide {
    template<> inline uint hash(const QSize& v) {
        return qHash(qMakePair(v.width(), v.height()));
    }
};

// End of code injection


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QSize_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QSize >()))
        return -1;

    QSize* cptr = 0;
    int overloadId = -1;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QSize", 0, 2, &(pyargs[0]), &(pyargs[1])))
        return -1;

    // Overloaded function decisor
    // 0: QSize()
    // 1: QSize(QSize)
    // 2: QSize(int,int)
    if (numArgs == 0) {
        overloadId = 0; // QSize()
    } else if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 2; // QSize(int,int)
    } else if (numArgs == 1 && Shiboken::Converter< ::QSize >::isConvertible(pyargs[0])) {
        overloadId = 1; // QSize(QSize)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QSize_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QSize()
            {

                if(!PyErr_Occurred()) {
                    // QSize()
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QSize();
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // QSize(QSize)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QSize cppArg0 = Shiboken::Converter<QSize >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QSize(QSize)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QSize(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 2: // QSize(int,int)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // QSize(int,int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QSize(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QSize >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QSize_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QSize_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtCore.QSize", "int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QSize", overloads);
        return -1;
}

static PyObject* Sbk_QSizeFunc___reduce__(PyObject* self)
{
    QSize* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QSize* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // __reduce__()
                // Begin code injection

                // TEMPLATE - reduce_code - START
                pyResult = Py_BuildValue("(N(ii))", PyObject_Type(self), cppSelf->width(), cppSelf->height());
                // TEMPLATE - reduce_code - END

                // End of code injection


            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QSizeFunc___repr__(PyObject* self)
{
    QSize* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QSize* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // __repr__()
                // Begin code injection

                // TEMPLATE - repr_code - START
                QString format = QString().sprintf("%s(%i, %i)", ((PyObject*)self)->ob_type->tp_name, cppSelf->width(), cppSelf->height());
                pyResult = PyString_FromString(qPrintable(format));
                // TEMPLATE - repr_code - END

                // End of code injection


            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QSizeFunc_boundedTo(PyObject* self, PyObject* arg)
{
    QSize* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QSize* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: boundedTo(QSize)const
    if (Shiboken::Converter< ::QSize >::isConvertible(arg)) {
        overloadId = 0; // boundedTo(QSize)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QSizeFunc_boundedTo_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QSize cppArg0 = Shiboken::Converter<QSize >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // boundedTo(QSize)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QSize cppResult = const_cast<const QSize*>(cppSelf)->boundedTo(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QSize >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QSizeFunc_boundedTo_TypeError:
        const char* overloads[] = {"PySide.QtCore.QSize", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QSize.boundedTo", overloads);
        return 0;
}

static PyObject* Sbk_QSizeFunc_expandedTo(PyObject* self, PyObject* arg)
{
    QSize* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QSize* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: expandedTo(QSize)const
    if (Shiboken::Converter< ::QSize >::isConvertible(arg)) {
        overloadId = 0; // expandedTo(QSize)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QSizeFunc_expandedTo_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QSize cppArg0 = Shiboken::Converter<QSize >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // expandedTo(QSize)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QSize cppResult = const_cast<const QSize*>(cppSelf)->expandedTo(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QSize >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QSizeFunc_expandedTo_TypeError:
        const char* overloads[] = {"PySide.QtCore.QSize", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QSize.expandedTo", overloads);
        return 0;
}

static PyObject* Sbk_QSizeFunc_height(PyObject* self)
{
    QSize* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QSize* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // height()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QSize*>(cppSelf)->height();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QSizeFunc_isEmpty(PyObject* self)
{
    QSize* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QSize* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isEmpty()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QSize*>(cppSelf)->isEmpty();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QSizeFunc_isNull(PyObject* self)
{
    QSize* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QSize* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isNull()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QSize*>(cppSelf)->isNull();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QSizeFunc_isValid(PyObject* self)
{
    QSize* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QSize* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isValid()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QSize*>(cppSelf)->isValid();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QSizeFunc_scale(PyObject* self, PyObject* args)
{
    QSize* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QSize* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "scale", 2, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: scale(QSize,Qt::AspectRatioMode)
    // 1: scale(int,int,Qt::AspectRatioMode)
    if (numArgs == 3 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && Shiboken::Converter< ::Qt::AspectRatioMode >::isConvertible(pyargs[2])) {
        overloadId = 1; // scale(int,int,Qt::AspectRatioMode)
    } else if (numArgs == 2 && Shiboken::Converter< ::QSize >::isConvertible(pyargs[0]) && Shiboken::Converter< ::Qt::AspectRatioMode >::isConvertible(pyargs[1])) {
        overloadId = 0; // scale(QSize,Qt::AspectRatioMode)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QSizeFunc_scale_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // scale(QSize,Qt::AspectRatioMode)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QSize cppArg0 = Shiboken::Converter<QSize >::toCpp(pyargs[0]);
                Qt::AspectRatioMode cppArg1 = Shiboken::Converter<Qt::AspectRatioMode >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // scale(QSize,Qt::AspectRatioMode)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->scale(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // scale(int,int,Qt::AspectRatioMode)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                Qt::AspectRatioMode cppArg2 = Shiboken::Converter<Qt::AspectRatioMode >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                    // scale(int,int,Qt::AspectRatioMode)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->scale(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QSizeFunc_scale_TypeError:
        const char* overloads[] = {"PySide.QtCore.QSize, PySide.QtCore.Qt.AspectRatioMode", "int, int, PySide.QtCore.Qt.AspectRatioMode", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QSize.scale", overloads);
        return 0;
}

static PyObject* Sbk_QSizeFunc_setHeight(PyObject* self, PyObject* arg)
{
    QSize* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QSize* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setHeight(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setHeight(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QSizeFunc_setHeight_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setHeight(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setHeight(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QSizeFunc_setHeight_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QSize.setHeight", overloads);
        return 0;
}

static PyObject* Sbk_QSizeFunc_setWidth(PyObject* self, PyObject* arg)
{
    QSize* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QSize* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setWidth(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setWidth(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QSizeFunc_setWidth_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setWidth(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setWidth(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QSizeFunc_setWidth_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QSize.setWidth", overloads);
        return 0;
}

static PyObject* Sbk_QSizeFunc_transpose(PyObject* self)
{
    QSize* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QSize* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // transpose()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->transpose();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QSizeFunc_width(PyObject* self)
{
    QSize* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QSize* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // width()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QSize*>(cppSelf)->width();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject *Sbk_QSize___copy__(PyObject *self)
{
        QSize* cppSelf = 0;
        if (!Shiboken::Object::isValid(self))
            return 0;
        cppSelf = Shiboken::Converter<QSize*>::toCpp(self);
        PyObject* pyResult = 0;
        QSize* copy = new QSize(*cppSelf);
        pyResult = Shiboken::Converter<QSize*>::toPython(copy);
        Shiboken::Object::getOwnership(pyResult);

        if (PyErr_Occurred() || !pyResult) {
            Py_XDECREF(pyResult);
            return 0;
        }
        return pyResult;
}

static PyMethodDef Sbk_QSize_methods[] = {
    {"__reduce__", (PyCFunction)Sbk_QSizeFunc___reduce__, METH_NOARGS},
    {"boundedTo", (PyCFunction)Sbk_QSizeFunc_boundedTo, METH_O},
    {"expandedTo", (PyCFunction)Sbk_QSizeFunc_expandedTo, METH_O},
    {"height", (PyCFunction)Sbk_QSizeFunc_height, METH_NOARGS},
    {"isEmpty", (PyCFunction)Sbk_QSizeFunc_isEmpty, METH_NOARGS},
    {"isNull", (PyCFunction)Sbk_QSizeFunc_isNull, METH_NOARGS},
    {"isValid", (PyCFunction)Sbk_QSizeFunc_isValid, METH_NOARGS},
    {"scale", (PyCFunction)Sbk_QSizeFunc_scale, METH_VARARGS},
    {"setHeight", (PyCFunction)Sbk_QSizeFunc_setHeight, METH_O},
    {"setWidth", (PyCFunction)Sbk_QSizeFunc_setWidth, METH_O},
    {"transpose", (PyCFunction)Sbk_QSizeFunc_transpose, METH_NOARGS},
    {"width", (PyCFunction)Sbk_QSizeFunc_width, METH_NOARGS},

    {"__copy__", (PyCFunction)Sbk_QSize___copy__, METH_NOARGS},
    {0} // Sentinel
};

static int Sbk_QSize___nb_bool(PyObject* pyObj)
{
    if (!Shiboken::Object::isValid(pyObj))
        return -1;
    const ::QSize* cppSelf = Shiboken::Converter< ::QSize*>::toCpp(pyObj);
    int result;
    Py_BEGIN_ALLOW_THREADS
    result = !cppSelf->isNull();
    Py_END_ALLOW_THREADS
    return result;
}

static PyObject* Sbk_QSizeFunc___mul__(PyObject* self, PyObject* arg)
{
    QSize* cppSelf = 0;
    bool isReverse = Shiboken::Converter< ::QSize >::checkType(arg) && !Shiboken::Converter< ::QSize >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QSize* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && Shiboken::Object::checkType(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__rmul__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__rmul__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator*(qreal,QSize)
    // 1: operator*(QSize,qreal)
    if (!isReverse && SbkNumber_Check(arg)) {
        overloadId = 1; // operator*(QSize,qreal)
    } else if (isReverse && SbkNumber_Check(arg)) {
        overloadId = 0; // operator*(qreal,QSize)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QSizeFunc___mul___TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // operator*(qreal,QSize)
            {
                qreal cppArg0 = Shiboken::Converter<qreal >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // operator*(qreal,QSize) [reverse operator]
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    const QSize cppResult = cppArg0 * (*cppSelf);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QSize >::toPython(cppResult);
                }
                break;
            }
            case 1: // operator*(QSize,qreal)
            {
                qreal cppArg0 = Shiboken::Converter<qreal >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // operator*(QSize,qreal)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    const QSize cppResult = (*cppSelf) * cppArg0;
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QSize >::toPython(cppResult);
                }
                break;
            }
        }
    }


    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QSizeFunc___mul___TypeError:
        const char* overloads[] = {"float", "float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QSize.__mul__", overloads);
        return 0;
}

static PyObject* Sbk_QSizeFunc___imul__(PyObject* self, PyObject* arg)
{
    QSize* cppSelf = 0;
    bool isReverse = Shiboken::Converter< ::QSize >::checkType(arg) && !Shiboken::Converter< ::QSize >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QSize* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: operator*=(qreal)
    if (!isReverse && SbkNumber_Check(arg)) {
        overloadId = 0; // operator*=(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QSizeFunc___imul___TypeError;

    // Call function/method
    {
        {
            qreal cppArg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // operator*=(qreal)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (*cppSelf) *= cppArg0;
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_INCREF(self);
    return self;

    Sbk_QSizeFunc___imul___TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QSize.__imul__", overloads);
        return 0;
}

static PyObject* Sbk_QSizeFunc___add__(PyObject* self, PyObject* arg)
{
    QSize* cppSelf = 0;
    bool isReverse = Shiboken::Converter< ::QSize >::checkType(arg) && !Shiboken::Converter< ::QSize >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QSize* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && Shiboken::Object::checkType(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__radd__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__radd__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator+(QSize,QSize)
    if (!isReverse && Shiboken::Converter< ::QSize >::isConvertible(arg)) {
        overloadId = 0; // operator+(QSize,QSize)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QSizeFunc___add___TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QSize cppArg0 = Shiboken::Converter<QSize >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // operator+(QSize,QSize)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                const QSize cppResult = (*cppSelf) + (cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QSize >::toPython(cppResult);
            }
        }
    }


    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QSizeFunc___add___TypeError:
        const char* overloads[] = {"PySide.QtCore.QSize", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QSize.__add__", overloads);
        return 0;
}

static PyObject* Sbk_QSizeFunc___iadd__(PyObject* self, PyObject* arg)
{
    QSize* cppSelf = 0;
    bool isReverse = Shiboken::Converter< ::QSize >::checkType(arg) && !Shiboken::Converter< ::QSize >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QSize* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: operator+=(QSize)
    if (!isReverse && Shiboken::Converter< ::QSize >::isConvertible(arg)) {
        overloadId = 0; // operator+=(QSize)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QSizeFunc___iadd___TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QSize cppArg0 = Shiboken::Converter<QSize >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // operator+=(QSize)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (*cppSelf) += (cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_INCREF(self);
    return self;

    Sbk_QSizeFunc___iadd___TypeError:
        const char* overloads[] = {"PySide.QtCore.QSize", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QSize.__iadd__", overloads);
        return 0;
}

static PyObject* Sbk_QSizeFunc___sub__(PyObject* self, PyObject* arg)
{
    QSize* cppSelf = 0;
    bool isReverse = Shiboken::Converter< ::QSize >::checkType(arg) && !Shiboken::Converter< ::QSize >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QSize* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && Shiboken::Object::checkType(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__rsub__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__rsub__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator-(QSize,QSize)
    if (!isReverse && Shiboken::Converter< ::QSize >::isConvertible(arg)) {
        overloadId = 0; // operator-(QSize,QSize)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QSizeFunc___sub___TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QSize cppArg0 = Shiboken::Converter<QSize >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // operator-(QSize,QSize)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                const QSize cppResult = (*cppSelf) - (cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QSize >::toPython(cppResult);
            }
        }
    }


    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QSizeFunc___sub___TypeError:
        const char* overloads[] = {"PySide.QtCore.QSize", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QSize.__sub__", overloads);
        return 0;
}

static PyObject* Sbk_QSizeFunc___isub__(PyObject* self, PyObject* arg)
{
    QSize* cppSelf = 0;
    bool isReverse = Shiboken::Converter< ::QSize >::checkType(arg) && !Shiboken::Converter< ::QSize >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QSize* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: operator-=(QSize)
    if (!isReverse && Shiboken::Converter< ::QSize >::isConvertible(arg)) {
        overloadId = 0; // operator-=(QSize)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QSizeFunc___isub___TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QSize cppArg0 = Shiboken::Converter<QSize >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // operator-=(QSize)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (*cppSelf) -= (cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_INCREF(self);
    return self;

    Sbk_QSizeFunc___isub___TypeError:
        const char* overloads[] = {"PySide.QtCore.QSize", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QSize.__isub__", overloads);
        return 0;
}

static PyObject* Sbk_QSizeFunc___div__(PyObject* self, PyObject* arg)
{
    QSize* cppSelf = 0;
    bool isReverse = Shiboken::Converter< ::QSize >::checkType(arg) && !Shiboken::Converter< ::QSize >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QSize* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && Shiboken::Object::checkType(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__rdiv__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__rdiv__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator/(QSize,qreal)
    if (!isReverse && SbkNumber_Check(arg)) {
        overloadId = 0; // operator/(QSize,qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QSizeFunc___div___TypeError;

    // Call function/method
    {
        {
            qreal cppArg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // operator/(QSize,qreal)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                const QSize cppResult = (*cppSelf) / cppArg0;
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QSize >::toPython(cppResult);
            }
        }
    }


    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QSizeFunc___div___TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QSize.__div__", overloads);
        return 0;
}

static PyObject* Sbk_QSizeFunc___idiv__(PyObject* self, PyObject* arg)
{
    QSize* cppSelf = 0;
    bool isReverse = Shiboken::Converter< ::QSize >::checkType(arg) && !Shiboken::Converter< ::QSize >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QSize* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: operator/=(qreal)
    if (!isReverse && SbkNumber_Check(arg)) {
        overloadId = 0; // operator/=(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QSizeFunc___idiv___TypeError;

    // Call function/method
    {
        {
            qreal cppArg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // operator/=(qreal)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (*cppSelf) /= cppArg0;
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_INCREF(self);
    return self;

    Sbk_QSizeFunc___idiv___TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QSize.__idiv__", overloads);
        return 0;
}

// type has number operators
static PyNumberMethods Sbk_QSize_as_number = {
    /*nb_add*/                  (binaryfunc)Sbk_QSizeFunc___add__,
    /*nb_subtract*/             (binaryfunc)Sbk_QSizeFunc___sub__,
    /*nb_multiply*/             (binaryfunc)Sbk_QSizeFunc___mul__,
    /*nb_divide*/               (binaryfunc)Sbk_QSizeFunc___div__,
    /*nb_remainder*/            (binaryfunc)0,
    /*nb_divmod*/               0,
    /*nb_power*/                0,
    /*nb_negative*/             (unaryfunc)0,
    /*nb_positive*/             (unaryfunc)0,
    /*nb_absolute*/             0,
    /*nb_nonzero*/              Sbk_QSize___nb_bool,
    /*nb_invert*/               (unaryfunc)0,
    /*nb_lshift*/               (binaryfunc)0,
    /*nb_rshift*/               (binaryfunc)0,
    /*nb_and*/                  (binaryfunc)0,
    /*nb_xor*/                  (binaryfunc)0,
    /*nb_or*/                   (binaryfunc)0,
    /*nb_coerce*/               0,
    /*nb_int*/                  0,
    /*nb_long*/                 0,
    /*nb_float*/                0,
    /*nb_oct*/                  0,
    /*nb_hex*/                  0,
    /*nb_inplace_add*/          (binaryfunc)Sbk_QSizeFunc___iadd__,
    /*nb_inplace_subtract*/     (binaryfunc)Sbk_QSizeFunc___isub__,
    /*nb_inplace_multiply*/     (binaryfunc)Sbk_QSizeFunc___imul__,
    /*nb_inplace_divide*/       (binaryfunc)Sbk_QSizeFunc___idiv__,
    /*nb_inplace_remainder*/    (binaryfunc)0,
    /*nb_inplace_power*/        0,
    /*nb_inplace_lshift*/       (binaryfunc)0,
    /*nb_inplace_rshift*/       (binaryfunc)0,
    /*nb_inplace_and*/          (binaryfunc)0,
    /*nb_inplace_xor*/          (binaryfunc)0,
    /*nb_inplace_or*/           (binaryfunc)0,
    /*nb_floor_divide*/         0,
    /*nb_true_divide*/          (binaryfunc)Sbk_QSizeFunc___div__,
    /*nb_inplace_floor_divide*/ 0,
    /*nb_inplace_true_divide*/  0,
    /*nb_index*/                0
};

// Rich comparison
static PyObject* Sbk_QSize_richcompare(PyObject* self, PyObject* arg, int op)
{
    PyObject* pyResult = 0;
    QSize& cppSelf = *Shiboken::Converter< QSize* >::toCpp(self);

    switch (op) {
        case Py_NE:
            if (Shiboken::Converter< ::QSize >::isConvertible(arg)) {
                // operator!=(const QSize & s2)
                QSize cppArg0 = Shiboken::Converter< ::QSize >::toCpp(arg);
                pyResult = Shiboken::Converter< bool >::toPython(cppSelf != cppArg0);
            } else goto Sbk_QSize_RichComparison_TypeError;

            break;
        case Py_EQ:
            if (Shiboken::Converter< ::QSize >::isConvertible(arg)) {
                // operator==(const QSize & s2)
                QSize cppArg0 = Shiboken::Converter< ::QSize >::toCpp(arg);
                pyResult = Shiboken::Converter< bool >::toPython(cppSelf == cppArg0);
            } else goto Sbk_QSize_RichComparison_TypeError;

            break;
        default:
            goto Sbk_QSize_RichComparison_TypeError;
    }

    if (pyResult && !PyErr_Occurred())
        return pyResult;
    Sbk_QSize_RichComparison_TypeError:
    PyErr_SetString(PyExc_NotImplementedError, "operator not implemented.");
    return 0;

}

} // extern "C"

static long Sbk_QSize_HashFunc(PyObject* obj){
    return PySide::hash(Shiboken::Converter< ::QSize >::toCpp(obj));
}

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QSize_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtCore.QSize",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Sbk_QSizeFunc___repr__,
    /*tp_as_number*/        &Sbk_QSize_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             &Sbk_QSize_HashFunc,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      Sbk_QSize_richcompare,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QSize_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QSize_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QSize(PyObject* module)
{
    SbkPySide_QtCoreTypes[SBK_QSIZE_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QSize_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QSize_Type);

    Shiboken::ObjectType::setDestructorFunction(&Sbk_QSize_Type, &Shiboken::callCppDestructor<QSize >);
    if (PyType_Ready((PyTypeObject*)&Sbk_QSize_Type) < 0)
        return;

    Shiboken::ObjectType::setOriginalName(&Sbk_QSize_Type, "QSize");
    PyModule_AddObject(module, "QSize",
        ((PyObject*)&Sbk_QSize_Type));



    Shiboken::TypeResolver::createValueTypeResolver<QSize >("QSize");
    Shiboken::TypeResolver::createObjectTypeResolver<QSize >("QSize*");
    Shiboken::TypeResolver::createValueTypeResolver<QSize >(typeid(QSize).name());
    PySide::initQtMetaType< ::QSize >();
}


