/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtcore_python.h"

#include "qtextdecoder_wrapper.h"

// Extra includes
#include <qbytearray.h>
#include <qtextcodec.h>



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QTextDecoder_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QTextDecoder >()))
        return -1;

    QTextDecoder* cptr = 0;
    int overloadId = -1;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QTextDecoder", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return -1;

    // Overloaded function decisor
    // 0: QTextDecoder(const QTextCodec*)
    // 1: QTextDecoder(const QTextCodec*,QFlags<QTextCodec::ConversionFlag>)
    if (Shiboken::Converter< ::QTextCodec * >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // QTextDecoder(const QTextCodec*)
        } else if (numArgs == 2 && Shiboken::Converter< ::QFlags<QTextCodec::ConversionFlag> >::isConvertible(pyargs[1])) {
            overloadId = 1; // QTextDecoder(const QTextCodec*,QFlags<QTextCodec::ConversionFlag>)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextDecoder_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QTextDecoder(const QTextCodec*)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QTextCodec * cppArg0 = Shiboken::Converter<QTextCodec * >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QTextDecoder(const QTextCodec*)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QTextDecoder(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // QTextDecoder(const QTextCodec*,QFlags<QTextCodec::ConversionFlag>)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QTextCodec * cppArg0 = Shiboken::Converter<QTextCodec * >::toCpp(pyargs[0]);
                QFlags<QTextCodec::ConversionFlag> cppArg1 = Shiboken::Converter<QFlags<QTextCodec::ConversionFlag> >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // QTextDecoder(const QTextCodec*,QFlags<QTextCodec::ConversionFlag>)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QTextDecoder(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QTextDecoder >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QTextDecoder_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QTextDecoder_Init_TypeError:
        const char* overloads[] = {"PySide.QtCore.QTextCodec", "PySide.QtCore.QTextCodec, PySide.QtCore.QTextCodec.ConversionFlags", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QTextDecoder", overloads);
        return -1;
}

static PyObject* Sbk_QTextDecoderFunc_hasFailure(PyObject* self)
{
    QTextDecoder* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextDecoder* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // hasFailure()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QTextDecoder*>(cppSelf)->hasFailure();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextDecoderFunc_toUnicode(PyObject* self, PyObject* arg)
{
    QTextDecoder* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextDecoder* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: toUnicode(QByteArray)
    if (Shiboken::Converter< ::QByteArray >::isConvertible(arg)) {
        overloadId = 0; // toUnicode(QByteArray)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextDecoderFunc_toUnicode_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QByteArray cppArg0 = Shiboken::Converter<QByteArray >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // toUnicode(QByteArray)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = cppSelf->toUnicode(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QTextDecoderFunc_toUnicode_TypeError:
        const char* overloads[] = {"PySide.QtCore.QByteArray", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QTextDecoder.toUnicode", overloads);
        return 0;
}

static PyMethodDef Sbk_QTextDecoder_methods[] = {
    {"hasFailure", (PyCFunction)Sbk_QTextDecoderFunc_hasFailure, METH_NOARGS},
    {"toUnicode", (PyCFunction)Sbk_QTextDecoderFunc_toUnicode, METH_O},

    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QTextDecoder_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtCore.QTextDecoder",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QTextDecoder_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QTextDecoder_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QTextDecoder(PyObject* module)
{
    SbkPySide_QtCoreTypes[SBK_QTEXTDECODER_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QTextDecoder_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QTextDecoder_Type);
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QTextDecoder_Type, &Shiboken::callCppDestructor<QTextDecoder >);
    if (PyType_Ready((PyTypeObject*)&Sbk_QTextDecoder_Type) < 0)
        return;

    Shiboken::ObjectType::setOriginalName(&Sbk_QTextDecoder_Type, "QTextDecoder*");
    PyModule_AddObject(module, "QTextDecoder",
        ((PyObject*)&Sbk_QTextDecoder_Type));


    Shiboken::TypeResolver::createObjectTypeResolver<QTextDecoder >("QTextDecoder*");
    Shiboken::TypeResolver::createObjectTypeResolver<QTextDecoder >(typeid(QTextDecoder).name());
    PySide::initQtMetaType< ::QTextDecoder* >();
}

