/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include "pyside_qtcore_python.h"

#include "qtimeline_wrapper.h"

// Extra includes
#include <QList>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qeasingcurve.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qthread.h>
#include <qtimeline.h>


// Native ---------------------------------------------------------

QTimeLineWrapper::QTimeLineWrapper(int duration, QObject * parent) : QTimeLine(duration, parent) {
    // ... middle
}

void QTimeLineWrapper::childEvent(QChildEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "childEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::childEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QChildEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QTimeLineWrapper::connectNotify(const char * signal)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "connectNotify"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QTimeLineWrapper::customEvent(QEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "customEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::customEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QTimeLineWrapper::disconnectNotify(const char * signal)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "disconnectNotify"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

bool QTimeLineWrapper::event(QEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return bool(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "event"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::event(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QTimeLine.event", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
    return cppResult;
}

bool QTimeLineWrapper::eventFilter(QObject * arg__1, QEvent * arg__2)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return bool(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "eventFilter"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::eventFilter(arg__1, arg__2);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter< ::QObject * >::toPython(arg__1),
        Shiboken::Converter< ::QEvent * >::toPython(arg__2)
    ));
    bool invalidadeArg2 = PyTuple_GET_ITEM(pyargs, 1)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QTimeLine.eventFilter", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    if (invalidadeArg2)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 1));
    return cppResult;
}

void QTimeLineWrapper::timerEvent(QTimerEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "timerEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QTimeLine::timerEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QTimerEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

qreal QTimeLineWrapper::valueForTime(int msec) const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return qreal(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "valueForTime"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QTimeLine::valueForTime(msec);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(i)",
        msec
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return qreal(0);
    }
    // Check return type
    bool typeIsValid = PyFloat_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QTimeLine.valueForTime", "qreal", pyResult->ob_type->tp_name);
        return qreal(0);
    }
    qreal cppResult(Shiboken::Converter< double >::toCpp(pyResult));
    return cppResult;
}

const QMetaObject* QTimeLineWrapper::metaObject() const
{
    SbkObject* pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    return reinterpret_cast<QMetaObject*>(Shiboken::Object::getTypeUserData(pySelf));
}

int QTimeLineWrapper::qt_metacall(QMetaObject::Call call, int id, void** args)
{
    int result = QTimeLine::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

QTimeLineWrapper::~QTimeLineWrapper()
{
    SbkObject* wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QTimeLine_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QTimeLine >()))
        return -1;

    QTimeLineWrapper* cptr = 0;
    int overloadId = -1;
    const char* argNames[] = {"duration", "parent"};
    const QMetaObject* metaObject;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_ParseTuple(args, "|OO:QTimeLine", &(pyargs[0]), &(pyargs[1])))
        return -1;

    // Overloaded function decisor
    // 0: QTimeLine(int,QObject*)
    if (numArgs == 0) {
        overloadId = 0; // QTimeLine(int,QObject*)
    } else if (SbkNumber_Check(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // QTimeLine(int,QObject*)
        } else if (Shiboken::Converter< ::QObject * >::isConvertible(pyargs[1])) {
            overloadId = 0; // QTimeLine(int,QObject*)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTimeLine_Init_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "duration");
                if (value) {
                    if (pyargs[0])
                        errorArgName = "duration";
                    else if (SbkNumber_Check(value))
                        pyargs[0] = value;
                    else
                        goto Sbk_QTimeLine_Init_TypeError;
                }
                value = PyDict_GetItemString(kwds, "parent");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "parent";
                    else if (Shiboken::Converter< ::QObject * >::isConvertible(value))
                        pyargs[1] = value;
                    else
                        goto Sbk_QTimeLine_Init_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.QTimeLine(): got multiple values for keyword argument '%s'", errorArgName);
                    return -1;
                }
            }
            int cppArg0 = pyargs[0] ? Shiboken::Converter<int >::toCpp(pyargs[0]) : 1000;
            if (!Shiboken::Object::isValid(pyargs[1]))
                return -1;
            QObject * cppArg1 = pyargs[1] ? Shiboken::Converter<QObject * >::toCpp(pyargs[1]) : 0;

            if(!PyErr_Occurred()) {
                // QTimeLine(int,QObject*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new QTimeLineWrapper(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                Shiboken::Object::setParent(pyargs[1], self);
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QTimeLine >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QTimeLine_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    metaObject = cptr->metaObject(); // <- init python qt properties
    if (kwds && !PySide::fillQtProperties(self, metaObject, kwds, argNames, 2))
        return -1;


    return 1;

    Sbk_QTimeLine_Init_TypeError:
        const char* overloads[] = {"int = 1000, PySide.QtCore.QObject = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QTimeLine", overloads);
        return -1;
}

static PyObject* Sbk_QTimeLineFunc_currentFrame(PyObject* self)
{
    QTimeLine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTimeLine* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // currentFrame()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QTimeLine*>(cppSelf)->currentFrame();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTimeLineFunc_currentTime(PyObject* self)
{
    QTimeLine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTimeLine* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // currentTime()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QTimeLine*>(cppSelf)->currentTime();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTimeLineFunc_currentValue(PyObject* self)
{
    QTimeLine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTimeLine* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // currentValue()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                qreal cppResult = const_cast<const QTimeLine*>(cppSelf)->currentValue();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< double >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTimeLineFunc_curveShape(PyObject* self)
{
    QTimeLine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTimeLine* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // curveShape()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QTimeLine::CurveShape cppResult = const_cast<const QTimeLine*>(cppSelf)->curveShape();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QTimeLine::CurveShape >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTimeLineFunc_direction(PyObject* self)
{
    QTimeLine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTimeLine* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // direction()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QTimeLine::Direction cppResult = const_cast<const QTimeLine*>(cppSelf)->direction();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QTimeLine::Direction >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTimeLineFunc_duration(PyObject* self)
{
    QTimeLine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTimeLine* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // duration()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QTimeLine*>(cppSelf)->duration();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTimeLineFunc_easingCurve(PyObject* self)
{
    QTimeLine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTimeLine* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // easingCurve()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QEasingCurve cppResult = const_cast<const QTimeLine*>(cppSelf)->easingCurve();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QEasingCurve >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTimeLineFunc_endFrame(PyObject* self)
{
    QTimeLine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTimeLine* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // endFrame()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QTimeLine*>(cppSelf)->endFrame();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTimeLineFunc_frameForTime(PyObject* self, PyObject* arg)
{
    QTimeLine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTimeLine* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: frameForTime(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // frameForTime(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTimeLineFunc_frameForTime_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // frameForTime(int)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QTimeLine*>(cppSelf)->frameForTime(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QTimeLineFunc_frameForTime_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QTimeLine.frameForTime", overloads);
        return 0;
}

static PyObject* Sbk_QTimeLineFunc_loopCount(PyObject* self)
{
    QTimeLine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTimeLine* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // loopCount()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QTimeLine*>(cppSelf)->loopCount();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTimeLineFunc_resume(PyObject* self)
{
    QTimeLine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTimeLine* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // resume()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->resume();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QTimeLineFunc_setCurrentTime(PyObject* self, PyObject* arg)
{
    QTimeLine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTimeLine* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setCurrentTime(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setCurrentTime(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTimeLineFunc_setCurrentTime_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setCurrentTime(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setCurrentTime(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTimeLineFunc_setCurrentTime_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QTimeLine.setCurrentTime", overloads);
        return 0;
}

static PyObject* Sbk_QTimeLineFunc_setCurveShape(PyObject* self, PyObject* arg)
{
    QTimeLine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTimeLine* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setCurveShape(QTimeLine::CurveShape)
    if (Shiboken::Converter< ::QTimeLine::CurveShape >::isConvertible(arg)) {
        overloadId = 0; // setCurveShape(QTimeLine::CurveShape)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTimeLineFunc_setCurveShape_TypeError;

    // Call function/method
    {
        {
            QTimeLine::CurveShape cppArg0 = Shiboken::Converter<QTimeLine::CurveShape >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setCurveShape(QTimeLine::CurveShape)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setCurveShape(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTimeLineFunc_setCurveShape_TypeError:
        const char* overloads[] = {"PySide.QtCore.QTimeLine.CurveShape", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QTimeLine.setCurveShape", overloads);
        return 0;
}

static PyObject* Sbk_QTimeLineFunc_setDirection(PyObject* self, PyObject* arg)
{
    QTimeLine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTimeLine* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setDirection(QTimeLine::Direction)
    if (Shiboken::Converter< ::QTimeLine::Direction >::isConvertible(arg)) {
        overloadId = 0; // setDirection(QTimeLine::Direction)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTimeLineFunc_setDirection_TypeError;

    // Call function/method
    {
        {
            QTimeLine::Direction cppArg0 = Shiboken::Converter<QTimeLine::Direction >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setDirection(QTimeLine::Direction)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setDirection(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTimeLineFunc_setDirection_TypeError:
        const char* overloads[] = {"PySide.QtCore.QTimeLine.Direction", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QTimeLine.setDirection", overloads);
        return 0;
}

static PyObject* Sbk_QTimeLineFunc_setDuration(PyObject* self, PyObject* arg)
{
    QTimeLine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTimeLine* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setDuration(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setDuration(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTimeLineFunc_setDuration_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setDuration(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setDuration(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTimeLineFunc_setDuration_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QTimeLine.setDuration", overloads);
        return 0;
}

static PyObject* Sbk_QTimeLineFunc_setEasingCurve(PyObject* self, PyObject* arg)
{
    QTimeLine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTimeLine* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setEasingCurve(QEasingCurve)
    if (Shiboken::Converter< ::QEasingCurve >::isConvertible(arg)) {
        overloadId = 0; // setEasingCurve(QEasingCurve)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTimeLineFunc_setEasingCurve_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QEasingCurve cppArg0 = Shiboken::Converter<QEasingCurve >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setEasingCurve(QEasingCurve)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setEasingCurve(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTimeLineFunc_setEasingCurve_TypeError:
        const char* overloads[] = {"PySide.QtCore.QEasingCurve", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QTimeLine.setEasingCurve", overloads);
        return 0;
}

static PyObject* Sbk_QTimeLineFunc_setEndFrame(PyObject* self, PyObject* arg)
{
    QTimeLine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTimeLine* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setEndFrame(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setEndFrame(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTimeLineFunc_setEndFrame_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setEndFrame(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setEndFrame(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTimeLineFunc_setEndFrame_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QTimeLine.setEndFrame", overloads);
        return 0;
}

static PyObject* Sbk_QTimeLineFunc_setFrameRange(PyObject* self, PyObject* args)
{
    QTimeLine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTimeLine* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setFrameRange", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setFrameRange(int,int)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 0; // setFrameRange(int,int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTimeLineFunc_setFrameRange_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // setFrameRange(int,int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setFrameRange(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTimeLineFunc_setFrameRange_TypeError:
        const char* overloads[] = {"int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QTimeLine.setFrameRange", overloads);
        return 0;
}

static PyObject* Sbk_QTimeLineFunc_setLoopCount(PyObject* self, PyObject* arg)
{
    QTimeLine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTimeLine* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setLoopCount(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setLoopCount(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTimeLineFunc_setLoopCount_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setLoopCount(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setLoopCount(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTimeLineFunc_setLoopCount_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QTimeLine.setLoopCount", overloads);
        return 0;
}

static PyObject* Sbk_QTimeLineFunc_setPaused(PyObject* self, PyObject* arg)
{
    QTimeLine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTimeLine* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setPaused(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setPaused(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTimeLineFunc_setPaused_TypeError;

    // Call function/method
    {
        {
            bool cppArg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setPaused(bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setPaused(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTimeLineFunc_setPaused_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QTimeLine.setPaused", overloads);
        return 0;
}

static PyObject* Sbk_QTimeLineFunc_setStartFrame(PyObject* self, PyObject* arg)
{
    QTimeLine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTimeLine* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setStartFrame(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setStartFrame(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTimeLineFunc_setStartFrame_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setStartFrame(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setStartFrame(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTimeLineFunc_setStartFrame_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QTimeLine.setStartFrame", overloads);
        return 0;
}

static PyObject* Sbk_QTimeLineFunc_setUpdateInterval(PyObject* self, PyObject* arg)
{
    QTimeLine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTimeLine* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setUpdateInterval(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setUpdateInterval(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTimeLineFunc_setUpdateInterval_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setUpdateInterval(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setUpdateInterval(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTimeLineFunc_setUpdateInterval_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QTimeLine.setUpdateInterval", overloads);
        return 0;
}

static PyObject* Sbk_QTimeLineFunc_start(PyObject* self)
{
    QTimeLine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTimeLine* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // start()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->start();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QTimeLineFunc_startFrame(PyObject* self)
{
    QTimeLine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTimeLine* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // startFrame()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QTimeLine*>(cppSelf)->startFrame();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTimeLineFunc_state(PyObject* self)
{
    QTimeLine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTimeLine* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // state()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QTimeLine::State cppResult = const_cast<const QTimeLine*>(cppSelf)->state();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QTimeLine::State >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTimeLineFunc_stop(PyObject* self)
{
    QTimeLine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTimeLine* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // stop()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->stop();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QTimeLineFunc_timerEvent(PyObject* self, PyObject* arg)
{
    QTimeLine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTimeLine* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: timerEvent(QTimerEvent*)
    if (Shiboken::Converter< ::QTimerEvent * >::isConvertible(arg)) {
        overloadId = 0; // timerEvent(QTimerEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTimeLineFunc_timerEvent_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QTimerEvent * cppArg0 = Shiboken::Converter<QTimerEvent * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // timerEvent(QTimerEvent*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QTimeLine::timerEvent(cppArg0) : cppSelf->timerEvent(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTimeLineFunc_timerEvent_TypeError:
        const char* overloads[] = {"PySide.QtCore.QTimerEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QTimeLine.timerEvent", overloads);
        return 0;
}

static PyObject* Sbk_QTimeLineFunc_toggleDirection(PyObject* self)
{
    QTimeLine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTimeLine* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // toggleDirection()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->toggleDirection();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QTimeLineFunc_updateInterval(PyObject* self)
{
    QTimeLine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTimeLine* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // updateInterval()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QTimeLine*>(cppSelf)->updateInterval();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTimeLineFunc_valueForTime(PyObject* self, PyObject* arg)
{
    QTimeLine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTimeLine* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: valueForTime(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // valueForTime(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTimeLineFunc_valueForTime_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // valueForTime(int)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                qreal cppResult = (Shiboken::Object::isUserType(self) ? const_cast<const QTimeLine*>(cppSelf)->::QTimeLine::valueForTime(cppArg0) : const_cast<const QTimeLine*>(cppSelf)->valueForTime(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< double >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QTimeLineFunc_valueForTime_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QTimeLine.valueForTime", overloads);
        return 0;
}

static PyMethodDef Sbk_QTimeLine_methods[] = {
    {"currentFrame", (PyCFunction)Sbk_QTimeLineFunc_currentFrame, METH_NOARGS},
    {"currentTime", (PyCFunction)Sbk_QTimeLineFunc_currentTime, METH_NOARGS},
    {"currentValue", (PyCFunction)Sbk_QTimeLineFunc_currentValue, METH_NOARGS},
    {"curveShape", (PyCFunction)Sbk_QTimeLineFunc_curveShape, METH_NOARGS},
    {"direction", (PyCFunction)Sbk_QTimeLineFunc_direction, METH_NOARGS},
    {"duration", (PyCFunction)Sbk_QTimeLineFunc_duration, METH_NOARGS},
    {"easingCurve", (PyCFunction)Sbk_QTimeLineFunc_easingCurve, METH_NOARGS},
    {"endFrame", (PyCFunction)Sbk_QTimeLineFunc_endFrame, METH_NOARGS},
    {"frameForTime", (PyCFunction)Sbk_QTimeLineFunc_frameForTime, METH_O},
    {"loopCount", (PyCFunction)Sbk_QTimeLineFunc_loopCount, METH_NOARGS},
    {"resume", (PyCFunction)Sbk_QTimeLineFunc_resume, METH_NOARGS},
    {"setCurrentTime", (PyCFunction)Sbk_QTimeLineFunc_setCurrentTime, METH_O},
    {"setCurveShape", (PyCFunction)Sbk_QTimeLineFunc_setCurveShape, METH_O},
    {"setDirection", (PyCFunction)Sbk_QTimeLineFunc_setDirection, METH_O},
    {"setDuration", (PyCFunction)Sbk_QTimeLineFunc_setDuration, METH_O},
    {"setEasingCurve", (PyCFunction)Sbk_QTimeLineFunc_setEasingCurve, METH_O},
    {"setEndFrame", (PyCFunction)Sbk_QTimeLineFunc_setEndFrame, METH_O},
    {"setFrameRange", (PyCFunction)Sbk_QTimeLineFunc_setFrameRange, METH_VARARGS},
    {"setLoopCount", (PyCFunction)Sbk_QTimeLineFunc_setLoopCount, METH_O},
    {"setPaused", (PyCFunction)Sbk_QTimeLineFunc_setPaused, METH_O},
    {"setStartFrame", (PyCFunction)Sbk_QTimeLineFunc_setStartFrame, METH_O},
    {"setUpdateInterval", (PyCFunction)Sbk_QTimeLineFunc_setUpdateInterval, METH_O},
    {"start", (PyCFunction)Sbk_QTimeLineFunc_start, METH_NOARGS},
    {"startFrame", (PyCFunction)Sbk_QTimeLineFunc_startFrame, METH_NOARGS},
    {"state", (PyCFunction)Sbk_QTimeLineFunc_state, METH_NOARGS},
    {"stop", (PyCFunction)Sbk_QTimeLineFunc_stop, METH_NOARGS},
    {"timerEvent", (PyCFunction)Sbk_QTimeLineFunc_timerEvent, METH_O},
    {"toggleDirection", (PyCFunction)Sbk_QTimeLineFunc_toggleDirection, METH_NOARGS},
    {"updateInterval", (PyCFunction)Sbk_QTimeLineFunc_updateInterval, METH_NOARGS},
    {"valueForTime", (PyCFunction)Sbk_QTimeLineFunc_valueForTime, METH_O},

    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QTimeLine_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtCore.QTimeLine",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QTimeLine_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QTimeLine_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern

static SbkObjectType* Sbk_QTimeLine_typeDiscovery(void* cptr, SbkObjectType* instanceType)
{
    if (instanceType == reinterpret_cast<SbkObjectType*>(Shiboken::SbkType<QObject >()) && dynamic_cast<QTimeLine*>(reinterpret_cast<QObject*>(cptr)))
        return &Sbk_QTimeLine_Type;
    return 0;
}


void init_QTimeLine(PyObject* module)
{
    SbkPySide_QtCoreTypes[SBK_QTIMELINE_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QTimeLine_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QTimeLine_Type);
    Shiboken::ObjectType::setSubTypeInitHook(&Sbk_QTimeLine_Type, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(&Sbk_QTimeLine_Type, &QTimeLine::staticMetaObject);    Sbk_QTimeLine_Type.super.ht_type.tp_base = SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX];
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QTimeLine_Type, &Shiboken::callCppDestructor<QTimeLine >);
    if (PyType_Ready((PyTypeObject*)&Sbk_QTimeLine_Type) < 0)
        return;

    // Fill type discovery information
    Shiboken::ObjectType::setTypeDiscoveryFunction(&Sbk_QTimeLine_Type, &Sbk_QTimeLine_typeDiscovery);
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkObjectType*>(SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX]), &Sbk_QTimeLine_Type);

    Shiboken::ObjectType::setOriginalName(&Sbk_QTimeLine_Type, "QTimeLine*");
    PyModule_AddObject(module, "QTimeLine",
        ((PyObject*)&Sbk_QTimeLine_Type));

    // Initialize enums
    PyObject* enumItem;

    // init enum: Direction
    PyTypeObject* SbkPySide_QtCore_QTimeLine_Direction = Shiboken::Enum::newType("PySide.QtCore.QTimeLine.Direction");
    SbkPySide_QtCoreTypes[SBK_QTIMELINE_DIRECTION_IDX] = SbkPySide_QtCore_QTimeLine_Direction;
    if (PyType_Ready(SbkPySide_QtCore_QTimeLine_Direction) < 0)
        return;
    PyDict_SetItemString(Sbk_QTimeLine_Type.super.ht_type.tp_dict,
            "Direction",((PyObject*)SbkPySide_QtCore_QTimeLine_Direction));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QTimeLine_Direction,(long) QTimeLine::Forward, "Forward");
    PyDict_SetItemString(Sbk_QTimeLine_Type.super.ht_type.tp_dict,"Forward", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QTimeLine_Direction->tp_dict,"Forward", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QTimeLine_Direction,(long) QTimeLine::Backward, "Backward");
    PyDict_SetItemString(Sbk_QTimeLine_Type.super.ht_type.tp_dict,"Backward", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QTimeLine_Direction->tp_dict,"Backward", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QTimeLine::Direction");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::Direction");
    // end of enum Direction

    // init enum: CurveShape
    PyTypeObject* SbkPySide_QtCore_QTimeLine_CurveShape = Shiboken::Enum::newType("PySide.QtCore.QTimeLine.CurveShape");
    SbkPySide_QtCoreTypes[SBK_QTIMELINE_CURVESHAPE_IDX] = SbkPySide_QtCore_QTimeLine_CurveShape;
    if (PyType_Ready(SbkPySide_QtCore_QTimeLine_CurveShape) < 0)
        return;
    PyDict_SetItemString(Sbk_QTimeLine_Type.super.ht_type.tp_dict,
            "CurveShape",((PyObject*)SbkPySide_QtCore_QTimeLine_CurveShape));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QTimeLine_CurveShape,(long) QTimeLine::EaseInCurve, "EaseInCurve");
    PyDict_SetItemString(Sbk_QTimeLine_Type.super.ht_type.tp_dict,"EaseInCurve", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QTimeLine_CurveShape->tp_dict,"EaseInCurve", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QTimeLine_CurveShape,(long) QTimeLine::EaseOutCurve, "EaseOutCurve");
    PyDict_SetItemString(Sbk_QTimeLine_Type.super.ht_type.tp_dict,"EaseOutCurve", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QTimeLine_CurveShape->tp_dict,"EaseOutCurve", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QTimeLine_CurveShape,(long) QTimeLine::EaseInOutCurve, "EaseInOutCurve");
    PyDict_SetItemString(Sbk_QTimeLine_Type.super.ht_type.tp_dict,"EaseInOutCurve", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QTimeLine_CurveShape->tp_dict,"EaseInOutCurve", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QTimeLine_CurveShape,(long) QTimeLine::LinearCurve, "LinearCurve");
    PyDict_SetItemString(Sbk_QTimeLine_Type.super.ht_type.tp_dict,"LinearCurve", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QTimeLine_CurveShape->tp_dict,"LinearCurve", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QTimeLine_CurveShape,(long) QTimeLine::SineCurve, "SineCurve");
    PyDict_SetItemString(Sbk_QTimeLine_Type.super.ht_type.tp_dict,"SineCurve", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QTimeLine_CurveShape->tp_dict,"SineCurve", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QTimeLine_CurveShape,(long) QTimeLine::CosineCurve, "CosineCurve");
    PyDict_SetItemString(Sbk_QTimeLine_Type.super.ht_type.tp_dict,"CosineCurve", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QTimeLine_CurveShape->tp_dict,"CosineCurve", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QTimeLine::CurveShape");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::CurveShape");
    // end of enum CurveShape

    // init enum: State
    PyTypeObject* SbkPySide_QtCore_QTimeLine_State = Shiboken::Enum::newType("PySide.QtCore.QTimeLine.State");
    SbkPySide_QtCoreTypes[SBK_QTIMELINE_STATE_IDX] = SbkPySide_QtCore_QTimeLine_State;
    if (PyType_Ready(SbkPySide_QtCore_QTimeLine_State) < 0)
        return;
    PyDict_SetItemString(Sbk_QTimeLine_Type.super.ht_type.tp_dict,
            "State",((PyObject*)SbkPySide_QtCore_QTimeLine_State));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QTimeLine_State,(long) QTimeLine::NotRunning, "NotRunning");
    PyDict_SetItemString(Sbk_QTimeLine_Type.super.ht_type.tp_dict,"NotRunning", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QTimeLine_State->tp_dict,"NotRunning", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QTimeLine_State,(long) QTimeLine::Paused, "Paused");
    PyDict_SetItemString(Sbk_QTimeLine_Type.super.ht_type.tp_dict,"Paused", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QTimeLine_State->tp_dict,"Paused", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QTimeLine_State,(long) QTimeLine::Running, "Running");
    PyDict_SetItemString(Sbk_QTimeLine_Type.super.ht_type.tp_dict,"Running", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QTimeLine_State->tp_dict,"Running", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QTimeLine::State");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::State");
    // end of enum State

    // Initialize signals
    PySideSignal* signal_item;

    signal_item = PySide::Signal::newObject("finished", "void", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QTimeLine_Type, "finished", signal_item);
    Py_DECREF((PyObject*) signal_item);
    signal_item = PySide::Signal::newObject("frameChanged", "int", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QTimeLine_Type, "frameChanged", signal_item);
    Py_DECREF((PyObject*) signal_item);
    signal_item = PySide::Signal::newObject("valueChanged", "qreal", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QTimeLine_Type, "valueChanged", signal_item);
    Py_DECREF((PyObject*) signal_item);
    signal_item = PySide::Signal::newObject("stateChanged", "QTimeLine::State", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QTimeLine_Type, "stateChanged", signal_item);
    Py_DECREF((PyObject*) signal_item);


    Shiboken::TypeResolver::createObjectTypeResolver<QTimeLine >("QTimeLine*");
    Shiboken::TypeResolver::createObjectTypeResolver<QTimeLine >(typeid(QTimeLine).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QTimeLine >(typeid(QTimeLineWrapper).name());
    PySide::initQtMetaType< ::QTimeLine* >();
    qRegisterMetaType< ::QTimeLine::Direction >("QTimeLine::Direction");
    qRegisterMetaType< ::QTimeLine::CurveShape >("QTimeLine::CurveShape");
    qRegisterMetaType< ::QTimeLine::State >("QTimeLine::State");
}

