/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <set>
#include "pyside_qtdeclarative_python.h"

#include "qdeclarativeextensionplugin_wrapper.h"

// Extra includes
#include <QList>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qdeclarativeengine.h>
#include <qdeclarativeextensionplugin.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qthread.h>


// Native ---------------------------------------------------------

QDeclarativeExtensionPluginWrapper::QDeclarativeExtensionPluginWrapper(QObject * parent) : QDeclarativeExtensionPlugin(parent) {
    // ... middle
}

void QDeclarativeExtensionPluginWrapper::childEvent(QChildEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "childEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::childEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QChildEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QDeclarativeExtensionPluginWrapper::connectNotify(const char * signal)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "connectNotify"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QDeclarativeExtensionPluginWrapper::customEvent(QEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "customEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::customEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QDeclarativeExtensionPluginWrapper::disconnectNotify(const char * signal)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "disconnectNotify"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

bool QDeclarativeExtensionPluginWrapper::event(QEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return bool(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "event"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::event(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QDeclarativeExtensionPlugin.event", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    return cppResult;
}

bool QDeclarativeExtensionPluginWrapper::eventFilter(QObject * arg__1, QEvent * arg__2)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return bool(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "eventFilter"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::eventFilter(arg__1, arg__2);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter< ::QObject * >::toPython(arg__1),
        Shiboken::Converter< ::QEvent * >::toPython(arg__2)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QDeclarativeExtensionPlugin.eventFilter", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    return cppResult;
}

void QDeclarativeExtensionPluginWrapper::initializeEngine(QDeclarativeEngine * engine, const char * uri)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "initializeEngine"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QDeclarativeExtensionPlugin::initializeEngine(engine, uri);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter< ::QDeclarativeEngine * >::toPython(engine),
        Shiboken::Converter< const char * >::toPython(uri)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QDeclarativeExtensionPluginWrapper::registerTypes(const char * uri)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "registerTypes"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QDeclarativeExtensionPlugin.registerTypes()' not implemented.");
        return ;
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< const char * >::toPython(uri)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QDeclarativeExtensionPluginWrapper::timerEvent(QTimerEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "timerEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::timerEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QTimerEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

const QMetaObject* QDeclarativeExtensionPluginWrapper::metaObject() const
{
    SbkObject* pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    return reinterpret_cast<QMetaObject*>(Shiboken::Object::getTypeUserData(pySelf));
}

int QDeclarativeExtensionPluginWrapper::qt_metacall(QMetaObject::Call call, int id, void** args)
{
    int result = QDeclarativeExtensionPlugin::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

QDeclarativeExtensionPluginWrapper::~QDeclarativeExtensionPluginWrapper()
{
    SbkObject* wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QDeclarativeExtensionPlugin_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QDeclarativeExtensionPlugin >()))
        return -1;

    QDeclarativeExtensionPluginWrapper* cptr = 0;
    int overloadId = -1;
    const char* argNames[] = {"parent"};
    const QMetaObject* metaObject;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);
    SbkObjectType* type = reinterpret_cast<SbkObjectType*>(self->ob_type);
    SbkObjectType* myType = reinterpret_cast<SbkObjectType*>(SbkPySide_QtDeclarativeTypes[SBK_QDECLARATIVEEXTENSIONPLUGIN_IDX]);
    if (type == myType) {
        PyErr_SetString(PyExc_NotImplementedError,
            "'QDeclarativeExtensionPlugin' represents a C++ abstract class and cannot be instantiated");
        return -1;
    }

        Shiboken::ObjectType::copyMultimpleheritance(type, myType);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths


    if (!PyArg_ParseTuple(args, "|O:QDeclarativeExtensionPlugin", &(pyargs[0])))
        return -1;

    // Overloaded function decisor
    // 0: QDeclarativeExtensionPlugin(QObject*)
    if (numArgs == 0) {
        overloadId = 0; // QDeclarativeExtensionPlugin(QObject*)
    } else if (Shiboken::Converter< ::QObject * >::isConvertible(pyargs[0])) {
        overloadId = 0; // QDeclarativeExtensionPlugin(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDeclarativeExtensionPlugin_Init_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "parent");
                if (value) {
                    if (pyargs[0])
                        errorArgName = "parent";
                    else if (Shiboken::Converter< ::QObject * >::isConvertible(value))
                        pyargs[0] = value;
                    else
                        goto Sbk_QDeclarativeExtensionPlugin_Init_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtDeclarative.QDeclarativeExtensionPlugin(): got multiple values for keyword argument '%s'", errorArgName);
                    return -1;
                }
            }
            if (!Shiboken::Object::isValid(pyargs[0]))
                return -1;
            QObject * cppArg0 = pyargs[0] ? Shiboken::Converter<QObject * >::toCpp(pyargs[0]) : 0;

            if(!PyErr_Occurred()) {
                // QDeclarativeExtensionPlugin(QObject*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new QDeclarativeExtensionPluginWrapper(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                Shiboken::Object::setParent(pyargs[0], self);
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QDeclarativeExtensionPlugin >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QDeclarativeExtensionPlugin_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    metaObject = cptr->metaObject(); // <- init python qt properties
    if (kwds && !PySide::fillQtProperties(self, metaObject, kwds, argNames, 1))
        return -1;


    return 1;

    Sbk_QDeclarativeExtensionPlugin_Init_TypeError:
        const char* overloads[] = {"PySide.QtCore.QObject = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtDeclarative.QDeclarativeExtensionPlugin", overloads);
        return -1;
}

static PyObject* Sbk_QDeclarativeExtensionPluginFunc_initializeEngine(PyObject* self, PyObject* args)
{
    QDeclarativeExtensionPlugin* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDeclarativeExtensionPlugin* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "initializeEngine", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: initializeEngine(QDeclarativeEngine*,const char*)
    if (numArgs == 2 && Shiboken::Converter< ::QDeclarativeEngine * >::isConvertible(pyargs[0]) && Shiboken::Converter< const char * >::isConvertible(pyargs[1])) {
        overloadId = 0; // initializeEngine(QDeclarativeEngine*,const char*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDeclarativeExtensionPluginFunc_initializeEngine_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QDeclarativeEngine * cppArg0 = Shiboken::Converter<QDeclarativeEngine * >::toCpp(pyargs[0]);
            const char * cppArg1 = Shiboken::Converter<const char * >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // initializeEngine(QDeclarativeEngine*,const char*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QDeclarativeExtensionPlugin::initializeEngine(cppArg0, cppArg1) : cppSelf->initializeEngine(cppArg0, cppArg1));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QDeclarativeExtensionPluginFunc_initializeEngine_TypeError:
        const char* overloads[] = {"PySide.QtDeclarative.QDeclarativeEngine, str", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtDeclarative.QDeclarativeExtensionPlugin.initializeEngine", overloads);
        return 0;
}

static PyObject* Sbk_QDeclarativeExtensionPluginFunc_registerTypes(PyObject* self, PyObject* arg)
{
    QDeclarativeExtensionPlugin* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDeclarativeExtensionPlugin* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: registerTypes(const char*)
    if (Shiboken::Converter< const char * >::isConvertible(arg)) {
        overloadId = 0; // registerTypes(const char*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDeclarativeExtensionPluginFunc_registerTypes_TypeError;

    // Call function/method
    {
        {
            const char * cppArg0 = Shiboken::Converter<const char * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // registerTypes(const char*)
                if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self))) {
                    PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QDeclarativeExtensionPlugin.registerTypes()' not implemented.");
                    return 0;
                }
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->registerTypes(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QDeclarativeExtensionPluginFunc_registerTypes_TypeError:
        const char* overloads[] = {"str", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtDeclarative.QDeclarativeExtensionPlugin.registerTypes", overloads);
        return 0;
}

static PyMethodDef Sbk_QDeclarativeExtensionPlugin_methods[] = {
    {"initializeEngine", (PyCFunction)Sbk_QDeclarativeExtensionPluginFunc_initializeEngine, METH_VARARGS},
    {"registerTypes", (PyCFunction)Sbk_QDeclarativeExtensionPluginFunc_registerTypes, METH_O},

    {0} // Sentinel
};

} // extern "C"

static int mi_offsets[] = { -1, -1, -1, -1, -1 };
int*
Sbk_QDeclarativeExtensionPlugin_mi_init(const void* cptr)
{
    if (mi_offsets[0] == -1) {
        std::set<int> offsets;
        std::set<int>::iterator it;
        const QDeclarativeExtensionPlugin* class_ptr = reinterpret_cast<const QDeclarativeExtensionPlugin*>(cptr);
        size_t base = (size_t) class_ptr;
        offsets.insert(((size_t) static_cast<const QObject*>(class_ptr)) - base);
        offsets.insert(((size_t) static_cast<const QObject*>((QDeclarativeExtensionPlugin*)((void*)class_ptr))) - base);
        offsets.insert(((size_t) static_cast<const QDeclarativeExtensionInterface*>(class_ptr)) - base);
        offsets.insert(((size_t) static_cast<const QDeclarativeExtensionInterface*>((QDeclarativeExtensionPlugin*)((void*)class_ptr))) - base);

        offsets.erase(0);

        int i = 0;
        for (it = offsets.begin(); it != offsets.end(); it++) {
            mi_offsets[i] = *it;
            i++;
        }
    }
    return mi_offsets;
}
static void* Sbk_QDeclarativeExtensionPluginSpecialCastFunction(void* obj, SbkObjectType* desiredType)
{
    QDeclarativeExtensionPlugin* me = reinterpret_cast<QDeclarativeExtensionPlugin*>(obj);
    if (desiredType == reinterpret_cast<SbkObjectType*>(SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX]))
        return static_cast<QObject*>(me);
    else if (desiredType == reinterpret_cast<SbkObjectType*>(SbkPySide_QtDeclarativeTypes[SBK_QDECLARATIVEEXTENSIONINTERFACE_IDX]))
        return static_cast<QDeclarativeExtensionInterface*>(me);
    return me;
}


// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QDeclarativeExtensionPlugin_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtDeclarative.QDeclarativeExtensionPlugin",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QDeclarativeExtensionPlugin_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QDeclarativeExtensionPlugin_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern

static SbkObjectType* Sbk_QDeclarativeExtensionPlugin_typeDiscovery(void* cptr, SbkObjectType* instanceType)
{
    if (instanceType == reinterpret_cast<SbkObjectType*>(Shiboken::SbkType<QObject >()) && dynamic_cast<QDeclarativeExtensionPlugin*>(reinterpret_cast<QObject*>(cptr)))
        return &Sbk_QDeclarativeExtensionPlugin_Type;
    if (instanceType == reinterpret_cast<SbkObjectType*>(Shiboken::SbkType<QDeclarativeExtensionInterface >()) && dynamic_cast<QDeclarativeExtensionPlugin*>(reinterpret_cast<QDeclarativeExtensionInterface*>(cptr)))
        return &Sbk_QDeclarativeExtensionPlugin_Type;
    return 0;
}


void init_QDeclarativeExtensionPlugin(PyObject* module)
{
    SbkPySide_QtDeclarativeTypes[SBK_QDECLARATIVEEXTENSIONPLUGIN_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QDeclarativeExtensionPlugin_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QDeclarativeExtensionPlugin_Type);
    Shiboken::ObjectType::setSubTypeInitHook(&Sbk_QDeclarativeExtensionPlugin_Type, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(&Sbk_QDeclarativeExtensionPlugin_Type, &QDeclarativeExtensionPlugin::staticMetaObject);    Sbk_QDeclarativeExtensionPlugin_Type.super.ht_type.tp_base = SbkPySide_QtDeclarativeTypes[SBK_QDECLARATIVEEXTENSIONINTERFACE_IDX];
    Sbk_QDeclarativeExtensionPlugin_Type.super.ht_type.tp_bases = PyTuple_Pack(2,
        (PyTypeObject*)SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX], (PyTypeObject*)SbkPySide_QtDeclarativeTypes[SBK_QDECLARATIVEEXTENSIONINTERFACE_IDX]);

    MultipleInheritanceInitFunction func;
    func = Sbk_QDeclarativeExtensionPlugin_mi_init;
    Shiboken::ObjectType::setMultipleIheritanceFunction(&Sbk_QDeclarativeExtensionPlugin_Type, func);
    Shiboken::ObjectType::setCastFunction(&Sbk_QDeclarativeExtensionPlugin_Type, &Sbk_QDeclarativeExtensionPluginSpecialCastFunction);
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QDeclarativeExtensionPlugin_Type, &Shiboken::callCppDestructor<QDeclarativeExtensionPlugin >);
    if (PyType_Ready((PyTypeObject*)&Sbk_QDeclarativeExtensionPlugin_Type) < 0)
        return;

    // Fill type discovery information
    Shiboken::ObjectType::setTypeDiscoveryFunction(&Sbk_QDeclarativeExtensionPlugin_Type, &Sbk_QDeclarativeExtensionPlugin_typeDiscovery);
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkObjectType*>(SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX]), &Sbk_QDeclarativeExtensionPlugin_Type);
    bm.addClassInheritance(reinterpret_cast<SbkObjectType*>(SbkPySide_QtDeclarativeTypes[SBK_QDECLARATIVEEXTENSIONINTERFACE_IDX]), &Sbk_QDeclarativeExtensionPlugin_Type);

    Shiboken::ObjectType::setOriginalName(&Sbk_QDeclarativeExtensionPlugin_Type, "QDeclarativeExtensionPlugin*");
    PyModule_AddObject(module, "QDeclarativeExtensionPlugin",
        ((PyObject*)&Sbk_QDeclarativeExtensionPlugin_Type));


    Shiboken::TypeResolver::createObjectTypeResolver<QDeclarativeExtensionPlugin >("QDeclarativeExtensionPlugin*");
    Shiboken::TypeResolver::createObjectTypeResolver<QDeclarativeExtensionPlugin >("QDeclarativeExtensionPlugin$ConcreteWrapper*");
    Shiboken::TypeResolver::createObjectTypeResolver<QDeclarativeExtensionPlugin >(typeid(QDeclarativeExtensionPlugin).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QDeclarativeExtensionPlugin >(typeid(QDeclarativeExtensionPluginWrapper).name());
    PySide::initQtMetaType< ::QDeclarativeExtensionPlugin* >();
}

