/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtdeclarative_python.h"

#include "qdeclarativelistreference_wrapper.h"

// Extra includes
#include <qdeclarativeengine.h>
#include <qdeclarativelist.h>
#include <qobject.h>
#include <qobjectdefs.h>



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QDeclarativeListReference_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QDeclarativeListReference >()))
        return -1;

    QDeclarativeListReference* cptr = 0;
    int overloadId = -1;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);

    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtDeclarative.QDeclarativeListReference(): too many arguments");
        return -1;
    }

    if (!PyArg_ParseTuple(args, "|OOO:QDeclarativeListReference", &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return -1;

    // Overloaded function decisor
    // 0: QDeclarativeListReference()
    // 1: QDeclarativeListReference(QObject*,const char*,QDeclarativeEngine*)
    // 2: QDeclarativeListReference(QDeclarativeListReference)
    if (numArgs == 0) {
        overloadId = 0; // QDeclarativeListReference()
    } else if (numArgs == 1 && Shiboken::Converter< ::QDeclarativeListReference >::isConvertible(pyargs[0])) {
        overloadId = 2; // QDeclarativeListReference(QDeclarativeListReference)
    } else if (numArgs >= 2 && Shiboken::Converter< ::QObject * >::isConvertible(pyargs[0]) && Shiboken::Converter< const char * >::isConvertible(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 1; // QDeclarativeListReference(QObject*,const char*,QDeclarativeEngine*)
        } else if (Shiboken::Converter< ::QDeclarativeEngine * >::isConvertible(pyargs[2])) {
            overloadId = 1; // QDeclarativeListReference(QObject*,const char*,QDeclarativeEngine*)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDeclarativeListReference_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QDeclarativeListReference()
            {

                if(!PyErr_Occurred()) {
                    // QDeclarativeListReference()
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QDeclarativeListReference();
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // QDeclarativeListReference(QObject*,const char*,QDeclarativeEngine*)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "arg__3");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "arg__3";
                        else if (Shiboken::Converter< ::QDeclarativeEngine * >::isConvertible(value))
                            pyargs[2] = value;
                        else
                            goto Sbk_QDeclarativeListReference_Init_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtDeclarative.QDeclarativeListReference(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QObject * cppArg0 = Shiboken::Converter<QObject * >::toCpp(pyargs[0]);
                const char * cppArg1 = Shiboken::Converter<const char * >::toCpp(pyargs[1]);
                if (!Shiboken::Object::isValid(pyargs[2]))
                    return -1;
                QDeclarativeEngine * cppArg2 = pyargs[2] ? Shiboken::Converter<QDeclarativeEngine * >::toCpp(pyargs[2]) : 0;

                if(!PyErr_Occurred()) {
                    // QDeclarativeListReference(QObject*,const char*,QDeclarativeEngine*)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QDeclarativeListReference(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 2: // QDeclarativeListReference(QDeclarativeListReference)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QDeclarativeListReference cppArg0 = Shiboken::Converter<QDeclarativeListReference >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QDeclarativeListReference(QDeclarativeListReference)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QDeclarativeListReference(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QDeclarativeListReference >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QDeclarativeListReference_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QDeclarativeListReference_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtCore.QObject, str, PySide.QtDeclarative.QDeclarativeEngine = None", "PySide.QtDeclarative.QDeclarativeListReference", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtDeclarative.QDeclarativeListReference", overloads);
        return -1;
}

static PyObject* Sbk_QDeclarativeListReferenceFunc_append(PyObject* self, PyObject* arg)
{
    QDeclarativeListReference* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDeclarativeListReference* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: append(QObject*)const
    if (Shiboken::Converter< ::QObject * >::isConvertible(arg)) {
        overloadId = 0; // append(QObject*)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDeclarativeListReferenceFunc_append_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QObject * cppArg0 = Shiboken::Converter<QObject * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // append(QObject*)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QDeclarativeListReference*>(cppSelf)->append(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QDeclarativeListReferenceFunc_append_TypeError:
        const char* overloads[] = {"PySide.QtCore.QObject", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtDeclarative.QDeclarativeListReference.append", overloads);
        return 0;
}

static PyObject* Sbk_QDeclarativeListReferenceFunc_at(PyObject* self, PyObject* arg)
{
    QDeclarativeListReference* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDeclarativeListReference* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: at(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // at(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDeclarativeListReferenceFunc_at_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // at(int)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QObject * cppResult = const_cast<const QDeclarativeListReference*>(cppSelf)->at(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QObject * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QDeclarativeListReferenceFunc_at_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtDeclarative.QDeclarativeListReference.at", overloads);
        return 0;
}

static PyObject* Sbk_QDeclarativeListReferenceFunc_canAppend(PyObject* self)
{
    QDeclarativeListReference* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDeclarativeListReference* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // canAppend()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QDeclarativeListReference*>(cppSelf)->canAppend();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDeclarativeListReferenceFunc_canAt(PyObject* self)
{
    QDeclarativeListReference* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDeclarativeListReference* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // canAt()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QDeclarativeListReference*>(cppSelf)->canAt();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDeclarativeListReferenceFunc_canClear(PyObject* self)
{
    QDeclarativeListReference* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDeclarativeListReference* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // canClear()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QDeclarativeListReference*>(cppSelf)->canClear();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDeclarativeListReferenceFunc_canCount(PyObject* self)
{
    QDeclarativeListReference* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDeclarativeListReference* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // canCount()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QDeclarativeListReference*>(cppSelf)->canCount();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDeclarativeListReferenceFunc_clear(PyObject* self)
{
    QDeclarativeListReference* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDeclarativeListReference* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // clear()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QDeclarativeListReference*>(cppSelf)->clear();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDeclarativeListReferenceFunc_count(PyObject* self)
{
    QDeclarativeListReference* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDeclarativeListReference* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // count()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QDeclarativeListReference*>(cppSelf)->count();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDeclarativeListReferenceFunc_isValid(PyObject* self)
{
    QDeclarativeListReference* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDeclarativeListReference* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isValid()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QDeclarativeListReference*>(cppSelf)->isValid();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDeclarativeListReferenceFunc_listElementType(PyObject* self)
{
    QDeclarativeListReference* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDeclarativeListReference* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // listElementType()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                const QMetaObject * cppResult = const_cast<const QDeclarativeListReference*>(cppSelf)->listElementType();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QMetaObject * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDeclarativeListReferenceFunc_object(PyObject* self)
{
    QDeclarativeListReference* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDeclarativeListReference* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // object()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QObject * cppResult = const_cast<const QDeclarativeListReference*>(cppSelf)->object();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QObject * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject *Sbk_QDeclarativeListReference___copy__(PyObject *self)
{
        QDeclarativeListReference* cppSelf = 0;
        if (!Shiboken::Object::isValid(self))
            return 0;
        cppSelf = Shiboken::Converter<QDeclarativeListReference*>::toCpp(self);
        PyObject* pyResult = 0;
        QDeclarativeListReference* copy = new QDeclarativeListReference(*cppSelf);
        pyResult = Shiboken::Converter<QDeclarativeListReference*>::toPython(copy);
        Shiboken::Object::getOwnership(pyResult);

        if (PyErr_Occurred() || !pyResult) {
            Py_XDECREF(pyResult);
            return 0;
        }
        return pyResult;
}

static PyMethodDef Sbk_QDeclarativeListReference_methods[] = {
    {"append", (PyCFunction)Sbk_QDeclarativeListReferenceFunc_append, METH_O},
    {"at", (PyCFunction)Sbk_QDeclarativeListReferenceFunc_at, METH_O},
    {"canAppend", (PyCFunction)Sbk_QDeclarativeListReferenceFunc_canAppend, METH_NOARGS},
    {"canAt", (PyCFunction)Sbk_QDeclarativeListReferenceFunc_canAt, METH_NOARGS},
    {"canClear", (PyCFunction)Sbk_QDeclarativeListReferenceFunc_canClear, METH_NOARGS},
    {"canCount", (PyCFunction)Sbk_QDeclarativeListReferenceFunc_canCount, METH_NOARGS},
    {"clear", (PyCFunction)Sbk_QDeclarativeListReferenceFunc_clear, METH_NOARGS},
    {"count", (PyCFunction)Sbk_QDeclarativeListReferenceFunc_count, METH_NOARGS},
    {"isValid", (PyCFunction)Sbk_QDeclarativeListReferenceFunc_isValid, METH_NOARGS},
    {"listElementType", (PyCFunction)Sbk_QDeclarativeListReferenceFunc_listElementType, METH_NOARGS},
    {"object", (PyCFunction)Sbk_QDeclarativeListReferenceFunc_object, METH_NOARGS},

    {"__copy__", (PyCFunction)Sbk_QDeclarativeListReference___copy__, METH_NOARGS},
    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QDeclarativeListReference_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtDeclarative.QDeclarativeListReference",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QDeclarativeListReference_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QDeclarativeListReference_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QDeclarativeListReference(PyObject* module)
{
    SbkPySide_QtDeclarativeTypes[SBK_QDECLARATIVELISTREFERENCE_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QDeclarativeListReference_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QDeclarativeListReference_Type);
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QDeclarativeListReference_Type, &Shiboken::callCppDestructor<QDeclarativeListReference >);
    if (PyType_Ready((PyTypeObject*)&Sbk_QDeclarativeListReference_Type) < 0)
        return;

    Shiboken::ObjectType::setOriginalName(&Sbk_QDeclarativeListReference_Type, "QDeclarativeListReference");
    PyModule_AddObject(module, "QDeclarativeListReference",
        ((PyObject*)&Sbk_QDeclarativeListReference_Type));


    Shiboken::TypeResolver::createValueTypeResolver<QDeclarativeListReference >("QDeclarativeListReference");
    Shiboken::TypeResolver::createObjectTypeResolver<QDeclarativeListReference >("QDeclarativeListReference*");
    Shiboken::TypeResolver::createValueTypeResolver<QDeclarativeListReference >(typeid(QDeclarativeListReference).name());
    PySide::initQtMetaType< ::QDeclarativeListReference >();
}

