/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


#include <Python.h>
#include <shiboken.h>
#include <algorithm>
#include "pyside_qtdeclarative_python.h"



// Extra includes
#include <QtDeclarative>
#include "pysideqmlregistertype.h"


// Global functions ------------------------------------------------------------
static PyObject* SbkQtDeclarativeModule_qmlRegisterType(PyObject* self, PyObject* args)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "qmlRegisterType", 5, 5, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4])))
        return 0;


    // Overloaded function decisor
    // 0: qmlRegisterType(PyTypeObject,const char*,int,int,const char*)
    if (numArgs == 5 && PyType_Check(pyargs[0]) && Shiboken::Converter< const char * >::isConvertible(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3]) && Shiboken::Converter< const char * >::isConvertible(pyargs[4])) {
        overloadId = 0; // qmlRegisterType(PyTypeObject,const char*,int,int,const char*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQtDeclarativeModule_qmlRegisterType_TypeError;

    // Call function/method
    {
        {
            const char * cppArg1 = Shiboken::Converter<const char * >::toCpp(pyargs[1]);
            int cppArg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);
            int cppArg3 = Shiboken::Converter<int >::toCpp(pyargs[3]);
            const char * cppArg4 = Shiboken::Converter<const char * >::toCpp(pyargs[4]);

            if(!PyErr_Occurred()) {
                // qmlRegisterType(PyTypeObject,const char*,int,int,const char*)
                // Begin code injection

                pyResult = Shiboken::Converter<int >::toPython(PySide::qmlRegisterType(pyargs[0], cppArg1, cppArg2, cppArg3, cppArg4));

                // End of code injection


            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQtDeclarativeModule_qmlRegisterType_TypeError:
        const char* overloads[] = {"PyTypeObject, str, int, int, str", 0};
        Shiboken::setErrorAboutWrongArguments(args, "qmlRegisterType", overloads);
        return 0;
}


static PyMethodDef QtDeclarative_methods[] = {
    {"qmlRegisterType", (PyCFunction)SbkQtDeclarativeModule_qmlRegisterType, METH_VARARGS},
    {0} // Sentinel
};

// Classes initialization functions ------------------------------------------------------------
void init_QDeclarativeScriptString(PyObject* module);
void init_QDeclarativeProperty(PyObject* module);
void init_QDeclarativeNetworkAccessManagerFactory(PyObject* module);
void init_QDeclarativeImageProvider(PyObject* module);
void init_QDeclarativeExtensionInterface(PyObject* module);
void init_QDeclarativeError(PyObject* module);
void init_QDeclarativeListReference(PyObject* module);
void init_QDeclarativePropertyValueSource(PyObject* module);
void init_QDeclarativeParserStatus(PyObject* module);
void init_QDeclarativeView(PyObject* module);
void init_QDeclarativeItem(PyObject* module);
void init_QDeclarativePropertyMap(PyObject* module);
void init_QDeclarativeExtensionPlugin(PyObject* module);
void init_QDeclarativeExpression(PyObject* module);
void init_QDeclarativeEngine(PyObject* module);
void init_QDeclarativeContext(PyObject* module);
void init_QDeclarativeComponent(PyObject* module);

// Enum definitions ------------------------------------------------------------
PyTypeObject** SbkPySide_QtDeclarativeTypes;

PyTypeObject** SbkPySide_QtCoreTypes;

PyTypeObject** SbkPySide_QtNetworkTypes;

PyTypeObject** SbkPySide_QtGuiTypes;

// Module initialization ------------------------------------------------------------

#if defined _WIN32 || defined __CYGWIN__
    #define SBK_EXPORT_MODULE __declspec(dllexport)
#elif __GNUC__ >= 4
    #define SBK_EXPORT_MODULE __attribute__ ((visibility("default")))
#else
    #define SBK_EXPORT_MODULE
#endif

extern "C" SBK_EXPORT_MODULE void initQtDeclarative()
{

    if (!Shiboken::importModule("PySide.QtCore", &SbkPySide_QtCoreTypes)) {
        PyErr_SetString(PyExc_ImportError,"could not import PySide.QtCore");
        return;
    }

    if (!Shiboken::importModule("PySide.QtNetwork", &SbkPySide_QtNetworkTypes)) {
        PyErr_SetString(PyExc_ImportError,"could not import PySide.QtNetwork");
        return;
    }

    if (!Shiboken::importModule("PySide.QtGui", &SbkPySide_QtGuiTypes)) {
        PyErr_SetString(PyExc_ImportError,"could not import PySide.QtGui");
        return;
    }

    Shiboken::init();
    PyObject* module = Py_InitModule("QtDeclarative", QtDeclarative_methods);

    // Create a CObject containing the API pointer array's address
    static PyTypeObject* cppApi[SBK_QtDeclarative_IDX_COUNT];
    SbkPySide_QtDeclarativeTypes = cppApi;
    PyObject* cppApiObject = PyCObject_FromVoidPtr(reinterpret_cast<void*>(cppApi), 0);
    PyModule_AddObject(module, "_Cpp_Api", cppApiObject);

    // Initialize classes in the type system
    init_QDeclarativeScriptString(module);
    init_QDeclarativeProperty(module);
    init_QDeclarativeNetworkAccessManagerFactory(module);
    init_QDeclarativeImageProvider(module);
    init_QDeclarativeExtensionInterface(module);
    init_QDeclarativeError(module);
    init_QDeclarativeListReference(module);
    init_QDeclarativePropertyValueSource(module);
    init_QDeclarativeParserStatus(module);
    init_QDeclarativeView(module);
    init_QDeclarativeItem(module);
    init_QDeclarativePropertyMap(module);
    init_QDeclarativeExtensionPlugin(module);
    init_QDeclarativeExpression(module);
    init_QDeclarativeEngine(module);
    init_QDeclarativeContext(module);
    init_QDeclarativeComponent(module);

    // Initialize enums
    PyObject* enumItem;

    // init anonymous enum identified by enum value: QML_HAS_ATTACHED_PROPERTIES
    PyModule_AddIntConstant(module,"QML_HAS_ATTACHED_PROPERTIES", (long) QML_HAS_ATTACHED_PROPERTIES);
    // end of enum QML_HAS_ATTACHED_PROPERTIES

    // Register primitive types on TypeResolver
    Shiboken::TypeResolver::createValueTypeResolver<QList<QDeclarativeError> >("QList<QDeclarativeError>");

    if (PyErr_Occurred()) {
        PyErr_Print();
        Py_FatalError("can't initialize module QtDeclarative");
    }
    // Begin code injection

    Shiboken::TypeResolver::createValueTypeResolver< QList<QObject*> >("QList<QObject*>");
    PySide::initQmlSupport(module);

    // End of code injection


}

