/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qgradient_wrapper.h"

// Extra includes
#include <QPair>
#include <QVector>
#include <qbrush.h>
#include <qcolor.h>



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QGradient_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QGradient >()))
        return -1;

    QGradient* cptr = 0;
    int overloadId = -1;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QGradient", 0, 1, &(pyargs[0])))
        return -1;

    // Overloaded function decisor
    // 0: QGradient()
    // 1: QGradient(QGradient)
    if (numArgs == 0) {
        overloadId = 0; // QGradient()
    } else if (numArgs == 1 && Shiboken::Converter< ::QGradient >::isConvertible(pyargs[0])) {
        overloadId = 1; // QGradient(QGradient)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGradient_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QGradient()
            {

                if(!PyErr_Occurred()) {
                    // QGradient()
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QGradient();
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // QGradient(QGradient)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QGradient cppArg0 = Shiboken::Converter<QGradient >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QGradient(QGradient)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QGradient(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QGradient >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QGradient_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QGradient_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtGui.QGradient", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGradient", overloads);
        return -1;
}

static PyObject* Sbk_QGradientFunc_coordinateMode(PyObject* self)
{
    QGradient* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGradient* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // coordinateMode()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QGradient::CoordinateMode cppResult = const_cast<const QGradient*>(cppSelf)->coordinateMode();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QGradient::CoordinateMode >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGradientFunc_interpolationMode(PyObject* self)
{
    QGradient* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGradient* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // interpolationMode()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QGradient::InterpolationMode cppResult = const_cast<const QGradient*>(cppSelf)->interpolationMode();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QGradient::InterpolationMode >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGradientFunc_setColorAt(PyObject* self, PyObject* args)
{
    QGradient* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGradient* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setColorAt", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setColorAt(qreal,QColor)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && Shiboken::Converter< ::QColor >::isConvertible(pyargs[1])) {
        overloadId = 0; // setColorAt(qreal,QColor)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGradientFunc_setColorAt_TypeError;

    // Call function/method
    {
        {
            qreal cppArg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            QColor cppArg1 = Shiboken::Converter<QColor >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // setColorAt(qreal,QColor)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setColorAt(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGradientFunc_setColorAt_TypeError:
        const char* overloads[] = {"float, PySide.QtGui.QColor", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGradient.setColorAt", overloads);
        return 0;
}

static PyObject* Sbk_QGradientFunc_setCoordinateMode(PyObject* self, PyObject* arg)
{
    QGradient* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGradient* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setCoordinateMode(QGradient::CoordinateMode)
    if (Shiboken::Converter< ::QGradient::CoordinateMode >::isConvertible(arg)) {
        overloadId = 0; // setCoordinateMode(QGradient::CoordinateMode)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGradientFunc_setCoordinateMode_TypeError;

    // Call function/method
    {
        {
            QGradient::CoordinateMode cppArg0 = Shiboken::Converter<QGradient::CoordinateMode >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setCoordinateMode(QGradient::CoordinateMode)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setCoordinateMode(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGradientFunc_setCoordinateMode_TypeError:
        const char* overloads[] = {"PySide.QtGui.QGradient.CoordinateMode", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGradient.setCoordinateMode", overloads);
        return 0;
}

static PyObject* Sbk_QGradientFunc_setInterpolationMode(PyObject* self, PyObject* arg)
{
    QGradient* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGradient* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setInterpolationMode(QGradient::InterpolationMode)
    if (Shiboken::Converter< ::QGradient::InterpolationMode >::isConvertible(arg)) {
        overloadId = 0; // setInterpolationMode(QGradient::InterpolationMode)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGradientFunc_setInterpolationMode_TypeError;

    // Call function/method
    {
        {
            QGradient::InterpolationMode cppArg0 = Shiboken::Converter<QGradient::InterpolationMode >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setInterpolationMode(QGradient::InterpolationMode)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setInterpolationMode(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGradientFunc_setInterpolationMode_TypeError:
        const char* overloads[] = {"PySide.QtGui.QGradient.InterpolationMode", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGradient.setInterpolationMode", overloads);
        return 0;
}

static PyObject* Sbk_QGradientFunc_setSpread(PyObject* self, PyObject* arg)
{
    QGradient* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGradient* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setSpread(QGradient::Spread)
    if (Shiboken::Converter< ::QGradient::Spread >::isConvertible(arg)) {
        overloadId = 0; // setSpread(QGradient::Spread)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGradientFunc_setSpread_TypeError;

    // Call function/method
    {
        {
            QGradient::Spread cppArg0 = Shiboken::Converter<QGradient::Spread >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setSpread(QGradient::Spread)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setSpread(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGradientFunc_setSpread_TypeError:
        const char* overloads[] = {"PySide.QtGui.QGradient.Spread", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGradient.setSpread", overloads);
        return 0;
}

static PyObject* Sbk_QGradientFunc_setStops(PyObject* self, PyObject* arg)
{
    QGradient* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGradient* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setStops(QVector<QPair<qreal,QColor> >)
    if (Shiboken::Converter< ::QVector<QPair<qreal, QColor > > >::isConvertible(arg)) {
        overloadId = 0; // setStops(QVector<QPair<qreal,QColor> >)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGradientFunc_setStops_TypeError;

    // Call function/method
    {
        {
            QVector<QPair<qreal, QColor > > cppArg0 = Shiboken::Converter<QVector<QPair<qreal, QColor > > >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setStops(QVector<QPair<qreal,QColor> >)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setStops(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGradientFunc_setStops_TypeError:
        const char* overloads[] = {"list", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGradient.setStops", overloads);
        return 0;
}

static PyObject* Sbk_QGradientFunc_spread(PyObject* self)
{
    QGradient* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGradient* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // spread()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QGradient::Spread cppResult = const_cast<const QGradient*>(cppSelf)->spread();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QGradient::Spread >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGradientFunc_stops(PyObject* self)
{
    QGradient* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGradient* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // stops()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QVector<QPair<qreal, QColor > > cppResult = const_cast<const QGradient*>(cppSelf)->stops();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QVector<QPair<qreal, QColor > > >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGradientFunc_type(PyObject* self)
{
    QGradient* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGradient* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // type()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QGradient::Type cppResult = const_cast<const QGradient*>(cppSelf)->type();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QGradient::Type >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject *Sbk_QGradient___copy__(PyObject *self)
{
        QGradient* cppSelf = 0;
        if (!Shiboken::Object::isValid(self))
            return 0;
        cppSelf = Shiboken::Converter<QGradient*>::toCpp(self);
        PyObject* pyResult = 0;
        QGradient* copy = new QGradient(*cppSelf);
        pyResult = Shiboken::Converter<QGradient*>::toPython(copy);
        Shiboken::Object::getOwnership(pyResult);

        if (PyErr_Occurred() || !pyResult) {
            Py_XDECREF(pyResult);
            return 0;
        }
        return pyResult;
}

static PyMethodDef Sbk_QGradient_methods[] = {
    {"coordinateMode", (PyCFunction)Sbk_QGradientFunc_coordinateMode, METH_NOARGS},
    {"interpolationMode", (PyCFunction)Sbk_QGradientFunc_interpolationMode, METH_NOARGS},
    {"setColorAt", (PyCFunction)Sbk_QGradientFunc_setColorAt, METH_VARARGS},
    {"setCoordinateMode", (PyCFunction)Sbk_QGradientFunc_setCoordinateMode, METH_O},
    {"setInterpolationMode", (PyCFunction)Sbk_QGradientFunc_setInterpolationMode, METH_O},
    {"setSpread", (PyCFunction)Sbk_QGradientFunc_setSpread, METH_O},
    {"setStops", (PyCFunction)Sbk_QGradientFunc_setStops, METH_O},
    {"spread", (PyCFunction)Sbk_QGradientFunc_spread, METH_NOARGS},
    {"stops", (PyCFunction)Sbk_QGradientFunc_stops, METH_NOARGS},
    {"type", (PyCFunction)Sbk_QGradientFunc_type, METH_NOARGS},

    {"__copy__", (PyCFunction)Sbk_QGradient___copy__, METH_NOARGS},
    {0} // Sentinel
};

// Rich comparison
static PyObject* Sbk_QGradient_richcompare(PyObject* self, PyObject* arg, int op)
{
    PyObject* pyResult = 0;
    QGradient& cppSelf = *Shiboken::Converter< QGradient* >::toCpp(self);

    switch (op) {
        case Py_NE:
            if (Shiboken::Converter< ::QGradient >::isConvertible(arg)) {
                // operator!=(const QGradient & other) const
                QGradient cppArg0 = Shiboken::Converter< ::QGradient >::toCpp(arg);
                pyResult = Shiboken::Converter< bool >::toPython(cppSelf != cppArg0);
            } else goto Sbk_QGradient_RichComparison_TypeError;

            break;
        case Py_EQ:
            if (Shiboken::Converter< ::QGradient >::isConvertible(arg)) {
                // operator==(const QGradient & gradient)
                QGradient cppArg0 = Shiboken::Converter< ::QGradient >::toCpp(arg);
                pyResult = Shiboken::Converter< bool >::toPython(cppSelf == cppArg0);
            } else if (Shiboken::Converter< ::QGradient >::isConvertible(arg)) {
                // operator==(const QGradient & gradient) const
                QGradient cppArg0 = Shiboken::Converter< ::QGradient >::toCpp(arg);
                pyResult = Shiboken::Converter< bool >::toPython(cppSelf == cppArg0);
            } else goto Sbk_QGradient_RichComparison_TypeError;

            break;
        default:
            goto Sbk_QGradient_RichComparison_TypeError;
    }

    if (pyResult && !PyErr_Occurred())
        return pyResult;
    Sbk_QGradient_RichComparison_TypeError:
    PyErr_SetString(PyExc_NotImplementedError, "operator not implemented.");
    return 0;

}

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QGradient_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QGradient",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      Sbk_QGradient_richcompare,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QGradient_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QGradient_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QGradient(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QGRADIENT_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QGradient_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QGradient_Type);
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QGradient_Type, &Shiboken::callCppDestructor<QGradient >);
    if (PyType_Ready((PyTypeObject*)&Sbk_QGradient_Type) < 0)
        return;

    Shiboken::ObjectType::setOriginalName(&Sbk_QGradient_Type, "QGradient");
    PyModule_AddObject(module, "QGradient",
        ((PyObject*)&Sbk_QGradient_Type));

    // Initialize enums
    PyObject* enumItem;

    // init enum: CoordinateMode
    PyTypeObject* SbkPySide_QtGui_QGradient_CoordinateMode = Shiboken::Enum::newType("PySide.QtGui.QGradient.CoordinateMode");
    SbkPySide_QtGuiTypes[SBK_QGRADIENT_COORDINATEMODE_IDX] = SbkPySide_QtGui_QGradient_CoordinateMode;
    if (PyType_Ready(SbkPySide_QtGui_QGradient_CoordinateMode) < 0)
        return;
    PyDict_SetItemString(Sbk_QGradient_Type.super.ht_type.tp_dict,
            "CoordinateMode",((PyObject*)SbkPySide_QtGui_QGradient_CoordinateMode));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QGradient_CoordinateMode,(long) QGradient::LogicalMode, "LogicalMode");
    PyDict_SetItemString(Sbk_QGradient_Type.super.ht_type.tp_dict,"LogicalMode", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QGradient_CoordinateMode->tp_dict,"LogicalMode", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QGradient_CoordinateMode,(long) QGradient::StretchToDeviceMode, "StretchToDeviceMode");
    PyDict_SetItemString(Sbk_QGradient_Type.super.ht_type.tp_dict,"StretchToDeviceMode", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QGradient_CoordinateMode->tp_dict,"StretchToDeviceMode", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QGradient_CoordinateMode,(long) QGradient::ObjectBoundingMode, "ObjectBoundingMode");
    PyDict_SetItemString(Sbk_QGradient_Type.super.ht_type.tp_dict,"ObjectBoundingMode", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QGradient_CoordinateMode->tp_dict,"ObjectBoundingMode", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QGradient::CoordinateMode");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::CoordinateMode");
    // end of enum CoordinateMode

    // init enum: Spread
    PyTypeObject* SbkPySide_QtGui_QGradient_Spread = Shiboken::Enum::newType("PySide.QtGui.QGradient.Spread");
    SbkPySide_QtGuiTypes[SBK_QGRADIENT_SPREAD_IDX] = SbkPySide_QtGui_QGradient_Spread;
    if (PyType_Ready(SbkPySide_QtGui_QGradient_Spread) < 0)
        return;
    PyDict_SetItemString(Sbk_QGradient_Type.super.ht_type.tp_dict,
            "Spread",((PyObject*)SbkPySide_QtGui_QGradient_Spread));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QGradient_Spread,(long) QGradient::PadSpread, "PadSpread");
    PyDict_SetItemString(Sbk_QGradient_Type.super.ht_type.tp_dict,"PadSpread", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QGradient_Spread->tp_dict,"PadSpread", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QGradient_Spread,(long) QGradient::ReflectSpread, "ReflectSpread");
    PyDict_SetItemString(Sbk_QGradient_Type.super.ht_type.tp_dict,"ReflectSpread", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QGradient_Spread->tp_dict,"ReflectSpread", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QGradient_Spread,(long) QGradient::RepeatSpread, "RepeatSpread");
    PyDict_SetItemString(Sbk_QGradient_Type.super.ht_type.tp_dict,"RepeatSpread", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QGradient_Spread->tp_dict,"RepeatSpread", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QGradient::Spread");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::Spread");
    // end of enum Spread

    // init enum: Type
    PyTypeObject* SbkPySide_QtGui_QGradient_Type = Shiboken::Enum::newType("PySide.QtGui.QGradient.Type");
    SbkPySide_QtGuiTypes[SBK_QGRADIENT_TYPE_IDX] = SbkPySide_QtGui_QGradient_Type;
    if (PyType_Ready(SbkPySide_QtGui_QGradient_Type) < 0)
        return;
    PyDict_SetItemString(Sbk_QGradient_Type.super.ht_type.tp_dict,
            "Type",((PyObject*)SbkPySide_QtGui_QGradient_Type));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QGradient_Type,(long) QGradient::LinearGradient, "LinearGradient");
    PyDict_SetItemString(Sbk_QGradient_Type.super.ht_type.tp_dict,"LinearGradient", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QGradient_Type->tp_dict,"LinearGradient", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QGradient_Type,(long) QGradient::RadialGradient, "RadialGradient");
    PyDict_SetItemString(Sbk_QGradient_Type.super.ht_type.tp_dict,"RadialGradient", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QGradient_Type->tp_dict,"RadialGradient", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QGradient_Type,(long) QGradient::ConicalGradient, "ConicalGradient");
    PyDict_SetItemString(Sbk_QGradient_Type.super.ht_type.tp_dict,"ConicalGradient", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QGradient_Type->tp_dict,"ConicalGradient", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QGradient_Type,(long) QGradient::NoGradient, "NoGradient");
    PyDict_SetItemString(Sbk_QGradient_Type.super.ht_type.tp_dict,"NoGradient", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QGradient_Type->tp_dict,"NoGradient", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QGradient::Type");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::Type");
    // end of enum Type

    // init enum: InterpolationMode
    PyTypeObject* SbkPySide_QtGui_QGradient_InterpolationMode = Shiboken::Enum::newType("PySide.QtGui.QGradient.InterpolationMode");
    SbkPySide_QtGuiTypes[SBK_QGRADIENT_INTERPOLATIONMODE_IDX] = SbkPySide_QtGui_QGradient_InterpolationMode;
    if (PyType_Ready(SbkPySide_QtGui_QGradient_InterpolationMode) < 0)
        return;
    PyDict_SetItemString(Sbk_QGradient_Type.super.ht_type.tp_dict,
            "InterpolationMode",((PyObject*)SbkPySide_QtGui_QGradient_InterpolationMode));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QGradient_InterpolationMode,(long) QGradient::ColorInterpolation, "ColorInterpolation");
    PyDict_SetItemString(Sbk_QGradient_Type.super.ht_type.tp_dict,"ColorInterpolation", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QGradient_InterpolationMode->tp_dict,"ColorInterpolation", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QGradient_InterpolationMode,(long) QGradient::ComponentInterpolation, "ComponentInterpolation");
    PyDict_SetItemString(Sbk_QGradient_Type.super.ht_type.tp_dict,"ComponentInterpolation", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QGradient_InterpolationMode->tp_dict,"ComponentInterpolation", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QGradient::InterpolationMode");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::InterpolationMode");
    // end of enum InterpolationMode


    Shiboken::TypeResolver::createValueTypeResolver<QGradient >("QGradient");
    Shiboken::TypeResolver::createObjectTypeResolver<QGradient >("QGradient*");
    Shiboken::TypeResolver::createValueTypeResolver<QGradient >(typeid(QGradient).name());
    PySide::initQtMetaType< ::QGradient >();
    qRegisterMetaType< ::QGradient::CoordinateMode >("QGradient::CoordinateMode");
    qRegisterMetaType< ::QGradient::Spread >("QGradient::Spread");
    qRegisterMetaType< ::QGradient::Type >("QGradient::Type");
    qRegisterMetaType< ::QGradient::InterpolationMode >("QGradient::InterpolationMode");
}

