/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qiconengine_wrapper.h"

// Extra includes
#include <qpainter.h>
#include <qpixmap.h>
#include <qrect.h>
#include <qsize.h>


// Native ---------------------------------------------------------

QIconEngineWrapper::QIconEngineWrapper() : QIconEngine() {
    // ... middle
}

QSize QIconEngineWrapper::actualSize(const QSize & size, QIcon::Mode mode, QIcon::State state)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return QSize();
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "actualSize"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QIconEngine::actualSize(size, mode, state);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NNN)",
        Shiboken::Converter< ::QSize >::toPython(size),
        Shiboken::Converter< ::QIcon::Mode >::toPython(mode),
        Shiboken::Converter< ::QIcon::State >::toPython(state)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QSize();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QSize >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QIconEngine.actualSize", Shiboken::SbkType<QSize >()->tp_name, pyResult->ob_type->tp_name);
        return QSize();
    }
    QSize cppResult(Shiboken::Converter< ::QSize >::toCpp(pyResult));
    return cppResult;
}

void QIconEngineWrapper::addFile(const QString & fileName, const QSize & size, QIcon::Mode mode, QIcon::State state)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "addFile"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QIconEngine::addFile(fileName, size, mode, state);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NNNN)",
        Shiboken::Converter< QString >::toPython(fileName),
        Shiboken::Converter< ::QSize >::toPython(size),
        Shiboken::Converter< ::QIcon::Mode >::toPython(mode),
        Shiboken::Converter< ::QIcon::State >::toPython(state)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QIconEngineWrapper::addPixmap(const QPixmap & pixmap, QIcon::Mode mode, QIcon::State state)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "addPixmap"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QIconEngine::addPixmap(pixmap, mode, state);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NNN)",
        Shiboken::Converter< ::QPixmap >::toPython(pixmap),
        Shiboken::Converter< ::QIcon::Mode >::toPython(mode),
        Shiboken::Converter< ::QIcon::State >::toPython(state)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QIconEngineWrapper::paint(QPainter * painter, const QRect & rect, QIcon::Mode mode, QIcon::State state)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "paint"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QIconEngine.paint()' not implemented.");
        return ;
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NNNN)",
        Shiboken::Converter< ::QPainter * >::toPython(painter),
        Shiboken::Converter< ::QRect >::toPython(rect),
        Shiboken::Converter< ::QIcon::Mode >::toPython(mode),
        Shiboken::Converter< ::QIcon::State >::toPython(state)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

QPixmap QIconEngineWrapper::pixmap(const QSize & size, QIcon::Mode mode, QIcon::State state)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return QPixmap();
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "pixmap"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QIconEngine::pixmap(size, mode, state);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NNN)",
        Shiboken::Converter< ::QSize >::toPython(size),
        Shiboken::Converter< ::QIcon::Mode >::toPython(mode),
        Shiboken::Converter< ::QIcon::State >::toPython(state)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QPixmap();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QPixmap >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QIconEngine.pixmap", Shiboken::SbkType<QPixmap >()->tp_name, pyResult->ob_type->tp_name);
        return QPixmap();
    }
    QPixmap cppResult(Shiboken::Converter< ::QPixmap >::toCpp(pyResult));
    return cppResult;
}

QIconEngineWrapper::~QIconEngineWrapper()
{
    SbkObject* wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QIconEngine_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QIconEngine >()))
        return -1;

    QIconEngineWrapper* cptr = 0;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);
    SbkObjectType* type = reinterpret_cast<SbkObjectType*>(self->ob_type);
    SbkObjectType* myType = reinterpret_cast<SbkObjectType*>(SbkPySide_QtGuiTypes[SBK_QICONENGINE_IDX]);
    if (type == myType) {
        PyErr_SetString(PyExc_NotImplementedError,
            "'QIconEngine' represents a C++ abstract class and cannot be instantiated");
        return -1;
    }


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // QIconEngine()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new QIconEngineWrapper();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QIconEngine >(), cptr)) {
        delete cptr;
        return -1;
    }
    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject* Sbk_QIconEngineFunc_actualSize(PyObject* self, PyObject* args)
{
    QIconEngine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QIconEngine* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "actualSize", 3, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: actualSize(QSize,QIcon::Mode,QIcon::State)
    if (numArgs == 3 && Shiboken::Converter< ::QSize >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QIcon::Mode >::isConvertible(pyargs[1]) && Shiboken::Converter< ::QIcon::State >::isConvertible(pyargs[2])) {
        overloadId = 0; // actualSize(QSize,QIcon::Mode,QIcon::State)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QIconEngineFunc_actualSize_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QSize cppArg0 = Shiboken::Converter<QSize >::toCpp(pyargs[0]);
            QIcon::Mode cppArg1 = Shiboken::Converter<QIcon::Mode >::toCpp(pyargs[1]);
            QIcon::State cppArg2 = Shiboken::Converter<QIcon::State >::toCpp(pyargs[2]);

            if(!PyErr_Occurred()) {
                // actualSize(QSize,QIcon::Mode,QIcon::State)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QSize cppResult = (Shiboken::Object::isUserType(self) ? cppSelf->::QIconEngine::actualSize(cppArg0, cppArg1, cppArg2) : cppSelf->actualSize(cppArg0, cppArg1, cppArg2));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QSize >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QIconEngineFunc_actualSize_TypeError:
        const char* overloads[] = {"PySide.QtCore.QSize, PySide.QtGui.QIcon.Mode, PySide.QtGui.QIcon.State", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QIconEngine.actualSize", overloads);
        return 0;
}

static PyObject* Sbk_QIconEngineFunc_addFile(PyObject* self, PyObject* args)
{
    QIconEngine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QIconEngine* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "addFile", 4, 4, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: addFile(QString,QSize,QIcon::Mode,QIcon::State)
    if (numArgs == 4 && Shiboken::Converter< QString >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QSize >::isConvertible(pyargs[1]) && Shiboken::Converter< ::QIcon::Mode >::isConvertible(pyargs[2]) && Shiboken::Converter< ::QIcon::State >::isConvertible(pyargs[3])) {
        overloadId = 0; // addFile(QString,QSize,QIcon::Mode,QIcon::State)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QIconEngineFunc_addFile_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            QSize cppArg1 = Shiboken::Converter<QSize >::toCpp(pyargs[1]);
            QIcon::Mode cppArg2 = Shiboken::Converter<QIcon::Mode >::toCpp(pyargs[2]);
            QIcon::State cppArg3 = Shiboken::Converter<QIcon::State >::toCpp(pyargs[3]);

            if(!PyErr_Occurred()) {
                // addFile(QString,QSize,QIcon::Mode,QIcon::State)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QIconEngine::addFile(cppArg0, cppArg1, cppArg2, cppArg3) : cppSelf->addFile(cppArg0, cppArg1, cppArg2, cppArg3));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QIconEngineFunc_addFile_TypeError:
        const char* overloads[] = {"QString, PySide.QtCore.QSize, PySide.QtGui.QIcon.Mode, PySide.QtGui.QIcon.State", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QIconEngine.addFile", overloads);
        return 0;
}

static PyObject* Sbk_QIconEngineFunc_addPixmap(PyObject* self, PyObject* args)
{
    QIconEngine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QIconEngine* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "addPixmap", 3, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: addPixmap(QPixmap,QIcon::Mode,QIcon::State)
    if (numArgs == 3 && Shiboken::Converter< ::QPixmap >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QIcon::Mode >::isConvertible(pyargs[1]) && Shiboken::Converter< ::QIcon::State >::isConvertible(pyargs[2])) {
        overloadId = 0; // addPixmap(QPixmap,QIcon::Mode,QIcon::State)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QIconEngineFunc_addPixmap_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QPixmap cppArg0 = Shiboken::Converter<QPixmap >::toCpp(pyargs[0]);
            QIcon::Mode cppArg1 = Shiboken::Converter<QIcon::Mode >::toCpp(pyargs[1]);
            QIcon::State cppArg2 = Shiboken::Converter<QIcon::State >::toCpp(pyargs[2]);

            if(!PyErr_Occurred()) {
                // addPixmap(QPixmap,QIcon::Mode,QIcon::State)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QIconEngine::addPixmap(cppArg0, cppArg1, cppArg2) : cppSelf->addPixmap(cppArg0, cppArg1, cppArg2));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QIconEngineFunc_addPixmap_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPixmap, PySide.QtGui.QIcon.Mode, PySide.QtGui.QIcon.State", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QIconEngine.addPixmap", overloads);
        return 0;
}

static PyObject* Sbk_QIconEngineFunc_paint(PyObject* self, PyObject* args)
{
    QIconEngine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QIconEngine* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "paint", 4, 4, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: paint(QPainter*,QRect,QIcon::Mode,QIcon::State)
    if (numArgs == 4 && Shiboken::Converter< ::QPainter * >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QRect >::isConvertible(pyargs[1]) && Shiboken::Converter< ::QIcon::Mode >::isConvertible(pyargs[2]) && Shiboken::Converter< ::QIcon::State >::isConvertible(pyargs[3])) {
        overloadId = 0; // paint(QPainter*,QRect,QIcon::Mode,QIcon::State)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QIconEngineFunc_paint_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QPainter * cppArg0 = Shiboken::Converter<QPainter * >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            QRect cppArg1 = Shiboken::Converter<QRect >::toCpp(pyargs[1]);
            QIcon::Mode cppArg2 = Shiboken::Converter<QIcon::Mode >::toCpp(pyargs[2]);
            QIcon::State cppArg3 = Shiboken::Converter<QIcon::State >::toCpp(pyargs[3]);

            if(!PyErr_Occurred()) {
                // paint(QPainter*,QRect,QIcon::Mode,QIcon::State)
                if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self))) {
                    PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QIconEngine.paint()' not implemented.");
                    return 0;
                }
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->paint(cppArg0, cppArg1, cppArg2, cppArg3);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QIconEngineFunc_paint_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPainter, PySide.QtCore.QRect, PySide.QtGui.QIcon.Mode, PySide.QtGui.QIcon.State", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QIconEngine.paint", overloads);
        return 0;
}

static PyObject* Sbk_QIconEngineFunc_pixmap(PyObject* self, PyObject* args)
{
    QIconEngine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QIconEngine* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "pixmap", 3, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: pixmap(QSize,QIcon::Mode,QIcon::State)
    if (numArgs == 3 && Shiboken::Converter< ::QSize >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QIcon::Mode >::isConvertible(pyargs[1]) && Shiboken::Converter< ::QIcon::State >::isConvertible(pyargs[2])) {
        overloadId = 0; // pixmap(QSize,QIcon::Mode,QIcon::State)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QIconEngineFunc_pixmap_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QSize cppArg0 = Shiboken::Converter<QSize >::toCpp(pyargs[0]);
            QIcon::Mode cppArg1 = Shiboken::Converter<QIcon::Mode >::toCpp(pyargs[1]);
            QIcon::State cppArg2 = Shiboken::Converter<QIcon::State >::toCpp(pyargs[2]);

            if(!PyErr_Occurred()) {
                // pixmap(QSize,QIcon::Mode,QIcon::State)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QPixmap cppResult = (Shiboken::Object::isUserType(self) ? cppSelf->::QIconEngine::pixmap(cppArg0, cppArg1, cppArg2) : cppSelf->pixmap(cppArg0, cppArg1, cppArg2));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QPixmap >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QIconEngineFunc_pixmap_TypeError:
        const char* overloads[] = {"PySide.QtCore.QSize, PySide.QtGui.QIcon.Mode, PySide.QtGui.QIcon.State", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QIconEngine.pixmap", overloads);
        return 0;
}

static PyMethodDef Sbk_QIconEngine_methods[] = {
    {"actualSize", (PyCFunction)Sbk_QIconEngineFunc_actualSize, METH_VARARGS},
    {"addFile", (PyCFunction)Sbk_QIconEngineFunc_addFile, METH_VARARGS},
    {"addPixmap", (PyCFunction)Sbk_QIconEngineFunc_addPixmap, METH_VARARGS},
    {"paint", (PyCFunction)Sbk_QIconEngineFunc_paint, METH_VARARGS},
    {"pixmap", (PyCFunction)Sbk_QIconEngineFunc_pixmap, METH_VARARGS},

    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QIconEngine_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QIconEngine",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QIconEngine_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QIconEngine_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QIconEngine(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QICONENGINE_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QIconEngine_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QIconEngine_Type);
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QIconEngine_Type, &Shiboken::callCppDestructor<QIconEngine >);
    if (PyType_Ready((PyTypeObject*)&Sbk_QIconEngine_Type) < 0)
        return;

    // Fill type discovery information

    Shiboken::ObjectType::setOriginalName(&Sbk_QIconEngine_Type, "QIconEngine*");
    PyModule_AddObject(module, "QIconEngine",
        ((PyObject*)&Sbk_QIconEngine_Type));


    Shiboken::TypeResolver::createObjectTypeResolver<QIconEngine >("QIconEngine*");
    Shiboken::TypeResolver::createObjectTypeResolver<QIconEngine >("QIconEngine$ConcreteWrapper*");
    Shiboken::TypeResolver::createObjectTypeResolver<QIconEngine >(typeid(QIconEngine).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QIconEngine >(typeid(QIconEngineWrapper).name());
    PySide::initQtMetaType< ::QIconEngine* >();
}

