/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include "pyside_qtgui_python.h"

#include "qitemselectionmodel_wrapper.h"

// Extra includes
#include <QList>
#include <qabstractitemmodel.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qitemselectionmodel.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qthread.h>


// Native ---------------------------------------------------------

QItemSelectionModelWrapper::QItemSelectionModelWrapper(QAbstractItemModel * model) : QItemSelectionModel(model) {
    // ... middle
}

QItemSelectionModelWrapper::QItemSelectionModelWrapper(QAbstractItemModel * model, QObject * parent) : QItemSelectionModel(model, parent) {
    // ... middle
}

void QItemSelectionModelWrapper::childEvent(QChildEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "childEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::childEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QChildEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QItemSelectionModelWrapper::clear()
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "clear"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QItemSelectionModel::clear();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QItemSelectionModelWrapper::connectNotify(const char * signal)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "connectNotify"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QItemSelectionModelWrapper::customEvent(QEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "customEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::customEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QItemSelectionModelWrapper::disconnectNotify(const char * signal)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "disconnectNotify"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

bool QItemSelectionModelWrapper::event(QEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return bool(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "event"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::event(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QItemSelectionModel.event", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
    return cppResult;
}

bool QItemSelectionModelWrapper::eventFilter(QObject * arg__1, QEvent * arg__2)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return bool(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "eventFilter"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::eventFilter(arg__1, arg__2);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter< ::QObject * >::toPython(arg__1),
        Shiboken::Converter< ::QEvent * >::toPython(arg__2)
    ));
    bool invalidadeArg2 = PyTuple_GET_ITEM(pyargs, 1)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QItemSelectionModel.eventFilter", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    if (invalidadeArg2)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 1));
    return cppResult;
}

void QItemSelectionModelWrapper::reset()
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "reset"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QItemSelectionModel::reset();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QItemSelectionModelWrapper::select(const QItemSelection & selection, QFlags<QItemSelectionModel::SelectionFlag> command)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "select"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QItemSelectionModel::select(selection, command);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter< ::QItemSelection >::toPython(selection),
        Shiboken::Converter< ::QFlags<QItemSelectionModel::SelectionFlag> >::toPython(command)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QItemSelectionModelWrapper::select(const QModelIndex & index, QFlags<QItemSelectionModel::SelectionFlag> command)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "select"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QItemSelectionModel::select(index, command);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter< ::QModelIndex >::toPython(index),
        Shiboken::Converter< ::QFlags<QItemSelectionModel::SelectionFlag> >::toPython(command)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QItemSelectionModelWrapper::timerEvent(QTimerEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "timerEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::timerEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QTimerEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

const QMetaObject* QItemSelectionModelWrapper::metaObject() const
{
    SbkObject* pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    return reinterpret_cast<QMetaObject*>(Shiboken::Object::getTypeUserData(pySelf));
}

int QItemSelectionModelWrapper::qt_metacall(QMetaObject::Call call, int id, void** args)
{
    int result = QItemSelectionModel::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

QItemSelectionModelWrapper::~QItemSelectionModelWrapper()
{
    SbkObject* wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QItemSelectionModel_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QItemSelectionModel >()))
        return -1;

    QItemSelectionModelWrapper* cptr = 0;
    int overloadId = -1;
    const char** argNames = 0;
    const QMetaObject* metaObject;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QItemSelectionModel", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return -1;

    // Overloaded function decisor
    // 0: QItemSelectionModel(QAbstractItemModel*)
    // 1: QItemSelectionModel(QAbstractItemModel*,QObject*)
    if (Shiboken::Converter< ::QAbstractItemModel * >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // QItemSelectionModel(QAbstractItemModel*)
        } else if (numArgs == 2 && Shiboken::Converter< ::QObject * >::isConvertible(pyargs[1])) {
            overloadId = 1; // QItemSelectionModel(QAbstractItemModel*,QObject*)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QItemSelectionModel_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QItemSelectionModel(QAbstractItemModel*)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QAbstractItemModel * cppArg0 = Shiboken::Converter<QAbstractItemModel * >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QItemSelectionModel(QAbstractItemModel*)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QItemSelectionModelWrapper(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // QItemSelectionModel(QAbstractItemModel*,QObject*)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QAbstractItemModel * cppArg0 = Shiboken::Converter<QAbstractItemModel * >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return -1;
                QObject * cppArg1 = Shiboken::Converter<QObject * >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // QItemSelectionModel(QAbstractItemModel*,QObject*)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QItemSelectionModelWrapper(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    Shiboken::Object::setParent(pyargs[1], self);
                }
                break;
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QItemSelectionModel >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QItemSelectionModel_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    metaObject = cptr->metaObject(); // <- init python qt properties
    if (kwds && !PySide::fillQtProperties(self, metaObject, kwds, argNames, 0))
        return -1;


    return 1;

    Sbk_QItemSelectionModel_Init_TypeError:
        const char* overloads[] = {"PySide.QtCore.QAbstractItemModel", "PySide.QtCore.QAbstractItemModel, PySide.QtCore.QObject", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QItemSelectionModel", overloads);
        return -1;
}

static PyObject* Sbk_QItemSelectionModelFunc_clear(PyObject* self)
{
    QItemSelectionModel* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QItemSelectionModel* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // clear()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QItemSelectionModel::clear() : cppSelf->clear());
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QItemSelectionModelFunc_clearSelection(PyObject* self)
{
    QItemSelectionModel* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QItemSelectionModel* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // clearSelection()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->clearSelection();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QItemSelectionModelFunc_columnIntersectsSelection(PyObject* self, PyObject* args)
{
    QItemSelectionModel* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QItemSelectionModel* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "columnIntersectsSelection", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: columnIntersectsSelection(int,QModelIndex)const
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && Shiboken::Converter< ::QModelIndex >::isConvertible(pyargs[1])) {
        overloadId = 0; // columnIntersectsSelection(int,QModelIndex)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QItemSelectionModelFunc_columnIntersectsSelection_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            QModelIndex cppArg1 = Shiboken::Converter<QModelIndex >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // columnIntersectsSelection(int,QModelIndex)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QItemSelectionModel*>(cppSelf)->columnIntersectsSelection(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QItemSelectionModelFunc_columnIntersectsSelection_TypeError:
        const char* overloads[] = {"int, PySide.QtCore.QModelIndex", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QItemSelectionModel.columnIntersectsSelection", overloads);
        return 0;
}

static PyObject* Sbk_QItemSelectionModelFunc_currentIndex(PyObject* self)
{
    QItemSelectionModel* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QItemSelectionModel* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // currentIndex()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QModelIndex cppResult = const_cast<const QItemSelectionModel*>(cppSelf)->currentIndex();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QModelIndex >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QItemSelectionModelFunc_emitSelectionChanged(PyObject* self, PyObject* args)
{
    QItemSelectionModel* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QItemSelectionModel* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "emitSelectionChanged", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: emitSelectionChanged(QItemSelection,QItemSelection)
    if (numArgs == 2 && Shiboken::Converter< ::QItemSelection >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QItemSelection >::isConvertible(pyargs[1])) {
        overloadId = 0; // emitSelectionChanged(QItemSelection,QItemSelection)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QItemSelectionModelFunc_emitSelectionChanged_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QItemSelection cppArg0 = Shiboken::Converter<QItemSelection >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            QItemSelection cppArg1 = Shiboken::Converter<QItemSelection >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // emitSelectionChanged(QItemSelection,QItemSelection)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->emitSelectionChanged(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QItemSelectionModelFunc_emitSelectionChanged_TypeError:
        const char* overloads[] = {"PySide.QtGui.QItemSelection, PySide.QtGui.QItemSelection", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QItemSelectionModel.emitSelectionChanged", overloads);
        return 0;
}

static PyObject* Sbk_QItemSelectionModelFunc_hasSelection(PyObject* self)
{
    QItemSelectionModel* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QItemSelectionModel* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // hasSelection()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QItemSelectionModel*>(cppSelf)->hasSelection();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QItemSelectionModelFunc_isColumnSelected(PyObject* self, PyObject* args)
{
    QItemSelectionModel* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QItemSelectionModel* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "isColumnSelected", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: isColumnSelected(int,QModelIndex)const
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && Shiboken::Converter< ::QModelIndex >::isConvertible(pyargs[1])) {
        overloadId = 0; // isColumnSelected(int,QModelIndex)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QItemSelectionModelFunc_isColumnSelected_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            QModelIndex cppArg1 = Shiboken::Converter<QModelIndex >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // isColumnSelected(int,QModelIndex)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QItemSelectionModel*>(cppSelf)->isColumnSelected(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QItemSelectionModelFunc_isColumnSelected_TypeError:
        const char* overloads[] = {"int, PySide.QtCore.QModelIndex", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QItemSelectionModel.isColumnSelected", overloads);
        return 0;
}

static PyObject* Sbk_QItemSelectionModelFunc_isRowSelected(PyObject* self, PyObject* args)
{
    QItemSelectionModel* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QItemSelectionModel* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "isRowSelected", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: isRowSelected(int,QModelIndex)const
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && Shiboken::Converter< ::QModelIndex >::isConvertible(pyargs[1])) {
        overloadId = 0; // isRowSelected(int,QModelIndex)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QItemSelectionModelFunc_isRowSelected_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            QModelIndex cppArg1 = Shiboken::Converter<QModelIndex >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // isRowSelected(int,QModelIndex)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QItemSelectionModel*>(cppSelf)->isRowSelected(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QItemSelectionModelFunc_isRowSelected_TypeError:
        const char* overloads[] = {"int, PySide.QtCore.QModelIndex", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QItemSelectionModel.isRowSelected", overloads);
        return 0;
}

static PyObject* Sbk_QItemSelectionModelFunc_isSelected(PyObject* self, PyObject* arg)
{
    QItemSelectionModel* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QItemSelectionModel* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: isSelected(QModelIndex)const
    if (Shiboken::Converter< ::QModelIndex >::isConvertible(arg)) {
        overloadId = 0; // isSelected(QModelIndex)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QItemSelectionModelFunc_isSelected_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QModelIndex cppArg0 = Shiboken::Converter<QModelIndex >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // isSelected(QModelIndex)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QItemSelectionModel*>(cppSelf)->isSelected(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QItemSelectionModelFunc_isSelected_TypeError:
        const char* overloads[] = {"PySide.QtCore.QModelIndex", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QItemSelectionModel.isSelected", overloads);
        return 0;
}

static PyObject* Sbk_QItemSelectionModelFunc_model(PyObject* self)
{
    QItemSelectionModel* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QItemSelectionModel* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // model()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                const QAbstractItemModel * cppResult = const_cast<const QItemSelectionModel*>(cppSelf)->model();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QAbstractItemModel * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QItemSelectionModelFunc_reset(PyObject* self)
{
    QItemSelectionModel* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QItemSelectionModel* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // reset()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QItemSelectionModel::reset() : cppSelf->reset());
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QItemSelectionModelFunc_rowIntersectsSelection(PyObject* self, PyObject* args)
{
    QItemSelectionModel* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QItemSelectionModel* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "rowIntersectsSelection", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: rowIntersectsSelection(int,QModelIndex)const
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && Shiboken::Converter< ::QModelIndex >::isConvertible(pyargs[1])) {
        overloadId = 0; // rowIntersectsSelection(int,QModelIndex)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QItemSelectionModelFunc_rowIntersectsSelection_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            QModelIndex cppArg1 = Shiboken::Converter<QModelIndex >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // rowIntersectsSelection(int,QModelIndex)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QItemSelectionModel*>(cppSelf)->rowIntersectsSelection(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QItemSelectionModelFunc_rowIntersectsSelection_TypeError:
        const char* overloads[] = {"int, PySide.QtCore.QModelIndex", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QItemSelectionModel.rowIntersectsSelection", overloads);
        return 0;
}

static PyObject* Sbk_QItemSelectionModelFunc_select(PyObject* self, PyObject* args)
{
    QItemSelectionModel* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QItemSelectionModel* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "select", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: select(QItemSelection,QFlags<QItemSelectionModel::SelectionFlag>)
    // 1: select(QModelIndex,QFlags<QItemSelectionModel::SelectionFlag>)
    if (numArgs == 2 && Shiboken::Converter< ::QModelIndex >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QFlags<QItemSelectionModel::SelectionFlag> >::isConvertible(pyargs[1])) {
        overloadId = 1; // select(QModelIndex,QFlags<QItemSelectionModel::SelectionFlag>)
    } else if (numArgs == 2 && Shiboken::Converter< ::QItemSelection >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QFlags<QItemSelectionModel::SelectionFlag> >::isConvertible(pyargs[1])) {
        overloadId = 0; // select(QItemSelection,QFlags<QItemSelectionModel::SelectionFlag>)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QItemSelectionModelFunc_select_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // select(QItemSelection,QFlags<QItemSelectionModel::SelectionFlag>)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QItemSelection cppArg0 = Shiboken::Converter<QItemSelection >::toCpp(pyargs[0]);
                QFlags<QItemSelectionModel::SelectionFlag> cppArg1 = Shiboken::Converter<QFlags<QItemSelectionModel::SelectionFlag> >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // select(QItemSelection,QFlags<QItemSelectionModel::SelectionFlag>)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    (Shiboken::Object::isUserType(self) ? cppSelf->::QItemSelectionModel::select(cppArg0, cppArg1) : cppSelf->select(cppArg0, cppArg1));
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // select(QModelIndex,QFlags<QItemSelectionModel::SelectionFlag>)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QModelIndex cppArg0 = Shiboken::Converter<QModelIndex >::toCpp(pyargs[0]);
                QFlags<QItemSelectionModel::SelectionFlag> cppArg1 = Shiboken::Converter<QFlags<QItemSelectionModel::SelectionFlag> >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // select(QModelIndex,QFlags<QItemSelectionModel::SelectionFlag>)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    (Shiboken::Object::isUserType(self) ? cppSelf->::QItemSelectionModel::select(cppArg0, cppArg1) : cppSelf->select(cppArg0, cppArg1));
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QItemSelectionModelFunc_select_TypeError:
        const char* overloads[] = {"PySide.QtGui.QItemSelection, PySide.QtGui.QItemSelectionModel.SelectionFlags", "PySide.QtCore.QModelIndex, PySide.QtGui.QItemSelectionModel.SelectionFlags", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QItemSelectionModel.select", overloads);
        return 0;
}

static PyObject* Sbk_QItemSelectionModelFunc_selectedColumns(PyObject* self, PyObject* args, PyObject* kwds)
{
    QItemSelectionModel* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QItemSelectionModel* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QItemSelectionModel.selectedColumns(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:selectedColumns", &(pyargs[0])))
        return 0;


    // Overloaded function decisor
    // 0: selectedColumns(int)const
    if (numArgs == 0) {
        overloadId = 0; // selectedColumns(int)const
    } else if (SbkNumber_Check(pyargs[0])) {
        overloadId = 0; // selectedColumns(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QItemSelectionModelFunc_selectedColumns_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "row");
                if (value) {
                    if (pyargs[0])
                        errorArgName = "row";
                    else if (SbkNumber_Check(value))
                        pyargs[0] = value;
                    else
                        goto Sbk_QItemSelectionModelFunc_selectedColumns_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QItemSelectionModel.selectedColumns(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            int cppArg0 = pyargs[0] ? Shiboken::Converter<int >::toCpp(pyargs[0]) : 0;

            if(!PyErr_Occurred()) {
                // selectedColumns(int)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QList<QModelIndex > cppResult = const_cast<const QItemSelectionModel*>(cppSelf)->selectedColumns(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QList<QModelIndex > >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QItemSelectionModelFunc_selectedColumns_TypeError:
        const char* overloads[] = {"int = 0", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QItemSelectionModel.selectedColumns", overloads);
        return 0;
}

static PyObject* Sbk_QItemSelectionModelFunc_selectedIndexes(PyObject* self)
{
    QItemSelectionModel* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QItemSelectionModel* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // selectedIndexes()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QList<QModelIndex > cppResult = const_cast<const QItemSelectionModel*>(cppSelf)->selectedIndexes();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QList<QModelIndex > >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QItemSelectionModelFunc_selectedRows(PyObject* self, PyObject* args, PyObject* kwds)
{
    QItemSelectionModel* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QItemSelectionModel* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QItemSelectionModel.selectedRows(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:selectedRows", &(pyargs[0])))
        return 0;


    // Overloaded function decisor
    // 0: selectedRows(int)const
    if (numArgs == 0) {
        overloadId = 0; // selectedRows(int)const
    } else if (SbkNumber_Check(pyargs[0])) {
        overloadId = 0; // selectedRows(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QItemSelectionModelFunc_selectedRows_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "column");
                if (value) {
                    if (pyargs[0])
                        errorArgName = "column";
                    else if (SbkNumber_Check(value))
                        pyargs[0] = value;
                    else
                        goto Sbk_QItemSelectionModelFunc_selectedRows_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QItemSelectionModel.selectedRows(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            int cppArg0 = pyargs[0] ? Shiboken::Converter<int >::toCpp(pyargs[0]) : 0;

            if(!PyErr_Occurred()) {
                // selectedRows(int)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QList<QModelIndex > cppResult = const_cast<const QItemSelectionModel*>(cppSelf)->selectedRows(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QList<QModelIndex > >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QItemSelectionModelFunc_selectedRows_TypeError:
        const char* overloads[] = {"int = 0", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QItemSelectionModel.selectedRows", overloads);
        return 0;
}

static PyObject* Sbk_QItemSelectionModelFunc_selection(PyObject* self)
{
    QItemSelectionModel* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QItemSelectionModel* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // selection()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                const QItemSelection cppResult = const_cast<const QItemSelectionModel*>(cppSelf)->selection();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QItemSelection >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QItemSelectionModelFunc_setCurrentIndex(PyObject* self, PyObject* args)
{
    QItemSelectionModel* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QItemSelectionModel* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setCurrentIndex", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setCurrentIndex(QModelIndex,QFlags<QItemSelectionModel::SelectionFlag>)
    if (numArgs == 2 && Shiboken::Converter< ::QModelIndex >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QFlags<QItemSelectionModel::SelectionFlag> >::isConvertible(pyargs[1])) {
        overloadId = 0; // setCurrentIndex(QModelIndex,QFlags<QItemSelectionModel::SelectionFlag>)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QItemSelectionModelFunc_setCurrentIndex_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QModelIndex cppArg0 = Shiboken::Converter<QModelIndex >::toCpp(pyargs[0]);
            QFlags<QItemSelectionModel::SelectionFlag> cppArg1 = Shiboken::Converter<QFlags<QItemSelectionModel::SelectionFlag> >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // setCurrentIndex(QModelIndex,QFlags<QItemSelectionModel::SelectionFlag>)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setCurrentIndex(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QItemSelectionModelFunc_setCurrentIndex_TypeError:
        const char* overloads[] = {"PySide.QtCore.QModelIndex, PySide.QtGui.QItemSelectionModel.SelectionFlags", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QItemSelectionModel.setCurrentIndex", overloads);
        return 0;
}

static PyMethodDef Sbk_QItemSelectionModel_methods[] = {
    {"clear", (PyCFunction)Sbk_QItemSelectionModelFunc_clear, METH_NOARGS},
    {"clearSelection", (PyCFunction)Sbk_QItemSelectionModelFunc_clearSelection, METH_NOARGS},
    {"columnIntersectsSelection", (PyCFunction)Sbk_QItemSelectionModelFunc_columnIntersectsSelection, METH_VARARGS},
    {"currentIndex", (PyCFunction)Sbk_QItemSelectionModelFunc_currentIndex, METH_NOARGS},
    {"emitSelectionChanged", (PyCFunction)Sbk_QItemSelectionModelFunc_emitSelectionChanged, METH_VARARGS},
    {"hasSelection", (PyCFunction)Sbk_QItemSelectionModelFunc_hasSelection, METH_NOARGS},
    {"isColumnSelected", (PyCFunction)Sbk_QItemSelectionModelFunc_isColumnSelected, METH_VARARGS},
    {"isRowSelected", (PyCFunction)Sbk_QItemSelectionModelFunc_isRowSelected, METH_VARARGS},
    {"isSelected", (PyCFunction)Sbk_QItemSelectionModelFunc_isSelected, METH_O},
    {"model", (PyCFunction)Sbk_QItemSelectionModelFunc_model, METH_NOARGS},
    {"reset", (PyCFunction)Sbk_QItemSelectionModelFunc_reset, METH_NOARGS},
    {"rowIntersectsSelection", (PyCFunction)Sbk_QItemSelectionModelFunc_rowIntersectsSelection, METH_VARARGS},
    {"select", (PyCFunction)Sbk_QItemSelectionModelFunc_select, METH_VARARGS},
    {"selectedColumns", (PyCFunction)Sbk_QItemSelectionModelFunc_selectedColumns, METH_VARARGS|METH_KEYWORDS},
    {"selectedIndexes", (PyCFunction)Sbk_QItemSelectionModelFunc_selectedIndexes, METH_NOARGS},
    {"selectedRows", (PyCFunction)Sbk_QItemSelectionModelFunc_selectedRows, METH_VARARGS|METH_KEYWORDS},
    {"selection", (PyCFunction)Sbk_QItemSelectionModelFunc_selection, METH_NOARGS},
    {"setCurrentIndex", (PyCFunction)Sbk_QItemSelectionModelFunc_setCurrentIndex, METH_VARARGS},

    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QItemSelectionModel_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QItemSelectionModel",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QItemSelectionModel_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QItemSelectionModel_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern

static SbkObjectType* Sbk_QItemSelectionModel_typeDiscovery(void* cptr, SbkObjectType* instanceType)
{
    if (instanceType == reinterpret_cast<SbkObjectType*>(Shiboken::SbkType<QObject >()) && dynamic_cast<QItemSelectionModel*>(reinterpret_cast<QObject*>(cptr)))
        return &Sbk_QItemSelectionModel_Type;
    return 0;
}

PyObject* SbkPySide_QtGui_QItemSelectionModel_SelectionFlag___and__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QItemSelectionModel::SelectionFlags >::toPython(
        Shiboken::Converter<QItemSelectionModel::SelectionFlags>::toCpp(self)
        & Shiboken::Converter< QItemSelectionModel::SelectionFlags >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtGui_QItemSelectionModel_SelectionFlag___or__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QItemSelectionModel::SelectionFlags >::toPython(
        Shiboken::Converter<QItemSelectionModel::SelectionFlags>::toCpp(self)
        | Shiboken::Converter< QItemSelectionModel::SelectionFlags >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtGui_QItemSelectionModel_SelectionFlag___xor__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QItemSelectionModel::SelectionFlags >::toPython(
        Shiboken::Converter<QItemSelectionModel::SelectionFlags>::toCpp(self)
        ^ Shiboken::Converter< QItemSelectionModel::SelectionFlags >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtGui_QItemSelectionModel_SelectionFlag___invert__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QItemSelectionModel::SelectionFlags >::toPython(
        ~Shiboken::Converter<QItemSelectionModel::SelectionFlags >::toCpp(self)
    );
}


static PyNumberMethods SbkPySide_QtGui_QItemSelectionModel_SelectionFlag_as_number = {
    /*nb_add*/                  0,
    /*nb_subtract*/             0,
    /*nb_multiply*/             0,
    /*nb_divide*/               0,
    /*nb_remainder*/            0,
    /*nb_divmod*/               0,
    /*nb_power*/                0,
    /*nb_negative*/             0,
    /*nb_positive*/             0,
    /*nb_absolute*/             0,
    /*nb_nonzero*/              0,
    /*nb_invert*/               (unaryfunc)SbkPySide_QtGui_QItemSelectionModel_SelectionFlag___invert__,
    /*nb_lshift*/               0,
    /*nb_rshift*/               0,
    /*nb_and*/                  (binaryfunc)SbkPySide_QtGui_QItemSelectionModel_SelectionFlag___and__,
    /*nb_xor*/                  (binaryfunc)SbkPySide_QtGui_QItemSelectionModel_SelectionFlag___xor__,
    /*nb_or*/                   (binaryfunc)SbkPySide_QtGui_QItemSelectionModel_SelectionFlag___or__,
    /*nb_coerce*/               0,
    /*nb_int*/                  0,
    /*nb_long*/                 0,
    /*nb_float*/                0,
    /*nb_oct*/                  0,
    /*nb_hex*/                  0,
    /*nb_inplace_add*/          0,
    /*nb_inplace_subtract*/     0,
    /*nb_inplace_multiply*/     0,
    /*nb_inplace_divide*/       0,
    /*nb_inplace_remainder*/    0,
    /*nb_inplace_power*/        0,
    /*nb_inplace_lshift*/       0,
    /*nb_inplace_rshift*/       0,
    /*nb_inplace_and*/          0,
    /*nb_inplace_xor*/          0,
    /*nb_inplace_or*/           0,
    /*nb_floor_divide*/         0,
    /*nb_true_divide*/          0,
    /*nb_inplace_floor_divide*/ 0,
    /*nb_inplace_true_divide*/  0,
    /*nb_index*/                0
};


// forward declaration of new function
static PyTypeObject SbkPySide_QtGui_QItemSelectionModel_SelectionFlags_Type = {
    PyObject_HEAD_INIT(&PyType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "SelectionFlags",
    /*tp_basicsize*/        0,
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        &SbkPySide_QtGui_QItemSelectionModel_SelectionFlag_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT | Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              PyInt_Type.tp_new,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};



void init_QItemSelectionModel(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QITEMSELECTIONMODEL_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QItemSelectionModel_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QItemSelectionModel_Type);
    Shiboken::ObjectType::setSubTypeInitHook(&Sbk_QItemSelectionModel_Type, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(&Sbk_QItemSelectionModel_Type, &QItemSelectionModel::staticMetaObject);    Sbk_QItemSelectionModel_Type.super.ht_type.tp_base = SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX];
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QItemSelectionModel_Type, &Shiboken::callCppDestructor<QItemSelectionModel >);
    if (PyType_Ready((PyTypeObject*)&Sbk_QItemSelectionModel_Type) < 0)
        return;

    // Fill type discovery information
    Shiboken::ObjectType::setTypeDiscoveryFunction(&Sbk_QItemSelectionModel_Type, &Sbk_QItemSelectionModel_typeDiscovery);
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkObjectType*>(SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX]), &Sbk_QItemSelectionModel_Type);

    Shiboken::ObjectType::setOriginalName(&Sbk_QItemSelectionModel_Type, "QItemSelectionModel*");
    PyModule_AddObject(module, "QItemSelectionModel",
        ((PyObject*)&Sbk_QItemSelectionModel_Type));

    // Initialize enums
    PyObject* enumItem;

    // init enum: SelectionFlag
    PyTypeObject* SbkPySide_QtGui_QItemSelectionModel_SelectionFlag = Shiboken::Enum::newType("PySide.QtGui.QItemSelectionModel.SelectionFlag");
    SbkPySide_QtGui_QItemSelectionModel_SelectionFlag->tp_as_number = &SbkPySide_QtGui_QItemSelectionModel_SelectionFlag_as_number;
    SbkPySide_QtGuiTypes[SBK_QITEMSELECTIONMODEL_SELECTIONFLAG_IDX] = SbkPySide_QtGui_QItemSelectionModel_SelectionFlag;
    if (PyType_Ready(SbkPySide_QtGui_QItemSelectionModel_SelectionFlag) < 0)
        return;
    PyDict_SetItemString(Sbk_QItemSelectionModel_Type.super.ht_type.tp_dict,
            "SelectionFlag",((PyObject*)SbkPySide_QtGui_QItemSelectionModel_SelectionFlag));

    // init flags class: QFlags<QItemSelectionModel::SelectionFlag>
    SbkPySide_QtGuiTypes[SBK_QFLAGS_QITEMSELECTIONMODEL_SELECTIONFLAG__IDX] = &SbkPySide_QtGui_QItemSelectionModel_SelectionFlags_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtGui_QItemSelectionModel_SelectionFlags_Type) < 0)
        return;
    PyDict_SetItemString(Sbk_QItemSelectionModel_Type.super.ht_type.tp_dict,
            "SelectionFlags",((PyObject*)&SbkPySide_QtGui_QItemSelectionModel_SelectionFlags_Type));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QItemSelectionModel_SelectionFlag,(long) QItemSelectionModel::NoUpdate, "NoUpdate");
    PyDict_SetItemString(Sbk_QItemSelectionModel_Type.super.ht_type.tp_dict,"NoUpdate", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QItemSelectionModel_SelectionFlag->tp_dict,"NoUpdate", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QItemSelectionModel_SelectionFlag,(long) QItemSelectionModel::Clear, "Clear");
    PyDict_SetItemString(Sbk_QItemSelectionModel_Type.super.ht_type.tp_dict,"Clear", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QItemSelectionModel_SelectionFlag->tp_dict,"Clear", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QItemSelectionModel_SelectionFlag,(long) QItemSelectionModel::Select, "Select");
    PyDict_SetItemString(Sbk_QItemSelectionModel_Type.super.ht_type.tp_dict,"Select", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QItemSelectionModel_SelectionFlag->tp_dict,"Select", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QItemSelectionModel_SelectionFlag,(long) QItemSelectionModel::Deselect, "Deselect");
    PyDict_SetItemString(Sbk_QItemSelectionModel_Type.super.ht_type.tp_dict,"Deselect", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QItemSelectionModel_SelectionFlag->tp_dict,"Deselect", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QItemSelectionModel_SelectionFlag,(long) QItemSelectionModel::Toggle, "Toggle");
    PyDict_SetItemString(Sbk_QItemSelectionModel_Type.super.ht_type.tp_dict,"Toggle", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QItemSelectionModel_SelectionFlag->tp_dict,"Toggle", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QItemSelectionModel_SelectionFlag,(long) QItemSelectionModel::Current, "Current");
    PyDict_SetItemString(Sbk_QItemSelectionModel_Type.super.ht_type.tp_dict,"Current", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QItemSelectionModel_SelectionFlag->tp_dict,"Current", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QItemSelectionModel_SelectionFlag,(long) QItemSelectionModel::Rows, "Rows");
    PyDict_SetItemString(Sbk_QItemSelectionModel_Type.super.ht_type.tp_dict,"Rows", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QItemSelectionModel_SelectionFlag->tp_dict,"Rows", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QItemSelectionModel_SelectionFlag,(long) QItemSelectionModel::Columns, "Columns");
    PyDict_SetItemString(Sbk_QItemSelectionModel_Type.super.ht_type.tp_dict,"Columns", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QItemSelectionModel_SelectionFlag->tp_dict,"Columns", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QItemSelectionModel_SelectionFlag,(long) QItemSelectionModel::SelectCurrent, "SelectCurrent");
    PyDict_SetItemString(Sbk_QItemSelectionModel_Type.super.ht_type.tp_dict,"SelectCurrent", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QItemSelectionModel_SelectionFlag->tp_dict,"SelectCurrent", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QItemSelectionModel_SelectionFlag,(long) QItemSelectionModel::ToggleCurrent, "ToggleCurrent");
    PyDict_SetItemString(Sbk_QItemSelectionModel_Type.super.ht_type.tp_dict,"ToggleCurrent", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QItemSelectionModel_SelectionFlag->tp_dict,"ToggleCurrent", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QItemSelectionModel_SelectionFlag,(long) QItemSelectionModel::ClearAndSelect, "ClearAndSelect");
    PyDict_SetItemString(Sbk_QItemSelectionModel_Type.super.ht_type.tp_dict,"ClearAndSelect", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QItemSelectionModel_SelectionFlag->tp_dict,"ClearAndSelect", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QItemSelectionModel::SelectionFlag");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::SelectionFlag");
    // end of enum SelectionFlag

    // Initialize signals
    PySideSignal* signal_item;

    signal_item = PySide::Signal::newObject("currentColumnChanged", "QModelIndex,QModelIndex", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QItemSelectionModel_Type, "currentColumnChanged", signal_item);
    Py_DECREF((PyObject*) signal_item);
    signal_item = PySide::Signal::newObject("selectionChanged", "QItemSelection,QItemSelection", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QItemSelectionModel_Type, "selectionChanged", signal_item);
    Py_DECREF((PyObject*) signal_item);
    signal_item = PySide::Signal::newObject("currentRowChanged", "QModelIndex,QModelIndex", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QItemSelectionModel_Type, "currentRowChanged", signal_item);
    Py_DECREF((PyObject*) signal_item);
    signal_item = PySide::Signal::newObject("currentChanged", "QModelIndex,QModelIndex", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QItemSelectionModel_Type, "currentChanged", signal_item);
    Py_DECREF((PyObject*) signal_item);


    Shiboken::TypeResolver::createObjectTypeResolver<QItemSelectionModel >("QItemSelectionModel*");
    Shiboken::TypeResolver::createObjectTypeResolver<QItemSelectionModel >(typeid(QItemSelectionModel).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QItemSelectionModel >(typeid(QItemSelectionModelWrapper).name());
    PySide::initQtMetaType< ::QItemSelectionModel* >();
    qRegisterMetaType< ::QItemSelectionModel::SelectionFlag >("QItemSelectionModel::SelectionFlag");
    qRegisterMetaType< ::QItemSelectionModel::SelectionFlags >("QItemSelectionModel::SelectionFlags");
}

