/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qmatrix3x2_wrapper.h"

// Extra includes
#include <qgenericmatrix.h>



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QMatrix3x2_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QMatrix3x2 >()))
        return -1;

    QMatrix3x2* cptr = 0;
    int overloadId = -1;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QMatrix3x2", 1, 1, &(pyargs[0])))
        return -1;

    // Overloaded function decisor
    // 0: QMatrix3x2(PySequence*)
    // 1: QMatrix3x2(QMatrix3x2)
    if (numArgs == 1 && Shiboken::Converter< ::QMatrix3x2 >::isConvertible(pyargs[0])) {
        overloadId = 1; // QMatrix3x2(QMatrix3x2)
    } else if (numArgs == 1 && PySequence_Check(pyargs[0])) {
        overloadId = 0; // QMatrix3x2(PySequence*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QMatrix3x2_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QMatrix3x2(PySequence*)
            {

                if(!PyErr_Occurred()) {
                    // QMatrix3x2(PySequence*)
                    // Begin code injection

                    // TEMPLATE - matrix_constructor - START
                    if (PySequence_Size(pyargs[1-1]) == 6) {
                        Shiboken::AutoDecRef fast(PySequence_Fast(pyargs[1-1], "Fail to parse sequnce on QMatrix3x2 constructor."));
                        qreal values[6];
                        for(int i=0; i < 6; i++) {
                            PyObject *pv = PySequence_Fast_GET_ITEM(fast.object(), i);
                            values[i] = Shiboken::Converter<qreal >::toCpp(pv);
                        }
                        cptr = new QMatrix3x2(values);
                    }
                    // TEMPLATE - matrix_constructor - END

                    // End of code injection

                }
                break;
            }
            case 1: // QMatrix3x2(QMatrix3x2)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QMatrix3x2 cppArg0 = Shiboken::Converter<QMatrix3x2 >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QMatrix3x2(QMatrix3x2)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QMatrix3x2(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QMatrix3x2 >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QMatrix3x2_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QMatrix3x2_Init_TypeError:
        const char* overloads[] = {"PySequence", "PySide.QtGui.QMatrix3x2", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QMatrix3x2", overloads);
        return -1;
}

static PyObject* Sbk_QMatrix3x2Func___reduce__(PyObject* self)
{
    QMatrix3x2* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QMatrix3x2* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // __reduce__()
                // Begin code injection

                // TEMPLATE - reduce_code_matrix - START
                QList< qreal > cppArgs;
                qreal data[6];
                cppSelf->copyDataTo(data);
                int matrixSize = 6;
                for(int size=0; size < matrixSize; size++)
                cppArgs.append(data[size]);

                PyObject *type = PyObject_Type(self);
                PyObject *args = Py_BuildValue("(N)", Shiboken::Converter<QList<qreal>  >::toPython(cppArgs));
                pyResult = Py_BuildValue("(NN)", type, args);
                // TEMPLATE - reduce_code_matrix - END

                // End of code injection


            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QMatrix3x2Func___repr__(PyObject* self)
{
    QMatrix3x2* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QMatrix3x2* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // __repr__()
                // Begin code injection

                // TEMPLATE - repr_code_matrix - START
                QString format= QString("%1((").arg(((PyObject*)self)->ob_type->tp_name);

                QList< qreal > cppArgs;
                qreal data[6];
                cppSelf->copyDataTo(data);
                int matrixSize = 6;
                for(int size=0; size < matrixSize; size++) {
                if (size > 0)
                    format += ", ";
                format += QString::number(data[size]);
                }
                format += "))";

                pyResult = PyString_FromString(qPrintable(format));
                // TEMPLATE - repr_code_matrix - END

                // End of code injection


            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QMatrix3x2Func_data(PyObject* self)
{
    QMatrix3x2* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QMatrix3x2* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // data()
                // Begin code injection

                // TEMPLATE - matrix_data_function - START
                const qreal* data = cppSelf->constData();
                PyObject *pyData = PyTuple_New(6);
                if (data) {
                    for(int i=0; i < 6; i++)
                        PyTuple_SET_ITEM(pyData, i, Shiboken::Converter<qreal >::toPython(data[i]));
                }
                return pyData;
                // TEMPLATE - matrix_data_function - END

                // End of code injection


            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QMatrix3x2Func_fill(PyObject* self, PyObject* arg)
{
    QMatrix3x2* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QMatrix3x2* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: fill(PyObject*)
    if (PyObject_Check(arg)) {
        overloadId = 0; // fill(PyObject*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QMatrix3x2Func_fill_TypeError;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // fill(PyObject*)
                // Begin code injection

                // TEMPLATE - matrix_fill_function - START
                qreal value = Shiboken::Converter<qreal >::toCpp(arg);
                cppSelf->fill(value);
                // TEMPLATE - matrix_fill_function - END

                // End of code injection


            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QMatrix3x2Func_fill_TypeError:
        const char* overloads[] = {"PyObject", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QMatrix3x2.fill", overloads);
        return 0;
}

static PyObject* Sbk_QMatrix3x2Func_transposed(PyObject* self)
{
    QMatrix3x2* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QMatrix3x2* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // transposed()
                // Begin code injection

                // TEMPLATE - matrix_transposed_function - START
                return Shiboken::Converter<QMatrix2x3 >::toPython(cppSelf->transposed());
                // TEMPLATE - matrix_transposed_function - END

                // End of code injection


            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject *Sbk_QMatrix3x2___copy__(PyObject *self)
{
        QMatrix3x2* cppSelf = 0;
        if (!Shiboken::Object::isValid(self))
            return 0;
        cppSelf = Shiboken::Converter<QMatrix3x2*>::toCpp(self);
        PyObject* pyResult = 0;
        QMatrix3x2* copy = new QMatrix3x2(*cppSelf);
        pyResult = Shiboken::Converter<QMatrix3x2*>::toPython(copy);
        Shiboken::Object::getOwnership(pyResult);

        if (PyErr_Occurred() || !pyResult) {
            Py_XDECREF(pyResult);
            return 0;
        }
        return pyResult;
}

static PyMethodDef Sbk_QMatrix3x2_methods[] = {
    {"__reduce__", (PyCFunction)Sbk_QMatrix3x2Func___reduce__, METH_NOARGS},
    {"data", (PyCFunction)Sbk_QMatrix3x2Func_data, METH_NOARGS},
    {"fill", (PyCFunction)Sbk_QMatrix3x2Func_fill, METH_O},
    {"transposed", (PyCFunction)Sbk_QMatrix3x2Func_transposed, METH_NOARGS},

    {"__copy__", (PyCFunction)Sbk_QMatrix3x2___copy__, METH_NOARGS},
    {0} // Sentinel
};

static PyObject* Sbk_QMatrix3x2Func___imul__(PyObject* self, PyObject* arg)
{
    QMatrix3x2* cppSelf = 0;
    bool isReverse = Shiboken::Converter< ::QMatrix3x2 >::checkType(arg) && !Shiboken::Converter< ::QMatrix3x2 >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QMatrix3x2* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: operator*=(qreal)
    if (!isReverse && SbkNumber_Check(arg)) {
        overloadId = 0; // operator*=(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QMatrix3x2Func___imul___TypeError;

    // Call function/method
    {
        {
            qreal cppArg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // operator*=(qreal)
                // Begin code injection

                return Shiboken::Converter<QMatrix3x2 >::toPython(*cppSelf *= cppArg0);

                // End of code injection


            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_INCREF(self);
    return self;

    Sbk_QMatrix3x2Func___imul___TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QMatrix3x2.__imul__", overloads);
        return 0;
}

static PyObject* Sbk_QMatrix3x2Func___iadd__(PyObject* self, PyObject* arg)
{
    QMatrix3x2* cppSelf = 0;
    bool isReverse = Shiboken::Converter< ::QMatrix3x2 >::checkType(arg) && !Shiboken::Converter< ::QMatrix3x2 >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QMatrix3x2* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: operator+=(QMatrix3x2)
    if (!isReverse && Shiboken::Converter< ::QMatrix3x2 >::isConvertible(arg)) {
        overloadId = 0; // operator+=(QMatrix3x2)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QMatrix3x2Func___iadd___TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QMatrix3x2 cppArg0 = Shiboken::Converter<QMatrix3x2 >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // operator+=(QMatrix3x2)
                // Begin code injection

                return Shiboken::Converter<QMatrix3x2 >::toPython(*cppSelf += cppArg0);

                // End of code injection


            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_INCREF(self);
    return self;

    Sbk_QMatrix3x2Func___iadd___TypeError:
        const char* overloads[] = {"PySide.QtGui.QMatrix3x2", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QMatrix3x2.__iadd__", overloads);
        return 0;
}

static PyObject* Sbk_QMatrix3x2Func___isub__(PyObject* self, PyObject* arg)
{
    QMatrix3x2* cppSelf = 0;
    bool isReverse = Shiboken::Converter< ::QMatrix3x2 >::checkType(arg) && !Shiboken::Converter< ::QMatrix3x2 >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QMatrix3x2* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: operator-=(QMatrix3x2)
    if (!isReverse && Shiboken::Converter< ::QMatrix3x2 >::isConvertible(arg)) {
        overloadId = 0; // operator-=(QMatrix3x2)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QMatrix3x2Func___isub___TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QMatrix3x2 cppArg0 = Shiboken::Converter<QMatrix3x2 >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // operator-=(QMatrix3x2)
                // Begin code injection

                return Shiboken::Converter<QMatrix3x2 >::toPython(*cppSelf -= cppArg0);

                // End of code injection


            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_INCREF(self);
    return self;

    Sbk_QMatrix3x2Func___isub___TypeError:
        const char* overloads[] = {"PySide.QtGui.QMatrix3x2", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QMatrix3x2.__isub__", overloads);
        return 0;
}

static PyObject* Sbk_QMatrix3x2Func___idiv__(PyObject* self, PyObject* arg)
{
    QMatrix3x2* cppSelf = 0;
    bool isReverse = Shiboken::Converter< ::QMatrix3x2 >::checkType(arg) && !Shiboken::Converter< ::QMatrix3x2 >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QMatrix3x2* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: operator/=(qreal)
    if (!isReverse && SbkNumber_Check(arg)) {
        overloadId = 0; // operator/=(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QMatrix3x2Func___idiv___TypeError;

    // Call function/method
    {
        {
            qreal cppArg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // operator/=(qreal)
                // Begin code injection

                return Shiboken::Converter<QMatrix3x2 >::toPython(*cppSelf /= cppArg0);

                // End of code injection


            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_INCREF(self);
    return self;

    Sbk_QMatrix3x2Func___idiv___TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QMatrix3x2.__idiv__", overloads);
        return 0;
}

// type has number operators
static PyNumberMethods Sbk_QMatrix3x2_as_number = {
    /*nb_add*/                  (binaryfunc)0,
    /*nb_subtract*/             (binaryfunc)0,
    /*nb_multiply*/             (binaryfunc)0,
    /*nb_divide*/               (binaryfunc)0,
    /*nb_remainder*/            (binaryfunc)0,
    /*nb_divmod*/               0,
    /*nb_power*/                0,
    /*nb_negative*/             (unaryfunc)0,
    /*nb_positive*/             (unaryfunc)0,
    /*nb_absolute*/             0,
    /*nb_nonzero*/              0,
    /*nb_invert*/               (unaryfunc)0,
    /*nb_lshift*/               (binaryfunc)0,
    /*nb_rshift*/               (binaryfunc)0,
    /*nb_and*/                  (binaryfunc)0,
    /*nb_xor*/                  (binaryfunc)0,
    /*nb_or*/                   (binaryfunc)0,
    /*nb_coerce*/               0,
    /*nb_int*/                  0,
    /*nb_long*/                 0,
    /*nb_float*/                0,
    /*nb_oct*/                  0,
    /*nb_hex*/                  0,
    /*nb_inplace_add*/          (binaryfunc)Sbk_QMatrix3x2Func___iadd__,
    /*nb_inplace_subtract*/     (binaryfunc)Sbk_QMatrix3x2Func___isub__,
    /*nb_inplace_multiply*/     (binaryfunc)Sbk_QMatrix3x2Func___imul__,
    /*nb_inplace_divide*/       (binaryfunc)Sbk_QMatrix3x2Func___idiv__,
    /*nb_inplace_remainder*/    (binaryfunc)0,
    /*nb_inplace_power*/        0,
    /*nb_inplace_lshift*/       (binaryfunc)0,
    /*nb_inplace_rshift*/       (binaryfunc)0,
    /*nb_inplace_and*/          (binaryfunc)0,
    /*nb_inplace_xor*/          (binaryfunc)0,
    /*nb_inplace_or*/           (binaryfunc)0,
    /*nb_floor_divide*/         0,
    /*nb_true_divide*/          (binaryfunc)0,
    /*nb_inplace_floor_divide*/ 0,
    /*nb_inplace_true_divide*/  0,
    /*nb_index*/                0
};

// Rich comparison
static PyObject* Sbk_QMatrix3x2_richcompare(PyObject* self, PyObject* arg, int op)
{
    PyObject* pyResult = 0;
    QMatrix3x2& cppSelf = *Shiboken::Converter< QMatrix3x2* >::toCpp(self);

    switch (op) {
        case Py_NE:
            if (Shiboken::Converter< ::QMatrix3x2 >::isConvertible(arg)) {
                // operator!=(QMatrix3x2 arg__1)
                QMatrix3x2 cppArg0 = Shiboken::Converter< ::QMatrix3x2 >::toCpp(arg);
            } else goto Sbk_QMatrix3x2_RichComparison_TypeError;

            break;
        case Py_EQ:
            if (Shiboken::Converter< ::QMatrix3x2 >::isConvertible(arg)) {
                // operator==(QMatrix3x2 arg__1)
                QMatrix3x2 cppArg0 = Shiboken::Converter< ::QMatrix3x2 >::toCpp(arg);
            } else goto Sbk_QMatrix3x2_RichComparison_TypeError;

            break;
        default:
            goto Sbk_QMatrix3x2_RichComparison_TypeError;
    }

    if (pyResult && !PyErr_Occurred())
        return pyResult;
    Sbk_QMatrix3x2_RichComparison_TypeError:
    PyErr_SetString(PyExc_NotImplementedError, "operator not implemented.");
    return 0;

}

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QMatrix3x2_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QMatrix3x2",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Sbk_QMatrix3x2Func___repr__,
    /*tp_as_number*/        &Sbk_QMatrix3x2_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      Sbk_QMatrix3x2_richcompare,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QMatrix3x2_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QMatrix3x2_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QMatrix3x2(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QMATRIX3X2_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QMatrix3x2_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QMatrix3x2_Type);
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QMatrix3x2_Type, &Shiboken::callCppDestructor<QMatrix3x2 >);
    if (PyType_Ready((PyTypeObject*)&Sbk_QMatrix3x2_Type) < 0)
        return;

    Shiboken::ObjectType::setOriginalName(&Sbk_QMatrix3x2_Type, "QMatrix3x2");
    PyModule_AddObject(module, "QMatrix3x2",
        ((PyObject*)&Sbk_QMatrix3x2_Type));


    Shiboken::TypeResolver::createValueTypeResolver<QMatrix3x2 >("QMatrix3x2");
    Shiboken::TypeResolver::createObjectTypeResolver<QMatrix3x2 >("QMatrix3x2*");
    Shiboken::TypeResolver::createValueTypeResolver<QMatrix3x2 >(typeid(QMatrix3x2).name());
    PySide::initQtMetaType< ::QMatrix3x2 >();
}

