/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qprinter_wrapper.h"

// Extra includes
#include <QList>
#include <QPrinterInfo>
#include <qpaintengine.h>
#include <qprintengine.h>
#include <qprinter.h>
#include <qprinterinfo.h>
#include <qrect.h>
#include <qsize.h>


// Native ---------------------------------------------------------

QPrinterWrapper::QPrinterWrapper(QPrinter::PrinterMode mode) : QPrinter(mode) {
    // ... middle
}

QPrinterWrapper::QPrinterWrapper(const QPrinterInfo & printer, QPrinter::PrinterMode mode) : QPrinter(printer, mode) {
    // ... middle
}

int QPrinterWrapper::devType() const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return int(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "devType"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QPrinter::devType();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return int(0);
    }
    // Check return type
    bool typeIsValid = PyInt_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QPrinter.devType", "int", pyResult->ob_type->tp_name);
        return int(0);
    }
    int cppResult(Shiboken::Converter< int >::toCpp(pyResult));
    return cppResult;
}

int QPrinterWrapper::metric(QPaintDevice::PaintDeviceMetric arg__1) const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return int(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "metric"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QPrinter::metric(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QPaintDevice::PaintDeviceMetric >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return int(0);
    }
    // Check return type
    bool typeIsValid = PyInt_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QPrinter.metric", "int", pyResult->ob_type->tp_name);
        return int(0);
    }
    int cppResult(Shiboken::Converter< int >::toCpp(pyResult));
    return cppResult;
}

QPaintEngine * QPrinterWrapper::paintEngine() const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return 0;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "paintEngine"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QPrinter::paintEngine();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return 0;
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QPaintEngine * >::isConvertible(pyResult);
    typeIsValid = typeIsValid || (pyResult == Py_None);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QPrinter.paintEngine", Shiboken::SbkType<QPaintEngine >()->tp_name, pyResult->ob_type->tp_name);
        return 0;
    }
    QPaintEngine * cppResult(Shiboken::Converter< ::QPaintEngine * >::toCpp(pyResult));
    return cppResult;
}

QPrinterWrapper::~QPrinterWrapper()
{
    SbkObject* wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QPrinter_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QPrinter >()))
        return -1;

    QPrinterWrapper* cptr = 0;
    int overloadId = -1;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);

    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QPrinter(): too many arguments");
        return -1;
    }

    if (!PyArg_ParseTuple(args, "|OO:QPrinter", &(pyargs[0]), &(pyargs[1])))
        return -1;

    // Overloaded function decisor
    // 0: QPrinter(QPrinter::PrinterMode)
    // 1: QPrinter(QPrinterInfo,QPrinter::PrinterMode)
    if (numArgs == 0) {
        overloadId = 0; // QPrinter(QPrinter::PrinterMode)
    } else if (Shiboken::Converter< ::QPrinterInfo >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 1; // QPrinter(QPrinterInfo,QPrinter::PrinterMode)
        } else if (Shiboken::Converter< ::QPrinter::PrinterMode >::isConvertible(pyargs[1])) {
            overloadId = 1; // QPrinter(QPrinterInfo,QPrinter::PrinterMode)
        }
    } else if (Shiboken::Converter< ::QPrinter::PrinterMode >::isConvertible(pyargs[0])) {
        overloadId = 0; // QPrinter(QPrinter::PrinterMode)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPrinter_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QPrinter(QPrinter::PrinterMode)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "mode");
                    if (value) {
                        if (pyargs[0])
                            errorArgName = "mode";
                        else if (Shiboken::Converter< ::QPrinter::PrinterMode >::isConvertible(value))
                            pyargs[0] = value;
                        else
                            goto Sbk_QPrinter_Init_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPrinter(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                QPrinter::PrinterMode cppArg0 = pyargs[0] ? Shiboken::Converter<QPrinter::PrinterMode >::toCpp(pyargs[0]) : QPrinter::ScreenResolution;

                if(!PyErr_Occurred()) {
                    // QPrinter(QPrinter::PrinterMode)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QPrinterWrapper(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // QPrinter(QPrinterInfo,QPrinter::PrinterMode)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "mode");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "mode";
                        else if (Shiboken::Converter< ::QPrinter::PrinterMode >::isConvertible(value))
                            pyargs[1] = value;
                        else
                            goto Sbk_QPrinter_Init_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPrinter(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QPrinterInfo cppArg0 = Shiboken::Converter<QPrinterInfo >::toCpp(pyargs[0]);
                QPrinter::PrinterMode cppArg1 = pyargs[1] ? Shiboken::Converter<QPrinter::PrinterMode >::toCpp(pyargs[1]) : QPrinter::ScreenResolution;

                if(!PyErr_Occurred()) {
                    // QPrinter(QPrinterInfo,QPrinter::PrinterMode)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QPrinterWrapper(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QPrinter >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QPrinter_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QPrinter_Init_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPrinter.PrinterMode = ScreenResolution", "PySide.QtGui.QPrinterInfo, PySide.QtGui.QPrinter.PrinterMode = ScreenResolution", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPrinter", overloads);
        return -1;
}

static PyObject* Sbk_QPrinterFunc_abort(PyObject* self)
{
    QPrinter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPrinter* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // abort()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->abort();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPrinterFunc_actualNumCopies(PyObject* self)
{
    QPrinter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPrinter* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // actualNumCopies()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QPrinter*>(cppSelf)->actualNumCopies();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPrinterFunc_collateCopies(PyObject* self)
{
    QPrinter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPrinter* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // collateCopies()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QPrinter*>(cppSelf)->collateCopies();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPrinterFunc_colorMode(PyObject* self)
{
    QPrinter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPrinter* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // colorMode()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QPrinter::ColorMode cppResult = const_cast<const QPrinter*>(cppSelf)->colorMode();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QPrinter::ColorMode >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPrinterFunc_copyCount(PyObject* self)
{
    QPrinter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPrinter* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // copyCount()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QPrinter*>(cppSelf)->copyCount();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPrinterFunc_creator(PyObject* self)
{
    QPrinter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPrinter* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // creator()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QPrinter*>(cppSelf)->creator();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPrinterFunc_devType(PyObject* self)
{
    QPrinter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPrinter* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // devType()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = (Shiboken::Object::isUserType(self) ? const_cast<const QPrinter*>(cppSelf)->::QPrinter::devType() : const_cast<const QPrinter*>(cppSelf)->devType());
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPrinterFunc_docName(PyObject* self)
{
    QPrinter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPrinter* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // docName()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QPrinter*>(cppSelf)->docName();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPrinterFunc_doubleSidedPrinting(PyObject* self)
{
    QPrinter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPrinter* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // doubleSidedPrinting()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QPrinter*>(cppSelf)->doubleSidedPrinting();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPrinterFunc_duplex(PyObject* self)
{
    QPrinter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPrinter* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // duplex()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QPrinter::DuplexMode cppResult = const_cast<const QPrinter*>(cppSelf)->duplex();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QPrinter::DuplexMode >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPrinterFunc_fontEmbeddingEnabled(PyObject* self)
{
    QPrinter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPrinter* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // fontEmbeddingEnabled()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QPrinter*>(cppSelf)->fontEmbeddingEnabled();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPrinterFunc_fromPage(PyObject* self)
{
    QPrinter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPrinter* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // fromPage()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QPrinter*>(cppSelf)->fromPage();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPrinterFunc_fullPage(PyObject* self)
{
    QPrinter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPrinter* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // fullPage()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QPrinter*>(cppSelf)->fullPage();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPrinterFunc_isValid(PyObject* self)
{
    QPrinter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPrinter* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isValid()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QPrinter*>(cppSelf)->isValid();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPrinterFunc_metric(PyObject* self, PyObject* arg)
{
    QPrinter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPrinter* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: metric(QPaintDevice::PaintDeviceMetric)const
    if (Shiboken::Converter< ::QPaintDevice::PaintDeviceMetric >::isConvertible(arg)) {
        overloadId = 0; // metric(QPaintDevice::PaintDeviceMetric)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPrinterFunc_metric_TypeError;

    // Call function/method
    {
        {
            QPaintDevice::PaintDeviceMetric cppArg0 = Shiboken::Converter<QPaintDevice::PaintDeviceMetric >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // metric(QPaintDevice::PaintDeviceMetric)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = (Shiboken::Object::isUserType(self) ? const_cast<const QPrinter*>(cppSelf)->::QPrinter::metric(cppArg0) : const_cast<const QPrinter*>(cppSelf)->metric(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QPrinterFunc_metric_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPaintDevice.PaintDeviceMetric", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPrinter.metric", overloads);
        return 0;
}

static PyObject* Sbk_QPrinterFunc_newPage(PyObject* self)
{
    QPrinter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPrinter* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // newPage()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->newPage();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPrinterFunc_numCopies(PyObject* self)
{
    QPrinter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPrinter* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // numCopies()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QPrinter*>(cppSelf)->numCopies();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPrinterFunc_orientation(PyObject* self)
{
    QPrinter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPrinter* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // orientation()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QPrinter::Orientation cppResult = const_cast<const QPrinter*>(cppSelf)->orientation();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QPrinter::Orientation >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPrinterFunc_outputFileName(PyObject* self)
{
    QPrinter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPrinter* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // outputFileName()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QPrinter*>(cppSelf)->outputFileName();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPrinterFunc_outputFormat(PyObject* self)
{
    QPrinter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPrinter* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // outputFormat()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QPrinter::OutputFormat cppResult = const_cast<const QPrinter*>(cppSelf)->outputFormat();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QPrinter::OutputFormat >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPrinterFunc_pageOrder(PyObject* self)
{
    QPrinter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPrinter* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // pageOrder()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QPrinter::PageOrder cppResult = const_cast<const QPrinter*>(cppSelf)->pageOrder();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QPrinter::PageOrder >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPrinterFunc_pageRect(PyObject* self, PyObject* args)
{
    QPrinter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPrinter* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "pageRect", 0, 1, &(pyargs[0])))
        return 0;


    // Overloaded function decisor
    // 0: pageRect()const
    // 1: pageRect(QPrinter::Unit)const
    if (numArgs == 0) {
        overloadId = 0; // pageRect()const
    } else if (numArgs == 1 && Shiboken::Converter< ::QPrinter::Unit >::isConvertible(pyargs[0])) {
        overloadId = 1; // pageRect(QPrinter::Unit)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPrinterFunc_pageRect_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // pageRect()const
            {

                if(!PyErr_Occurred()) {
                    // pageRect()const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QRect cppResult = const_cast<const QPrinter*>(cppSelf)->pageRect();
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QRect >::toPython(cppResult);
                }
                break;
            }
            case 1: // pageRect(QPrinter::Unit)const
            {
                QPrinter::Unit cppArg0 = Shiboken::Converter<QPrinter::Unit >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // pageRect(QPrinter::Unit)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QRectF cppResult = const_cast<const QPrinter*>(cppSelf)->pageRect(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QRectF >::toPython(cppResult);
                }
                break;
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QPrinterFunc_pageRect_TypeError:
        const char* overloads[] = {"", "PySide.QtGui.QPrinter.Unit", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPrinter.pageRect", overloads);
        return 0;
}

static PyObject* Sbk_QPrinterFunc_pageSize(PyObject* self)
{
    QPrinter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPrinter* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // pageSize()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QPrinter::PageSize cppResult = const_cast<const QPrinter*>(cppSelf)->pageSize();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QPrinter::PageSize >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPrinterFunc_paintEngine(PyObject* self)
{
    QPrinter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPrinter* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // paintEngine()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QPaintEngine * cppResult = (Shiboken::Object::isUserType(self) ? const_cast<const QPrinter*>(cppSelf)->::QPrinter::paintEngine() : const_cast<const QPrinter*>(cppSelf)->paintEngine());
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QPaintEngine * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPrinterFunc_paperRect(PyObject* self, PyObject* args)
{
    QPrinter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPrinter* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "paperRect", 0, 1, &(pyargs[0])))
        return 0;


    // Overloaded function decisor
    // 0: paperRect()const
    // 1: paperRect(QPrinter::Unit)const
    if (numArgs == 0) {
        overloadId = 0; // paperRect()const
    } else if (numArgs == 1 && Shiboken::Converter< ::QPrinter::Unit >::isConvertible(pyargs[0])) {
        overloadId = 1; // paperRect(QPrinter::Unit)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPrinterFunc_paperRect_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // paperRect()const
            {

                if(!PyErr_Occurred()) {
                    // paperRect()const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QRect cppResult = const_cast<const QPrinter*>(cppSelf)->paperRect();
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QRect >::toPython(cppResult);
                }
                break;
            }
            case 1: // paperRect(QPrinter::Unit)const
            {
                QPrinter::Unit cppArg0 = Shiboken::Converter<QPrinter::Unit >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // paperRect(QPrinter::Unit)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QRectF cppResult = const_cast<const QPrinter*>(cppSelf)->paperRect(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QRectF >::toPython(cppResult);
                }
                break;
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QPrinterFunc_paperRect_TypeError:
        const char* overloads[] = {"", "PySide.QtGui.QPrinter.Unit", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPrinter.paperRect", overloads);
        return 0;
}

static PyObject* Sbk_QPrinterFunc_paperSize(PyObject* self, PyObject* args)
{
    QPrinter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPrinter* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "paperSize", 0, 1, &(pyargs[0])))
        return 0;


    // Overloaded function decisor
    // 0: paperSize()const
    // 1: paperSize(QPrinter::Unit)const
    if (numArgs == 0) {
        overloadId = 0; // paperSize()const
    } else if (numArgs == 1 && Shiboken::Converter< ::QPrinter::Unit >::isConvertible(pyargs[0])) {
        overloadId = 1; // paperSize(QPrinter::Unit)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPrinterFunc_paperSize_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // paperSize()const
            {

                if(!PyErr_Occurred()) {
                    // paperSize()const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QPrinter::PageSize cppResult = const_cast<const QPrinter*>(cppSelf)->paperSize();
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QPrinter::PageSize >::toPython(cppResult);
                }
                break;
            }
            case 1: // paperSize(QPrinter::Unit)const
            {
                QPrinter::Unit cppArg0 = Shiboken::Converter<QPrinter::Unit >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // paperSize(QPrinter::Unit)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QSizeF cppResult = const_cast<const QPrinter*>(cppSelf)->paperSize(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QSizeF >::toPython(cppResult);
                }
                break;
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QPrinterFunc_paperSize_TypeError:
        const char* overloads[] = {"", "PySide.QtGui.QPrinter.Unit", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPrinter.paperSize", overloads);
        return 0;
}

static PyObject* Sbk_QPrinterFunc_paperSource(PyObject* self)
{
    QPrinter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPrinter* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // paperSource()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QPrinter::PaperSource cppResult = const_cast<const QPrinter*>(cppSelf)->paperSource();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QPrinter::PaperSource >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPrinterFunc_printEngine(PyObject* self)
{
    QPrinter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPrinter* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // printEngine()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QPrintEngine * cppResult = const_cast<const QPrinter*>(cppSelf)->printEngine();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QPrintEngine * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPrinterFunc_printProgram(PyObject* self)
{
    QPrinter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPrinter* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // printProgram()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QPrinter*>(cppSelf)->printProgram();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPrinterFunc_printRange(PyObject* self)
{
    QPrinter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPrinter* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // printRange()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QPrinter::PrintRange cppResult = const_cast<const QPrinter*>(cppSelf)->printRange();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QPrinter::PrintRange >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPrinterFunc_printerName(PyObject* self)
{
    QPrinter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPrinter* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // printerName()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QPrinter*>(cppSelf)->printerName();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPrinterFunc_printerState(PyObject* self)
{
    QPrinter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPrinter* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // printerState()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QPrinter::PrinterState cppResult = const_cast<const QPrinter*>(cppSelf)->printerState();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QPrinter::PrinterState >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPrinterFunc_resolution(PyObject* self)
{
    QPrinter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPrinter* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // resolution()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QPrinter*>(cppSelf)->resolution();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPrinterFunc_setCollateCopies(PyObject* self, PyObject* arg)
{
    QPrinter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPrinter* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setCollateCopies(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setCollateCopies(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPrinterFunc_setCollateCopies_TypeError;

    // Call function/method
    {
        {
            bool cppArg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setCollateCopies(bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setCollateCopies(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPrinterFunc_setCollateCopies_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPrinter.setCollateCopies", overloads);
        return 0;
}

static PyObject* Sbk_QPrinterFunc_setColorMode(PyObject* self, PyObject* arg)
{
    QPrinter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPrinter* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setColorMode(QPrinter::ColorMode)
    if (Shiboken::Converter< ::QPrinter::ColorMode >::isConvertible(arg)) {
        overloadId = 0; // setColorMode(QPrinter::ColorMode)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPrinterFunc_setColorMode_TypeError;

    // Call function/method
    {
        {
            QPrinter::ColorMode cppArg0 = Shiboken::Converter<QPrinter::ColorMode >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setColorMode(QPrinter::ColorMode)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setColorMode(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPrinterFunc_setColorMode_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPrinter.ColorMode", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPrinter.setColorMode", overloads);
        return 0;
}

static PyObject* Sbk_QPrinterFunc_setCopyCount(PyObject* self, PyObject* arg)
{
    QPrinter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPrinter* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setCopyCount(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setCopyCount(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPrinterFunc_setCopyCount_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setCopyCount(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setCopyCount(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPrinterFunc_setCopyCount_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPrinter.setCopyCount", overloads);
        return 0;
}

static PyObject* Sbk_QPrinterFunc_setCreator(PyObject* self, PyObject* arg)
{
    QPrinter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPrinter* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setCreator(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // setCreator(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPrinterFunc_setCreator_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setCreator(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setCreator(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPrinterFunc_setCreator_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPrinter.setCreator", overloads);
        return 0;
}

static PyObject* Sbk_QPrinterFunc_setDocName(PyObject* self, PyObject* arg)
{
    QPrinter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPrinter* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setDocName(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // setDocName(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPrinterFunc_setDocName_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setDocName(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setDocName(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPrinterFunc_setDocName_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPrinter.setDocName", overloads);
        return 0;
}

static PyObject* Sbk_QPrinterFunc_setDoubleSidedPrinting(PyObject* self, PyObject* arg)
{
    QPrinter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPrinter* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setDoubleSidedPrinting(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setDoubleSidedPrinting(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPrinterFunc_setDoubleSidedPrinting_TypeError;

    // Call function/method
    {
        {
            bool cppArg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setDoubleSidedPrinting(bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setDoubleSidedPrinting(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPrinterFunc_setDoubleSidedPrinting_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPrinter.setDoubleSidedPrinting", overloads);
        return 0;
}

static PyObject* Sbk_QPrinterFunc_setDuplex(PyObject* self, PyObject* arg)
{
    QPrinter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPrinter* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setDuplex(QPrinter::DuplexMode)
    if (Shiboken::Converter< ::QPrinter::DuplexMode >::isConvertible(arg)) {
        overloadId = 0; // setDuplex(QPrinter::DuplexMode)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPrinterFunc_setDuplex_TypeError;

    // Call function/method
    {
        {
            QPrinter::DuplexMode cppArg0 = Shiboken::Converter<QPrinter::DuplexMode >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setDuplex(QPrinter::DuplexMode)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setDuplex(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPrinterFunc_setDuplex_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPrinter.DuplexMode", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPrinter.setDuplex", overloads);
        return 0;
}

static PyObject* Sbk_QPrinterFunc_setEngines(PyObject* self, PyObject* args)
{
    QPrinter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPrinter* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setEngines", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setEngines(QPrintEngine*,QPaintEngine*)
    if (numArgs == 2 && Shiboken::Converter< ::QPrintEngine * >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QPaintEngine * >::isConvertible(pyargs[1])) {
        overloadId = 0; // setEngines(QPrintEngine*,QPaintEngine*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPrinterFunc_setEngines_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QPrintEngine * cppArg0 = Shiboken::Converter<QPrintEngine * >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            QPaintEngine * cppArg1 = Shiboken::Converter<QPaintEngine * >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // setEngines(QPrintEngine*,QPaintEngine*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setEngines(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                Shiboken::Object::setParent(self, pyargs[0]);
                Shiboken::Object::setParent(self, pyargs[1]);
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPrinterFunc_setEngines_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPrintEngine, PySide.QtGui.QPaintEngine", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPrinter.setEngines", overloads);
        return 0;
}

static PyObject* Sbk_QPrinterFunc_setFontEmbeddingEnabled(PyObject* self, PyObject* arg)
{
    QPrinter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPrinter* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setFontEmbeddingEnabled(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setFontEmbeddingEnabled(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPrinterFunc_setFontEmbeddingEnabled_TypeError;

    // Call function/method
    {
        {
            bool cppArg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setFontEmbeddingEnabled(bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setFontEmbeddingEnabled(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPrinterFunc_setFontEmbeddingEnabled_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPrinter.setFontEmbeddingEnabled", overloads);
        return 0;
}

static PyObject* Sbk_QPrinterFunc_setFromTo(PyObject* self, PyObject* args)
{
    QPrinter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPrinter* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setFromTo", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setFromTo(int,int)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 0; // setFromTo(int,int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPrinterFunc_setFromTo_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // setFromTo(int,int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setFromTo(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPrinterFunc_setFromTo_TypeError:
        const char* overloads[] = {"int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPrinter.setFromTo", overloads);
        return 0;
}

static PyObject* Sbk_QPrinterFunc_setFullPage(PyObject* self, PyObject* arg)
{
    QPrinter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPrinter* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setFullPage(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setFullPage(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPrinterFunc_setFullPage_TypeError;

    // Call function/method
    {
        {
            bool cppArg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setFullPage(bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setFullPage(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPrinterFunc_setFullPage_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPrinter.setFullPage", overloads);
        return 0;
}

static PyObject* Sbk_QPrinterFunc_setNumCopies(PyObject* self, PyObject* arg)
{
    QPrinter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPrinter* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setNumCopies(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setNumCopies(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPrinterFunc_setNumCopies_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setNumCopies(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setNumCopies(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPrinterFunc_setNumCopies_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPrinter.setNumCopies", overloads);
        return 0;
}

static PyObject* Sbk_QPrinterFunc_setOrientation(PyObject* self, PyObject* arg)
{
    QPrinter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPrinter* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setOrientation(QPrinter::Orientation)
    if (Shiboken::Converter< ::QPrinter::Orientation >::isConvertible(arg)) {
        overloadId = 0; // setOrientation(QPrinter::Orientation)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPrinterFunc_setOrientation_TypeError;

    // Call function/method
    {
        {
            QPrinter::Orientation cppArg0 = Shiboken::Converter<QPrinter::Orientation >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setOrientation(QPrinter::Orientation)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setOrientation(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPrinterFunc_setOrientation_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPrinter.Orientation", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPrinter.setOrientation", overloads);
        return 0;
}

static PyObject* Sbk_QPrinterFunc_setOutputFileName(PyObject* self, PyObject* arg)
{
    QPrinter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPrinter* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setOutputFileName(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // setOutputFileName(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPrinterFunc_setOutputFileName_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setOutputFileName(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setOutputFileName(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPrinterFunc_setOutputFileName_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPrinter.setOutputFileName", overloads);
        return 0;
}

static PyObject* Sbk_QPrinterFunc_setOutputFormat(PyObject* self, PyObject* arg)
{
    QPrinter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPrinter* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setOutputFormat(QPrinter::OutputFormat)
    if (Shiboken::Converter< ::QPrinter::OutputFormat >::isConvertible(arg)) {
        overloadId = 0; // setOutputFormat(QPrinter::OutputFormat)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPrinterFunc_setOutputFormat_TypeError;

    // Call function/method
    {
        {
            QPrinter::OutputFormat cppArg0 = Shiboken::Converter<QPrinter::OutputFormat >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setOutputFormat(QPrinter::OutputFormat)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setOutputFormat(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPrinterFunc_setOutputFormat_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPrinter.OutputFormat", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPrinter.setOutputFormat", overloads);
        return 0;
}

static PyObject* Sbk_QPrinterFunc_setPageMargins(PyObject* self, PyObject* args)
{
    QPrinter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPrinter* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setPageMargins", 5, 5, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4])))
        return 0;


    // Overloaded function decisor
    // 0: setPageMargins(qreal,qreal,qreal,qreal,QPrinter::Unit)
    if (numArgs == 5 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3]) && Shiboken::Converter< ::QPrinter::Unit >::isConvertible(pyargs[4])) {
        overloadId = 0; // setPageMargins(qreal,qreal,qreal,qreal,QPrinter::Unit)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPrinterFunc_setPageMargins_TypeError;

    // Call function/method
    {
        {
            qreal cppArg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
            qreal cppArg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);
            qreal cppArg2 = Shiboken::Converter<qreal >::toCpp(pyargs[2]);
            qreal cppArg3 = Shiboken::Converter<qreal >::toCpp(pyargs[3]);
            QPrinter::Unit cppArg4 = Shiboken::Converter<QPrinter::Unit >::toCpp(pyargs[4]);

            if(!PyErr_Occurred()) {
                // setPageMargins(qreal,qreal,qreal,qreal,QPrinter::Unit)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setPageMargins(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPrinterFunc_setPageMargins_TypeError:
        const char* overloads[] = {"float, float, float, float, PySide.QtGui.QPrinter.Unit", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPrinter.setPageMargins", overloads);
        return 0;
}

static PyObject* Sbk_QPrinterFunc_setPageOrder(PyObject* self, PyObject* arg)
{
    QPrinter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPrinter* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setPageOrder(QPrinter::PageOrder)
    if (Shiboken::Converter< ::QPrinter::PageOrder >::isConvertible(arg)) {
        overloadId = 0; // setPageOrder(QPrinter::PageOrder)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPrinterFunc_setPageOrder_TypeError;

    // Call function/method
    {
        {
            QPrinter::PageOrder cppArg0 = Shiboken::Converter<QPrinter::PageOrder >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setPageOrder(QPrinter::PageOrder)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setPageOrder(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPrinterFunc_setPageOrder_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPrinter.PageOrder", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPrinter.setPageOrder", overloads);
        return 0;
}

static PyObject* Sbk_QPrinterFunc_setPageSize(PyObject* self, PyObject* arg)
{
    QPrinter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPrinter* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setPageSize(QPrinter::PageSize)
    if (Shiboken::Converter< ::QPrinter::PageSize >::isConvertible(arg)) {
        overloadId = 0; // setPageSize(QPrinter::PageSize)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPrinterFunc_setPageSize_TypeError;

    // Call function/method
    {
        {
            QPrinter::PageSize cppArg0 = Shiboken::Converter<QPrinter::PageSize >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setPageSize(QPrinter::PageSize)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setPageSize(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPrinterFunc_setPageSize_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPrinter.PageSize", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPrinter.setPageSize", overloads);
        return 0;
}

static PyObject* Sbk_QPrinterFunc_setPaperSize(PyObject* self, PyObject* args)
{
    QPrinter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPrinter* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setPaperSize", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setPaperSize(QPrinter::PageSize)
    // 1: setPaperSize(QSizeF,QPrinter::Unit)
    if (numArgs == 2 && Shiboken::Converter< ::QSizeF >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QPrinter::Unit >::isConvertible(pyargs[1])) {
        overloadId = 1; // setPaperSize(QSizeF,QPrinter::Unit)
    } else if (numArgs == 1 && Shiboken::Converter< ::QPrinter::PageSize >::isConvertible(pyargs[0])) {
        overloadId = 0; // setPaperSize(QPrinter::PageSize)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPrinterFunc_setPaperSize_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // setPaperSize(QPrinter::PageSize)
            {
                QPrinter::PageSize cppArg0 = Shiboken::Converter<QPrinter::PageSize >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // setPaperSize(QPrinter::PageSize)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setPaperSize(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // setPaperSize(QSizeF,QPrinter::Unit)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QSizeF cppArg0 = Shiboken::Converter<QSizeF >::toCpp(pyargs[0]);
                QPrinter::Unit cppArg1 = Shiboken::Converter<QPrinter::Unit >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // setPaperSize(QSizeF,QPrinter::Unit)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setPaperSize(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPrinterFunc_setPaperSize_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPrinter.PageSize", "PySide.QtCore.QSizeF, PySide.QtGui.QPrinter.Unit", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPrinter.setPaperSize", overloads);
        return 0;
}

static PyObject* Sbk_QPrinterFunc_setPaperSource(PyObject* self, PyObject* arg)
{
    QPrinter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPrinter* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setPaperSource(QPrinter::PaperSource)
    if (Shiboken::Converter< ::QPrinter::PaperSource >::isConvertible(arg)) {
        overloadId = 0; // setPaperSource(QPrinter::PaperSource)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPrinterFunc_setPaperSource_TypeError;

    // Call function/method
    {
        {
            QPrinter::PaperSource cppArg0 = Shiboken::Converter<QPrinter::PaperSource >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setPaperSource(QPrinter::PaperSource)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setPaperSource(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPrinterFunc_setPaperSource_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPrinter.PaperSource", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPrinter.setPaperSource", overloads);
        return 0;
}

static PyObject* Sbk_QPrinterFunc_setPrintProgram(PyObject* self, PyObject* arg)
{
    QPrinter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPrinter* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setPrintProgram(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // setPrintProgram(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPrinterFunc_setPrintProgram_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setPrintProgram(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setPrintProgram(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPrinterFunc_setPrintProgram_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPrinter.setPrintProgram", overloads);
        return 0;
}

static PyObject* Sbk_QPrinterFunc_setPrintRange(PyObject* self, PyObject* arg)
{
    QPrinter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPrinter* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setPrintRange(QPrinter::PrintRange)
    if (Shiboken::Converter< ::QPrinter::PrintRange >::isConvertible(arg)) {
        overloadId = 0; // setPrintRange(QPrinter::PrintRange)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPrinterFunc_setPrintRange_TypeError;

    // Call function/method
    {
        {
            QPrinter::PrintRange cppArg0 = Shiboken::Converter<QPrinter::PrintRange >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setPrintRange(QPrinter::PrintRange)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setPrintRange(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPrinterFunc_setPrintRange_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPrinter.PrintRange", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPrinter.setPrintRange", overloads);
        return 0;
}

static PyObject* Sbk_QPrinterFunc_setPrinterName(PyObject* self, PyObject* arg)
{
    QPrinter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPrinter* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setPrinterName(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // setPrinterName(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPrinterFunc_setPrinterName_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setPrinterName(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setPrinterName(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPrinterFunc_setPrinterName_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPrinter.setPrinterName", overloads);
        return 0;
}

static PyObject* Sbk_QPrinterFunc_setResolution(PyObject* self, PyObject* arg)
{
    QPrinter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPrinter* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setResolution(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setResolution(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPrinterFunc_setResolution_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setResolution(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setResolution(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPrinterFunc_setResolution_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPrinter.setResolution", overloads);
        return 0;
}

static PyObject* Sbk_QPrinterFunc_supportedResolutions(PyObject* self)
{
    QPrinter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPrinter* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // supportedResolutions()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QList<int > cppResult = const_cast<const QPrinter*>(cppSelf)->supportedResolutions();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QList<int > >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPrinterFunc_supportsMultipleCopies(PyObject* self)
{
    QPrinter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPrinter* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // supportsMultipleCopies()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QPrinter*>(cppSelf)->supportsMultipleCopies();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPrinterFunc_toPage(PyObject* self)
{
    QPrinter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPrinter* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // toPage()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QPrinter*>(cppSelf)->toPage();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef Sbk_QPrinter_methods[] = {
    {"abort", (PyCFunction)Sbk_QPrinterFunc_abort, METH_NOARGS},
    {"actualNumCopies", (PyCFunction)Sbk_QPrinterFunc_actualNumCopies, METH_NOARGS},
    {"collateCopies", (PyCFunction)Sbk_QPrinterFunc_collateCopies, METH_NOARGS},
    {"colorMode", (PyCFunction)Sbk_QPrinterFunc_colorMode, METH_NOARGS},
    {"copyCount", (PyCFunction)Sbk_QPrinterFunc_copyCount, METH_NOARGS},
    {"creator", (PyCFunction)Sbk_QPrinterFunc_creator, METH_NOARGS},
    {"devType", (PyCFunction)Sbk_QPrinterFunc_devType, METH_NOARGS},
    {"docName", (PyCFunction)Sbk_QPrinterFunc_docName, METH_NOARGS},
    {"doubleSidedPrinting", (PyCFunction)Sbk_QPrinterFunc_doubleSidedPrinting, METH_NOARGS},
    {"duplex", (PyCFunction)Sbk_QPrinterFunc_duplex, METH_NOARGS},
    {"fontEmbeddingEnabled", (PyCFunction)Sbk_QPrinterFunc_fontEmbeddingEnabled, METH_NOARGS},
    {"fromPage", (PyCFunction)Sbk_QPrinterFunc_fromPage, METH_NOARGS},
    {"fullPage", (PyCFunction)Sbk_QPrinterFunc_fullPage, METH_NOARGS},
    {"isValid", (PyCFunction)Sbk_QPrinterFunc_isValid, METH_NOARGS},
    {"metric", (PyCFunction)Sbk_QPrinterFunc_metric, METH_O},
    {"newPage", (PyCFunction)Sbk_QPrinterFunc_newPage, METH_NOARGS},
    {"numCopies", (PyCFunction)Sbk_QPrinterFunc_numCopies, METH_NOARGS},
    {"orientation", (PyCFunction)Sbk_QPrinterFunc_orientation, METH_NOARGS},
    {"outputFileName", (PyCFunction)Sbk_QPrinterFunc_outputFileName, METH_NOARGS},
    {"outputFormat", (PyCFunction)Sbk_QPrinterFunc_outputFormat, METH_NOARGS},
    {"pageOrder", (PyCFunction)Sbk_QPrinterFunc_pageOrder, METH_NOARGS},
    {"pageRect", (PyCFunction)Sbk_QPrinterFunc_pageRect, METH_VARARGS},
    {"pageSize", (PyCFunction)Sbk_QPrinterFunc_pageSize, METH_NOARGS},
    {"paintEngine", (PyCFunction)Sbk_QPrinterFunc_paintEngine, METH_NOARGS},
    {"paperRect", (PyCFunction)Sbk_QPrinterFunc_paperRect, METH_VARARGS},
    {"paperSize", (PyCFunction)Sbk_QPrinterFunc_paperSize, METH_VARARGS},
    {"paperSource", (PyCFunction)Sbk_QPrinterFunc_paperSource, METH_NOARGS},
    {"printEngine", (PyCFunction)Sbk_QPrinterFunc_printEngine, METH_NOARGS},
    {"printProgram", (PyCFunction)Sbk_QPrinterFunc_printProgram, METH_NOARGS},
    {"printRange", (PyCFunction)Sbk_QPrinterFunc_printRange, METH_NOARGS},
    {"printerName", (PyCFunction)Sbk_QPrinterFunc_printerName, METH_NOARGS},
    {"printerState", (PyCFunction)Sbk_QPrinterFunc_printerState, METH_NOARGS},
    {"resolution", (PyCFunction)Sbk_QPrinterFunc_resolution, METH_NOARGS},
    {"setCollateCopies", (PyCFunction)Sbk_QPrinterFunc_setCollateCopies, METH_O},
    {"setColorMode", (PyCFunction)Sbk_QPrinterFunc_setColorMode, METH_O},
    {"setCopyCount", (PyCFunction)Sbk_QPrinterFunc_setCopyCount, METH_O},
    {"setCreator", (PyCFunction)Sbk_QPrinterFunc_setCreator, METH_O},
    {"setDocName", (PyCFunction)Sbk_QPrinterFunc_setDocName, METH_O},
    {"setDoubleSidedPrinting", (PyCFunction)Sbk_QPrinterFunc_setDoubleSidedPrinting, METH_O},
    {"setDuplex", (PyCFunction)Sbk_QPrinterFunc_setDuplex, METH_O},
    {"setEngines", (PyCFunction)Sbk_QPrinterFunc_setEngines, METH_VARARGS},
    {"setFontEmbeddingEnabled", (PyCFunction)Sbk_QPrinterFunc_setFontEmbeddingEnabled, METH_O},
    {"setFromTo", (PyCFunction)Sbk_QPrinterFunc_setFromTo, METH_VARARGS},
    {"setFullPage", (PyCFunction)Sbk_QPrinterFunc_setFullPage, METH_O},
    {"setNumCopies", (PyCFunction)Sbk_QPrinterFunc_setNumCopies, METH_O},
    {"setOrientation", (PyCFunction)Sbk_QPrinterFunc_setOrientation, METH_O},
    {"setOutputFileName", (PyCFunction)Sbk_QPrinterFunc_setOutputFileName, METH_O},
    {"setOutputFormat", (PyCFunction)Sbk_QPrinterFunc_setOutputFormat, METH_O},
    {"setPageMargins", (PyCFunction)Sbk_QPrinterFunc_setPageMargins, METH_VARARGS},
    {"setPageOrder", (PyCFunction)Sbk_QPrinterFunc_setPageOrder, METH_O},
    {"setPageSize", (PyCFunction)Sbk_QPrinterFunc_setPageSize, METH_O},
    {"setPaperSize", (PyCFunction)Sbk_QPrinterFunc_setPaperSize, METH_VARARGS},
    {"setPaperSource", (PyCFunction)Sbk_QPrinterFunc_setPaperSource, METH_O},
    {"setPrintProgram", (PyCFunction)Sbk_QPrinterFunc_setPrintProgram, METH_O},
    {"setPrintRange", (PyCFunction)Sbk_QPrinterFunc_setPrintRange, METH_O},
    {"setPrinterName", (PyCFunction)Sbk_QPrinterFunc_setPrinterName, METH_O},
    {"setResolution", (PyCFunction)Sbk_QPrinterFunc_setResolution, METH_O},
    {"supportedResolutions", (PyCFunction)Sbk_QPrinterFunc_supportedResolutions, METH_NOARGS},
    {"supportsMultipleCopies", (PyCFunction)Sbk_QPrinterFunc_supportsMultipleCopies, METH_NOARGS},
    {"toPage", (PyCFunction)Sbk_QPrinterFunc_toPage, METH_NOARGS},

    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QPrinter_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QPrinter",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QPrinter_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QPrinter_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern

static SbkObjectType* Sbk_QPrinter_typeDiscovery(void* cptr, SbkObjectType* instanceType)
{
    if (instanceType == reinterpret_cast<SbkObjectType*>(Shiboken::SbkType<QPaintDevice >()) && dynamic_cast<QPrinter*>(reinterpret_cast<QPaintDevice*>(cptr)))
        return &Sbk_QPrinter_Type;
    return 0;
}


void init_QPrinter(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QPRINTER_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QPrinter_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QPrinter_Type);
    Sbk_QPrinter_Type.super.ht_type.tp_base = SbkPySide_QtGuiTypes[SBK_QPAINTDEVICE_IDX];
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QPrinter_Type, &Shiboken::callCppDestructor<QPrinter >);
    if (PyType_Ready((PyTypeObject*)&Sbk_QPrinter_Type) < 0)
        return;

    // Fill type discovery information
    Shiboken::ObjectType::setTypeDiscoveryFunction(&Sbk_QPrinter_Type, &Sbk_QPrinter_typeDiscovery);
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkObjectType*>(SbkPySide_QtGuiTypes[SBK_QPAINTDEVICE_IDX]), &Sbk_QPrinter_Type);

    Shiboken::ObjectType::setOriginalName(&Sbk_QPrinter_Type, "QPrinter*");
    PyModule_AddObject(module, "QPrinter",
        ((PyObject*)&Sbk_QPrinter_Type));

    // Initialize enums
    PyObject* enumItem;

    // init enum: OutputFormat
    PyTypeObject* SbkPySide_QtGui_QPrinter_OutputFormat = Shiboken::Enum::newType("PySide.QtGui.QPrinter.OutputFormat");
    SbkPySide_QtGuiTypes[SBK_QPRINTER_OUTPUTFORMAT_IDX] = SbkPySide_QtGui_QPrinter_OutputFormat;
    if (PyType_Ready(SbkPySide_QtGui_QPrinter_OutputFormat) < 0)
        return;
    PyDict_SetItemString(Sbk_QPrinter_Type.super.ht_type.tp_dict,
            "OutputFormat",((PyObject*)SbkPySide_QtGui_QPrinter_OutputFormat));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPrinter_OutputFormat,(long) QPrinter::NativeFormat, "NativeFormat");
    PyDict_SetItemString(Sbk_QPrinter_Type.super.ht_type.tp_dict,"NativeFormat", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPrinter_OutputFormat->tp_dict,"NativeFormat", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPrinter_OutputFormat,(long) QPrinter::PdfFormat, "PdfFormat");
    PyDict_SetItemString(Sbk_QPrinter_Type.super.ht_type.tp_dict,"PdfFormat", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPrinter_OutputFormat->tp_dict,"PdfFormat", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPrinter_OutputFormat,(long) QPrinter::PostScriptFormat, "PostScriptFormat");
    PyDict_SetItemString(Sbk_QPrinter_Type.super.ht_type.tp_dict,"PostScriptFormat", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPrinter_OutputFormat->tp_dict,"PostScriptFormat", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QPrinter::OutputFormat");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::OutputFormat");
    // end of enum OutputFormat

    // init enum: DuplexMode
    PyTypeObject* SbkPySide_QtGui_QPrinter_DuplexMode = Shiboken::Enum::newType("PySide.QtGui.QPrinter.DuplexMode");
    SbkPySide_QtGuiTypes[SBK_QPRINTER_DUPLEXMODE_IDX] = SbkPySide_QtGui_QPrinter_DuplexMode;
    if (PyType_Ready(SbkPySide_QtGui_QPrinter_DuplexMode) < 0)
        return;
    PyDict_SetItemString(Sbk_QPrinter_Type.super.ht_type.tp_dict,
            "DuplexMode",((PyObject*)SbkPySide_QtGui_QPrinter_DuplexMode));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPrinter_DuplexMode,(long) QPrinter::DuplexNone, "DuplexNone");
    PyDict_SetItemString(Sbk_QPrinter_Type.super.ht_type.tp_dict,"DuplexNone", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPrinter_DuplexMode->tp_dict,"DuplexNone", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPrinter_DuplexMode,(long) QPrinter::DuplexAuto, "DuplexAuto");
    PyDict_SetItemString(Sbk_QPrinter_Type.super.ht_type.tp_dict,"DuplexAuto", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPrinter_DuplexMode->tp_dict,"DuplexAuto", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPrinter_DuplexMode,(long) QPrinter::DuplexLongSide, "DuplexLongSide");
    PyDict_SetItemString(Sbk_QPrinter_Type.super.ht_type.tp_dict,"DuplexLongSide", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPrinter_DuplexMode->tp_dict,"DuplexLongSide", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPrinter_DuplexMode,(long) QPrinter::DuplexShortSide, "DuplexShortSide");
    PyDict_SetItemString(Sbk_QPrinter_Type.super.ht_type.tp_dict,"DuplexShortSide", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPrinter_DuplexMode->tp_dict,"DuplexShortSide", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QPrinter::DuplexMode");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::DuplexMode");
    // end of enum DuplexMode

    // init enum: PrintRange
    PyTypeObject* SbkPySide_QtGui_QPrinter_PrintRange = Shiboken::Enum::newType("PySide.QtGui.QPrinter.PrintRange");
    SbkPySide_QtGuiTypes[SBK_QPRINTER_PRINTRANGE_IDX] = SbkPySide_QtGui_QPrinter_PrintRange;
    if (PyType_Ready(SbkPySide_QtGui_QPrinter_PrintRange) < 0)
        return;
    PyDict_SetItemString(Sbk_QPrinter_Type.super.ht_type.tp_dict,
            "PrintRange",((PyObject*)SbkPySide_QtGui_QPrinter_PrintRange));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPrinter_PrintRange,(long) QPrinter::AllPages, "AllPages");
    PyDict_SetItemString(Sbk_QPrinter_Type.super.ht_type.tp_dict,"AllPages", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPrinter_PrintRange->tp_dict,"AllPages", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPrinter_PrintRange,(long) QPrinter::Selection, "Selection");
    PyDict_SetItemString(Sbk_QPrinter_Type.super.ht_type.tp_dict,"Selection", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPrinter_PrintRange->tp_dict,"Selection", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPrinter_PrintRange,(long) QPrinter::PageRange, "PageRange");
    PyDict_SetItemString(Sbk_QPrinter_Type.super.ht_type.tp_dict,"PageRange", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPrinter_PrintRange->tp_dict,"PageRange", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPrinter_PrintRange,(long) QPrinter::CurrentPage, "CurrentPage");
    PyDict_SetItemString(Sbk_QPrinter_Type.super.ht_type.tp_dict,"CurrentPage", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPrinter_PrintRange->tp_dict,"CurrentPage", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QPrinter::PrintRange");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::PrintRange");
    // end of enum PrintRange

    // init enum: Unit
    PyTypeObject* SbkPySide_QtGui_QPrinter_Unit = Shiboken::Enum::newType("PySide.QtGui.QPrinter.Unit");
    SbkPySide_QtGuiTypes[SBK_QPRINTER_UNIT_IDX] = SbkPySide_QtGui_QPrinter_Unit;
    if (PyType_Ready(SbkPySide_QtGui_QPrinter_Unit) < 0)
        return;
    PyDict_SetItemString(Sbk_QPrinter_Type.super.ht_type.tp_dict,
            "Unit",((PyObject*)SbkPySide_QtGui_QPrinter_Unit));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPrinter_Unit,(long) QPrinter::Millimeter, "Millimeter");
    PyDict_SetItemString(Sbk_QPrinter_Type.super.ht_type.tp_dict,"Millimeter", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPrinter_Unit->tp_dict,"Millimeter", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPrinter_Unit,(long) QPrinter::Point, "Point");
    PyDict_SetItemString(Sbk_QPrinter_Type.super.ht_type.tp_dict,"Point", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPrinter_Unit->tp_dict,"Point", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPrinter_Unit,(long) QPrinter::Inch, "Inch");
    PyDict_SetItemString(Sbk_QPrinter_Type.super.ht_type.tp_dict,"Inch", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPrinter_Unit->tp_dict,"Inch", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPrinter_Unit,(long) QPrinter::Pica, "Pica");
    PyDict_SetItemString(Sbk_QPrinter_Type.super.ht_type.tp_dict,"Pica", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPrinter_Unit->tp_dict,"Pica", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPrinter_Unit,(long) QPrinter::Didot, "Didot");
    PyDict_SetItemString(Sbk_QPrinter_Type.super.ht_type.tp_dict,"Didot", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPrinter_Unit->tp_dict,"Didot", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPrinter_Unit,(long) QPrinter::Cicero, "Cicero");
    PyDict_SetItemString(Sbk_QPrinter_Type.super.ht_type.tp_dict,"Cicero", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPrinter_Unit->tp_dict,"Cicero", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPrinter_Unit,(long) QPrinter::DevicePixel, "DevicePixel");
    PyDict_SetItemString(Sbk_QPrinter_Type.super.ht_type.tp_dict,"DevicePixel", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPrinter_Unit->tp_dict,"DevicePixel", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QPrinter::Unit");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::Unit");
    // end of enum Unit

    // init enum: PrinterMode
    PyTypeObject* SbkPySide_QtGui_QPrinter_PrinterMode = Shiboken::Enum::newType("PySide.QtGui.QPrinter.PrinterMode");
    SbkPySide_QtGuiTypes[SBK_QPRINTER_PRINTERMODE_IDX] = SbkPySide_QtGui_QPrinter_PrinterMode;
    if (PyType_Ready(SbkPySide_QtGui_QPrinter_PrinterMode) < 0)
        return;
    PyDict_SetItemString(Sbk_QPrinter_Type.super.ht_type.tp_dict,
            "PrinterMode",((PyObject*)SbkPySide_QtGui_QPrinter_PrinterMode));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPrinter_PrinterMode,(long) QPrinter::ScreenResolution, "ScreenResolution");
    PyDict_SetItemString(Sbk_QPrinter_Type.super.ht_type.tp_dict,"ScreenResolution", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPrinter_PrinterMode->tp_dict,"ScreenResolution", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPrinter_PrinterMode,(long) QPrinter::PrinterResolution, "PrinterResolution");
    PyDict_SetItemString(Sbk_QPrinter_Type.super.ht_type.tp_dict,"PrinterResolution", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPrinter_PrinterMode->tp_dict,"PrinterResolution", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPrinter_PrinterMode,(long) QPrinter::HighResolution, "HighResolution");
    PyDict_SetItemString(Sbk_QPrinter_Type.super.ht_type.tp_dict,"HighResolution", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPrinter_PrinterMode->tp_dict,"HighResolution", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QPrinter::PrinterMode");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::PrinterMode");
    // end of enum PrinterMode

    // init enum: Orientation
    PyTypeObject* SbkPySide_QtGui_QPrinter_Orientation = Shiboken::Enum::newType("PySide.QtGui.QPrinter.Orientation");
    SbkPySide_QtGuiTypes[SBK_QPRINTER_ORIENTATION_IDX] = SbkPySide_QtGui_QPrinter_Orientation;
    if (PyType_Ready(SbkPySide_QtGui_QPrinter_Orientation) < 0)
        return;
    PyDict_SetItemString(Sbk_QPrinter_Type.super.ht_type.tp_dict,
            "Orientation",((PyObject*)SbkPySide_QtGui_QPrinter_Orientation));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPrinter_Orientation,(long) QPrinter::Portrait, "Portrait");
    PyDict_SetItemString(Sbk_QPrinter_Type.super.ht_type.tp_dict,"Portrait", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPrinter_Orientation->tp_dict,"Portrait", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPrinter_Orientation,(long) QPrinter::Landscape, "Landscape");
    PyDict_SetItemString(Sbk_QPrinter_Type.super.ht_type.tp_dict,"Landscape", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPrinter_Orientation->tp_dict,"Landscape", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QPrinter::Orientation");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::Orientation");
    // end of enum Orientation

    // init enum: PrinterState
    PyTypeObject* SbkPySide_QtGui_QPrinter_PrinterState = Shiboken::Enum::newType("PySide.QtGui.QPrinter.PrinterState");
    SbkPySide_QtGuiTypes[SBK_QPRINTER_PRINTERSTATE_IDX] = SbkPySide_QtGui_QPrinter_PrinterState;
    if (PyType_Ready(SbkPySide_QtGui_QPrinter_PrinterState) < 0)
        return;
    PyDict_SetItemString(Sbk_QPrinter_Type.super.ht_type.tp_dict,
            "PrinterState",((PyObject*)SbkPySide_QtGui_QPrinter_PrinterState));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPrinter_PrinterState,(long) QPrinter::Idle, "Idle");
    PyDict_SetItemString(Sbk_QPrinter_Type.super.ht_type.tp_dict,"Idle", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPrinter_PrinterState->tp_dict,"Idle", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPrinter_PrinterState,(long) QPrinter::Active, "Active");
    PyDict_SetItemString(Sbk_QPrinter_Type.super.ht_type.tp_dict,"Active", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPrinter_PrinterState->tp_dict,"Active", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPrinter_PrinterState,(long) QPrinter::Aborted, "Aborted");
    PyDict_SetItemString(Sbk_QPrinter_Type.super.ht_type.tp_dict,"Aborted", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPrinter_PrinterState->tp_dict,"Aborted", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPrinter_PrinterState,(long) QPrinter::Error, "Error");
    PyDict_SetItemString(Sbk_QPrinter_Type.super.ht_type.tp_dict,"Error", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPrinter_PrinterState->tp_dict,"Error", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QPrinter::PrinterState");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::PrinterState");
    // end of enum PrinterState

    // init enum: ColorMode
    PyTypeObject* SbkPySide_QtGui_QPrinter_ColorMode = Shiboken::Enum::newType("PySide.QtGui.QPrinter.ColorMode");
    SbkPySide_QtGuiTypes[SBK_QPRINTER_COLORMODE_IDX] = SbkPySide_QtGui_QPrinter_ColorMode;
    if (PyType_Ready(SbkPySide_QtGui_QPrinter_ColorMode) < 0)
        return;
    PyDict_SetItemString(Sbk_QPrinter_Type.super.ht_type.tp_dict,
            "ColorMode",((PyObject*)SbkPySide_QtGui_QPrinter_ColorMode));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPrinter_ColorMode,(long) QPrinter::GrayScale, "GrayScale");
    PyDict_SetItemString(Sbk_QPrinter_Type.super.ht_type.tp_dict,"GrayScale", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPrinter_ColorMode->tp_dict,"GrayScale", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPrinter_ColorMode,(long) QPrinter::Color, "Color");
    PyDict_SetItemString(Sbk_QPrinter_Type.super.ht_type.tp_dict,"Color", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPrinter_ColorMode->tp_dict,"Color", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QPrinter::ColorMode");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::ColorMode");
    // end of enum ColorMode

    // init enum: PaperSource
    PyTypeObject* SbkPySide_QtGui_QPrinter_PaperSource = Shiboken::Enum::newType("PySide.QtGui.QPrinter.PaperSource");
    SbkPySide_QtGuiTypes[SBK_QPRINTER_PAPERSOURCE_IDX] = SbkPySide_QtGui_QPrinter_PaperSource;
    if (PyType_Ready(SbkPySide_QtGui_QPrinter_PaperSource) < 0)
        return;
    PyDict_SetItemString(Sbk_QPrinter_Type.super.ht_type.tp_dict,
            "PaperSource",((PyObject*)SbkPySide_QtGui_QPrinter_PaperSource));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPrinter_PaperSource,(long) QPrinter::OnlyOne, "OnlyOne");
    PyDict_SetItemString(Sbk_QPrinter_Type.super.ht_type.tp_dict,"OnlyOne", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPrinter_PaperSource->tp_dict,"OnlyOne", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPrinter_PaperSource,(long) QPrinter::Lower, "Lower");
    PyDict_SetItemString(Sbk_QPrinter_Type.super.ht_type.tp_dict,"Lower", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPrinter_PaperSource->tp_dict,"Lower", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPrinter_PaperSource,(long) QPrinter::Middle, "Middle");
    PyDict_SetItemString(Sbk_QPrinter_Type.super.ht_type.tp_dict,"Middle", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPrinter_PaperSource->tp_dict,"Middle", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPrinter_PaperSource,(long) QPrinter::Manual, "Manual");
    PyDict_SetItemString(Sbk_QPrinter_Type.super.ht_type.tp_dict,"Manual", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPrinter_PaperSource->tp_dict,"Manual", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPrinter_PaperSource,(long) QPrinter::Envelope, "Envelope");
    PyDict_SetItemString(Sbk_QPrinter_Type.super.ht_type.tp_dict,"Envelope", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPrinter_PaperSource->tp_dict,"Envelope", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPrinter_PaperSource,(long) QPrinter::EnvelopeManual, "EnvelopeManual");
    PyDict_SetItemString(Sbk_QPrinter_Type.super.ht_type.tp_dict,"EnvelopeManual", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPrinter_PaperSource->tp_dict,"EnvelopeManual", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPrinter_PaperSource,(long) QPrinter::Auto, "Auto");
    PyDict_SetItemString(Sbk_QPrinter_Type.super.ht_type.tp_dict,"Auto", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPrinter_PaperSource->tp_dict,"Auto", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPrinter_PaperSource,(long) QPrinter::Tractor, "Tractor");
    PyDict_SetItemString(Sbk_QPrinter_Type.super.ht_type.tp_dict,"Tractor", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPrinter_PaperSource->tp_dict,"Tractor", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPrinter_PaperSource,(long) QPrinter::SmallFormat, "SmallFormat");
    PyDict_SetItemString(Sbk_QPrinter_Type.super.ht_type.tp_dict,"SmallFormat", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPrinter_PaperSource->tp_dict,"SmallFormat", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPrinter_PaperSource,(long) QPrinter::LargeFormat, "LargeFormat");
    PyDict_SetItemString(Sbk_QPrinter_Type.super.ht_type.tp_dict,"LargeFormat", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPrinter_PaperSource->tp_dict,"LargeFormat", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPrinter_PaperSource,(long) QPrinter::LargeCapacity, "LargeCapacity");
    PyDict_SetItemString(Sbk_QPrinter_Type.super.ht_type.tp_dict,"LargeCapacity", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPrinter_PaperSource->tp_dict,"LargeCapacity", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPrinter_PaperSource,(long) QPrinter::Cassette, "Cassette");
    PyDict_SetItemString(Sbk_QPrinter_Type.super.ht_type.tp_dict,"Cassette", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPrinter_PaperSource->tp_dict,"Cassette", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPrinter_PaperSource,(long) QPrinter::FormSource, "FormSource");
    PyDict_SetItemString(Sbk_QPrinter_Type.super.ht_type.tp_dict,"FormSource", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPrinter_PaperSource->tp_dict,"FormSource", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPrinter_PaperSource,(long) QPrinter::MaxPageSource, "MaxPageSource");
    PyDict_SetItemString(Sbk_QPrinter_Type.super.ht_type.tp_dict,"MaxPageSource", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPrinter_PaperSource->tp_dict,"MaxPageSource", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QPrinter::PaperSource");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::PaperSource");
    // end of enum PaperSource

    // init enum: PageOrder
    PyTypeObject* SbkPySide_QtGui_QPrinter_PageOrder = Shiboken::Enum::newType("PySide.QtGui.QPrinter.PageOrder");
    SbkPySide_QtGuiTypes[SBK_QPRINTER_PAGEORDER_IDX] = SbkPySide_QtGui_QPrinter_PageOrder;
    if (PyType_Ready(SbkPySide_QtGui_QPrinter_PageOrder) < 0)
        return;
    PyDict_SetItemString(Sbk_QPrinter_Type.super.ht_type.tp_dict,
            "PageOrder",((PyObject*)SbkPySide_QtGui_QPrinter_PageOrder));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPrinter_PageOrder,(long) QPrinter::FirstPageFirst, "FirstPageFirst");
    PyDict_SetItemString(Sbk_QPrinter_Type.super.ht_type.tp_dict,"FirstPageFirst", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPrinter_PageOrder->tp_dict,"FirstPageFirst", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPrinter_PageOrder,(long) QPrinter::LastPageFirst, "LastPageFirst");
    PyDict_SetItemString(Sbk_QPrinter_Type.super.ht_type.tp_dict,"LastPageFirst", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPrinter_PageOrder->tp_dict,"LastPageFirst", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QPrinter::PageOrder");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::PageOrder");
    // end of enum PageOrder

    // init enum: PageSize
    PyTypeObject* SbkPySide_QtGui_QPrinter_PageSize = Shiboken::Enum::newType("PySide.QtGui.QPrinter.PageSize");
    SbkPySide_QtGuiTypes[SBK_QPRINTER_PAGESIZE_IDX] = SbkPySide_QtGui_QPrinter_PageSize;
    if (PyType_Ready(SbkPySide_QtGui_QPrinter_PageSize) < 0)
        return;
    PyDict_SetItemString(Sbk_QPrinter_Type.super.ht_type.tp_dict,
            "PageSize",((PyObject*)SbkPySide_QtGui_QPrinter_PageSize));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPrinter_PageSize,(long) QPrinter::A4, "A4");
    PyDict_SetItemString(Sbk_QPrinter_Type.super.ht_type.tp_dict,"A4", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPrinter_PageSize->tp_dict,"A4", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPrinter_PageSize,(long) QPrinter::B5, "B5");
    PyDict_SetItemString(Sbk_QPrinter_Type.super.ht_type.tp_dict,"B5", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPrinter_PageSize->tp_dict,"B5", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPrinter_PageSize,(long) QPrinter::Letter, "Letter");
    PyDict_SetItemString(Sbk_QPrinter_Type.super.ht_type.tp_dict,"Letter", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPrinter_PageSize->tp_dict,"Letter", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPrinter_PageSize,(long) QPrinter::Legal, "Legal");
    PyDict_SetItemString(Sbk_QPrinter_Type.super.ht_type.tp_dict,"Legal", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPrinter_PageSize->tp_dict,"Legal", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPrinter_PageSize,(long) QPrinter::Executive, "Executive");
    PyDict_SetItemString(Sbk_QPrinter_Type.super.ht_type.tp_dict,"Executive", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPrinter_PageSize->tp_dict,"Executive", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPrinter_PageSize,(long) QPrinter::A0, "A0");
    PyDict_SetItemString(Sbk_QPrinter_Type.super.ht_type.tp_dict,"A0", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPrinter_PageSize->tp_dict,"A0", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPrinter_PageSize,(long) QPrinter::A1, "A1");
    PyDict_SetItemString(Sbk_QPrinter_Type.super.ht_type.tp_dict,"A1", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPrinter_PageSize->tp_dict,"A1", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPrinter_PageSize,(long) QPrinter::A2, "A2");
    PyDict_SetItemString(Sbk_QPrinter_Type.super.ht_type.tp_dict,"A2", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPrinter_PageSize->tp_dict,"A2", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPrinter_PageSize,(long) QPrinter::A3, "A3");
    PyDict_SetItemString(Sbk_QPrinter_Type.super.ht_type.tp_dict,"A3", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPrinter_PageSize->tp_dict,"A3", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPrinter_PageSize,(long) QPrinter::A5, "A5");
    PyDict_SetItemString(Sbk_QPrinter_Type.super.ht_type.tp_dict,"A5", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPrinter_PageSize->tp_dict,"A5", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPrinter_PageSize,(long) QPrinter::A6, "A6");
    PyDict_SetItemString(Sbk_QPrinter_Type.super.ht_type.tp_dict,"A6", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPrinter_PageSize->tp_dict,"A6", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPrinter_PageSize,(long) QPrinter::A7, "A7");
    PyDict_SetItemString(Sbk_QPrinter_Type.super.ht_type.tp_dict,"A7", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPrinter_PageSize->tp_dict,"A7", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPrinter_PageSize,(long) QPrinter::A8, "A8");
    PyDict_SetItemString(Sbk_QPrinter_Type.super.ht_type.tp_dict,"A8", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPrinter_PageSize->tp_dict,"A8", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPrinter_PageSize,(long) QPrinter::A9, "A9");
    PyDict_SetItemString(Sbk_QPrinter_Type.super.ht_type.tp_dict,"A9", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPrinter_PageSize->tp_dict,"A9", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPrinter_PageSize,(long) QPrinter::B0, "B0");
    PyDict_SetItemString(Sbk_QPrinter_Type.super.ht_type.tp_dict,"B0", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPrinter_PageSize->tp_dict,"B0", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPrinter_PageSize,(long) QPrinter::B1, "B1");
    PyDict_SetItemString(Sbk_QPrinter_Type.super.ht_type.tp_dict,"B1", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPrinter_PageSize->tp_dict,"B1", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPrinter_PageSize,(long) QPrinter::B10, "B10");
    PyDict_SetItemString(Sbk_QPrinter_Type.super.ht_type.tp_dict,"B10", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPrinter_PageSize->tp_dict,"B10", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPrinter_PageSize,(long) QPrinter::B2, "B2");
    PyDict_SetItemString(Sbk_QPrinter_Type.super.ht_type.tp_dict,"B2", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPrinter_PageSize->tp_dict,"B2", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPrinter_PageSize,(long) QPrinter::B3, "B3");
    PyDict_SetItemString(Sbk_QPrinter_Type.super.ht_type.tp_dict,"B3", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPrinter_PageSize->tp_dict,"B3", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPrinter_PageSize,(long) QPrinter::B4, "B4");
    PyDict_SetItemString(Sbk_QPrinter_Type.super.ht_type.tp_dict,"B4", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPrinter_PageSize->tp_dict,"B4", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPrinter_PageSize,(long) QPrinter::B6, "B6");
    PyDict_SetItemString(Sbk_QPrinter_Type.super.ht_type.tp_dict,"B6", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPrinter_PageSize->tp_dict,"B6", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPrinter_PageSize,(long) QPrinter::B7, "B7");
    PyDict_SetItemString(Sbk_QPrinter_Type.super.ht_type.tp_dict,"B7", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPrinter_PageSize->tp_dict,"B7", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPrinter_PageSize,(long) QPrinter::B8, "B8");
    PyDict_SetItemString(Sbk_QPrinter_Type.super.ht_type.tp_dict,"B8", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPrinter_PageSize->tp_dict,"B8", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPrinter_PageSize,(long) QPrinter::B9, "B9");
    PyDict_SetItemString(Sbk_QPrinter_Type.super.ht_type.tp_dict,"B9", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPrinter_PageSize->tp_dict,"B9", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPrinter_PageSize,(long) QPrinter::C5E, "C5E");
    PyDict_SetItemString(Sbk_QPrinter_Type.super.ht_type.tp_dict,"C5E", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPrinter_PageSize->tp_dict,"C5E", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPrinter_PageSize,(long) QPrinter::Comm10E, "Comm10E");
    PyDict_SetItemString(Sbk_QPrinter_Type.super.ht_type.tp_dict,"Comm10E", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPrinter_PageSize->tp_dict,"Comm10E", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPrinter_PageSize,(long) QPrinter::DLE, "DLE");
    PyDict_SetItemString(Sbk_QPrinter_Type.super.ht_type.tp_dict,"DLE", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPrinter_PageSize->tp_dict,"DLE", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPrinter_PageSize,(long) QPrinter::Folio, "Folio");
    PyDict_SetItemString(Sbk_QPrinter_Type.super.ht_type.tp_dict,"Folio", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPrinter_PageSize->tp_dict,"Folio", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPrinter_PageSize,(long) QPrinter::Ledger, "Ledger");
    PyDict_SetItemString(Sbk_QPrinter_Type.super.ht_type.tp_dict,"Ledger", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPrinter_PageSize->tp_dict,"Ledger", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPrinter_PageSize,(long) QPrinter::Tabloid, "Tabloid");
    PyDict_SetItemString(Sbk_QPrinter_Type.super.ht_type.tp_dict,"Tabloid", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPrinter_PageSize->tp_dict,"Tabloid", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPrinter_PageSize,(long) QPrinter::Custom, "Custom");
    PyDict_SetItemString(Sbk_QPrinter_Type.super.ht_type.tp_dict,"Custom", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPrinter_PageSize->tp_dict,"Custom", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPrinter_PageSize,(long) QPrinter::NPageSize, "NPageSize");
    PyDict_SetItemString(Sbk_QPrinter_Type.super.ht_type.tp_dict,"NPageSize", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPrinter_PageSize->tp_dict,"NPageSize", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPrinter_PageSize,(long) QPrinter::NPaperSize, "NPaperSize");
    PyDict_SetItemString(Sbk_QPrinter_Type.super.ht_type.tp_dict,"NPaperSize", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPrinter_PageSize->tp_dict,"NPaperSize", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QPrinter::PageSize");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::PageSize");
    // end of enum PageSize


    Shiboken::TypeResolver::createObjectTypeResolver<QPrinter >("QPrinter*");
    Shiboken::TypeResolver::createObjectTypeResolver<QPrinter >(typeid(QPrinter).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QPrinter >(typeid(QPrinterWrapper).name());
    PySide::initQtMetaType< ::QPrinter* >();
    qRegisterMetaType< ::QPrinter::OutputFormat >("QPrinter::OutputFormat");
    qRegisterMetaType< ::QPrinter::DuplexMode >("QPrinter::DuplexMode");
    qRegisterMetaType< ::QPrinter::PrintRange >("QPrinter::PrintRange");
    qRegisterMetaType< ::QPrinter::Unit >("QPrinter::Unit");
    qRegisterMetaType< ::QPrinter::PrinterMode >("QPrinter::PrinterMode");
    qRegisterMetaType< ::QPrinter::Orientation >("QPrinter::Orientation");
    qRegisterMetaType< ::QPrinter::PrinterState >("QPrinter::PrinterState");
    qRegisterMetaType< ::QPrinter::ColorMode >("QPrinter::ColorMode");
    qRegisterMetaType< ::QPrinter::PaperSource >("QPrinter::PaperSource");
    qRegisterMetaType< ::QPrinter::PageOrder >("QPrinter::PageOrder");
    qRegisterMetaType< ::QPrinter::PageSize >("QPrinter::PageSize");
}

