/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qquaternion_wrapper.h"

// Extra includes
#include <qdatastream.h>
#include <qquaternion.h>
#include <qvector3d.h>
#include <qvector4d.h>



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QQuaternion_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QQuaternion >()))
        return -1;

    QQuaternion* cptr = 0;
    int overloadId = -1;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs == 3)
        goto Sbk_QQuaternion_Init_TypeError;

    if (!PyArg_UnpackTuple(args, "QQuaternion", 0, 4, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return -1;

    // Overloaded function decisor
    // 0: QQuaternion()
    // 1: QQuaternion(QQuaternion)
    // 2: QQuaternion(QVector4D)
    // 3: QQuaternion(qreal,QVector3D)
    // 4: QQuaternion(qreal,qreal,qreal,qreal)
    if (numArgs == 0) {
        overloadId = 0; // QQuaternion()
    } else if (SbkNumber_Check(pyargs[0])) {
        if (numArgs == 4 && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3])) {
            overloadId = 4; // QQuaternion(qreal,qreal,qreal,qreal)
        } else if (numArgs == 2 && Shiboken::Converter< ::QVector3D >::isConvertible(pyargs[1])) {
            overloadId = 3; // QQuaternion(qreal,QVector3D)
        }
    } else if (numArgs == 1 && Shiboken::Converter< ::QVector4D >::isConvertible(pyargs[0])) {
        overloadId = 2; // QQuaternion(QVector4D)
    } else if (numArgs == 1 && Shiboken::Converter< ::QQuaternion >::isConvertible(pyargs[0])) {
        overloadId = 1; // QQuaternion(QQuaternion)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QQuaternion_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QQuaternion()
            {

                if(!PyErr_Occurred()) {
                    // QQuaternion()
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QQuaternion();
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // QQuaternion(QQuaternion)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QQuaternion cppArg0 = Shiboken::Converter<QQuaternion >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QQuaternion(QQuaternion)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QQuaternion(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 2: // QQuaternion(QVector4D)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QVector4D cppArg0 = Shiboken::Converter<QVector4D >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QQuaternion(QVector4D)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QQuaternion(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 3: // QQuaternion(qreal,QVector3D)
            {
                qreal cppArg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return -1;
                QVector3D cppArg1 = Shiboken::Converter<QVector3D >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // QQuaternion(qreal,QVector3D)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QQuaternion(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 4: // QQuaternion(qreal,qreal,qreal,qreal)
            {
                qreal cppArg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
                qreal cppArg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);
                qreal cppArg2 = Shiboken::Converter<qreal >::toCpp(pyargs[2]);
                qreal cppArg3 = Shiboken::Converter<qreal >::toCpp(pyargs[3]);

                if(!PyErr_Occurred()) {
                    // QQuaternion(qreal,qreal,qreal,qreal)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QQuaternion(cppArg0, cppArg1, cppArg2, cppArg3);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QQuaternion >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QQuaternion_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QQuaternion_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtGui.QQuaternion", "PySide.QtGui.QVector4D", "float, PySide.QtGui.QVector3D", "float, float, float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QQuaternion", overloads);
        return -1;
}

static PyObject* Sbk_QQuaternionFunc___reduce__(PyObject* self)
{
    QQuaternion* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QQuaternion* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // __reduce__()
                // Begin code injection

                // TEMPLATE - reduce_code - START
                pyResult = Py_BuildValue("(N(dddd))", PyObject_Type(self), cppSelf->scalar(), cppSelf->x(), cppSelf->y(), cppSelf->z());
                // TEMPLATE - reduce_code - END

                // End of code injection


            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QQuaternionFunc___repr__(PyObject* self)
{
    QQuaternion* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QQuaternion* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // __repr__()
                // Begin code injection

                // TEMPLATE - repr_code - START
                QString format = QString().sprintf("%s(%f, %f, %f, %f)", ((PyObject*)self)->ob_type->tp_name, cppSelf->scalar(), cppSelf->x(), cppSelf->y(), cppSelf->z());
                pyResult = PyString_FromString(qPrintable(format));
                // TEMPLATE - repr_code - END

                // End of code injection


            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QQuaternionFunc_conjugate(PyObject* self)
{
    QQuaternion* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QQuaternion* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // conjugate()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QQuaternion cppResult = const_cast<const QQuaternion*>(cppSelf)->conjugate();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QQuaternion >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QQuaternionFunc_fromAxisAndAngle(PyObject* self, PyObject* args)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs == 3)
        goto Sbk_QQuaternionFunc_fromAxisAndAngle_TypeError;

    if (!PyArg_UnpackTuple(args, "fromAxisAndAngle", 2, 4, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: fromAxisAndAngle(QVector3D,qreal)
    // 1: fromAxisAndAngle(qreal,qreal,qreal,qreal)
    if (numArgs == 4 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3])) {
        overloadId = 1; // fromAxisAndAngle(qreal,qreal,qreal,qreal)
    } else if (numArgs == 2 && Shiboken::Converter< ::QVector3D >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 0; // fromAxisAndAngle(QVector3D,qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QQuaternionFunc_fromAxisAndAngle_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // fromAxisAndAngle(QVector3D,qreal)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QVector3D cppArg0 = Shiboken::Converter<QVector3D >::toCpp(pyargs[0]);
                qreal cppArg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // fromAxisAndAngle(QVector3D,qreal)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QQuaternion cppResult = QQuaternion::fromAxisAndAngle(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QQuaternion >::toPython(cppResult);
                }
                break;
            }
            case 1: // fromAxisAndAngle(qreal,qreal,qreal,qreal)
            {
                qreal cppArg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
                qreal cppArg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);
                qreal cppArg2 = Shiboken::Converter<qreal >::toCpp(pyargs[2]);
                qreal cppArg3 = Shiboken::Converter<qreal >::toCpp(pyargs[3]);

                if(!PyErr_Occurred()) {
                    // fromAxisAndAngle(qreal,qreal,qreal,qreal)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QQuaternion cppResult = QQuaternion::fromAxisAndAngle(cppArg0, cppArg1, cppArg2, cppArg3);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QQuaternion >::toPython(cppResult);
                }
                break;
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QQuaternionFunc_fromAxisAndAngle_TypeError:
        const char* overloads[] = {"PySide.QtGui.QVector3D, float", "float, float, float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QQuaternion.fromAxisAndAngle", overloads);
        return 0;
}

static PyObject* Sbk_QQuaternionFunc_isIdentity(PyObject* self)
{
    QQuaternion* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QQuaternion* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isIdentity()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QQuaternion*>(cppSelf)->isIdentity();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QQuaternionFunc_isNull(PyObject* self)
{
    QQuaternion* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QQuaternion* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isNull()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QQuaternion*>(cppSelf)->isNull();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QQuaternionFunc_length(PyObject* self)
{
    QQuaternion* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QQuaternion* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // length()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                qreal cppResult = const_cast<const QQuaternion*>(cppSelf)->length();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< double >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QQuaternionFunc_lengthSquared(PyObject* self)
{
    QQuaternion* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QQuaternion* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // lengthSquared()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                qreal cppResult = const_cast<const QQuaternion*>(cppSelf)->lengthSquared();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< double >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QQuaternionFunc_nlerp(PyObject* self, PyObject* args)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "nlerp", 3, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: nlerp(QQuaternion,QQuaternion,qreal)
    if (numArgs == 3 && Shiboken::Converter< ::QQuaternion >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QQuaternion >::isConvertible(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
        overloadId = 0; // nlerp(QQuaternion,QQuaternion,qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QQuaternionFunc_nlerp_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QQuaternion cppArg0 = Shiboken::Converter<QQuaternion >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            QQuaternion cppArg1 = Shiboken::Converter<QQuaternion >::toCpp(pyargs[1]);
            qreal cppArg2 = Shiboken::Converter<qreal >::toCpp(pyargs[2]);

            if(!PyErr_Occurred()) {
                // nlerp(QQuaternion,QQuaternion,qreal)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QQuaternion cppResult = QQuaternion::nlerp(cppArg0, cppArg1, cppArg2);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QQuaternion >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QQuaternionFunc_nlerp_TypeError:
        const char* overloads[] = {"PySide.QtGui.QQuaternion, PySide.QtGui.QQuaternion, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QQuaternion.nlerp", overloads);
        return 0;
}

static PyObject* Sbk_QQuaternionFunc_normalize(PyObject* self)
{
    QQuaternion* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QQuaternion* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // normalize()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->normalize();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QQuaternionFunc_normalized(PyObject* self)
{
    QQuaternion* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QQuaternion* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // normalized()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QQuaternion cppResult = const_cast<const QQuaternion*>(cppSelf)->normalized();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QQuaternion >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QQuaternionFunc_rotatedVector(PyObject* self, PyObject* arg)
{
    QQuaternion* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QQuaternion* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: rotatedVector(QVector3D)const
    if (Shiboken::Converter< ::QVector3D >::isConvertible(arg)) {
        overloadId = 0; // rotatedVector(QVector3D)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QQuaternionFunc_rotatedVector_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QVector3D cppArg0 = Shiboken::Converter<QVector3D >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // rotatedVector(QVector3D)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QVector3D cppResult = const_cast<const QQuaternion*>(cppSelf)->rotatedVector(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QVector3D >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QQuaternionFunc_rotatedVector_TypeError:
        const char* overloads[] = {"PySide.QtGui.QVector3D", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QQuaternion.rotatedVector", overloads);
        return 0;
}

static PyObject* Sbk_QQuaternionFunc_scalar(PyObject* self)
{
    QQuaternion* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QQuaternion* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // scalar()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                qreal cppResult = const_cast<const QQuaternion*>(cppSelf)->scalar();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< double >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QQuaternionFunc_setScalar(PyObject* self, PyObject* arg)
{
    QQuaternion* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QQuaternion* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setScalar(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setScalar(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QQuaternionFunc_setScalar_TypeError;

    // Call function/method
    {
        {
            qreal cppArg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setScalar(qreal)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setScalar(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QQuaternionFunc_setScalar_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QQuaternion.setScalar", overloads);
        return 0;
}

static PyObject* Sbk_QQuaternionFunc_setVector(PyObject* self, PyObject* args)
{
    QQuaternion* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QQuaternion* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs == 2)
        goto Sbk_QQuaternionFunc_setVector_TypeError;

    if (!PyArg_UnpackTuple(args, "setVector", 1, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: setVector(QVector3D)
    // 1: setVector(qreal,qreal,qreal)
    if (numArgs == 3 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
        overloadId = 1; // setVector(qreal,qreal,qreal)
    } else if (numArgs == 1 && Shiboken::Converter< ::QVector3D >::isConvertible(pyargs[0])) {
        overloadId = 0; // setVector(QVector3D)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QQuaternionFunc_setVector_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // setVector(QVector3D)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QVector3D cppArg0 = Shiboken::Converter<QVector3D >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // setVector(QVector3D)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setVector(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // setVector(qreal,qreal,qreal)
            {
                qreal cppArg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
                qreal cppArg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);
                qreal cppArg2 = Shiboken::Converter<qreal >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                    // setVector(qreal,qreal,qreal)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setVector(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QQuaternionFunc_setVector_TypeError:
        const char* overloads[] = {"PySide.QtGui.QVector3D", "float, float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QQuaternion.setVector", overloads);
        return 0;
}

static PyObject* Sbk_QQuaternionFunc_setX(PyObject* self, PyObject* arg)
{
    QQuaternion* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QQuaternion* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setX(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setX(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QQuaternionFunc_setX_TypeError;

    // Call function/method
    {
        {
            qreal cppArg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setX(qreal)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setX(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QQuaternionFunc_setX_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QQuaternion.setX", overloads);
        return 0;
}

static PyObject* Sbk_QQuaternionFunc_setY(PyObject* self, PyObject* arg)
{
    QQuaternion* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QQuaternion* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setY(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setY(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QQuaternionFunc_setY_TypeError;

    // Call function/method
    {
        {
            qreal cppArg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setY(qreal)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setY(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QQuaternionFunc_setY_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QQuaternion.setY", overloads);
        return 0;
}

static PyObject* Sbk_QQuaternionFunc_setZ(PyObject* self, PyObject* arg)
{
    QQuaternion* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QQuaternion* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setZ(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setZ(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QQuaternionFunc_setZ_TypeError;

    // Call function/method
    {
        {
            qreal cppArg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setZ(qreal)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setZ(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QQuaternionFunc_setZ_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QQuaternion.setZ", overloads);
        return 0;
}

static PyObject* Sbk_QQuaternionFunc_slerp(PyObject* self, PyObject* args)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "slerp", 3, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: slerp(QQuaternion,QQuaternion,qreal)
    if (numArgs == 3 && Shiboken::Converter< ::QQuaternion >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QQuaternion >::isConvertible(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
        overloadId = 0; // slerp(QQuaternion,QQuaternion,qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QQuaternionFunc_slerp_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QQuaternion cppArg0 = Shiboken::Converter<QQuaternion >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            QQuaternion cppArg1 = Shiboken::Converter<QQuaternion >::toCpp(pyargs[1]);
            qreal cppArg2 = Shiboken::Converter<qreal >::toCpp(pyargs[2]);

            if(!PyErr_Occurred()) {
                // slerp(QQuaternion,QQuaternion,qreal)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QQuaternion cppResult = QQuaternion::slerp(cppArg0, cppArg1, cppArg2);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QQuaternion >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QQuaternionFunc_slerp_TypeError:
        const char* overloads[] = {"PySide.QtGui.QQuaternion, PySide.QtGui.QQuaternion, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QQuaternion.slerp", overloads);
        return 0;
}

static PyObject* Sbk_QQuaternionFunc_toVector4D(PyObject* self)
{
    QQuaternion* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QQuaternion* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // toVector4D()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QVector4D cppResult = const_cast<const QQuaternion*>(cppSelf)->toVector4D();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QVector4D >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QQuaternionFunc_vector(PyObject* self)
{
    QQuaternion* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QQuaternion* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // vector()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QVector3D cppResult = const_cast<const QQuaternion*>(cppSelf)->vector();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QVector3D >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QQuaternionFunc_x(PyObject* self)
{
    QQuaternion* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QQuaternion* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // x()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                qreal cppResult = const_cast<const QQuaternion*>(cppSelf)->x();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< double >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QQuaternionFunc_y(PyObject* self)
{
    QQuaternion* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QQuaternion* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // y()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                qreal cppResult = const_cast<const QQuaternion*>(cppSelf)->y();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< double >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QQuaternionFunc_z(PyObject* self)
{
    QQuaternion* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QQuaternion* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // z()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                qreal cppResult = const_cast<const QQuaternion*>(cppSelf)->z();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< double >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject *Sbk_QQuaternion___copy__(PyObject *self)
{
        QQuaternion* cppSelf = 0;
        if (!Shiboken::Object::isValid(self))
            return 0;
        cppSelf = Shiboken::Converter<QQuaternion*>::toCpp(self);
        PyObject* pyResult = 0;
        QQuaternion* copy = new QQuaternion(*cppSelf);
        pyResult = Shiboken::Converter<QQuaternion*>::toPython(copy);
        Shiboken::Object::getOwnership(pyResult);

        if (PyErr_Occurred() || !pyResult) {
            Py_XDECREF(pyResult);
            return 0;
        }
        return pyResult;
}

static PyMethodDef Sbk_QQuaternion_methods[] = {
    {"__reduce__", (PyCFunction)Sbk_QQuaternionFunc___reduce__, METH_NOARGS},
    {"conjugate", (PyCFunction)Sbk_QQuaternionFunc_conjugate, METH_NOARGS},
    {"fromAxisAndAngle", (PyCFunction)Sbk_QQuaternionFunc_fromAxisAndAngle, METH_VARARGS|METH_STATIC},
    {"isIdentity", (PyCFunction)Sbk_QQuaternionFunc_isIdentity, METH_NOARGS},
    {"isNull", (PyCFunction)Sbk_QQuaternionFunc_isNull, METH_NOARGS},
    {"length", (PyCFunction)Sbk_QQuaternionFunc_length, METH_NOARGS},
    {"lengthSquared", (PyCFunction)Sbk_QQuaternionFunc_lengthSquared, METH_NOARGS},
    {"nlerp", (PyCFunction)Sbk_QQuaternionFunc_nlerp, METH_VARARGS|METH_STATIC},
    {"normalize", (PyCFunction)Sbk_QQuaternionFunc_normalize, METH_NOARGS},
    {"normalized", (PyCFunction)Sbk_QQuaternionFunc_normalized, METH_NOARGS},
    {"rotatedVector", (PyCFunction)Sbk_QQuaternionFunc_rotatedVector, METH_O},
    {"scalar", (PyCFunction)Sbk_QQuaternionFunc_scalar, METH_NOARGS},
    {"setScalar", (PyCFunction)Sbk_QQuaternionFunc_setScalar, METH_O},
    {"setVector", (PyCFunction)Sbk_QQuaternionFunc_setVector, METH_VARARGS},
    {"setX", (PyCFunction)Sbk_QQuaternionFunc_setX, METH_O},
    {"setY", (PyCFunction)Sbk_QQuaternionFunc_setY, METH_O},
    {"setZ", (PyCFunction)Sbk_QQuaternionFunc_setZ, METH_O},
    {"slerp", (PyCFunction)Sbk_QQuaternionFunc_slerp, METH_VARARGS|METH_STATIC},
    {"toVector4D", (PyCFunction)Sbk_QQuaternionFunc_toVector4D, METH_NOARGS},
    {"vector", (PyCFunction)Sbk_QQuaternionFunc_vector, METH_NOARGS},
    {"x", (PyCFunction)Sbk_QQuaternionFunc_x, METH_NOARGS},
    {"y", (PyCFunction)Sbk_QQuaternionFunc_y, METH_NOARGS},
    {"z", (PyCFunction)Sbk_QQuaternionFunc_z, METH_NOARGS},

    {"__copy__", (PyCFunction)Sbk_QQuaternion___copy__, METH_NOARGS},
    {0} // Sentinel
};

static int Sbk_QQuaternion___nb_bool(PyObject* pyObj)
{
    if (!Shiboken::Object::isValid(pyObj))
        return -1;
    const ::QQuaternion* cppSelf = Shiboken::Converter< ::QQuaternion*>::toCpp(pyObj);
    int result;
    Py_BEGIN_ALLOW_THREADS
    result = !cppSelf->isNull();
    Py_END_ALLOW_THREADS
    return result;
}

static PyObject* Sbk_QQuaternionFunc___mul__(PyObject* self, PyObject* arg)
{
    QQuaternion* cppSelf = 0;
    bool isReverse = Shiboken::Converter< ::QQuaternion >::checkType(arg) && !Shiboken::Converter< ::QQuaternion >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QQuaternion* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && Shiboken::Object::checkType(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__rmul__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__rmul__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator*(QQuaternion,QQuaternion)
    // 1: operator*(QQuaternion,qreal)
    // 2: operator*(qreal,QQuaternion)
    if (isReverse && SbkNumber_Check(arg)) {
        overloadId = 2; // operator*(qreal,QQuaternion)
    } else if (!isReverse && SbkNumber_Check(arg)) {
        overloadId = 1; // operator*(QQuaternion,qreal)
    } else if (!isReverse && Shiboken::Converter< ::QQuaternion >::isConvertible(arg)) {
        overloadId = 0; // operator*(QQuaternion,QQuaternion)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QQuaternionFunc___mul___TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // operator*(QQuaternion,QQuaternion)
            {
                if (!Shiboken::Object::isValid(arg))
                    return 0;
                QQuaternion cppArg0 = Shiboken::Converter<QQuaternion >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // operator*(QQuaternion,QQuaternion)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    const QQuaternion cppResult = (*cppSelf) * (cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QQuaternion >::toPython(cppResult);
                }
                break;
            }
            case 1: // operator*(QQuaternion,qreal)
            {
                qreal cppArg0 = Shiboken::Converter<qreal >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // operator*(QQuaternion,qreal)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    const QQuaternion cppResult = (*cppSelf) * cppArg0;
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QQuaternion >::toPython(cppResult);
                }
                break;
            }
            case 2: // operator*(qreal,QQuaternion)
            {
                qreal cppArg0 = Shiboken::Converter<qreal >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // operator*(qreal,QQuaternion) [reverse operator]
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    const QQuaternion cppResult = cppArg0 * (*cppSelf);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QQuaternion >::toPython(cppResult);
                }
                break;
            }
        }
    }


    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QQuaternionFunc___mul___TypeError:
        const char* overloads[] = {"PySide.QtGui.QQuaternion", "float", "float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QQuaternion.__mul__", overloads);
        return 0;
}

static PyObject* Sbk_QQuaternionFunc___imul__(PyObject* self, PyObject* arg)
{
    QQuaternion* cppSelf = 0;
    bool isReverse = Shiboken::Converter< ::QQuaternion >::checkType(arg) && !Shiboken::Converter< ::QQuaternion >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QQuaternion* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: operator*=(QQuaternion)
    // 1: operator*=(qreal)
    if (!isReverse && SbkNumber_Check(arg)) {
        overloadId = 1; // operator*=(qreal)
    } else if (!isReverse && Shiboken::Converter< ::QQuaternion >::isConvertible(arg)) {
        overloadId = 0; // operator*=(QQuaternion)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QQuaternionFunc___imul___TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // operator*=(QQuaternion)
            {
                if (!Shiboken::Object::isValid(arg))
                    return 0;
                QQuaternion cppArg0 = Shiboken::Converter<QQuaternion >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // operator*=(QQuaternion)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    (*cppSelf) *= (cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // operator*=(qreal)
            {
                qreal cppArg0 = Shiboken::Converter<qreal >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // operator*=(qreal)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    (*cppSelf) *= cppArg0;
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_INCREF(self);
    return self;

    Sbk_QQuaternionFunc___imul___TypeError:
        const char* overloads[] = {"PySide.QtGui.QQuaternion", "float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QQuaternion.__imul__", overloads);
        return 0;
}

static PyObject* Sbk_QQuaternionFunc___add__(PyObject* self, PyObject* arg)
{
    QQuaternion* cppSelf = 0;
    bool isReverse = Shiboken::Converter< ::QQuaternion >::checkType(arg) && !Shiboken::Converter< ::QQuaternion >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QQuaternion* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && Shiboken::Object::checkType(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__radd__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__radd__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator+(QQuaternion,QQuaternion)
    if (!isReverse && Shiboken::Converter< ::QQuaternion >::isConvertible(arg)) {
        overloadId = 0; // operator+(QQuaternion,QQuaternion)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QQuaternionFunc___add___TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QQuaternion cppArg0 = Shiboken::Converter<QQuaternion >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // operator+(QQuaternion,QQuaternion)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                const QQuaternion cppResult = (*cppSelf) + (cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QQuaternion >::toPython(cppResult);
            }
        }
    }


    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QQuaternionFunc___add___TypeError:
        const char* overloads[] = {"PySide.QtGui.QQuaternion", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QQuaternion.__add__", overloads);
        return 0;
}

static PyObject* Sbk_QQuaternionFunc___iadd__(PyObject* self, PyObject* arg)
{
    QQuaternion* cppSelf = 0;
    bool isReverse = Shiboken::Converter< ::QQuaternion >::checkType(arg) && !Shiboken::Converter< ::QQuaternion >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QQuaternion* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: operator+=(QQuaternion)
    if (!isReverse && Shiboken::Converter< ::QQuaternion >::isConvertible(arg)) {
        overloadId = 0; // operator+=(QQuaternion)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QQuaternionFunc___iadd___TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QQuaternion cppArg0 = Shiboken::Converter<QQuaternion >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // operator+=(QQuaternion)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (*cppSelf) += (cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_INCREF(self);
    return self;

    Sbk_QQuaternionFunc___iadd___TypeError:
        const char* overloads[] = {"PySide.QtGui.QQuaternion", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QQuaternion.__iadd__", overloads);
        return 0;
}

static PyObject* Sbk_QQuaternionFunc___neg__(PyObject* self)
{
    QQuaternion* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QQuaternion* >::toCpp(self);

    PyObject* pyResult = 0;

    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // operator-(QQuaternion)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                const QQuaternion cppResult = - (*cppSelf);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QQuaternion >::toPython(cppResult);
            }
        }
    }


    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QQuaternionFunc___sub__(PyObject* self, PyObject* arg)
{
    QQuaternion* cppSelf = 0;
    bool isReverse = Shiboken::Converter< ::QQuaternion >::checkType(arg) && !Shiboken::Converter< ::QQuaternion >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QQuaternion* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && Shiboken::Object::checkType(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__rsub__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__rsub__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator-(QQuaternion,QQuaternion)
    if (!isReverse && Shiboken::Converter< ::QQuaternion >::isConvertible(arg)) {
        overloadId = 0; // operator-(QQuaternion,QQuaternion)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QQuaternionFunc___sub___TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QQuaternion cppArg0 = Shiboken::Converter<QQuaternion >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // operator-(QQuaternion,QQuaternion)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                const QQuaternion cppResult = (*cppSelf) - (cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QQuaternion >::toPython(cppResult);
            }
        }
    }


    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QQuaternionFunc___sub___TypeError:
        const char* overloads[] = {"PySide.QtGui.QQuaternion", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QQuaternion.__sub__", overloads);
        return 0;
}

static PyObject* Sbk_QQuaternionFunc___isub__(PyObject* self, PyObject* arg)
{
    QQuaternion* cppSelf = 0;
    bool isReverse = Shiboken::Converter< ::QQuaternion >::checkType(arg) && !Shiboken::Converter< ::QQuaternion >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QQuaternion* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: operator-=(QQuaternion)
    if (!isReverse && Shiboken::Converter< ::QQuaternion >::isConvertible(arg)) {
        overloadId = 0; // operator-=(QQuaternion)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QQuaternionFunc___isub___TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QQuaternion cppArg0 = Shiboken::Converter<QQuaternion >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // operator-=(QQuaternion)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (*cppSelf) -= (cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_INCREF(self);
    return self;

    Sbk_QQuaternionFunc___isub___TypeError:
        const char* overloads[] = {"PySide.QtGui.QQuaternion", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QQuaternion.__isub__", overloads);
        return 0;
}

static PyObject* Sbk_QQuaternionFunc___div__(PyObject* self, PyObject* arg)
{
    QQuaternion* cppSelf = 0;
    bool isReverse = Shiboken::Converter< ::QQuaternion >::checkType(arg) && !Shiboken::Converter< ::QQuaternion >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QQuaternion* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && Shiboken::Object::checkType(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__rdiv__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__rdiv__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator/(QQuaternion,qreal)
    if (!isReverse && SbkNumber_Check(arg)) {
        overloadId = 0; // operator/(QQuaternion,qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QQuaternionFunc___div___TypeError;

    // Call function/method
    {
        {
            qreal cppArg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // operator/(QQuaternion,qreal)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                const QQuaternion cppResult = (*cppSelf) / cppArg0;
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QQuaternion >::toPython(cppResult);
            }
        }
    }


    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QQuaternionFunc___div___TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QQuaternion.__div__", overloads);
        return 0;
}

static PyObject* Sbk_QQuaternionFunc___idiv__(PyObject* self, PyObject* arg)
{
    QQuaternion* cppSelf = 0;
    bool isReverse = Shiboken::Converter< ::QQuaternion >::checkType(arg) && !Shiboken::Converter< ::QQuaternion >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QQuaternion* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: operator/=(qreal)
    if (!isReverse && SbkNumber_Check(arg)) {
        overloadId = 0; // operator/=(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QQuaternionFunc___idiv___TypeError;

    // Call function/method
    {
        {
            qreal cppArg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // operator/=(qreal)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (*cppSelf) /= cppArg0;
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_INCREF(self);
    return self;

    Sbk_QQuaternionFunc___idiv___TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QQuaternion.__idiv__", overloads);
        return 0;
}

static PyObject* Sbk_QQuaternionFunc___lshift__(PyObject* self, PyObject* arg)
{
    QQuaternion* cppSelf = 0;
    bool isReverse = Shiboken::Converter< ::QQuaternion >::checkType(arg) && !Shiboken::Converter< ::QQuaternion >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QQuaternion* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && Shiboken::Object::checkType(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__rlshift__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__rlshift__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator<<(QDataStream&,QQuaternion)
    if (isReverse && Shiboken::Converter< ::QDataStream & >::isConvertible(arg)) {
        overloadId = 0; // operator<<(QDataStream&,QQuaternion)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QQuaternionFunc___lshift___TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QDataStream & cppArg0 = Shiboken::Converter<QDataStream & >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // operator<<(QDataStream&,QQuaternion) [reverse operator]
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QDataStream & cppResult = (cppArg0) << (*cppSelf);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QDataStream & >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QQuaternionFunc___lshift___TypeError:
        const char* overloads[] = {"PySide.QtCore.QDataStream", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QQuaternion.__lshift__", overloads);
        return 0;
}

static PyObject* Sbk_QQuaternionFunc___rshift__(PyObject* self, PyObject* arg)
{
    QQuaternion* cppSelf = 0;
    bool isReverse = Shiboken::Converter< ::QQuaternion >::checkType(arg) && !Shiboken::Converter< ::QQuaternion >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QQuaternion* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && Shiboken::Object::checkType(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__rrshift__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__rrshift__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator>>(QDataStream&,QQuaternion&)
    if (isReverse && Shiboken::Converter< ::QDataStream & >::isConvertible(arg)) {
        overloadId = 0; // operator>>(QDataStream&,QQuaternion&)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QQuaternionFunc___rshift___TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QDataStream & cppArg0 = Shiboken::Converter<QDataStream & >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // operator>>(QDataStream&,QQuaternion&) [reverse operator]
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QDataStream & cppResult = (cppArg0) >> (*cppSelf);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QDataStream & >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QQuaternionFunc___rshift___TypeError:
        const char* overloads[] = {"PySide.QtCore.QDataStream", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QQuaternion.__rshift__", overloads);
        return 0;
}

// type has number operators
static PyNumberMethods Sbk_QQuaternion_as_number = {
    /*nb_add*/                  (binaryfunc)Sbk_QQuaternionFunc___add__,
    /*nb_subtract*/             (binaryfunc)Sbk_QQuaternionFunc___sub__,
    /*nb_multiply*/             (binaryfunc)Sbk_QQuaternionFunc___mul__,
    /*nb_divide*/               (binaryfunc)Sbk_QQuaternionFunc___div__,
    /*nb_remainder*/            (binaryfunc)0,
    /*nb_divmod*/               0,
    /*nb_power*/                0,
    /*nb_negative*/             (unaryfunc)Sbk_QQuaternionFunc___neg__,
    /*nb_positive*/             (unaryfunc)0,
    /*nb_absolute*/             0,
    /*nb_nonzero*/              Sbk_QQuaternion___nb_bool,
    /*nb_invert*/               (unaryfunc)0,
    /*nb_lshift*/               (binaryfunc)Sbk_QQuaternionFunc___lshift__,
    /*nb_rshift*/               (binaryfunc)Sbk_QQuaternionFunc___rshift__,
    /*nb_and*/                  (binaryfunc)0,
    /*nb_xor*/                  (binaryfunc)0,
    /*nb_or*/                   (binaryfunc)0,
    /*nb_coerce*/               0,
    /*nb_int*/                  0,
    /*nb_long*/                 0,
    /*nb_float*/                0,
    /*nb_oct*/                  0,
    /*nb_hex*/                  0,
    /*nb_inplace_add*/          (binaryfunc)Sbk_QQuaternionFunc___iadd__,
    /*nb_inplace_subtract*/     (binaryfunc)Sbk_QQuaternionFunc___isub__,
    /*nb_inplace_multiply*/     (binaryfunc)Sbk_QQuaternionFunc___imul__,
    /*nb_inplace_divide*/       (binaryfunc)Sbk_QQuaternionFunc___idiv__,
    /*nb_inplace_remainder*/    (binaryfunc)0,
    /*nb_inplace_power*/        0,
    /*nb_inplace_lshift*/       (binaryfunc)0,
    /*nb_inplace_rshift*/       (binaryfunc)0,
    /*nb_inplace_and*/          (binaryfunc)0,
    /*nb_inplace_xor*/          (binaryfunc)0,
    /*nb_inplace_or*/           (binaryfunc)0,
    /*nb_floor_divide*/         0,
    /*nb_true_divide*/          (binaryfunc)Sbk_QQuaternionFunc___div__,
    /*nb_inplace_floor_divide*/ 0,
    /*nb_inplace_true_divide*/  0,
    /*nb_index*/                0
};

// Rich comparison
static PyObject* Sbk_QQuaternion_richcompare(PyObject* self, PyObject* arg, int op)
{
    PyObject* pyResult = 0;
    QQuaternion& cppSelf = *Shiboken::Converter< QQuaternion* >::toCpp(self);

    switch (op) {
        case Py_NE:
            if (Shiboken::Converter< ::QQuaternion >::isConvertible(arg)) {
                // operator!=(const QQuaternion & q2)
                QQuaternion cppArg0 = Shiboken::Converter< ::QQuaternion >::toCpp(arg);
                pyResult = Shiboken::Converter< bool >::toPython(cppSelf != cppArg0);
            } else goto Sbk_QQuaternion_RichComparison_TypeError;

            break;
        case Py_EQ:
            if (Shiboken::Converter< ::QQuaternion >::isConvertible(arg)) {
                // operator==(const QQuaternion & q2)
                QQuaternion cppArg0 = Shiboken::Converter< ::QQuaternion >::toCpp(arg);
                pyResult = Shiboken::Converter< bool >::toPython(cppSelf == cppArg0);
            } else goto Sbk_QQuaternion_RichComparison_TypeError;

            break;
        default:
            goto Sbk_QQuaternion_RichComparison_TypeError;
    }

    if (pyResult && !PyErr_Occurred())
        return pyResult;
    Sbk_QQuaternion_RichComparison_TypeError:
    PyErr_SetString(PyExc_NotImplementedError, "operator not implemented.");
    return 0;

}

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QQuaternion_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QQuaternion",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Sbk_QQuaternionFunc___repr__,
    /*tp_as_number*/        &Sbk_QQuaternion_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      Sbk_QQuaternion_richcompare,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QQuaternion_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QQuaternion_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QQuaternion(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QQUATERNION_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QQuaternion_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QQuaternion_Type);
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QQuaternion_Type, &Shiboken::callCppDestructor<QQuaternion >);
    if (PyType_Ready((PyTypeObject*)&Sbk_QQuaternion_Type) < 0)
        return;

    Shiboken::ObjectType::setOriginalName(&Sbk_QQuaternion_Type, "QQuaternion");
    PyModule_AddObject(module, "QQuaternion",
        ((PyObject*)&Sbk_QQuaternion_Type));


    Shiboken::TypeResolver::createValueTypeResolver<QQuaternion >("QQuaternion");
    Shiboken::TypeResolver::createObjectTypeResolver<QQuaternion >("QQuaternion*");
    Shiboken::TypeResolver::createValueTypeResolver<QQuaternion >(typeid(QQuaternion).name());
    PySide::initQtMetaType< ::QQuaternion >();
}

