/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qstyleoptiondockwidget_wrapper.h"

// Extra includes
#include <qstyleoption.h>
#include <qwidget.h>



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QStyleOptionDockWidget_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QStyleOptionDockWidget >()))
        return -1;

    QStyleOptionDockWidget* cptr = 0;
    int overloadId = -1;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QStyleOptionDockWidget", 0, 1, &(pyargs[0])))
        return -1;

    // Overloaded function decisor
    // 0: QStyleOptionDockWidget()
    // 1: QStyleOptionDockWidget(QStyleOptionDockWidget)
    // 2: QStyleOptionDockWidget(int)
    if (numArgs == 0) {
        overloadId = 0; // QStyleOptionDockWidget()
    } else if (numArgs == 1 && SbkNumber_Check(pyargs[0])) {
        overloadId = 2; // QStyleOptionDockWidget(int)
    } else if (numArgs == 1 && Shiboken::Converter< ::QStyleOptionDockWidget >::isConvertible(pyargs[0])) {
        overloadId = 1; // QStyleOptionDockWidget(QStyleOptionDockWidget)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QStyleOptionDockWidget_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QStyleOptionDockWidget()
            {

                if(!PyErr_Occurred()) {
                    // QStyleOptionDockWidget()
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QStyleOptionDockWidget();
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // QStyleOptionDockWidget(QStyleOptionDockWidget)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QStyleOptionDockWidget cppArg0 = Shiboken::Converter<QStyleOptionDockWidget >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QStyleOptionDockWidget(QStyleOptionDockWidget)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QStyleOptionDockWidget(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 2: // QStyleOptionDockWidget(int)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QStyleOptionDockWidget(int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QStyleOptionDockWidget(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QStyleOptionDockWidget >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QStyleOptionDockWidget_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QStyleOptionDockWidget_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtGui.QStyleOptionDockWidget", "int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QStyleOptionDockWidget", overloads);
        return -1;
}

static PyObject *Sbk_QStyleOptionDockWidget___copy__(PyObject *self)
{
        QStyleOptionDockWidget* cppSelf = 0;
        if (!Shiboken::Object::isValid(self))
            return 0;
        cppSelf = Shiboken::Converter<QStyleOptionDockWidget*>::toCpp(self);
        PyObject* pyResult = 0;
        QStyleOptionDockWidget* copy = new QStyleOptionDockWidget(*cppSelf);
        pyResult = Shiboken::Converter<QStyleOptionDockWidget*>::toPython(copy);
        Shiboken::Object::getOwnership(pyResult);

        if (PyErr_Occurred() || !pyResult) {
            Py_XDECREF(pyResult);
            return 0;
        }
        return pyResult;
}

static PyMethodDef Sbk_QStyleOptionDockWidget_methods[] = {

    {"__copy__", (PyCFunction)Sbk_QStyleOptionDockWidget___copy__, METH_NOARGS},
    {0} // Sentinel
};

static PyObject* Sbk_QStyleOptionDockWidget_get_title(PyObject* self, void*)
{
    PyObject* val = Shiboken::Converter< QString >::toPython( Shiboken::Converter< QStyleOptionDockWidget* >::toCpp(self)->title);
    return val;
}

static int Sbk_QStyleOptionDockWidget_set_title(PyObject* self, PyObject* value, void*)
{
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'title' may not be deleted");
        return -1;
    }
    if (!Shiboken::Converter< QString >::isConvertible(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'title', 'QString' or convertible type expected");
        return -1;
    }

    Shiboken::Converter< QStyleOptionDockWidget* >::toCpp(self)->title = Shiboken::Converter< QString >::toCpp(value);

    return 0;
}

static PyObject* Sbk_QStyleOptionDockWidget_get_floatable(PyObject* self, void*)
{
    PyObject* val = Shiboken::Converter< bool >::toPython( Shiboken::Converter< QStyleOptionDockWidget* >::toCpp(self)->floatable);
    return val;
}

static int Sbk_QStyleOptionDockWidget_set_floatable(PyObject* self, PyObject* value, void*)
{
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'floatable' may not be deleted");
        return -1;
    }
    if (!SbkNumber_Check(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'floatable', 'bool' or convertible type expected");
        return -1;
    }

    Shiboken::Converter< QStyleOptionDockWidget* >::toCpp(self)->floatable = Shiboken::Converter< bool >::toCpp(value);

    return 0;
}

static PyObject* Sbk_QStyleOptionDockWidget_get_closable(PyObject* self, void*)
{
    PyObject* val = Shiboken::Converter< bool >::toPython( Shiboken::Converter< QStyleOptionDockWidget* >::toCpp(self)->closable);
    return val;
}

static int Sbk_QStyleOptionDockWidget_set_closable(PyObject* self, PyObject* value, void*)
{
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'closable' may not be deleted");
        return -1;
    }
    if (!SbkNumber_Check(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'closable', 'bool' or convertible type expected");
        return -1;
    }

    Shiboken::Converter< QStyleOptionDockWidget* >::toCpp(self)->closable = Shiboken::Converter< bool >::toCpp(value);

    return 0;
}

static PyObject* Sbk_QStyleOptionDockWidget_get_movable(PyObject* self, void*)
{
    PyObject* val = Shiboken::Converter< bool >::toPython( Shiboken::Converter< QStyleOptionDockWidget* >::toCpp(self)->movable);
    return val;
}

static int Sbk_QStyleOptionDockWidget_set_movable(PyObject* self, PyObject* value, void*)
{
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'movable' may not be deleted");
        return -1;
    }
    if (!SbkNumber_Check(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'movable', 'bool' or convertible type expected");
        return -1;
    }

    Shiboken::Converter< QStyleOptionDockWidget* >::toCpp(self)->movable = Shiboken::Converter< bool >::toCpp(value);

    return 0;
}

// Getters and Setters for QStyleOptionDockWidget
static PyGetSetDef Sbk_QStyleOptionDockWidget_getsetlist[] = {
    {const_cast<char*>("title"), Sbk_QStyleOptionDockWidget_get_title, Sbk_QStyleOptionDockWidget_set_title},
    {const_cast<char*>("floatable"), Sbk_QStyleOptionDockWidget_get_floatable, Sbk_QStyleOptionDockWidget_set_floatable},
    {const_cast<char*>("closable"), Sbk_QStyleOptionDockWidget_get_closable, Sbk_QStyleOptionDockWidget_set_closable},
    {const_cast<char*>("movable"), Sbk_QStyleOptionDockWidget_get_movable, Sbk_QStyleOptionDockWidget_set_movable},
    {0}  // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QStyleOptionDockWidget_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QStyleOptionDockWidget",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QStyleOptionDockWidget_methods,
    /*tp_members*/          0,
    /*tp_getset*/           Sbk_QStyleOptionDockWidget_getsetlist,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QStyleOptionDockWidget_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QStyleOptionDockWidget(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONDOCKWIDGET_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QStyleOptionDockWidget_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QStyleOptionDockWidget_Type);
    Sbk_QStyleOptionDockWidget_Type.super.ht_type.tp_base = SbkPySide_QtGuiTypes[SBK_QSTYLEOPTION_IDX];
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QStyleOptionDockWidget_Type, &Shiboken::callCppDestructor<QStyleOptionDockWidget >);
    if (PyType_Ready((PyTypeObject*)&Sbk_QStyleOptionDockWidget_Type) < 0)
        return;

    Shiboken::ObjectType::setOriginalName(&Sbk_QStyleOptionDockWidget_Type, "QStyleOptionDockWidget");
    PyModule_AddObject(module, "QStyleOptionDockWidget",
        ((PyObject*)&Sbk_QStyleOptionDockWidget_Type));

    // Initialize enums
    PyObject* enumItem;

    // init enum: StyleOptionVersion
    PyTypeObject* SbkPySide_QtGui_QStyleOptionDockWidget_StyleOptionVersion = Shiboken::Enum::newType("PySide.QtGui.QStyleOptionDockWidget.StyleOptionVersion");
    SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONDOCKWIDGET_STYLEOPTIONVERSION_IDX] = SbkPySide_QtGui_QStyleOptionDockWidget_StyleOptionVersion;
    if (PyType_Ready(SbkPySide_QtGui_QStyleOptionDockWidget_StyleOptionVersion) < 0)
        return;
    PyDict_SetItemString(Sbk_QStyleOptionDockWidget_Type.super.ht_type.tp_dict,
            "StyleOptionVersion",((PyObject*)SbkPySide_QtGui_QStyleOptionDockWidget_StyleOptionVersion));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyleOptionDockWidget_StyleOptionVersion,(long) QStyleOptionDockWidget::Version, "Version");
    PyDict_SetItemString(Sbk_QStyleOptionDockWidget_Type.super.ht_type.tp_dict,"Version", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyleOptionDockWidget_StyleOptionVersion->tp_dict,"Version", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QStyleOptionDockWidget::StyleOptionVersion");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::StyleOptionVersion");
    // end of enum StyleOptionVersion

    // init enum: StyleOptionType
    PyTypeObject* SbkPySide_QtGui_QStyleOptionDockWidget_StyleOptionType = Shiboken::Enum::newType("PySide.QtGui.QStyleOptionDockWidget.StyleOptionType");
    SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONDOCKWIDGET_STYLEOPTIONTYPE_IDX] = SbkPySide_QtGui_QStyleOptionDockWidget_StyleOptionType;
    if (PyType_Ready(SbkPySide_QtGui_QStyleOptionDockWidget_StyleOptionType) < 0)
        return;
    PyDict_SetItemString(Sbk_QStyleOptionDockWidget_Type.super.ht_type.tp_dict,
            "StyleOptionType",((PyObject*)SbkPySide_QtGui_QStyleOptionDockWidget_StyleOptionType));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyleOptionDockWidget_StyleOptionType,(long) QStyleOptionDockWidget::Type, "Type");
    PyDict_SetItemString(Sbk_QStyleOptionDockWidget_Type.super.ht_type.tp_dict,"Type", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyleOptionDockWidget_StyleOptionType->tp_dict,"Type", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QStyleOptionDockWidget::StyleOptionType");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::StyleOptionType");
    // end of enum StyleOptionType


    Shiboken::TypeResolver::createValueTypeResolver<QStyleOptionDockWidget >("QStyleOptionDockWidget");
    Shiboken::TypeResolver::createObjectTypeResolver<QStyleOptionDockWidget >("QStyleOptionDockWidget*");
    Shiboken::TypeResolver::createValueTypeResolver<QStyleOptionDockWidget >(typeid(QStyleOptionDockWidget).name());
    PySide::initQtMetaType< ::QStyleOptionDockWidget >();
    qRegisterMetaType< ::QStyleOptionDockWidget::StyleOptionVersion >("QStyleOptionDockWidget::StyleOptionVersion");
    qRegisterMetaType< ::QStyleOptionDockWidget::StyleOptionType >("QStyleOptionDockWidget::StyleOptionType");
}

