/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qstyleoptionprogressbar_wrapper.h"

// Extra includes
#include <qstyleoption.h>
#include <qwidget.h>



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QStyleOptionProgressBar_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QStyleOptionProgressBar >()))
        return -1;

    QStyleOptionProgressBar* cptr = 0;
    int overloadId = -1;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QStyleOptionProgressBar", 0, 1, &(pyargs[0])))
        return -1;

    // Overloaded function decisor
    // 0: QStyleOptionProgressBar()
    // 1: QStyleOptionProgressBar(QStyleOptionProgressBar)
    // 2: QStyleOptionProgressBar(int)
    if (numArgs == 0) {
        overloadId = 0; // QStyleOptionProgressBar()
    } else if (numArgs == 1 && SbkNumber_Check(pyargs[0])) {
        overloadId = 2; // QStyleOptionProgressBar(int)
    } else if (numArgs == 1 && Shiboken::Converter< ::QStyleOptionProgressBar >::isConvertible(pyargs[0])) {
        overloadId = 1; // QStyleOptionProgressBar(QStyleOptionProgressBar)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QStyleOptionProgressBar_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QStyleOptionProgressBar()
            {

                if(!PyErr_Occurred()) {
                    // QStyleOptionProgressBar()
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QStyleOptionProgressBar();
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // QStyleOptionProgressBar(QStyleOptionProgressBar)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QStyleOptionProgressBar cppArg0 = Shiboken::Converter<QStyleOptionProgressBar >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QStyleOptionProgressBar(QStyleOptionProgressBar)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QStyleOptionProgressBar(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 2: // QStyleOptionProgressBar(int)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QStyleOptionProgressBar(int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QStyleOptionProgressBar(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QStyleOptionProgressBar >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QStyleOptionProgressBar_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QStyleOptionProgressBar_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtGui.QStyleOptionProgressBar", "int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QStyleOptionProgressBar", overloads);
        return -1;
}

static PyObject *Sbk_QStyleOptionProgressBar___copy__(PyObject *self)
{
        QStyleOptionProgressBar* cppSelf = 0;
        if (!Shiboken::Object::isValid(self))
            return 0;
        cppSelf = Shiboken::Converter<QStyleOptionProgressBar*>::toCpp(self);
        PyObject* pyResult = 0;
        QStyleOptionProgressBar* copy = new QStyleOptionProgressBar(*cppSelf);
        pyResult = Shiboken::Converter<QStyleOptionProgressBar*>::toPython(copy);
        Shiboken::Object::getOwnership(pyResult);

        if (PyErr_Occurred() || !pyResult) {
            Py_XDECREF(pyResult);
            return 0;
        }
        return pyResult;
}

static PyMethodDef Sbk_QStyleOptionProgressBar_methods[] = {

    {"__copy__", (PyCFunction)Sbk_QStyleOptionProgressBar___copy__, METH_NOARGS},
    {0} // Sentinel
};

static PyObject* Sbk_QStyleOptionProgressBar_get_minimum(PyObject* self, void*)
{
    PyObject* val = Shiboken::Converter< int >::toPython( Shiboken::Converter< QStyleOptionProgressBar* >::toCpp(self)->minimum);
    return val;
}

static int Sbk_QStyleOptionProgressBar_set_minimum(PyObject* self, PyObject* value, void*)
{
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'minimum' may not be deleted");
        return -1;
    }
    if (!SbkNumber_Check(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'minimum', 'int' or convertible type expected");
        return -1;
    }

    Shiboken::Converter< QStyleOptionProgressBar* >::toCpp(self)->minimum = Shiboken::Converter< int >::toCpp(value);

    return 0;
}

static PyObject* Sbk_QStyleOptionProgressBar_get_maximum(PyObject* self, void*)
{
    PyObject* val = Shiboken::Converter< int >::toPython( Shiboken::Converter< QStyleOptionProgressBar* >::toCpp(self)->maximum);
    return val;
}

static int Sbk_QStyleOptionProgressBar_set_maximum(PyObject* self, PyObject* value, void*)
{
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'maximum' may not be deleted");
        return -1;
    }
    if (!SbkNumber_Check(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'maximum', 'int' or convertible type expected");
        return -1;
    }

    Shiboken::Converter< QStyleOptionProgressBar* >::toCpp(self)->maximum = Shiboken::Converter< int >::toCpp(value);

    return 0;
}

static PyObject* Sbk_QStyleOptionProgressBar_get_progress(PyObject* self, void*)
{
    PyObject* val = Shiboken::Converter< int >::toPython( Shiboken::Converter< QStyleOptionProgressBar* >::toCpp(self)->progress);
    return val;
}

static int Sbk_QStyleOptionProgressBar_set_progress(PyObject* self, PyObject* value, void*)
{
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'progress' may not be deleted");
        return -1;
    }
    if (!SbkNumber_Check(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'progress', 'int' or convertible type expected");
        return -1;
    }

    Shiboken::Converter< QStyleOptionProgressBar* >::toCpp(self)->progress = Shiboken::Converter< int >::toCpp(value);

    return 0;
}

static PyObject* Sbk_QStyleOptionProgressBar_get_textAlignment(PyObject* self, void*)
{
    PyObject* val = Shiboken::Converter< ::QFlags<Qt::AlignmentFlag> >::toPython( Shiboken::Converter< QStyleOptionProgressBar* >::toCpp(self)->textAlignment);
    return val;
}

static int Sbk_QStyleOptionProgressBar_set_textAlignment(PyObject* self, PyObject* value, void*)
{
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'textAlignment' may not be deleted");
        return -1;
    }
    if (!Shiboken::Converter< ::QFlags<Qt::AlignmentFlag> >::isConvertible(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'textAlignment', 'Alignment' or convertible type expected");
        return -1;
    }

    Shiboken::Converter< QStyleOptionProgressBar* >::toCpp(self)->textAlignment = Shiboken::Converter< ::QFlags<Qt::AlignmentFlag> >::toCpp(value);

    return 0;
}

static PyObject* Sbk_QStyleOptionProgressBar_get_text(PyObject* self, void*)
{
    PyObject* val = Shiboken::Converter< QString >::toPython( Shiboken::Converter< QStyleOptionProgressBar* >::toCpp(self)->text);
    return val;
}

static int Sbk_QStyleOptionProgressBar_set_text(PyObject* self, PyObject* value, void*)
{
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'text' may not be deleted");
        return -1;
    }
    if (!Shiboken::Converter< QString >::isConvertible(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'text', 'QString' or convertible type expected");
        return -1;
    }

    Shiboken::Converter< QStyleOptionProgressBar* >::toCpp(self)->text = Shiboken::Converter< QString >::toCpp(value);

    return 0;
}

static PyObject* Sbk_QStyleOptionProgressBar_get_textVisible(PyObject* self, void*)
{
    PyObject* val = Shiboken::Converter< bool >::toPython( Shiboken::Converter< QStyleOptionProgressBar* >::toCpp(self)->textVisible);
    return val;
}

static int Sbk_QStyleOptionProgressBar_set_textVisible(PyObject* self, PyObject* value, void*)
{
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'textVisible' may not be deleted");
        return -1;
    }
    if (!SbkNumber_Check(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'textVisible', 'bool' or convertible type expected");
        return -1;
    }

    Shiboken::Converter< QStyleOptionProgressBar* >::toCpp(self)->textVisible = Shiboken::Converter< bool >::toCpp(value);

    return 0;
}

// Getters and Setters for QStyleOptionProgressBar
static PyGetSetDef Sbk_QStyleOptionProgressBar_getsetlist[] = {
    {const_cast<char*>("minimum"), Sbk_QStyleOptionProgressBar_get_minimum, Sbk_QStyleOptionProgressBar_set_minimum},
    {const_cast<char*>("maximum"), Sbk_QStyleOptionProgressBar_get_maximum, Sbk_QStyleOptionProgressBar_set_maximum},
    {const_cast<char*>("progress"), Sbk_QStyleOptionProgressBar_get_progress, Sbk_QStyleOptionProgressBar_set_progress},
    {const_cast<char*>("textAlignment"), Sbk_QStyleOptionProgressBar_get_textAlignment, Sbk_QStyleOptionProgressBar_set_textAlignment},
    {const_cast<char*>("text"), Sbk_QStyleOptionProgressBar_get_text, Sbk_QStyleOptionProgressBar_set_text},
    {const_cast<char*>("textVisible"), Sbk_QStyleOptionProgressBar_get_textVisible, Sbk_QStyleOptionProgressBar_set_textVisible},
    {0}  // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QStyleOptionProgressBar_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QStyleOptionProgressBar",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QStyleOptionProgressBar_methods,
    /*tp_members*/          0,
    /*tp_getset*/           Sbk_QStyleOptionProgressBar_getsetlist,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QStyleOptionProgressBar_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QStyleOptionProgressBar(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONPROGRESSBAR_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QStyleOptionProgressBar_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QStyleOptionProgressBar_Type);
    Sbk_QStyleOptionProgressBar_Type.super.ht_type.tp_base = SbkPySide_QtGuiTypes[SBK_QSTYLEOPTION_IDX];
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QStyleOptionProgressBar_Type, &Shiboken::callCppDestructor<QStyleOptionProgressBar >);
    if (PyType_Ready((PyTypeObject*)&Sbk_QStyleOptionProgressBar_Type) < 0)
        return;

    Shiboken::ObjectType::setOriginalName(&Sbk_QStyleOptionProgressBar_Type, "QStyleOptionProgressBar");
    PyModule_AddObject(module, "QStyleOptionProgressBar",
        ((PyObject*)&Sbk_QStyleOptionProgressBar_Type));

    // Initialize enums
    PyObject* enumItem;

    // init enum: StyleOptionVersion
    PyTypeObject* SbkPySide_QtGui_QStyleOptionProgressBar_StyleOptionVersion = Shiboken::Enum::newType("PySide.QtGui.QStyleOptionProgressBar.StyleOptionVersion");
    SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONPROGRESSBAR_STYLEOPTIONVERSION_IDX] = SbkPySide_QtGui_QStyleOptionProgressBar_StyleOptionVersion;
    if (PyType_Ready(SbkPySide_QtGui_QStyleOptionProgressBar_StyleOptionVersion) < 0)
        return;
    PyDict_SetItemString(Sbk_QStyleOptionProgressBar_Type.super.ht_type.tp_dict,
            "StyleOptionVersion",((PyObject*)SbkPySide_QtGui_QStyleOptionProgressBar_StyleOptionVersion));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyleOptionProgressBar_StyleOptionVersion,(long) QStyleOptionProgressBar::Version, "Version");
    PyDict_SetItemString(Sbk_QStyleOptionProgressBar_Type.super.ht_type.tp_dict,"Version", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyleOptionProgressBar_StyleOptionVersion->tp_dict,"Version", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QStyleOptionProgressBar::StyleOptionVersion");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::StyleOptionVersion");
    // end of enum StyleOptionVersion

    // init enum: StyleOptionType
    PyTypeObject* SbkPySide_QtGui_QStyleOptionProgressBar_StyleOptionType = Shiboken::Enum::newType("PySide.QtGui.QStyleOptionProgressBar.StyleOptionType");
    SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONPROGRESSBAR_STYLEOPTIONTYPE_IDX] = SbkPySide_QtGui_QStyleOptionProgressBar_StyleOptionType;
    if (PyType_Ready(SbkPySide_QtGui_QStyleOptionProgressBar_StyleOptionType) < 0)
        return;
    PyDict_SetItemString(Sbk_QStyleOptionProgressBar_Type.super.ht_type.tp_dict,
            "StyleOptionType",((PyObject*)SbkPySide_QtGui_QStyleOptionProgressBar_StyleOptionType));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyleOptionProgressBar_StyleOptionType,(long) QStyleOptionProgressBar::Type, "Type");
    PyDict_SetItemString(Sbk_QStyleOptionProgressBar_Type.super.ht_type.tp_dict,"Type", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyleOptionProgressBar_StyleOptionType->tp_dict,"Type", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QStyleOptionProgressBar::StyleOptionType");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::StyleOptionType");
    // end of enum StyleOptionType


    Shiboken::TypeResolver::createValueTypeResolver<QStyleOptionProgressBar >("QStyleOptionProgressBar");
    Shiboken::TypeResolver::createObjectTypeResolver<QStyleOptionProgressBar >("QStyleOptionProgressBar*");
    Shiboken::TypeResolver::createValueTypeResolver<QStyleOptionProgressBar >(typeid(QStyleOptionProgressBar).name());
    PySide::initQtMetaType< ::QStyleOptionProgressBar >();
    qRegisterMetaType< ::QStyleOptionProgressBar::StyleOptionVersion >("QStyleOptionProgressBar::StyleOptionVersion");
    qRegisterMetaType< ::QStyleOptionProgressBar::StyleOptionType >("QStyleOptionProgressBar::StyleOptionType");
}

