/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qstyleoptiontoolbar_wrapper.h"

// Extra includes
#include <qstyleoption.h>
#include <qwidget.h>



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QStyleOptionToolBar_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QStyleOptionToolBar >()))
        return -1;

    QStyleOptionToolBar* cptr = 0;
    int overloadId = -1;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QStyleOptionToolBar", 0, 1, &(pyargs[0])))
        return -1;

    // Overloaded function decisor
    // 0: QStyleOptionToolBar()
    // 1: QStyleOptionToolBar(QStyleOptionToolBar)
    // 2: QStyleOptionToolBar(int)
    if (numArgs == 0) {
        overloadId = 0; // QStyleOptionToolBar()
    } else if (numArgs == 1 && SbkNumber_Check(pyargs[0])) {
        overloadId = 2; // QStyleOptionToolBar(int)
    } else if (numArgs == 1 && Shiboken::Converter< ::QStyleOptionToolBar >::isConvertible(pyargs[0])) {
        overloadId = 1; // QStyleOptionToolBar(QStyleOptionToolBar)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QStyleOptionToolBar_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QStyleOptionToolBar()
            {

                if(!PyErr_Occurred()) {
                    // QStyleOptionToolBar()
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QStyleOptionToolBar();
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // QStyleOptionToolBar(QStyleOptionToolBar)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QStyleOptionToolBar cppArg0 = Shiboken::Converter<QStyleOptionToolBar >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QStyleOptionToolBar(QStyleOptionToolBar)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QStyleOptionToolBar(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 2: // QStyleOptionToolBar(int)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QStyleOptionToolBar(int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QStyleOptionToolBar(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QStyleOptionToolBar >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QStyleOptionToolBar_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QStyleOptionToolBar_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtGui.QStyleOptionToolBar", "int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QStyleOptionToolBar", overloads);
        return -1;
}

static PyObject *Sbk_QStyleOptionToolBar___copy__(PyObject *self)
{
        QStyleOptionToolBar* cppSelf = 0;
        if (!Shiboken::Object::isValid(self))
            return 0;
        cppSelf = Shiboken::Converter<QStyleOptionToolBar*>::toCpp(self);
        PyObject* pyResult = 0;
        QStyleOptionToolBar* copy = new QStyleOptionToolBar(*cppSelf);
        pyResult = Shiboken::Converter<QStyleOptionToolBar*>::toPython(copy);
        Shiboken::Object::getOwnership(pyResult);

        if (PyErr_Occurred() || !pyResult) {
            Py_XDECREF(pyResult);
            return 0;
        }
        return pyResult;
}

static PyMethodDef Sbk_QStyleOptionToolBar_methods[] = {

    {"__copy__", (PyCFunction)Sbk_QStyleOptionToolBar___copy__, METH_NOARGS},
    {0} // Sentinel
};

static PyObject* Sbk_QStyleOptionToolBar_get_lineWidth(PyObject* self, void*)
{
    PyObject* val = Shiboken::Converter< int >::toPython( Shiboken::Converter< QStyleOptionToolBar* >::toCpp(self)->lineWidth);
    return val;
}

static int Sbk_QStyleOptionToolBar_set_lineWidth(PyObject* self, PyObject* value, void*)
{
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'lineWidth' may not be deleted");
        return -1;
    }
    if (!SbkNumber_Check(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'lineWidth', 'int' or convertible type expected");
        return -1;
    }

    Shiboken::Converter< QStyleOptionToolBar* >::toCpp(self)->lineWidth = Shiboken::Converter< int >::toCpp(value);

    return 0;
}

static PyObject* Sbk_QStyleOptionToolBar_get_positionWithinLine(PyObject* self, void*)
{
    PyObject* val = Shiboken::Converter< ::QStyleOptionToolBar::ToolBarPosition >::toPython( Shiboken::Converter< QStyleOptionToolBar* >::toCpp(self)->positionWithinLine);
    return val;
}

static int Sbk_QStyleOptionToolBar_set_positionWithinLine(PyObject* self, PyObject* value, void*)
{
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'positionWithinLine' may not be deleted");
        return -1;
    }
    if (!Shiboken::Converter< ::QStyleOptionToolBar::ToolBarPosition >::isConvertible(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'positionWithinLine', 'ToolBarPosition' or convertible type expected");
        return -1;
    }

    Shiboken::Converter< QStyleOptionToolBar* >::toCpp(self)->positionWithinLine = Shiboken::Converter< ::QStyleOptionToolBar::ToolBarPosition >::toCpp(value);

    return 0;
}

static PyObject* Sbk_QStyleOptionToolBar_get_positionOfLine(PyObject* self, void*)
{
    PyObject* val = Shiboken::Converter< ::QStyleOptionToolBar::ToolBarPosition >::toPython( Shiboken::Converter< QStyleOptionToolBar* >::toCpp(self)->positionOfLine);
    return val;
}

static int Sbk_QStyleOptionToolBar_set_positionOfLine(PyObject* self, PyObject* value, void*)
{
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'positionOfLine' may not be deleted");
        return -1;
    }
    if (!Shiboken::Converter< ::QStyleOptionToolBar::ToolBarPosition >::isConvertible(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'positionOfLine', 'ToolBarPosition' or convertible type expected");
        return -1;
    }

    Shiboken::Converter< QStyleOptionToolBar* >::toCpp(self)->positionOfLine = Shiboken::Converter< ::QStyleOptionToolBar::ToolBarPosition >::toCpp(value);

    return 0;
}

static PyObject* Sbk_QStyleOptionToolBar_get_features(PyObject* self, void*)
{
    PyObject* val = Shiboken::Converter< ::QFlags<QStyleOptionToolBar::ToolBarFeature> >::toPython( Shiboken::Converter< QStyleOptionToolBar* >::toCpp(self)->features);
    return val;
}

static int Sbk_QStyleOptionToolBar_set_features(PyObject* self, PyObject* value, void*)
{
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'features' may not be deleted");
        return -1;
    }
    if (!Shiboken::Converter< ::QFlags<QStyleOptionToolBar::ToolBarFeature> >::isConvertible(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'features', 'ToolBarFeatures' or convertible type expected");
        return -1;
    }

    Shiboken::Converter< QStyleOptionToolBar* >::toCpp(self)->features = Shiboken::Converter< ::QFlags<QStyleOptionToolBar::ToolBarFeature> >::toCpp(value);

    return 0;
}

static PyObject* Sbk_QStyleOptionToolBar_get_toolBarArea(PyObject* self, void*)
{
    PyObject* val = Shiboken::Converter< ::Qt::ToolBarArea >::toPython( Shiboken::Converter< QStyleOptionToolBar* >::toCpp(self)->toolBarArea);
    return val;
}

static int Sbk_QStyleOptionToolBar_set_toolBarArea(PyObject* self, PyObject* value, void*)
{
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'toolBarArea' may not be deleted");
        return -1;
    }
    if (!Shiboken::Converter< ::Qt::ToolBarArea >::isConvertible(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'toolBarArea', 'ToolBarArea' or convertible type expected");
        return -1;
    }

    Shiboken::Converter< QStyleOptionToolBar* >::toCpp(self)->toolBarArea = Shiboken::Converter< ::Qt::ToolBarArea >::toCpp(value);

    return 0;
}

static PyObject* Sbk_QStyleOptionToolBar_get_midLineWidth(PyObject* self, void*)
{
    PyObject* val = Shiboken::Converter< int >::toPython( Shiboken::Converter< QStyleOptionToolBar* >::toCpp(self)->midLineWidth);
    return val;
}

static int Sbk_QStyleOptionToolBar_set_midLineWidth(PyObject* self, PyObject* value, void*)
{
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'midLineWidth' may not be deleted");
        return -1;
    }
    if (!SbkNumber_Check(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'midLineWidth', 'int' or convertible type expected");
        return -1;
    }

    Shiboken::Converter< QStyleOptionToolBar* >::toCpp(self)->midLineWidth = Shiboken::Converter< int >::toCpp(value);

    return 0;
}

// Getters and Setters for QStyleOptionToolBar
static PyGetSetDef Sbk_QStyleOptionToolBar_getsetlist[] = {
    {const_cast<char*>("lineWidth"), Sbk_QStyleOptionToolBar_get_lineWidth, Sbk_QStyleOptionToolBar_set_lineWidth},
    {const_cast<char*>("positionWithinLine"), Sbk_QStyleOptionToolBar_get_positionWithinLine, Sbk_QStyleOptionToolBar_set_positionWithinLine},
    {const_cast<char*>("positionOfLine"), Sbk_QStyleOptionToolBar_get_positionOfLine, Sbk_QStyleOptionToolBar_set_positionOfLine},
    {const_cast<char*>("features"), Sbk_QStyleOptionToolBar_get_features, Sbk_QStyleOptionToolBar_set_features},
    {const_cast<char*>("toolBarArea"), Sbk_QStyleOptionToolBar_get_toolBarArea, Sbk_QStyleOptionToolBar_set_toolBarArea},
    {const_cast<char*>("midLineWidth"), Sbk_QStyleOptionToolBar_get_midLineWidth, Sbk_QStyleOptionToolBar_set_midLineWidth},
    {0}  // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QStyleOptionToolBar_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QStyleOptionToolBar",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QStyleOptionToolBar_methods,
    /*tp_members*/          0,
    /*tp_getset*/           Sbk_QStyleOptionToolBar_getsetlist,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QStyleOptionToolBar_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern

PyObject* SbkPySide_QtGui_QStyleOptionToolBar_ToolBarFeature___and__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QStyleOptionToolBar::ToolBarFeatures >::toPython(
        Shiboken::Converter<QStyleOptionToolBar::ToolBarFeatures>::toCpp(self)
        & Shiboken::Converter< QStyleOptionToolBar::ToolBarFeatures >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtGui_QStyleOptionToolBar_ToolBarFeature___or__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QStyleOptionToolBar::ToolBarFeatures >::toPython(
        Shiboken::Converter<QStyleOptionToolBar::ToolBarFeatures>::toCpp(self)
        | Shiboken::Converter< QStyleOptionToolBar::ToolBarFeatures >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtGui_QStyleOptionToolBar_ToolBarFeature___xor__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QStyleOptionToolBar::ToolBarFeatures >::toPython(
        Shiboken::Converter<QStyleOptionToolBar::ToolBarFeatures>::toCpp(self)
        ^ Shiboken::Converter< QStyleOptionToolBar::ToolBarFeatures >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtGui_QStyleOptionToolBar_ToolBarFeature___invert__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QStyleOptionToolBar::ToolBarFeatures >::toPython(
        ~Shiboken::Converter<QStyleOptionToolBar::ToolBarFeatures >::toCpp(self)
    );
}


static PyNumberMethods SbkPySide_QtGui_QStyleOptionToolBar_ToolBarFeature_as_number = {
    /*nb_add*/                  0,
    /*nb_subtract*/             0,
    /*nb_multiply*/             0,
    /*nb_divide*/               0,
    /*nb_remainder*/            0,
    /*nb_divmod*/               0,
    /*nb_power*/                0,
    /*nb_negative*/             0,
    /*nb_positive*/             0,
    /*nb_absolute*/             0,
    /*nb_nonzero*/              0,
    /*nb_invert*/               (unaryfunc)SbkPySide_QtGui_QStyleOptionToolBar_ToolBarFeature___invert__,
    /*nb_lshift*/               0,
    /*nb_rshift*/               0,
    /*nb_and*/                  (binaryfunc)SbkPySide_QtGui_QStyleOptionToolBar_ToolBarFeature___and__,
    /*nb_xor*/                  (binaryfunc)SbkPySide_QtGui_QStyleOptionToolBar_ToolBarFeature___xor__,
    /*nb_or*/                   (binaryfunc)SbkPySide_QtGui_QStyleOptionToolBar_ToolBarFeature___or__,
    /*nb_coerce*/               0,
    /*nb_int*/                  0,
    /*nb_long*/                 0,
    /*nb_float*/                0,
    /*nb_oct*/                  0,
    /*nb_hex*/                  0,
    /*nb_inplace_add*/          0,
    /*nb_inplace_subtract*/     0,
    /*nb_inplace_multiply*/     0,
    /*nb_inplace_divide*/       0,
    /*nb_inplace_remainder*/    0,
    /*nb_inplace_power*/        0,
    /*nb_inplace_lshift*/       0,
    /*nb_inplace_rshift*/       0,
    /*nb_inplace_and*/          0,
    /*nb_inplace_xor*/          0,
    /*nb_inplace_or*/           0,
    /*nb_floor_divide*/         0,
    /*nb_true_divide*/          0,
    /*nb_inplace_floor_divide*/ 0,
    /*nb_inplace_true_divide*/  0,
    /*nb_index*/                0
};


// forward declaration of new function
static PyTypeObject SbkPySide_QtGui_QStyleOptionToolBar_ToolBarFeatures_Type = {
    PyObject_HEAD_INIT(&PyType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "ToolBarFeatures",
    /*tp_basicsize*/        0,
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        &SbkPySide_QtGui_QStyleOptionToolBar_ToolBarFeature_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT | Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              PyInt_Type.tp_new,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};



void init_QStyleOptionToolBar(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONTOOLBAR_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QStyleOptionToolBar_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QStyleOptionToolBar_Type);
    Sbk_QStyleOptionToolBar_Type.super.ht_type.tp_base = SbkPySide_QtGuiTypes[SBK_QSTYLEOPTION_IDX];
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QStyleOptionToolBar_Type, &Shiboken::callCppDestructor<QStyleOptionToolBar >);
    if (PyType_Ready((PyTypeObject*)&Sbk_QStyleOptionToolBar_Type) < 0)
        return;

    Shiboken::ObjectType::setOriginalName(&Sbk_QStyleOptionToolBar_Type, "QStyleOptionToolBar");
    PyModule_AddObject(module, "QStyleOptionToolBar",
        ((PyObject*)&Sbk_QStyleOptionToolBar_Type));

    // Initialize enums
    PyObject* enumItem;

    // init enum: StyleOptionVersion
    PyTypeObject* SbkPySide_QtGui_QStyleOptionToolBar_StyleOptionVersion = Shiboken::Enum::newType("PySide.QtGui.QStyleOptionToolBar.StyleOptionVersion");
    SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONTOOLBAR_STYLEOPTIONVERSION_IDX] = SbkPySide_QtGui_QStyleOptionToolBar_StyleOptionVersion;
    if (PyType_Ready(SbkPySide_QtGui_QStyleOptionToolBar_StyleOptionVersion) < 0)
        return;
    PyDict_SetItemString(Sbk_QStyleOptionToolBar_Type.super.ht_type.tp_dict,
            "StyleOptionVersion",((PyObject*)SbkPySide_QtGui_QStyleOptionToolBar_StyleOptionVersion));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyleOptionToolBar_StyleOptionVersion,(long) QStyleOptionToolBar::Version, "Version");
    PyDict_SetItemString(Sbk_QStyleOptionToolBar_Type.super.ht_type.tp_dict,"Version", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyleOptionToolBar_StyleOptionVersion->tp_dict,"Version", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QStyleOptionToolBar::StyleOptionVersion");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::StyleOptionVersion");
    // end of enum StyleOptionVersion

    // init enum: StyleOptionType
    PyTypeObject* SbkPySide_QtGui_QStyleOptionToolBar_StyleOptionType = Shiboken::Enum::newType("PySide.QtGui.QStyleOptionToolBar.StyleOptionType");
    SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONTOOLBAR_STYLEOPTIONTYPE_IDX] = SbkPySide_QtGui_QStyleOptionToolBar_StyleOptionType;
    if (PyType_Ready(SbkPySide_QtGui_QStyleOptionToolBar_StyleOptionType) < 0)
        return;
    PyDict_SetItemString(Sbk_QStyleOptionToolBar_Type.super.ht_type.tp_dict,
            "StyleOptionType",((PyObject*)SbkPySide_QtGui_QStyleOptionToolBar_StyleOptionType));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyleOptionToolBar_StyleOptionType,(long) QStyleOptionToolBar::Type, "Type");
    PyDict_SetItemString(Sbk_QStyleOptionToolBar_Type.super.ht_type.tp_dict,"Type", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyleOptionToolBar_StyleOptionType->tp_dict,"Type", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QStyleOptionToolBar::StyleOptionType");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::StyleOptionType");
    // end of enum StyleOptionType

    // init enum: ToolBarPosition
    PyTypeObject* SbkPySide_QtGui_QStyleOptionToolBar_ToolBarPosition = Shiboken::Enum::newType("PySide.QtGui.QStyleOptionToolBar.ToolBarPosition");
    SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONTOOLBAR_TOOLBARPOSITION_IDX] = SbkPySide_QtGui_QStyleOptionToolBar_ToolBarPosition;
    if (PyType_Ready(SbkPySide_QtGui_QStyleOptionToolBar_ToolBarPosition) < 0)
        return;
    PyDict_SetItemString(Sbk_QStyleOptionToolBar_Type.super.ht_type.tp_dict,
            "ToolBarPosition",((PyObject*)SbkPySide_QtGui_QStyleOptionToolBar_ToolBarPosition));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyleOptionToolBar_ToolBarPosition,(long) QStyleOptionToolBar::Beginning, "Beginning");
    PyDict_SetItemString(Sbk_QStyleOptionToolBar_Type.super.ht_type.tp_dict,"Beginning", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyleOptionToolBar_ToolBarPosition->tp_dict,"Beginning", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyleOptionToolBar_ToolBarPosition,(long) QStyleOptionToolBar::Middle, "Middle");
    PyDict_SetItemString(Sbk_QStyleOptionToolBar_Type.super.ht_type.tp_dict,"Middle", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyleOptionToolBar_ToolBarPosition->tp_dict,"Middle", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyleOptionToolBar_ToolBarPosition,(long) QStyleOptionToolBar::End, "End");
    PyDict_SetItemString(Sbk_QStyleOptionToolBar_Type.super.ht_type.tp_dict,"End", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyleOptionToolBar_ToolBarPosition->tp_dict,"End", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyleOptionToolBar_ToolBarPosition,(long) QStyleOptionToolBar::OnlyOne, "OnlyOne");
    PyDict_SetItemString(Sbk_QStyleOptionToolBar_Type.super.ht_type.tp_dict,"OnlyOne", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyleOptionToolBar_ToolBarPosition->tp_dict,"OnlyOne", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QStyleOptionToolBar::ToolBarPosition");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::ToolBarPosition");
    // end of enum ToolBarPosition

    // init enum: ToolBarFeature
    PyTypeObject* SbkPySide_QtGui_QStyleOptionToolBar_ToolBarFeature = Shiboken::Enum::newType("PySide.QtGui.QStyleOptionToolBar.ToolBarFeature");
    SbkPySide_QtGui_QStyleOptionToolBar_ToolBarFeature->tp_as_number = &SbkPySide_QtGui_QStyleOptionToolBar_ToolBarFeature_as_number;
    SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONTOOLBAR_TOOLBARFEATURE_IDX] = SbkPySide_QtGui_QStyleOptionToolBar_ToolBarFeature;
    if (PyType_Ready(SbkPySide_QtGui_QStyleOptionToolBar_ToolBarFeature) < 0)
        return;
    PyDict_SetItemString(Sbk_QStyleOptionToolBar_Type.super.ht_type.tp_dict,
            "ToolBarFeature",((PyObject*)SbkPySide_QtGui_QStyleOptionToolBar_ToolBarFeature));

    // init flags class: QFlags<QStyleOptionToolBar::ToolBarFeature>
    SbkPySide_QtGuiTypes[SBK_QFLAGS_QSTYLEOPTIONTOOLBAR_TOOLBARFEATURE__IDX] = &SbkPySide_QtGui_QStyleOptionToolBar_ToolBarFeatures_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtGui_QStyleOptionToolBar_ToolBarFeatures_Type) < 0)
        return;
    PyDict_SetItemString(Sbk_QStyleOptionToolBar_Type.super.ht_type.tp_dict,
            "ToolBarFeatures",((PyObject*)&SbkPySide_QtGui_QStyleOptionToolBar_ToolBarFeatures_Type));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyleOptionToolBar_ToolBarFeature,(long) QStyleOptionToolBar::None, "None");
    PyDict_SetItemString(Sbk_QStyleOptionToolBar_Type.super.ht_type.tp_dict,"None", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyleOptionToolBar_ToolBarFeature->tp_dict,"None", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyleOptionToolBar_ToolBarFeature,(long) QStyleOptionToolBar::Movable, "Movable");
    PyDict_SetItemString(Sbk_QStyleOptionToolBar_Type.super.ht_type.tp_dict,"Movable", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyleOptionToolBar_ToolBarFeature->tp_dict,"Movable", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QStyleOptionToolBar::ToolBarFeature");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::ToolBarFeature");
    // end of enum ToolBarFeature


    Shiboken::TypeResolver::createValueTypeResolver<QStyleOptionToolBar >("QStyleOptionToolBar");
    Shiboken::TypeResolver::createObjectTypeResolver<QStyleOptionToolBar >("QStyleOptionToolBar*");
    Shiboken::TypeResolver::createValueTypeResolver<QStyleOptionToolBar >(typeid(QStyleOptionToolBar).name());
    PySide::initQtMetaType< ::QStyleOptionToolBar >();
    qRegisterMetaType< ::QStyleOptionToolBar::StyleOptionVersion >("QStyleOptionToolBar::StyleOptionVersion");
    qRegisterMetaType< ::QStyleOptionToolBar::StyleOptionType >("QStyleOptionToolBar::StyleOptionType");
    qRegisterMetaType< ::QStyleOptionToolBar::ToolBarPosition >("QStyleOptionToolBar::ToolBarPosition");
    qRegisterMetaType< ::QStyleOptionToolBar::ToolBarFeature >("QStyleOptionToolBar::ToolBarFeature");
    qRegisterMetaType< ::QStyleOptionToolBar::ToolBarFeatures >("QStyleOptionToolBar::ToolBarFeatures");
}

