/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qstyleoptionviewitem_wrapper.h"

// Extra includes
#include <qstyleoption.h>
#include <qwidget.h>



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QStyleOptionViewItem_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QStyleOptionViewItem >()))
        return -1;

    QStyleOptionViewItem* cptr = 0;
    int overloadId = -1;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QStyleOptionViewItem", 0, 1, &(pyargs[0])))
        return -1;

    // Overloaded function decisor
    // 0: QStyleOptionViewItem()
    // 1: QStyleOptionViewItem(QStyleOptionViewItem)
    // 2: QStyleOptionViewItem(int)
    if (numArgs == 0) {
        overloadId = 0; // QStyleOptionViewItem()
    } else if (numArgs == 1 && SbkNumber_Check(pyargs[0])) {
        overloadId = 2; // QStyleOptionViewItem(int)
    } else if (numArgs == 1 && Shiboken::Converter< ::QStyleOptionViewItem >::isConvertible(pyargs[0])) {
        overloadId = 1; // QStyleOptionViewItem(QStyleOptionViewItem)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QStyleOptionViewItem_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QStyleOptionViewItem()
            {

                if(!PyErr_Occurred()) {
                    // QStyleOptionViewItem()
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QStyleOptionViewItem();
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // QStyleOptionViewItem(QStyleOptionViewItem)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QStyleOptionViewItem cppArg0 = Shiboken::Converter<QStyleOptionViewItem >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QStyleOptionViewItem(QStyleOptionViewItem)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QStyleOptionViewItem(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 2: // QStyleOptionViewItem(int)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QStyleOptionViewItem(int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QStyleOptionViewItem(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QStyleOptionViewItem >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QStyleOptionViewItem_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QStyleOptionViewItem_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtGui.QStyleOptionViewItem", "int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QStyleOptionViewItem", overloads);
        return -1;
}

static PyObject *Sbk_QStyleOptionViewItem___copy__(PyObject *self)
{
        QStyleOptionViewItem* cppSelf = 0;
        if (!Shiboken::Object::isValid(self))
            return 0;
        cppSelf = Shiboken::Converter<QStyleOptionViewItem*>::toCpp(self);
        PyObject* pyResult = 0;
        QStyleOptionViewItem* copy = new QStyleOptionViewItem(*cppSelf);
        pyResult = Shiboken::Converter<QStyleOptionViewItem*>::toPython(copy);
        Shiboken::Object::getOwnership(pyResult);

        if (PyErr_Occurred() || !pyResult) {
            Py_XDECREF(pyResult);
            return 0;
        }
        return pyResult;
}

static PyMethodDef Sbk_QStyleOptionViewItem_methods[] = {

    {"__copy__", (PyCFunction)Sbk_QStyleOptionViewItem___copy__, METH_NOARGS},
    {0} // Sentinel
};

static PyObject* Sbk_QStyleOptionViewItem_get_showDecorationSelected(PyObject* self, void*)
{
    PyObject* val = Shiboken::Converter< bool >::toPython( Shiboken::Converter< QStyleOptionViewItem* >::toCpp(self)->showDecorationSelected);
    return val;
}

static int Sbk_QStyleOptionViewItem_set_showDecorationSelected(PyObject* self, PyObject* value, void*)
{
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'showDecorationSelected' may not be deleted");
        return -1;
    }
    if (!SbkNumber_Check(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'showDecorationSelected', 'bool' or convertible type expected");
        return -1;
    }

    Shiboken::Converter< QStyleOptionViewItem* >::toCpp(self)->showDecorationSelected = Shiboken::Converter< bool >::toCpp(value);

    return 0;
}

static PyObject* Sbk_QStyleOptionViewItem_get_decorationPosition(PyObject* self, void*)
{
    PyObject* val = Shiboken::Converter< ::QStyleOptionViewItem::Position >::toPython( Shiboken::Converter< QStyleOptionViewItem* >::toCpp(self)->decorationPosition);
    return val;
}

static int Sbk_QStyleOptionViewItem_set_decorationPosition(PyObject* self, PyObject* value, void*)
{
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'decorationPosition' may not be deleted");
        return -1;
    }
    if (!Shiboken::Converter< ::QStyleOptionViewItem::Position >::isConvertible(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'decorationPosition', 'Position' or convertible type expected");
        return -1;
    }

    Shiboken::Converter< QStyleOptionViewItem* >::toCpp(self)->decorationPosition = Shiboken::Converter< ::QStyleOptionViewItem::Position >::toCpp(value);

    return 0;
}

static PyObject* Sbk_QStyleOptionViewItem_get_decorationAlignment(PyObject* self, void*)
{
    PyObject* val = Shiboken::Converter< ::QFlags<Qt::AlignmentFlag> >::toPython( Shiboken::Converter< QStyleOptionViewItem* >::toCpp(self)->decorationAlignment);
    return val;
}

static int Sbk_QStyleOptionViewItem_set_decorationAlignment(PyObject* self, PyObject* value, void*)
{
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'decorationAlignment' may not be deleted");
        return -1;
    }
    if (!Shiboken::Converter< ::QFlags<Qt::AlignmentFlag> >::isConvertible(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'decorationAlignment', 'Alignment' or convertible type expected");
        return -1;
    }

    Shiboken::Converter< QStyleOptionViewItem* >::toCpp(self)->decorationAlignment = Shiboken::Converter< ::QFlags<Qt::AlignmentFlag> >::toCpp(value);

    return 0;
}

static PyObject* Sbk_QStyleOptionViewItem_get_displayAlignment(PyObject* self, void*)
{
    PyObject* val = Shiboken::Converter< ::QFlags<Qt::AlignmentFlag> >::toPython( Shiboken::Converter< QStyleOptionViewItem* >::toCpp(self)->displayAlignment);
    return val;
}

static int Sbk_QStyleOptionViewItem_set_displayAlignment(PyObject* self, PyObject* value, void*)
{
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'displayAlignment' may not be deleted");
        return -1;
    }
    if (!Shiboken::Converter< ::QFlags<Qt::AlignmentFlag> >::isConvertible(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'displayAlignment', 'Alignment' or convertible type expected");
        return -1;
    }

    Shiboken::Converter< QStyleOptionViewItem* >::toCpp(self)->displayAlignment = Shiboken::Converter< ::QFlags<Qt::AlignmentFlag> >::toCpp(value);

    return 0;
}

static PyObject* Sbk_QStyleOptionViewItem_get_textElideMode(PyObject* self, void*)
{
    PyObject* val = Shiboken::Converter< ::Qt::TextElideMode >::toPython( Shiboken::Converter< QStyleOptionViewItem* >::toCpp(self)->textElideMode);
    return val;
}

static int Sbk_QStyleOptionViewItem_set_textElideMode(PyObject* self, PyObject* value, void*)
{
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'textElideMode' may not be deleted");
        return -1;
    }
    if (!Shiboken::Converter< ::Qt::TextElideMode >::isConvertible(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'textElideMode', 'TextElideMode' or convertible type expected");
        return -1;
    }

    Shiboken::Converter< QStyleOptionViewItem* >::toCpp(self)->textElideMode = Shiboken::Converter< ::Qt::TextElideMode >::toCpp(value);

    return 0;
}

static PyObject* Sbk_QStyleOptionViewItem_get_decorationSize(PyObject* self, void*)
{
    PyObject* val = Shiboken::createWrapper(&Shiboken::Converter< QStyleOptionViewItem* >::toCpp(self)->decorationSize);
    Shiboken::Object::releaseOwnership(val);
    return val;
}

static int Sbk_QStyleOptionViewItem_set_decorationSize(PyObject* self, PyObject* value, void*)
{
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'decorationSize' may not be deleted");
        return -1;
    }
    if (!Shiboken::Converter< ::QSize >::isConvertible(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'decorationSize', 'QSize' or convertible type expected");
        return -1;
    }

    Shiboken::Converter< QStyleOptionViewItem* >::toCpp(self)->decorationSize = Shiboken::Converter< ::QSize >::toCpp(value);

    return 0;
}

static PyObject* Sbk_QStyleOptionViewItem_get_font(PyObject* self, void*)
{
    PyObject* val = Shiboken::createWrapper(&Shiboken::Converter< QStyleOptionViewItem* >::toCpp(self)->font);
    Shiboken::Object::releaseOwnership(val);
    return val;
}

static int Sbk_QStyleOptionViewItem_set_font(PyObject* self, PyObject* value, void*)
{
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'font' may not be deleted");
        return -1;
    }
    if (!Shiboken::Converter< ::QFont >::isConvertible(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'font', 'QFont' or convertible type expected");
        return -1;
    }

    Shiboken::Converter< QStyleOptionViewItem* >::toCpp(self)->font = Shiboken::Converter< ::QFont >::toCpp(value);

    return 0;
}

// Getters and Setters for QStyleOptionViewItem
static PyGetSetDef Sbk_QStyleOptionViewItem_getsetlist[] = {
    {const_cast<char*>("showDecorationSelected"), Sbk_QStyleOptionViewItem_get_showDecorationSelected, Sbk_QStyleOptionViewItem_set_showDecorationSelected},
    {const_cast<char*>("decorationPosition"), Sbk_QStyleOptionViewItem_get_decorationPosition, Sbk_QStyleOptionViewItem_set_decorationPosition},
    {const_cast<char*>("decorationAlignment"), Sbk_QStyleOptionViewItem_get_decorationAlignment, Sbk_QStyleOptionViewItem_set_decorationAlignment},
    {const_cast<char*>("displayAlignment"), Sbk_QStyleOptionViewItem_get_displayAlignment, Sbk_QStyleOptionViewItem_set_displayAlignment},
    {const_cast<char*>("textElideMode"), Sbk_QStyleOptionViewItem_get_textElideMode, Sbk_QStyleOptionViewItem_set_textElideMode},
    {const_cast<char*>("decorationSize"), Sbk_QStyleOptionViewItem_get_decorationSize, Sbk_QStyleOptionViewItem_set_decorationSize},
    {const_cast<char*>("font"), Sbk_QStyleOptionViewItem_get_font, Sbk_QStyleOptionViewItem_set_font},
    {0}  // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QStyleOptionViewItem_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QStyleOptionViewItem",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QStyleOptionViewItem_methods,
    /*tp_members*/          0,
    /*tp_getset*/           Sbk_QStyleOptionViewItem_getsetlist,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QStyleOptionViewItem_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QStyleOptionViewItem(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONVIEWITEM_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QStyleOptionViewItem_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QStyleOptionViewItem_Type);
    Sbk_QStyleOptionViewItem_Type.super.ht_type.tp_base = SbkPySide_QtGuiTypes[SBK_QSTYLEOPTION_IDX];
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QStyleOptionViewItem_Type, &Shiboken::callCppDestructor<QStyleOptionViewItem >);
    if (PyType_Ready((PyTypeObject*)&Sbk_QStyleOptionViewItem_Type) < 0)
        return;

    Shiboken::ObjectType::setOriginalName(&Sbk_QStyleOptionViewItem_Type, "QStyleOptionViewItem");
    PyModule_AddObject(module, "QStyleOptionViewItem",
        ((PyObject*)&Sbk_QStyleOptionViewItem_Type));

    // Initialize enums
    PyObject* enumItem;

    // init enum: StyleOptionVersion
    PyTypeObject* SbkPySide_QtGui_QStyleOptionViewItem_StyleOptionVersion = Shiboken::Enum::newType("PySide.QtGui.QStyleOptionViewItem.StyleOptionVersion");
    SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONVIEWITEM_STYLEOPTIONVERSION_IDX] = SbkPySide_QtGui_QStyleOptionViewItem_StyleOptionVersion;
    if (PyType_Ready(SbkPySide_QtGui_QStyleOptionViewItem_StyleOptionVersion) < 0)
        return;
    PyDict_SetItemString(Sbk_QStyleOptionViewItem_Type.super.ht_type.tp_dict,
            "StyleOptionVersion",((PyObject*)SbkPySide_QtGui_QStyleOptionViewItem_StyleOptionVersion));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyleOptionViewItem_StyleOptionVersion,(long) QStyleOptionViewItem::Version, "Version");
    PyDict_SetItemString(Sbk_QStyleOptionViewItem_Type.super.ht_type.tp_dict,"Version", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyleOptionViewItem_StyleOptionVersion->tp_dict,"Version", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QStyleOptionViewItem::StyleOptionVersion");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::StyleOptionVersion");
    // end of enum StyleOptionVersion

    // init enum: StyleOptionType
    PyTypeObject* SbkPySide_QtGui_QStyleOptionViewItem_StyleOptionType = Shiboken::Enum::newType("PySide.QtGui.QStyleOptionViewItem.StyleOptionType");
    SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONVIEWITEM_STYLEOPTIONTYPE_IDX] = SbkPySide_QtGui_QStyleOptionViewItem_StyleOptionType;
    if (PyType_Ready(SbkPySide_QtGui_QStyleOptionViewItem_StyleOptionType) < 0)
        return;
    PyDict_SetItemString(Sbk_QStyleOptionViewItem_Type.super.ht_type.tp_dict,
            "StyleOptionType",((PyObject*)SbkPySide_QtGui_QStyleOptionViewItem_StyleOptionType));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyleOptionViewItem_StyleOptionType,(long) QStyleOptionViewItem::Type, "Type");
    PyDict_SetItemString(Sbk_QStyleOptionViewItem_Type.super.ht_type.tp_dict,"Type", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyleOptionViewItem_StyleOptionType->tp_dict,"Type", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QStyleOptionViewItem::StyleOptionType");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::StyleOptionType");
    // end of enum StyleOptionType

    // init enum: Position
    PyTypeObject* SbkPySide_QtGui_QStyleOptionViewItem_Position = Shiboken::Enum::newType("PySide.QtGui.QStyleOptionViewItem.Position");
    SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONVIEWITEM_POSITION_IDX] = SbkPySide_QtGui_QStyleOptionViewItem_Position;
    if (PyType_Ready(SbkPySide_QtGui_QStyleOptionViewItem_Position) < 0)
        return;
    PyDict_SetItemString(Sbk_QStyleOptionViewItem_Type.super.ht_type.tp_dict,
            "Position",((PyObject*)SbkPySide_QtGui_QStyleOptionViewItem_Position));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyleOptionViewItem_Position,(long) QStyleOptionViewItem::Left, "Left");
    PyDict_SetItemString(Sbk_QStyleOptionViewItem_Type.super.ht_type.tp_dict,"Left", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyleOptionViewItem_Position->tp_dict,"Left", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyleOptionViewItem_Position,(long) QStyleOptionViewItem::Right, "Right");
    PyDict_SetItemString(Sbk_QStyleOptionViewItem_Type.super.ht_type.tp_dict,"Right", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyleOptionViewItem_Position->tp_dict,"Right", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyleOptionViewItem_Position,(long) QStyleOptionViewItem::Top, "Top");
    PyDict_SetItemString(Sbk_QStyleOptionViewItem_Type.super.ht_type.tp_dict,"Top", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyleOptionViewItem_Position->tp_dict,"Top", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyleOptionViewItem_Position,(long) QStyleOptionViewItem::Bottom, "Bottom");
    PyDict_SetItemString(Sbk_QStyleOptionViewItem_Type.super.ht_type.tp_dict,"Bottom", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyleOptionViewItem_Position->tp_dict,"Bottom", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QStyleOptionViewItem::Position");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::Position");
    // end of enum Position


    Shiboken::TypeResolver::createValueTypeResolver<QStyleOptionViewItem >("QStyleOptionViewItem");
    Shiboken::TypeResolver::createObjectTypeResolver<QStyleOptionViewItem >("QStyleOptionViewItem*");
    Shiboken::TypeResolver::createValueTypeResolver<QStyleOptionViewItem >(typeid(QStyleOptionViewItem).name());
    PySide::initQtMetaType< ::QStyleOptionViewItem >();
    qRegisterMetaType< ::QStyleOptionViewItem::StyleOptionVersion >("QStyleOptionViewItem::StyleOptionVersion");
    qRegisterMetaType< ::QStyleOptionViewItem::StyleOptionType >("QStyleOptionViewItem::StyleOptionType");
    qRegisterMetaType< ::QStyleOptionViewItem::Position >("QStyleOptionViewItem::Position");
}

