/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qtextlayout_formatrange_wrapper.h"

// Extra includes



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QTextLayout_FormatRange_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QTextLayout::FormatRange >()))
        return -1;

    QTextLayout::FormatRange* cptr = 0;
    int overloadId = -1;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "FormatRange", 0, 1, &(pyargs[0])))
        return -1;

    // Overloaded function decisor
    // 0: FormatRange()
    // 1: FormatRange(QTextLayout::FormatRange)
    if (numArgs == 0) {
        overloadId = 0; // FormatRange()
    } else if (numArgs == 1 && Shiboken::Converter< ::QTextLayout::FormatRange >::isConvertible(pyargs[0])) {
        overloadId = 1; // FormatRange(QTextLayout::FormatRange)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextLayout_FormatRange_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // FormatRange()
            {

                if(!PyErr_Occurred()) {
                    // FormatRange()
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QTextLayout::FormatRange();
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // FormatRange(QTextLayout::FormatRange)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QTextLayout::FormatRange cppArg0 = Shiboken::Converter<QTextLayout::FormatRange >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // FormatRange(QTextLayout::FormatRange)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QTextLayout::FormatRange(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QTextLayout::FormatRange >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QTextLayout_FormatRange_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QTextLayout_FormatRange_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtGui.QTextLayout::FormatRange", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.FormatRange", overloads);
        return -1;
}

static PyObject *Sbk_QTextLayout_FormatRange___copy__(PyObject *self)
{
        QTextLayout::FormatRange* cppSelf = 0;
        if (!Shiboken::Object::isValid(self))
            return 0;
        cppSelf = Shiboken::Converter<QTextLayout::FormatRange*>::toCpp(self);
        PyObject* pyResult = 0;
        QTextLayout::FormatRange* copy = new QTextLayout::FormatRange(*cppSelf);
        pyResult = Shiboken::Converter<QTextLayout::FormatRange*>::toPython(copy);
        Shiboken::Object::getOwnership(pyResult);

        if (PyErr_Occurred() || !pyResult) {
            Py_XDECREF(pyResult);
            return 0;
        }
        return pyResult;
}

static PyMethodDef Sbk_QTextLayout_FormatRange_methods[] = {

    {"__copy__", (PyCFunction)Sbk_QTextLayout_FormatRange___copy__, METH_NOARGS},
    {0} // Sentinel
};

static PyObject* Sbk_QTextLayout_FormatRange_get_format(PyObject* self, void*)
{
    PyObject* val = Shiboken::createWrapper(&Shiboken::Converter< QTextLayout::FormatRange* >::toCpp(self)->format);
    Shiboken::Object::releaseOwnership(val);
    return val;
}

static int Sbk_QTextLayout_FormatRange_set_format(PyObject* self, PyObject* value, void*)
{
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'format' may not be deleted");
        return -1;
    }
    if (!Shiboken::Converter< ::QTextCharFormat >::isConvertible(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'format', 'QTextCharFormat' or convertible type expected");
        return -1;
    }

    Shiboken::Converter< QTextLayout::FormatRange* >::toCpp(self)->format = Shiboken::Converter< ::QTextCharFormat >::toCpp(value);

    return 0;
}

static PyObject* Sbk_QTextLayout_FormatRange_get_length(PyObject* self, void*)
{
    PyObject* val = Shiboken::Converter< int >::toPython( Shiboken::Converter< QTextLayout::FormatRange* >::toCpp(self)->length);
    return val;
}

static int Sbk_QTextLayout_FormatRange_set_length(PyObject* self, PyObject* value, void*)
{
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'length' may not be deleted");
        return -1;
    }
    if (!SbkNumber_Check(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'length', 'int' or convertible type expected");
        return -1;
    }

    Shiboken::Converter< QTextLayout::FormatRange* >::toCpp(self)->length = Shiboken::Converter< int >::toCpp(value);

    return 0;
}

static PyObject* Sbk_QTextLayout_FormatRange_get_start(PyObject* self, void*)
{
    PyObject* val = Shiboken::Converter< int >::toPython( Shiboken::Converter< QTextLayout::FormatRange* >::toCpp(self)->start);
    return val;
}

static int Sbk_QTextLayout_FormatRange_set_start(PyObject* self, PyObject* value, void*)
{
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'start' may not be deleted");
        return -1;
    }
    if (!SbkNumber_Check(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'start', 'int' or convertible type expected");
        return -1;
    }

    Shiboken::Converter< QTextLayout::FormatRange* >::toCpp(self)->start = Shiboken::Converter< int >::toCpp(value);

    return 0;
}

// Getters and Setters for FormatRange
static PyGetSetDef Sbk_QTextLayout_FormatRange_getsetlist[] = {
    {const_cast<char*>("format"), Sbk_QTextLayout_FormatRange_get_format, Sbk_QTextLayout_FormatRange_set_format},
    {const_cast<char*>("length"), Sbk_QTextLayout_FormatRange_get_length, Sbk_QTextLayout_FormatRange_set_length},
    {const_cast<char*>("start"), Sbk_QTextLayout_FormatRange_get_start, Sbk_QTextLayout_FormatRange_set_start},
    {0}  // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QTextLayout_FormatRange_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QTextLayout.FormatRange",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QTextLayout_FormatRange_methods,
    /*tp_members*/          0,
    /*tp_getset*/           Sbk_QTextLayout_FormatRange_getsetlist,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QTextLayout_FormatRange_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QTextLayout_FormatRange(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QTEXTLAYOUT_FORMATRANGE_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QTextLayout_FormatRange_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QTextLayout_FormatRange_Type);
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QTextLayout_FormatRange_Type, &Shiboken::callCppDestructor<QTextLayout::FormatRange >);
    if (PyType_Ready((PyTypeObject*)&Sbk_QTextLayout_FormatRange_Type) < 0)
        return;

    Shiboken::ObjectType::setOriginalName(&Sbk_QTextLayout_FormatRange_Type, "QTextLayout::FormatRange");
    PyDict_SetItemString(module,"FormatRange", (PyObject*)&Sbk_QTextLayout_FormatRange_Type);

    Shiboken::TypeResolver::createValueTypeResolver<QTextLayout::FormatRange >("QTextLayout::FormatRange");
    Shiboken::TypeResolver::createObjectTypeResolver<QTextLayout::FormatRange >("QTextLayout::FormatRange*");
    Shiboken::TypeResolver::createValueTypeResolver<QTextLayout::FormatRange >(typeid(QTextLayout::FormatRange).name());
    PySide::initQtMetaType< ::QTextLayout::FormatRange >();
}

