/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qtouchevent_wrapper.h"
#include "qtouchevent_touchpoint_wrapper.h"

// Extra includes
#include <QList>
#include <qevent.h>
#include <qwidget.h>


// Native ---------------------------------------------------------

QTouchEventWrapper::~QTouchEventWrapper()
{
    SbkObject* wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static PyObject* Sbk_QTouchEventFunc_deviceType(PyObject* self)
{
    QTouchEvent* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTouchEvent* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // deviceType()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QTouchEvent::DeviceType cppResult = const_cast<const QTouchEvent*>(cppSelf)->deviceType();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QTouchEvent::DeviceType >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTouchEventFunc_setDeviceType(PyObject* self, PyObject* arg)
{
    QTouchEvent* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTouchEvent* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setDeviceType(QTouchEvent::DeviceType)
    if (Shiboken::Converter< ::QTouchEvent::DeviceType >::isConvertible(arg)) {
        overloadId = 0; // setDeviceType(QTouchEvent::DeviceType)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTouchEventFunc_setDeviceType_TypeError;

    // Call function/method
    {
        {
            QTouchEvent::DeviceType cppArg0 = Shiboken::Converter<QTouchEvent::DeviceType >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setDeviceType(QTouchEvent::DeviceType)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setDeviceType(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTouchEventFunc_setDeviceType_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTouchEvent.DeviceType", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTouchEvent.setDeviceType", overloads);
        return 0;
}

static PyObject* Sbk_QTouchEventFunc_setTouchPoints(PyObject* self, PyObject* arg)
{
    QTouchEvent* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTouchEvent* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setTouchPoints(QList<QTouchEvent::TouchPoint>)
    if (Shiboken::Converter< ::QList<QTouchEvent::TouchPoint > >::isConvertible(arg)) {
        overloadId = 0; // setTouchPoints(QList<QTouchEvent::TouchPoint>)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTouchEventFunc_setTouchPoints_TypeError;

    // Call function/method
    {
        {
            QList<QTouchEvent::TouchPoint > cppArg0 = Shiboken::Converter<QList<QTouchEvent::TouchPoint > >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setTouchPoints(QList<QTouchEvent::TouchPoint>)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setTouchPoints(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTouchEventFunc_setTouchPoints_TypeError:
        const char* overloads[] = {"list", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTouchEvent.setTouchPoints", overloads);
        return 0;
}

static PyObject* Sbk_QTouchEventFunc_setWidget(PyObject* self, PyObject* arg)
{
    QTouchEvent* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTouchEvent* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setWidget(QWidget*)
    if (Shiboken::Converter< ::QWidget * >::isConvertible(arg)) {
        overloadId = 0; // setWidget(QWidget*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTouchEventFunc_setWidget_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QWidget * cppArg0 = Shiboken::Converter<QWidget * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setWidget(QWidget*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setWidget(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTouchEventFunc_setWidget_TypeError:
        const char* overloads[] = {"PySide.QtGui.QWidget", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTouchEvent.setWidget", overloads);
        return 0;
}

static PyObject* Sbk_QTouchEventFunc_touchPoints(PyObject* self)
{
    QTouchEvent* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTouchEvent* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // touchPoints()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                const QList<QTouchEvent::TouchPoint > & cppResult = const_cast<const QTouchEvent*>(cppSelf)->touchPoints();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QList<QTouchEvent::TouchPoint > >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTouchEventFunc_widget(PyObject* self)
{
    QTouchEvent* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTouchEvent* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // widget()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QWidget * cppResult = const_cast<const QTouchEvent*>(cppSelf)->widget();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QWidget * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef Sbk_QTouchEvent_methods[] = {
    {"deviceType", (PyCFunction)Sbk_QTouchEventFunc_deviceType, METH_NOARGS},
    {"setDeviceType", (PyCFunction)Sbk_QTouchEventFunc_setDeviceType, METH_O},
    {"setTouchPoints", (PyCFunction)Sbk_QTouchEventFunc_setTouchPoints, METH_O},
    {"setWidget", (PyCFunction)Sbk_QTouchEventFunc_setWidget, METH_O},
    {"touchPoints", (PyCFunction)Sbk_QTouchEventFunc_touchPoints, METH_NOARGS},
    {"widget", (PyCFunction)Sbk_QTouchEventFunc_widget, METH_NOARGS},

    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QTouchEvent_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QTouchEvent",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QTouchEvent_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              0,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern

static SbkObjectType* Sbk_QTouchEvent_typeDiscovery(void* cptr, SbkObjectType* instanceType)
{
    if (instanceType == reinterpret_cast<SbkObjectType*>(Shiboken::SbkType<QEvent >()) && dynamic_cast<QTouchEvent*>(reinterpret_cast<QEvent*>(cptr)))
        return &Sbk_QTouchEvent_Type;
    return 0;
}


void init_QTouchEvent(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QTOUCHEVENT_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QTouchEvent_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QTouchEvent_Type);
    Sbk_QTouchEvent_Type.super.ht_type.tp_base = SbkPySide_QtGuiTypes[SBK_QINPUTEVENT_IDX];
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QTouchEvent_Type, &Shiboken::callCppDestructor<QTouchEvent >);
    if (PyType_Ready((PyTypeObject*)&Sbk_QTouchEvent_Type) < 0)
        return;

    // Fill type discovery information
    Shiboken::ObjectType::setTypeDiscoveryFunction(&Sbk_QTouchEvent_Type, &Sbk_QTouchEvent_typeDiscovery);
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkObjectType*>(SbkPySide_QtGuiTypes[SBK_QINPUTEVENT_IDX]), &Sbk_QTouchEvent_Type);

    Shiboken::ObjectType::setOriginalName(&Sbk_QTouchEvent_Type, "QTouchEvent*");
    PyModule_AddObject(module, "QTouchEvent",
        ((PyObject*)&Sbk_QTouchEvent_Type));

    // Initialize enums
    PyObject* enumItem;

    // init enum: DeviceType
    PyTypeObject* SbkPySide_QtGui_QTouchEvent_DeviceType = Shiboken::Enum::newType("PySide.QtGui.QTouchEvent.DeviceType");
    SbkPySide_QtGuiTypes[SBK_QTOUCHEVENT_DEVICETYPE_IDX] = SbkPySide_QtGui_QTouchEvent_DeviceType;
    if (PyType_Ready(SbkPySide_QtGui_QTouchEvent_DeviceType) < 0)
        return;
    PyDict_SetItemString(Sbk_QTouchEvent_Type.super.ht_type.tp_dict,
            "DeviceType",((PyObject*)SbkPySide_QtGui_QTouchEvent_DeviceType));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTouchEvent_DeviceType,(long) QTouchEvent::TouchScreen, "TouchScreen");
    PyDict_SetItemString(Sbk_QTouchEvent_Type.super.ht_type.tp_dict,"TouchScreen", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTouchEvent_DeviceType->tp_dict,"TouchScreen", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTouchEvent_DeviceType,(long) QTouchEvent::TouchPad, "TouchPad");
    PyDict_SetItemString(Sbk_QTouchEvent_Type.super.ht_type.tp_dict,"TouchPad", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTouchEvent_DeviceType->tp_dict,"TouchPad", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QTouchEvent::DeviceType");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::DeviceType");
    // end of enum DeviceType


    Shiboken::TypeResolver::createObjectTypeResolver<QTouchEvent >("QTouchEvent*");
    Shiboken::TypeResolver::createObjectTypeResolver<QTouchEvent >(typeid(QTouchEvent).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QTouchEvent >(typeid(QTouchEventWrapper).name());
    PySide::initQtMetaType< ::QTouchEvent* >();
    qRegisterMetaType< ::QTouchEvent::DeviceType >("QTouchEvent::DeviceType");
}

