/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qwhatsthisclickedevent_wrapper.h"

// Extra includes


// Native ---------------------------------------------------------

QWhatsThisClickedEventWrapper::QWhatsThisClickedEventWrapper(const QString & href) : QWhatsThisClickedEvent(href) {
    // ... middle
}

QWhatsThisClickedEventWrapper::~QWhatsThisClickedEventWrapper()
{
    SbkObject* wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QWhatsThisClickedEvent_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QWhatsThisClickedEvent >()))
        return -1;

    QWhatsThisClickedEventWrapper* cptr = 0;
    int overloadId = -1;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QWhatsThisClickedEvent", 1, 1, &(pyargs[0])))
        return -1;

    // Overloaded function decisor
    // 0: QWhatsThisClickedEvent(QString)
    if (numArgs == 1 && Shiboken::Converter< QString >::isConvertible(pyargs[0])) {
        overloadId = 0; // QWhatsThisClickedEvent(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWhatsThisClickedEvent_Init_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);

            if(!PyErr_Occurred()) {
                // QWhatsThisClickedEvent(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new QWhatsThisClickedEventWrapper(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QWhatsThisClickedEvent >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QWhatsThisClickedEvent_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QWhatsThisClickedEvent_Init_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QWhatsThisClickedEvent", overloads);
        return -1;
}

static PyObject* Sbk_QWhatsThisClickedEventFunc_href(PyObject* self)
{
    QWhatsThisClickedEvent* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWhatsThisClickedEvent* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // href()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QWhatsThisClickedEvent*>(cppSelf)->href();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef Sbk_QWhatsThisClickedEvent_methods[] = {
    {"href", (PyCFunction)Sbk_QWhatsThisClickedEventFunc_href, METH_NOARGS},

    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QWhatsThisClickedEvent_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QWhatsThisClickedEvent",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QWhatsThisClickedEvent_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QWhatsThisClickedEvent_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern

static SbkObjectType* Sbk_QWhatsThisClickedEvent_typeDiscovery(void* cptr, SbkObjectType* instanceType)
{
     if ( reinterpret_cast<QWhatsThisClickedEvent*>(cptr)->type() == QEvent::WhatsThisClicked)
        return &Sbk_QWhatsThisClickedEvent_Type;
    return 0;
}


void init_QWhatsThisClickedEvent(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QWHATSTHISCLICKEDEVENT_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QWhatsThisClickedEvent_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QWhatsThisClickedEvent_Type);
    Sbk_QWhatsThisClickedEvent_Type.super.ht_type.tp_base = SbkPySide_QtCoreTypes[SBK_QEVENT_IDX];
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QWhatsThisClickedEvent_Type, &Shiboken::callCppDestructor<QWhatsThisClickedEvent >);
    if (PyType_Ready((PyTypeObject*)&Sbk_QWhatsThisClickedEvent_Type) < 0)
        return;

    // Fill type discovery information
    Shiboken::ObjectType::setTypeDiscoveryFunction(&Sbk_QWhatsThisClickedEvent_Type, &Sbk_QWhatsThisClickedEvent_typeDiscovery);
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkObjectType*>(SbkPySide_QtCoreTypes[SBK_QEVENT_IDX]), &Sbk_QWhatsThisClickedEvent_Type);

    Shiboken::ObjectType::setOriginalName(&Sbk_QWhatsThisClickedEvent_Type, "QWhatsThisClickedEvent*");
    PyModule_AddObject(module, "QWhatsThisClickedEvent",
        ((PyObject*)&Sbk_QWhatsThisClickedEvent_Type));


    Shiboken::TypeResolver::createObjectTypeResolver<QWhatsThisClickedEvent >("QWhatsThisClickedEvent*");
    Shiboken::TypeResolver::createObjectTypeResolver<QWhatsThisClickedEvent >(typeid(QWhatsThisClickedEvent).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QWhatsThisClickedEvent >(typeid(QWhatsThisClickedEventWrapper).name());
    PySide::initQtMetaType< ::QWhatsThisClickedEvent* >();
}

