/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <set>
#include "pyside_qtgui_python.h"

#include "qwizard_wrapper.h"

// Extra includes
#include <QList>
#include <qabstractbutton.h>
#include <qaction.h>
#include <qbitmap.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qcursor.h>
#include <qevent.h>
#include <qfont.h>
#include <qfontinfo.h>
#include <qfontmetrics.h>
#include <qgraphicseffect.h>
#include <qgraphicsproxywidget.h>
#include <qicon.h>
#include <qinputcontext.h>
#include <qkeysequence.h>
#include <qlayout.h>
#include <qlocale.h>
#include <qmargins.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qpaintdevice.h>
#include <qpaintengine.h>
#include <qpainter.h>
#include <qpalette.h>
#include <qpixmap.h>
#include <qpoint.h>
#include <qrect.h>
#include <qregion.h>
#include <qsize.h>
#include <qsizepolicy.h>
#include <qstyle.h>
#include <qwidget.h>
#include <qwizard.h>
#include <qx11info_x11.h>


// Native ---------------------------------------------------------

QWizardWrapper::QWizardWrapper(QWidget * parent, QFlags<Qt::WindowType> flags) : QWizard(parent, flags) {
    // ... middle
}

void QWizardWrapper::accept()
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "accept"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QDialog::accept();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QWizardWrapper::actionEvent(QActionEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "actionEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::actionEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QActionEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QWizardWrapper::changeEvent(QEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "changeEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::changeEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QWizardWrapper::childEvent(QChildEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "childEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::childEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QChildEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QWizardWrapper::cleanupPage(int id)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "cleanupPage"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWizard::cleanupPage(id);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(i)",
        id
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QWizardWrapper::closeEvent(QCloseEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "closeEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QDialog::closeEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QCloseEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QWizardWrapper::connectNotify(const char * signal)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "connectNotify"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QWizardWrapper::contextMenuEvent(QContextMenuEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "contextMenuEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QDialog::contextMenuEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QContextMenuEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QWizardWrapper::customEvent(QEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "customEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::customEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

int QWizardWrapper::devType() const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return int(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "devType"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::devType();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return int(0);
    }
    // Check return type
    bool typeIsValid = PyInt_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QWizard.devType", "int", pyResult->ob_type->tp_name);
        return int(0);
    }
    int cppResult(Shiboken::Converter< int >::toCpp(pyResult));
    return cppResult;
}

void QWizardWrapper::disconnectNotify(const char * signal)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "disconnectNotify"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QWizardWrapper::done(int result)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "done"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWizard::done(result);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(i)",
        result
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QWizardWrapper::dragEnterEvent(QDragEnterEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "dragEnterEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::dragEnterEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QDragEnterEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QWizardWrapper::dragLeaveEvent(QDragLeaveEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "dragLeaveEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::dragLeaveEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QDragLeaveEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QWizardWrapper::dragMoveEvent(QDragMoveEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "dragMoveEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::dragMoveEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QDragMoveEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QWizardWrapper::dropEvent(QDropEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "dropEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::dropEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QDropEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QWizardWrapper::enterEvent(QEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "enterEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::enterEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

bool QWizardWrapper::event(QEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return bool(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "event"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWizard::event(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(event)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QWizard.event", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    return cppResult;
}

bool QWizardWrapper::eventFilter(QObject * arg__1, QEvent * arg__2)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return bool(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "eventFilter"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QDialog::eventFilter(arg__1, arg__2);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter< ::QObject * >::toPython(arg__1),
        Shiboken::Converter< ::QEvent * >::toPython(arg__2)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QWizard.eventFilter", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    return cppResult;
}

void QWizardWrapper::focusInEvent(QFocusEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "focusInEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::focusInEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QFocusEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

bool QWizardWrapper::focusNextPrevChild(bool next)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return bool(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "focusNextPrevChild"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::focusNextPrevChild(next);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< bool >::toPython(next)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QWizard.focusNextPrevChild", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    return cppResult;
}

void QWizardWrapper::focusOutEvent(QFocusEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "focusOutEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::focusOutEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QFocusEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

int QWizardWrapper::heightForWidth(int arg__1) const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return int(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "heightForWidth"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::heightForWidth(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(i)",
        arg__1
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return int(0);
    }
    // Check return type
    bool typeIsValid = PyInt_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QWizard.heightForWidth", "int", pyResult->ob_type->tp_name);
        return int(0);
    }
    int cppResult(Shiboken::Converter< int >::toCpp(pyResult));
    return cppResult;
}

void QWizardWrapper::hideEvent(QHideEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "hideEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::hideEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QHideEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QWizardWrapper::initializePage(int id)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "initializePage"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWizard::initializePage(id);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(i)",
        id
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QWizardWrapper::inputMethodEvent(QInputMethodEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "inputMethodEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::inputMethodEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QInputMethodEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

QVariant QWizardWrapper::inputMethodQuery(Qt::InputMethodQuery arg__1) const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return QVariant(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "inputMethodQuery"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::inputMethodQuery(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::Qt::InputMethodQuery >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QVariant(0);
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< QVariant >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QWizard.inputMethodQuery", "QVariant", pyResult->ob_type->tp_name);
        return QVariant(0);
    }
    QVariant cppResult(Shiboken::Converter< QVariant >::toCpp(pyResult));
    return cppResult;
}

void QWizardWrapper::keyPressEvent(QKeyEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "keyPressEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QDialog::keyPressEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QKeyEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QWizardWrapper::keyReleaseEvent(QKeyEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "keyReleaseEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::keyReleaseEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QKeyEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QWizardWrapper::languageChange()
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "languageChange"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::languageChange();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QWizardWrapper::leaveEvent(QEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "leaveEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::leaveEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

int QWizardWrapper::metric(QPaintDevice::PaintDeviceMetric arg__1) const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return int(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "metric"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::metric(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QPaintDevice::PaintDeviceMetric >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return int(0);
    }
    // Check return type
    bool typeIsValid = PyInt_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QWizard.metric", "int", pyResult->ob_type->tp_name);
        return int(0);
    }
    int cppResult(Shiboken::Converter< int >::toCpp(pyResult));
    return cppResult;
}

QSize QWizardWrapper::minimumSizeHint() const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return QSize();
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "minimumSizeHint"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QDialog::minimumSizeHint();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QSize();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QSize >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QWizard.minimumSizeHint", Shiboken::SbkType<QSize >()->tp_name, pyResult->ob_type->tp_name);
        return QSize();
    }
    QSize cppResult(Shiboken::Converter< ::QSize >::toCpp(pyResult));
    return cppResult;
}

void QWizardWrapper::mouseDoubleClickEvent(QMouseEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "mouseDoubleClickEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::mouseDoubleClickEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QMouseEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QWizardWrapper::mouseMoveEvent(QMouseEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "mouseMoveEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::mouseMoveEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QMouseEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QWizardWrapper::mousePressEvent(QMouseEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "mousePressEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::mousePressEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QMouseEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QWizardWrapper::mouseReleaseEvent(QMouseEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "mouseReleaseEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::mouseReleaseEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QMouseEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QWizardWrapper::moveEvent(QMoveEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "moveEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::moveEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QMoveEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

int QWizardWrapper::nextId() const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return int(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "nextId"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWizard::nextId();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return int(0);
    }
    // Check return type
    bool typeIsValid = PyInt_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QWizard.nextId", "int", pyResult->ob_type->tp_name);
        return int(0);
    }
    int cppResult(Shiboken::Converter< int >::toCpp(pyResult));
    return cppResult;
}

QPaintEngine * QWizardWrapper::paintEngine() const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return 0;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "paintEngine"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::paintEngine();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return 0;
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QPaintEngine * >::isConvertible(pyResult);
    typeIsValid = typeIsValid || (pyResult == Py_None);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QWizard.paintEngine", Shiboken::SbkType<QPaintEngine >()->tp_name, pyResult->ob_type->tp_name);
        return 0;
    }
    QPaintEngine * cppResult(Shiboken::Converter< ::QPaintEngine * >::toCpp(pyResult));
    return cppResult;
}

void QWizardWrapper::paintEvent(QPaintEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "paintEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWizard::paintEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QPaintEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QWizardWrapper::reject()
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "reject"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QDialog::reject();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QWizardWrapper::resizeEvent(QResizeEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "resizeEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWizard::resizeEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QResizeEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QWizardWrapper::setVisible(bool visible)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "setVisible"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWizard::setVisible(visible);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< bool >::toPython(visible)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QWizardWrapper::showEvent(QShowEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "showEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QDialog::showEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QShowEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

QSize QWizardWrapper::sizeHint() const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return QSize();
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "sizeHint"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWizard::sizeHint();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QSize();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QSize >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QWizard.sizeHint", Shiboken::SbkType<QSize >()->tp_name, pyResult->ob_type->tp_name);
        return QSize();
    }
    QSize cppResult(Shiboken::Converter< ::QSize >::toCpp(pyResult));
    return cppResult;
}

void QWizardWrapper::tabletEvent(QTabletEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "tabletEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::tabletEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QTabletEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QWizardWrapper::timerEvent(QTimerEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "timerEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::timerEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QTimerEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

bool QWizardWrapper::validateCurrentPage()
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return bool(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "validateCurrentPage"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWizard::validateCurrentPage();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QWizard.validateCurrentPage", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    return cppResult;
}

void QWizardWrapper::wheelEvent(QWheelEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "wheelEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::wheelEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QWheelEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

const QMetaObject* QWizardWrapper::metaObject() const
{
    SbkObject* pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    return reinterpret_cast<QMetaObject*>(Shiboken::Object::getTypeUserData(pySelf));
}

int QWizardWrapper::qt_metacall(QMetaObject::Call call, int id, void** args)
{
    int result = QWizard::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

QWizardWrapper::~QWizardWrapper()
{
    SbkObject* wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QWizard_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QWizard >()))
        return -1;

    QWizardWrapper* cptr = 0;
    int overloadId = -1;
    const char* argNames[] = {"flags", "parent"};
    const QMetaObject* metaObject;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_ParseTuple(args, "|OO:QWizard", &(pyargs[0]), &(pyargs[1])))
        return -1;

    // Overloaded function decisor
    // 0: QWizard(QWidget*,QFlags<Qt::WindowType>)
    if (numArgs == 0) {
        overloadId = 0; // QWizard(QWidget*,QFlags<Qt::WindowType>)
    } else if (Shiboken::Converter< ::QWidget * >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // QWizard(QWidget*,QFlags<Qt::WindowType>)
        } else if (Shiboken::Converter< ::QFlags<Qt::WindowType> >::isConvertible(pyargs[1])) {
            overloadId = 0; // QWizard(QWidget*,QFlags<Qt::WindowType>)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWizard_Init_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "parent");
                if (value) {
                    if (pyargs[0])
                        errorArgName = "parent";
                    else if (Shiboken::Converter< ::QWidget * >::isConvertible(value))
                        pyargs[0] = value;
                    else
                        goto Sbk_QWizard_Init_TypeError;
                }
                value = PyDict_GetItemString(kwds, "flags");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "flags";
                    else if (Shiboken::Converter< ::QFlags<Qt::WindowType> >::isConvertible(value))
                        pyargs[1] = value;
                    else
                        goto Sbk_QWizard_Init_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QWizard(): got multiple values for keyword argument '%s'", errorArgName);
                    return -1;
                }
            }
            if (!Shiboken::Object::isValid(pyargs[0]))
                return -1;
            QWidget * cppArg0 = pyargs[0] ? Shiboken::Converter<QWidget * >::toCpp(pyargs[0]) : 0;
            QFlags<Qt::WindowType> cppArg1 = pyargs[1] ? Shiboken::Converter<QFlags<Qt::WindowType> >::toCpp(pyargs[1]) : QFlags<Qt::WindowType>(0);

            if(!PyErr_Occurred()) {
                // QWizard(QWidget*,QFlags<Qt::WindowType>)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new QWizardWrapper(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                Shiboken::Object::setParent(pyargs[0], self);
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QWizard >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QWizard_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    metaObject = cptr->metaObject(); // <- init python qt properties
    if (kwds && !PySide::fillQtProperties(self, metaObject, kwds, argNames, 2))
        return -1;


    return 1;

    Sbk_QWizard_Init_TypeError:
        const char* overloads[] = {"PySide.QtGui.QWidget = None, PySide.QtCore.Qt.WindowFlags = 0", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QWizard", overloads);
        return -1;
}

static PyObject* Sbk_QWizardFunc_addPage(PyObject* self, PyObject* arg)
{
    QWizard* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWizard* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: addPage(QWizardPage*)
    if (Shiboken::Converter< ::QWizardPage * >::isConvertible(arg)) {
        overloadId = 0; // addPage(QWizardPage*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWizardFunc_addPage_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QWizardPage * cppArg0 = Shiboken::Converter<QWizardPage * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // addPage(QWizardPage*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = cppSelf->addPage(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
                Shiboken::Object::setParent(self, arg);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QWizardFunc_addPage_TypeError:
        const char* overloads[] = {"PySide.QtGui.QWizardPage", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWizard.addPage", overloads);
        return 0;
}

static PyObject* Sbk_QWizardFunc_back(PyObject* self)
{
    QWizard* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWizard* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // back()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->back();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QWizardFunc_button(PyObject* self, PyObject* arg)
{
    QWizard* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWizard* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: button(QWizard::WizardButton)const
    if (Shiboken::Converter< ::QWizard::WizardButton >::isConvertible(arg)) {
        overloadId = 0; // button(QWizard::WizardButton)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWizardFunc_button_TypeError;

    // Call function/method
    {
        {
            QWizard::WizardButton cppArg0 = Shiboken::Converter<QWizard::WizardButton >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // button(QWizard::WizardButton)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QAbstractButton * cppResult = const_cast<const QWizard*>(cppSelf)->button(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QAbstractButton * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QWizardFunc_button_TypeError:
        const char* overloads[] = {"PySide.QtGui.QWizard.WizardButton", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWizard.button", overloads);
        return 0;
}

static PyObject* Sbk_QWizardFunc_buttonText(PyObject* self, PyObject* arg)
{
    QWizard* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWizard* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: buttonText(QWizard::WizardButton)const
    if (Shiboken::Converter< ::QWizard::WizardButton >::isConvertible(arg)) {
        overloadId = 0; // buttonText(QWizard::WizardButton)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWizardFunc_buttonText_TypeError;

    // Call function/method
    {
        {
            QWizard::WizardButton cppArg0 = Shiboken::Converter<QWizard::WizardButton >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // buttonText(QWizard::WizardButton)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QWizard*>(cppSelf)->buttonText(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QWizardFunc_buttonText_TypeError:
        const char* overloads[] = {"PySide.QtGui.QWizard.WizardButton", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWizard.buttonText", overloads);
        return 0;
}

static PyObject* Sbk_QWizardFunc_cleanupPage(PyObject* self, PyObject* arg)
{
    QWizard* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWizard* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: cleanupPage(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // cleanupPage(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWizardFunc_cleanupPage_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // cleanupPage(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QWizard::cleanupPage(cppArg0) : cppSelf->cleanupPage(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWizardFunc_cleanupPage_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWizard.cleanupPage", overloads);
        return 0;
}

static PyObject* Sbk_QWizardFunc_currentId(PyObject* self)
{
    QWizard* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWizard* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // currentId()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QWizard*>(cppSelf)->currentId();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWizardFunc_currentPage(PyObject* self)
{
    QWizard* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWizard* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // currentPage()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QWizardPage * cppResult = const_cast<const QWizard*>(cppSelf)->currentPage();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QWizardPage * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWizardFunc_done(PyObject* self, PyObject* arg)
{
    QWizard* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWizard* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: done(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // done(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWizardFunc_done_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // done(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QWizard::done(cppArg0) : cppSelf->done(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWizardFunc_done_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWizard.done", overloads);
        return 0;
}

static PyObject* Sbk_QWizardFunc_event(PyObject* self, PyObject* arg)
{
    QWizard* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWizard* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: event(QEvent*)
    if (Shiboken::Converter< ::QEvent * >::isConvertible(arg)) {
        overloadId = 0; // event(QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWizardFunc_event_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QEvent * cppArg0 = Shiboken::Converter<QEvent * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // event(QEvent*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = (Shiboken::Object::isUserType(self) ? cppSelf->::QWizard::event(cppArg0) : cppSelf->event(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QWizardFunc_event_TypeError:
        const char* overloads[] = {"PySide.QtCore.QEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWizard.event", overloads);
        return 0;
}

static PyObject* Sbk_QWizardFunc_field(PyObject* self, PyObject* arg)
{
    QWizard* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWizard* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: field(QString)const
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // field(QString)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWizardFunc_field_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // field(QString)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QVariant cppResult = const_cast<const QWizard*>(cppSelf)->field(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QVariant >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QWizardFunc_field_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWizard.field", overloads);
        return 0;
}

static PyObject* Sbk_QWizardFunc_hasVisitedPage(PyObject* self, PyObject* arg)
{
    QWizard* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWizard* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: hasVisitedPage(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // hasVisitedPage(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWizardFunc_hasVisitedPage_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // hasVisitedPage(int)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QWizard*>(cppSelf)->hasVisitedPage(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QWizardFunc_hasVisitedPage_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWizard.hasVisitedPage", overloads);
        return 0;
}

static PyObject* Sbk_QWizardFunc_initializePage(PyObject* self, PyObject* arg)
{
    QWizard* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWizard* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: initializePage(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // initializePage(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWizardFunc_initializePage_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // initializePage(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QWizard::initializePage(cppArg0) : cppSelf->initializePage(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWizardFunc_initializePage_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWizard.initializePage", overloads);
        return 0;
}

static PyObject* Sbk_QWizardFunc_next(PyObject* self)
{
    QWizard* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWizard* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // next()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->next();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QWizardFunc_nextId(PyObject* self)
{
    QWizard* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWizard* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // nextId()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = (Shiboken::Object::isUserType(self) ? const_cast<const QWizard*>(cppSelf)->::QWizard::nextId() : const_cast<const QWizard*>(cppSelf)->nextId());
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWizardFunc_options(PyObject* self)
{
    QWizard* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWizard* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // options()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QFlags<QWizard::WizardOption> cppResult = const_cast<const QWizard*>(cppSelf)->options();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QFlags<QWizard::WizardOption> >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWizardFunc_page(PyObject* self, PyObject* arg)
{
    QWizard* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWizard* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: page(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // page(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWizardFunc_page_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // page(int)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QWizardPage * cppResult = const_cast<const QWizard*>(cppSelf)->page(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QWizardPage * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QWizardFunc_page_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWizard.page", overloads);
        return 0;
}

static PyObject* Sbk_QWizardFunc_pageIds(PyObject* self)
{
    QWizard* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWizard* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // pageIds()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QList<int > cppResult = const_cast<const QWizard*>(cppSelf)->pageIds();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QList<int > >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWizardFunc_paintEvent(PyObject* self, PyObject* arg)
{
    QWizard* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWizard* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: paintEvent(QPaintEvent*)
    if (Shiboken::Converter< ::QPaintEvent * >::isConvertible(arg)) {
        overloadId = 0; // paintEvent(QPaintEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWizardFunc_paintEvent_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QPaintEvent * cppArg0 = Shiboken::Converter<QPaintEvent * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // paintEvent(QPaintEvent*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QWizard::paintEvent(cppArg0) : cppSelf->paintEvent(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWizardFunc_paintEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPaintEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWizard.paintEvent", overloads);
        return 0;
}

static PyObject* Sbk_QWizardFunc_pixmap(PyObject* self, PyObject* arg)
{
    QWizard* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWizard* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: pixmap(QWizard::WizardPixmap)const
    if (Shiboken::Converter< ::QWizard::WizardPixmap >::isConvertible(arg)) {
        overloadId = 0; // pixmap(QWizard::WizardPixmap)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWizardFunc_pixmap_TypeError;

    // Call function/method
    {
        {
            QWizard::WizardPixmap cppArg0 = Shiboken::Converter<QWizard::WizardPixmap >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // pixmap(QWizard::WizardPixmap)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QPixmap cppResult = const_cast<const QWizard*>(cppSelf)->pixmap(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QPixmap >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QWizardFunc_pixmap_TypeError:
        const char* overloads[] = {"PySide.QtGui.QWizard.WizardPixmap", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWizard.pixmap", overloads);
        return 0;
}

static PyObject* Sbk_QWizardFunc_removePage(PyObject* self, PyObject* arg)
{
    QWizard* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWizard* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: removePage(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // removePage(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWizardFunc_removePage_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // removePage(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->removePage(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWizardFunc_removePage_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWizard.removePage", overloads);
        return 0;
}

static PyObject* Sbk_QWizardFunc_resizeEvent(PyObject* self, PyObject* arg)
{
    QWizard* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWizard* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: resizeEvent(QResizeEvent*)
    if (Shiboken::Converter< ::QResizeEvent * >::isConvertible(arg)) {
        overloadId = 0; // resizeEvent(QResizeEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWizardFunc_resizeEvent_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QResizeEvent * cppArg0 = Shiboken::Converter<QResizeEvent * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // resizeEvent(QResizeEvent*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QWizard::resizeEvent(cppArg0) : cppSelf->resizeEvent(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWizardFunc_resizeEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QResizeEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWizard.resizeEvent", overloads);
        return 0;
}

static PyObject* Sbk_QWizardFunc_restart(PyObject* self)
{
    QWizard* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWizard* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // restart()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->restart();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QWizardFunc_setButton(PyObject* self, PyObject* args)
{
    QWizard* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWizard* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setButton", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setButton(QWizard::WizardButton,QAbstractButton*)
    if (numArgs == 2 && Shiboken::Converter< ::QWizard::WizardButton >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QAbstractButton * >::isConvertible(pyargs[1])) {
        overloadId = 0; // setButton(QWizard::WizardButton,QAbstractButton*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWizardFunc_setButton_TypeError;

    // Call function/method
    {
        {
            QWizard::WizardButton cppArg0 = Shiboken::Converter<QWizard::WizardButton >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            QAbstractButton * cppArg1 = Shiboken::Converter<QAbstractButton * >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // setButton(QWizard::WizardButton,QAbstractButton*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setButton(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                Shiboken::Object::setParent(self, pyargs[1]);
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWizardFunc_setButton_TypeError:
        const char* overloads[] = {"PySide.QtGui.QWizard.WizardButton, PySide.QtGui.QAbstractButton", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QWizard.setButton", overloads);
        return 0;
}

static PyObject* Sbk_QWizardFunc_setButtonLayout(PyObject* self, PyObject* arg)
{
    QWizard* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWizard* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setButtonLayout(QList<QWizard::WizardButton>)
    if (Shiboken::Converter< ::QList<QWizard::WizardButton > >::isConvertible(arg)) {
        overloadId = 0; // setButtonLayout(QList<QWizard::WizardButton>)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWizardFunc_setButtonLayout_TypeError;

    // Call function/method
    {
        {
            QList<QWizard::WizardButton > cppArg0 = Shiboken::Converter<QList<QWizard::WizardButton > >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setButtonLayout(QList<QWizard::WizardButton>)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setButtonLayout(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWizardFunc_setButtonLayout_TypeError:
        const char* overloads[] = {"list", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWizard.setButtonLayout", overloads);
        return 0;
}

static PyObject* Sbk_QWizardFunc_setButtonText(PyObject* self, PyObject* args)
{
    QWizard* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWizard* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setButtonText", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setButtonText(QWizard::WizardButton,QString)
    if (numArgs == 2 && Shiboken::Converter< ::QWizard::WizardButton >::isConvertible(pyargs[0]) && Shiboken::Converter< QString >::isConvertible(pyargs[1])) {
        overloadId = 0; // setButtonText(QWizard::WizardButton,QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWizardFunc_setButtonText_TypeError;

    // Call function/method
    {
        {
            QWizard::WizardButton cppArg0 = Shiboken::Converter<QWizard::WizardButton >::toCpp(pyargs[0]);
            QString cppArg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // setButtonText(QWizard::WizardButton,QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setButtonText(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWizardFunc_setButtonText_TypeError:
        const char* overloads[] = {"PySide.QtGui.QWizard.WizardButton, QString", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QWizard.setButtonText", overloads);
        return 0;
}

static PyObject* Sbk_QWizardFunc_setDefaultProperty(PyObject* self, PyObject* args)
{
    QWizard* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWizard* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setDefaultProperty", 3, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: setDefaultProperty(const char*,const char*,const char*)
    if (numArgs == 3 && Shiboken::Converter< const char * >::isConvertible(pyargs[0]) && Shiboken::Converter< const char * >::isConvertible(pyargs[1]) && Shiboken::Converter< const char * >::isConvertible(pyargs[2])) {
        overloadId = 0; // setDefaultProperty(const char*,const char*,const char*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWizardFunc_setDefaultProperty_TypeError;

    // Call function/method
    {
        {
            const char * cppArg0 = Shiboken::Converter<const char * >::toCpp(pyargs[0]);
            const char * cppArg1 = Shiboken::Converter<const char * >::toCpp(pyargs[1]);
            const char * cppArg2 = Shiboken::Converter<const char * >::toCpp(pyargs[2]);

            if(!PyErr_Occurred()) {
                // setDefaultProperty(const char*,const char*,const char*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setDefaultProperty(cppArg0, cppArg1, cppArg2);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWizardFunc_setDefaultProperty_TypeError:
        const char* overloads[] = {"str, str, str", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QWizard.setDefaultProperty", overloads);
        return 0;
}

static PyObject* Sbk_QWizardFunc_setField(PyObject* self, PyObject* args)
{
    QWizard* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWizard* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setField", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setField(QString,QVariant)
    if (numArgs == 2 && Shiboken::Converter< QString >::isConvertible(pyargs[0]) && Shiboken::Converter< QVariant >::isConvertible(pyargs[1])) {
        overloadId = 0; // setField(QString,QVariant)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWizardFunc_setField_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            QVariant cppArg1 = Shiboken::Converter<QVariant >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // setField(QString,QVariant)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setField(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWizardFunc_setField_TypeError:
        const char* overloads[] = {"QString, QVariant", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QWizard.setField", overloads);
        return 0;
}

static PyObject* Sbk_QWizardFunc_setOption(PyObject* self, PyObject* args, PyObject* kwds)
{
    QWizard* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWizard* >::toCpp(self);

    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QWizard.setOption(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QWizard.setOption(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:setOption", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setOption(QWizard::WizardOption,bool)
    if (Shiboken::Converter< ::QWizard::WizardOption >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // setOption(QWizard::WizardOption,bool)
        } else if (SbkNumber_Check(pyargs[1])) {
            overloadId = 0; // setOption(QWizard::WizardOption,bool)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWizardFunc_setOption_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "on");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "on";
                    else if (SbkNumber_Check(value))
                        pyargs[1] = value;
                    else
                        goto Sbk_QWizardFunc_setOption_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QWizard.setOption(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QWizard::WizardOption cppArg0 = Shiboken::Converter<QWizard::WizardOption >::toCpp(pyargs[0]);
            bool cppArg1 = pyargs[1] ? Shiboken::Converter<bool >::toCpp(pyargs[1]) : true;

            if(!PyErr_Occurred()) {
                // setOption(QWizard::WizardOption,bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setOption(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWizardFunc_setOption_TypeError:
        const char* overloads[] = {"PySide.QtGui.QWizard.WizardOption, bool = true", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QWizard.setOption", overloads);
        return 0;
}

static PyObject* Sbk_QWizardFunc_setOptions(PyObject* self, PyObject* arg)
{
    QWizard* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWizard* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setOptions(QFlags<QWizard::WizardOption>)
    if (Shiboken::Converter< ::QFlags<QWizard::WizardOption> >::isConvertible(arg)) {
        overloadId = 0; // setOptions(QFlags<QWizard::WizardOption>)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWizardFunc_setOptions_TypeError;

    // Call function/method
    {
        {
            QFlags<QWizard::WizardOption> cppArg0 = Shiboken::Converter<QFlags<QWizard::WizardOption> >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setOptions(QFlags<QWizard::WizardOption>)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setOptions(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWizardFunc_setOptions_TypeError:
        const char* overloads[] = {"PySide.QtGui.QWizard.WizardOptions", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWizard.setOptions", overloads);
        return 0;
}

static PyObject* Sbk_QWizardFunc_setPage(PyObject* self, PyObject* args)
{
    QWizard* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWizard* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setPage", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setPage(int,QWizardPage*)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && Shiboken::Converter< ::QWizardPage * >::isConvertible(pyargs[1])) {
        overloadId = 0; // setPage(int,QWizardPage*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWizardFunc_setPage_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            QWizardPage * cppArg1 = Shiboken::Converter<QWizardPage * >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // setPage(int,QWizardPage*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setPage(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWizardFunc_setPage_TypeError:
        const char* overloads[] = {"int, PySide.QtGui.QWizardPage", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QWizard.setPage", overloads);
        return 0;
}

static PyObject* Sbk_QWizardFunc_setPixmap(PyObject* self, PyObject* args)
{
    QWizard* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWizard* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setPixmap", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setPixmap(QWizard::WizardPixmap,QPixmap)
    if (numArgs == 2 && Shiboken::Converter< ::QWizard::WizardPixmap >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QPixmap >::isConvertible(pyargs[1])) {
        overloadId = 0; // setPixmap(QWizard::WizardPixmap,QPixmap)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWizardFunc_setPixmap_TypeError;

    // Call function/method
    {
        {
            QWizard::WizardPixmap cppArg0 = Shiboken::Converter<QWizard::WizardPixmap >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            QPixmap cppArg1 = Shiboken::Converter<QPixmap >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // setPixmap(QWizard::WizardPixmap,QPixmap)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setPixmap(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWizardFunc_setPixmap_TypeError:
        const char* overloads[] = {"PySide.QtGui.QWizard.WizardPixmap, PySide.QtGui.QPixmap", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QWizard.setPixmap", overloads);
        return 0;
}

static PyObject* Sbk_QWizardFunc_setSideWidget(PyObject* self, PyObject* arg)
{
    QWizard* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWizard* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setSideWidget(QWidget*)
    if (Shiboken::Converter< ::QWidget * >::isConvertible(arg)) {
        overloadId = 0; // setSideWidget(QWidget*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWizardFunc_setSideWidget_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QWidget * cppArg0 = Shiboken::Converter<QWidget * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setSideWidget(QWidget*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setSideWidget(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWizardFunc_setSideWidget_TypeError:
        const char* overloads[] = {"PySide.QtGui.QWidget", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWizard.setSideWidget", overloads);
        return 0;
}

static PyObject* Sbk_QWizardFunc_setStartId(PyObject* self, PyObject* arg)
{
    QWizard* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWizard* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setStartId(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setStartId(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWizardFunc_setStartId_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setStartId(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setStartId(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWizardFunc_setStartId_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWizard.setStartId", overloads);
        return 0;
}

static PyObject* Sbk_QWizardFunc_setSubTitleFormat(PyObject* self, PyObject* arg)
{
    QWizard* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWizard* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setSubTitleFormat(Qt::TextFormat)
    if (Shiboken::Converter< ::Qt::TextFormat >::isConvertible(arg)) {
        overloadId = 0; // setSubTitleFormat(Qt::TextFormat)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWizardFunc_setSubTitleFormat_TypeError;

    // Call function/method
    {
        {
            Qt::TextFormat cppArg0 = Shiboken::Converter<Qt::TextFormat >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setSubTitleFormat(Qt::TextFormat)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setSubTitleFormat(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWizardFunc_setSubTitleFormat_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.TextFormat", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWizard.setSubTitleFormat", overloads);
        return 0;
}

static PyObject* Sbk_QWizardFunc_setTitleFormat(PyObject* self, PyObject* arg)
{
    QWizard* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWizard* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setTitleFormat(Qt::TextFormat)
    if (Shiboken::Converter< ::Qt::TextFormat >::isConvertible(arg)) {
        overloadId = 0; // setTitleFormat(Qt::TextFormat)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWizardFunc_setTitleFormat_TypeError;

    // Call function/method
    {
        {
            Qt::TextFormat cppArg0 = Shiboken::Converter<Qt::TextFormat >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setTitleFormat(Qt::TextFormat)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setTitleFormat(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWizardFunc_setTitleFormat_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.TextFormat", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWizard.setTitleFormat", overloads);
        return 0;
}

static PyObject* Sbk_QWizardFunc_setVisible(PyObject* self, PyObject* arg)
{
    QWizard* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWizard* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setVisible(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setVisible(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWizardFunc_setVisible_TypeError;

    // Call function/method
    {
        {
            bool cppArg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setVisible(bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QWizard::setVisible(cppArg0) : cppSelf->setVisible(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWizardFunc_setVisible_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWizard.setVisible", overloads);
        return 0;
}

static PyObject* Sbk_QWizardFunc_setWizardStyle(PyObject* self, PyObject* arg)
{
    QWizard* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWizard* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setWizardStyle(QWizard::WizardStyle)
    if (Shiboken::Converter< ::QWizard::WizardStyle >::isConvertible(arg)) {
        overloadId = 0; // setWizardStyle(QWizard::WizardStyle)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWizardFunc_setWizardStyle_TypeError;

    // Call function/method
    {
        {
            QWizard::WizardStyle cppArg0 = Shiboken::Converter<QWizard::WizardStyle >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setWizardStyle(QWizard::WizardStyle)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setWizardStyle(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWizardFunc_setWizardStyle_TypeError:
        const char* overloads[] = {"PySide.QtGui.QWizard.WizardStyle", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWizard.setWizardStyle", overloads);
        return 0;
}

static PyObject* Sbk_QWizardFunc_sideWidget(PyObject* self)
{
    QWizard* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWizard* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // sideWidget()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QWidget * cppResult = const_cast<const QWizard*>(cppSelf)->sideWidget();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QWidget * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWizardFunc_sizeHint(PyObject* self)
{
    QWizard* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWizard* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // sizeHint()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QSize cppResult = (Shiboken::Object::isUserType(self) ? const_cast<const QWizard*>(cppSelf)->::QWizard::sizeHint() : const_cast<const QWizard*>(cppSelf)->sizeHint());
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QSize >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWizardFunc_startId(PyObject* self)
{
    QWizard* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWizard* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // startId()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QWizard*>(cppSelf)->startId();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWizardFunc_subTitleFormat(PyObject* self)
{
    QWizard* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWizard* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // subTitleFormat()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                Qt::TextFormat cppResult = const_cast<const QWizard*>(cppSelf)->subTitleFormat();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::Qt::TextFormat >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWizardFunc_testOption(PyObject* self, PyObject* arg)
{
    QWizard* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWizard* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: testOption(QWizard::WizardOption)const
    if (Shiboken::Converter< ::QWizard::WizardOption >::isConvertible(arg)) {
        overloadId = 0; // testOption(QWizard::WizardOption)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWizardFunc_testOption_TypeError;

    // Call function/method
    {
        {
            QWizard::WizardOption cppArg0 = Shiboken::Converter<QWizard::WizardOption >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // testOption(QWizard::WizardOption)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QWizard*>(cppSelf)->testOption(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QWizardFunc_testOption_TypeError:
        const char* overloads[] = {"PySide.QtGui.QWizard.WizardOption", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWizard.testOption", overloads);
        return 0;
}

static PyObject* Sbk_QWizardFunc_titleFormat(PyObject* self)
{
    QWizard* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWizard* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // titleFormat()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                Qt::TextFormat cppResult = const_cast<const QWizard*>(cppSelf)->titleFormat();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::Qt::TextFormat >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWizardFunc_validateCurrentPage(PyObject* self)
{
    QWizard* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWizard* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // validateCurrentPage()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = (Shiboken::Object::isUserType(self) ? cppSelf->::QWizard::validateCurrentPage() : cppSelf->validateCurrentPage());
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWizardFunc_visitedPages(PyObject* self)
{
    QWizard* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWizard* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // visitedPages()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QList<int > cppResult = const_cast<const QWizard*>(cppSelf)->visitedPages();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QList<int > >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWizardFunc_wizardStyle(PyObject* self)
{
    QWizard* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWizard* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // wizardStyle()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QWizard::WizardStyle cppResult = const_cast<const QWizard*>(cppSelf)->wizardStyle();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QWizard::WizardStyle >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef Sbk_QWizard_methods[] = {
    {"addPage", (PyCFunction)Sbk_QWizardFunc_addPage, METH_O},
    {"back", (PyCFunction)Sbk_QWizardFunc_back, METH_NOARGS},
    {"button", (PyCFunction)Sbk_QWizardFunc_button, METH_O},
    {"buttonText", (PyCFunction)Sbk_QWizardFunc_buttonText, METH_O},
    {"cleanupPage", (PyCFunction)Sbk_QWizardFunc_cleanupPage, METH_O},
    {"currentId", (PyCFunction)Sbk_QWizardFunc_currentId, METH_NOARGS},
    {"currentPage", (PyCFunction)Sbk_QWizardFunc_currentPage, METH_NOARGS},
    {"done", (PyCFunction)Sbk_QWizardFunc_done, METH_O},
    {"event", (PyCFunction)Sbk_QWizardFunc_event, METH_O},
    {"field", (PyCFunction)Sbk_QWizardFunc_field, METH_O},
    {"hasVisitedPage", (PyCFunction)Sbk_QWizardFunc_hasVisitedPage, METH_O},
    {"initializePage", (PyCFunction)Sbk_QWizardFunc_initializePage, METH_O},
    {"next", (PyCFunction)Sbk_QWizardFunc_next, METH_NOARGS},
    {"nextId", (PyCFunction)Sbk_QWizardFunc_nextId, METH_NOARGS},
    {"options", (PyCFunction)Sbk_QWizardFunc_options, METH_NOARGS},
    {"page", (PyCFunction)Sbk_QWizardFunc_page, METH_O},
    {"pageIds", (PyCFunction)Sbk_QWizardFunc_pageIds, METH_NOARGS},
    {"paintEvent", (PyCFunction)Sbk_QWizardFunc_paintEvent, METH_O},
    {"pixmap", (PyCFunction)Sbk_QWizardFunc_pixmap, METH_O},
    {"removePage", (PyCFunction)Sbk_QWizardFunc_removePage, METH_O},
    {"resizeEvent", (PyCFunction)Sbk_QWizardFunc_resizeEvent, METH_O},
    {"restart", (PyCFunction)Sbk_QWizardFunc_restart, METH_NOARGS},
    {"setButton", (PyCFunction)Sbk_QWizardFunc_setButton, METH_VARARGS},
    {"setButtonLayout", (PyCFunction)Sbk_QWizardFunc_setButtonLayout, METH_O},
    {"setButtonText", (PyCFunction)Sbk_QWizardFunc_setButtonText, METH_VARARGS},
    {"setDefaultProperty", (PyCFunction)Sbk_QWizardFunc_setDefaultProperty, METH_VARARGS},
    {"setField", (PyCFunction)Sbk_QWizardFunc_setField, METH_VARARGS},
    {"setOption", (PyCFunction)Sbk_QWizardFunc_setOption, METH_VARARGS|METH_KEYWORDS},
    {"setOptions", (PyCFunction)Sbk_QWizardFunc_setOptions, METH_O},
    {"setPage", (PyCFunction)Sbk_QWizardFunc_setPage, METH_VARARGS},
    {"setPixmap", (PyCFunction)Sbk_QWizardFunc_setPixmap, METH_VARARGS},
    {"setSideWidget", (PyCFunction)Sbk_QWizardFunc_setSideWidget, METH_O},
    {"setStartId", (PyCFunction)Sbk_QWizardFunc_setStartId, METH_O},
    {"setSubTitleFormat", (PyCFunction)Sbk_QWizardFunc_setSubTitleFormat, METH_O},
    {"setTitleFormat", (PyCFunction)Sbk_QWizardFunc_setTitleFormat, METH_O},
    {"setVisible", (PyCFunction)Sbk_QWizardFunc_setVisible, METH_O},
    {"setWizardStyle", (PyCFunction)Sbk_QWizardFunc_setWizardStyle, METH_O},
    {"sideWidget", (PyCFunction)Sbk_QWizardFunc_sideWidget, METH_NOARGS},
    {"sizeHint", (PyCFunction)Sbk_QWizardFunc_sizeHint, METH_NOARGS},
    {"startId", (PyCFunction)Sbk_QWizardFunc_startId, METH_NOARGS},
    {"subTitleFormat", (PyCFunction)Sbk_QWizardFunc_subTitleFormat, METH_NOARGS},
    {"testOption", (PyCFunction)Sbk_QWizardFunc_testOption, METH_O},
    {"titleFormat", (PyCFunction)Sbk_QWizardFunc_titleFormat, METH_NOARGS},
    {"validateCurrentPage", (PyCFunction)Sbk_QWizardFunc_validateCurrentPage, METH_NOARGS},
    {"visitedPages", (PyCFunction)Sbk_QWizardFunc_visitedPages, METH_NOARGS},
    {"wizardStyle", (PyCFunction)Sbk_QWizardFunc_wizardStyle, METH_NOARGS},

    {0} // Sentinel
};

} // extern "C"

static void* Sbk_QWizardSpecialCastFunction(void* obj, SbkObjectType* desiredType)
{
    QWizard* me = reinterpret_cast<QWizard*>(obj);
    if (desiredType == reinterpret_cast<SbkObjectType*>(SbkPySide_QtGuiTypes[SBK_QDIALOG_IDX]))
        return static_cast<QDialog*>(me);
    else if (desiredType == reinterpret_cast<SbkObjectType*>(SbkPySide_QtGuiTypes[SBK_QWIDGET_IDX]))
        return static_cast<QWidget*>(me);
    else if (desiredType == reinterpret_cast<SbkObjectType*>(SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX]))
        return static_cast<QObject*>(me);
    else if (desiredType == reinterpret_cast<SbkObjectType*>(SbkPySide_QtGuiTypes[SBK_QPAINTDEVICE_IDX]))
        return static_cast<QPaintDevice*>(me);
    return me;
}


// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QWizard_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QWizard",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QWizard_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QWizard_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern

static SbkObjectType* Sbk_QWizard_typeDiscovery(void* cptr, SbkObjectType* instanceType)
{
    if (instanceType == reinterpret_cast<SbkObjectType*>(Shiboken::SbkType<QObject >()) && dynamic_cast<QWizard*>(reinterpret_cast<QObject*>(cptr)))
        return &Sbk_QWizard_Type;
    if (instanceType == reinterpret_cast<SbkObjectType*>(Shiboken::SbkType<QPaintDevice >()) && dynamic_cast<QWizard*>(reinterpret_cast<QPaintDevice*>(cptr)))
        return &Sbk_QWizard_Type;
    return 0;
}

PyObject* SbkPySide_QtGui_QWizard_WizardOption___and__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QWizard::WizardOptions >::toPython(
        Shiboken::Converter<QWizard::WizardOptions>::toCpp(self)
        & Shiboken::Converter< QWizard::WizardOptions >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtGui_QWizard_WizardOption___or__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QWizard::WizardOptions >::toPython(
        Shiboken::Converter<QWizard::WizardOptions>::toCpp(self)
        | Shiboken::Converter< QWizard::WizardOptions >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtGui_QWizard_WizardOption___xor__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QWizard::WizardOptions >::toPython(
        Shiboken::Converter<QWizard::WizardOptions>::toCpp(self)
        ^ Shiboken::Converter< QWizard::WizardOptions >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtGui_QWizard_WizardOption___invert__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QWizard::WizardOptions >::toPython(
        ~Shiboken::Converter<QWizard::WizardOptions >::toCpp(self)
    );
}


static PyNumberMethods SbkPySide_QtGui_QWizard_WizardOption_as_number = {
    /*nb_add*/                  0,
    /*nb_subtract*/             0,
    /*nb_multiply*/             0,
    /*nb_divide*/               0,
    /*nb_remainder*/            0,
    /*nb_divmod*/               0,
    /*nb_power*/                0,
    /*nb_negative*/             0,
    /*nb_positive*/             0,
    /*nb_absolute*/             0,
    /*nb_nonzero*/              0,
    /*nb_invert*/               (unaryfunc)SbkPySide_QtGui_QWizard_WizardOption___invert__,
    /*nb_lshift*/               0,
    /*nb_rshift*/               0,
    /*nb_and*/                  (binaryfunc)SbkPySide_QtGui_QWizard_WizardOption___and__,
    /*nb_xor*/                  (binaryfunc)SbkPySide_QtGui_QWizard_WizardOption___xor__,
    /*nb_or*/                   (binaryfunc)SbkPySide_QtGui_QWizard_WizardOption___or__,
    /*nb_coerce*/               0,
    /*nb_int*/                  0,
    /*nb_long*/                 0,
    /*nb_float*/                0,
    /*nb_oct*/                  0,
    /*nb_hex*/                  0,
    /*nb_inplace_add*/          0,
    /*nb_inplace_subtract*/     0,
    /*nb_inplace_multiply*/     0,
    /*nb_inplace_divide*/       0,
    /*nb_inplace_remainder*/    0,
    /*nb_inplace_power*/        0,
    /*nb_inplace_lshift*/       0,
    /*nb_inplace_rshift*/       0,
    /*nb_inplace_and*/          0,
    /*nb_inplace_xor*/          0,
    /*nb_inplace_or*/           0,
    /*nb_floor_divide*/         0,
    /*nb_true_divide*/          0,
    /*nb_inplace_floor_divide*/ 0,
    /*nb_inplace_true_divide*/  0,
    /*nb_index*/                0
};


// forward declaration of new function
static PyTypeObject SbkPySide_QtGui_QWizard_WizardOptions_Type = {
    PyObject_HEAD_INIT(&PyType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "WizardOptions",
    /*tp_basicsize*/        0,
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        &SbkPySide_QtGui_QWizard_WizardOption_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT | Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              PyInt_Type.tp_new,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};



void init_QWizard(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QWIZARD_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QWizard_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QWizard_Type);
    Shiboken::ObjectType::setSubTypeInitHook(&Sbk_QWizard_Type, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(&Sbk_QWizard_Type, &QWizard::staticMetaObject);    Sbk_QWizard_Type.super.ht_type.tp_base = SbkPySide_QtGuiTypes[SBK_QDIALOG_IDX];
    MultipleInheritanceInitFunction func;
    func = Shiboken::ObjectType::getMultipleIheritanceFunction(reinterpret_cast<SbkObjectType*>(SbkPySide_QtGuiTypes[SBK_QWIDGET_IDX]));
    Shiboken::ObjectType::setMultipleIheritanceFunction(&Sbk_QWizard_Type, func);
    Shiboken::ObjectType::setCastFunction(&Sbk_QWizard_Type, &Sbk_QWizardSpecialCastFunction);
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QWizard_Type, &Shiboken::callCppDestructor<QWizard >);
    if (PyType_Ready((PyTypeObject*)&Sbk_QWizard_Type) < 0)
        return;

    // Fill type discovery information
    Shiboken::ObjectType::setTypeDiscoveryFunction(&Sbk_QWizard_Type, &Sbk_QWizard_typeDiscovery);
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkObjectType*>(SbkPySide_QtGuiTypes[SBK_QDIALOG_IDX]), &Sbk_QWizard_Type);

    Shiboken::ObjectType::setOriginalName(&Sbk_QWizard_Type, "QWizard*");
    PyModule_AddObject(module, "QWizard",
        ((PyObject*)&Sbk_QWizard_Type));

    // Initialize enums
    PyObject* enumItem;

    // init enum: WizardButton
    PyTypeObject* SbkPySide_QtGui_QWizard_WizardButton = Shiboken::Enum::newType("PySide.QtGui.QWizard.WizardButton");
    SbkPySide_QtGuiTypes[SBK_QWIZARD_WIZARDBUTTON_IDX] = SbkPySide_QtGui_QWizard_WizardButton;
    if (PyType_Ready(SbkPySide_QtGui_QWizard_WizardButton) < 0)
        return;
    PyDict_SetItemString(Sbk_QWizard_Type.super.ht_type.tp_dict,
            "WizardButton",((PyObject*)SbkPySide_QtGui_QWizard_WizardButton));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QWizard_WizardButton,(long) QWizard::BackButton, "BackButton");
    PyDict_SetItemString(Sbk_QWizard_Type.super.ht_type.tp_dict,"BackButton", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QWizard_WizardButton->tp_dict,"BackButton", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QWizard_WizardButton,(long) QWizard::NextButton, "NextButton");
    PyDict_SetItemString(Sbk_QWizard_Type.super.ht_type.tp_dict,"NextButton", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QWizard_WizardButton->tp_dict,"NextButton", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QWizard_WizardButton,(long) QWizard::CommitButton, "CommitButton");
    PyDict_SetItemString(Sbk_QWizard_Type.super.ht_type.tp_dict,"CommitButton", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QWizard_WizardButton->tp_dict,"CommitButton", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QWizard_WizardButton,(long) QWizard::FinishButton, "FinishButton");
    PyDict_SetItemString(Sbk_QWizard_Type.super.ht_type.tp_dict,"FinishButton", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QWizard_WizardButton->tp_dict,"FinishButton", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QWizard_WizardButton,(long) QWizard::CancelButton, "CancelButton");
    PyDict_SetItemString(Sbk_QWizard_Type.super.ht_type.tp_dict,"CancelButton", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QWizard_WizardButton->tp_dict,"CancelButton", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QWizard_WizardButton,(long) QWizard::HelpButton, "HelpButton");
    PyDict_SetItemString(Sbk_QWizard_Type.super.ht_type.tp_dict,"HelpButton", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QWizard_WizardButton->tp_dict,"HelpButton", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QWizard_WizardButton,(long) QWizard::CustomButton1, "CustomButton1");
    PyDict_SetItemString(Sbk_QWizard_Type.super.ht_type.tp_dict,"CustomButton1", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QWizard_WizardButton->tp_dict,"CustomButton1", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QWizard_WizardButton,(long) QWizard::CustomButton2, "CustomButton2");
    PyDict_SetItemString(Sbk_QWizard_Type.super.ht_type.tp_dict,"CustomButton2", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QWizard_WizardButton->tp_dict,"CustomButton2", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QWizard_WizardButton,(long) QWizard::CustomButton3, "CustomButton3");
    PyDict_SetItemString(Sbk_QWizard_Type.super.ht_type.tp_dict,"CustomButton3", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QWizard_WizardButton->tp_dict,"CustomButton3", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QWizard_WizardButton,(long) QWizard::Stretch, "Stretch");
    PyDict_SetItemString(Sbk_QWizard_Type.super.ht_type.tp_dict,"Stretch", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QWizard_WizardButton->tp_dict,"Stretch", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QWizard_WizardButton,(long) QWizard::NoButton, "NoButton");
    PyDict_SetItemString(Sbk_QWizard_Type.super.ht_type.tp_dict,"NoButton", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QWizard_WizardButton->tp_dict,"NoButton", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QWizard_WizardButton,(long) QWizard::NStandardButtons, "NStandardButtons");
    PyDict_SetItemString(Sbk_QWizard_Type.super.ht_type.tp_dict,"NStandardButtons", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QWizard_WizardButton->tp_dict,"NStandardButtons", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QWizard_WizardButton,(long) QWizard::NButtons, "NButtons");
    PyDict_SetItemString(Sbk_QWizard_Type.super.ht_type.tp_dict,"NButtons", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QWizard_WizardButton->tp_dict,"NButtons", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QWizard::WizardButton");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::WizardButton");
    // end of enum WizardButton

    // init enum: WizardStyle
    PyTypeObject* SbkPySide_QtGui_QWizard_WizardStyle = Shiboken::Enum::newType("PySide.QtGui.QWizard.WizardStyle");
    SbkPySide_QtGuiTypes[SBK_QWIZARD_WIZARDSTYLE_IDX] = SbkPySide_QtGui_QWizard_WizardStyle;
    if (PyType_Ready(SbkPySide_QtGui_QWizard_WizardStyle) < 0)
        return;
    PyDict_SetItemString(Sbk_QWizard_Type.super.ht_type.tp_dict,
            "WizardStyle",((PyObject*)SbkPySide_QtGui_QWizard_WizardStyle));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QWizard_WizardStyle,(long) QWizard::ClassicStyle, "ClassicStyle");
    PyDict_SetItemString(Sbk_QWizard_Type.super.ht_type.tp_dict,"ClassicStyle", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QWizard_WizardStyle->tp_dict,"ClassicStyle", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QWizard_WizardStyle,(long) QWizard::ModernStyle, "ModernStyle");
    PyDict_SetItemString(Sbk_QWizard_Type.super.ht_type.tp_dict,"ModernStyle", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QWizard_WizardStyle->tp_dict,"ModernStyle", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QWizard_WizardStyle,(long) QWizard::MacStyle, "MacStyle");
    PyDict_SetItemString(Sbk_QWizard_Type.super.ht_type.tp_dict,"MacStyle", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QWizard_WizardStyle->tp_dict,"MacStyle", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QWizard_WizardStyle,(long) QWizard::AeroStyle, "AeroStyle");
    PyDict_SetItemString(Sbk_QWizard_Type.super.ht_type.tp_dict,"AeroStyle", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QWizard_WizardStyle->tp_dict,"AeroStyle", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QWizard_WizardStyle,(long) QWizard::NStyles, "NStyles");
    PyDict_SetItemString(Sbk_QWizard_Type.super.ht_type.tp_dict,"NStyles", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QWizard_WizardStyle->tp_dict,"NStyles", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QWizard::WizardStyle");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::WizardStyle");
    // end of enum WizardStyle

    // init enum: WizardPixmap
    PyTypeObject* SbkPySide_QtGui_QWizard_WizardPixmap = Shiboken::Enum::newType("PySide.QtGui.QWizard.WizardPixmap");
    SbkPySide_QtGuiTypes[SBK_QWIZARD_WIZARDPIXMAP_IDX] = SbkPySide_QtGui_QWizard_WizardPixmap;
    if (PyType_Ready(SbkPySide_QtGui_QWizard_WizardPixmap) < 0)
        return;
    PyDict_SetItemString(Sbk_QWizard_Type.super.ht_type.tp_dict,
            "WizardPixmap",((PyObject*)SbkPySide_QtGui_QWizard_WizardPixmap));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QWizard_WizardPixmap,(long) QWizard::WatermarkPixmap, "WatermarkPixmap");
    PyDict_SetItemString(Sbk_QWizard_Type.super.ht_type.tp_dict,"WatermarkPixmap", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QWizard_WizardPixmap->tp_dict,"WatermarkPixmap", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QWizard_WizardPixmap,(long) QWizard::LogoPixmap, "LogoPixmap");
    PyDict_SetItemString(Sbk_QWizard_Type.super.ht_type.tp_dict,"LogoPixmap", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QWizard_WizardPixmap->tp_dict,"LogoPixmap", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QWizard_WizardPixmap,(long) QWizard::BannerPixmap, "BannerPixmap");
    PyDict_SetItemString(Sbk_QWizard_Type.super.ht_type.tp_dict,"BannerPixmap", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QWizard_WizardPixmap->tp_dict,"BannerPixmap", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QWizard_WizardPixmap,(long) QWizard::BackgroundPixmap, "BackgroundPixmap");
    PyDict_SetItemString(Sbk_QWizard_Type.super.ht_type.tp_dict,"BackgroundPixmap", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QWizard_WizardPixmap->tp_dict,"BackgroundPixmap", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QWizard_WizardPixmap,(long) QWizard::NPixmaps, "NPixmaps");
    PyDict_SetItemString(Sbk_QWizard_Type.super.ht_type.tp_dict,"NPixmaps", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QWizard_WizardPixmap->tp_dict,"NPixmaps", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QWizard::WizardPixmap");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::WizardPixmap");
    // end of enum WizardPixmap

    // init enum: WizardOption
    PyTypeObject* SbkPySide_QtGui_QWizard_WizardOption = Shiboken::Enum::newType("PySide.QtGui.QWizard.WizardOption");
    SbkPySide_QtGui_QWizard_WizardOption->tp_as_number = &SbkPySide_QtGui_QWizard_WizardOption_as_number;
    SbkPySide_QtGuiTypes[SBK_QWIZARD_WIZARDOPTION_IDX] = SbkPySide_QtGui_QWizard_WizardOption;
    if (PyType_Ready(SbkPySide_QtGui_QWizard_WizardOption) < 0)
        return;
    PyDict_SetItemString(Sbk_QWizard_Type.super.ht_type.tp_dict,
            "WizardOption",((PyObject*)SbkPySide_QtGui_QWizard_WizardOption));

    // init flags class: QFlags<QWizard::WizardOption>
    SbkPySide_QtGuiTypes[SBK_QFLAGS_QWIZARD_WIZARDOPTION__IDX] = &SbkPySide_QtGui_QWizard_WizardOptions_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtGui_QWizard_WizardOptions_Type) < 0)
        return;
    PyDict_SetItemString(Sbk_QWizard_Type.super.ht_type.tp_dict,
            "WizardOptions",((PyObject*)&SbkPySide_QtGui_QWizard_WizardOptions_Type));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QWizard_WizardOption,(long) QWizard::IndependentPages, "IndependentPages");
    PyDict_SetItemString(Sbk_QWizard_Type.super.ht_type.tp_dict,"IndependentPages", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QWizard_WizardOption->tp_dict,"IndependentPages", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QWizard_WizardOption,(long) QWizard::IgnoreSubTitles, "IgnoreSubTitles");
    PyDict_SetItemString(Sbk_QWizard_Type.super.ht_type.tp_dict,"IgnoreSubTitles", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QWizard_WizardOption->tp_dict,"IgnoreSubTitles", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QWizard_WizardOption,(long) QWizard::ExtendedWatermarkPixmap, "ExtendedWatermarkPixmap");
    PyDict_SetItemString(Sbk_QWizard_Type.super.ht_type.tp_dict,"ExtendedWatermarkPixmap", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QWizard_WizardOption->tp_dict,"ExtendedWatermarkPixmap", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QWizard_WizardOption,(long) QWizard::NoDefaultButton, "NoDefaultButton");
    PyDict_SetItemString(Sbk_QWizard_Type.super.ht_type.tp_dict,"NoDefaultButton", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QWizard_WizardOption->tp_dict,"NoDefaultButton", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QWizard_WizardOption,(long) QWizard::NoBackButtonOnStartPage, "NoBackButtonOnStartPage");
    PyDict_SetItemString(Sbk_QWizard_Type.super.ht_type.tp_dict,"NoBackButtonOnStartPage", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QWizard_WizardOption->tp_dict,"NoBackButtonOnStartPage", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QWizard_WizardOption,(long) QWizard::NoBackButtonOnLastPage, "NoBackButtonOnLastPage");
    PyDict_SetItemString(Sbk_QWizard_Type.super.ht_type.tp_dict,"NoBackButtonOnLastPage", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QWizard_WizardOption->tp_dict,"NoBackButtonOnLastPage", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QWizard_WizardOption,(long) QWizard::DisabledBackButtonOnLastPage, "DisabledBackButtonOnLastPage");
    PyDict_SetItemString(Sbk_QWizard_Type.super.ht_type.tp_dict,"DisabledBackButtonOnLastPage", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QWizard_WizardOption->tp_dict,"DisabledBackButtonOnLastPage", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QWizard_WizardOption,(long) QWizard::HaveNextButtonOnLastPage, "HaveNextButtonOnLastPage");
    PyDict_SetItemString(Sbk_QWizard_Type.super.ht_type.tp_dict,"HaveNextButtonOnLastPage", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QWizard_WizardOption->tp_dict,"HaveNextButtonOnLastPage", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QWizard_WizardOption,(long) QWizard::HaveFinishButtonOnEarlyPages, "HaveFinishButtonOnEarlyPages");
    PyDict_SetItemString(Sbk_QWizard_Type.super.ht_type.tp_dict,"HaveFinishButtonOnEarlyPages", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QWizard_WizardOption->tp_dict,"HaveFinishButtonOnEarlyPages", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QWizard_WizardOption,(long) QWizard::NoCancelButton, "NoCancelButton");
    PyDict_SetItemString(Sbk_QWizard_Type.super.ht_type.tp_dict,"NoCancelButton", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QWizard_WizardOption->tp_dict,"NoCancelButton", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QWizard_WizardOption,(long) QWizard::CancelButtonOnLeft, "CancelButtonOnLeft");
    PyDict_SetItemString(Sbk_QWizard_Type.super.ht_type.tp_dict,"CancelButtonOnLeft", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QWizard_WizardOption->tp_dict,"CancelButtonOnLeft", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QWizard_WizardOption,(long) QWizard::HaveHelpButton, "HaveHelpButton");
    PyDict_SetItemString(Sbk_QWizard_Type.super.ht_type.tp_dict,"HaveHelpButton", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QWizard_WizardOption->tp_dict,"HaveHelpButton", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QWizard_WizardOption,(long) QWizard::HelpButtonOnRight, "HelpButtonOnRight");
    PyDict_SetItemString(Sbk_QWizard_Type.super.ht_type.tp_dict,"HelpButtonOnRight", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QWizard_WizardOption->tp_dict,"HelpButtonOnRight", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QWizard_WizardOption,(long) QWizard::HaveCustomButton1, "HaveCustomButton1");
    PyDict_SetItemString(Sbk_QWizard_Type.super.ht_type.tp_dict,"HaveCustomButton1", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QWizard_WizardOption->tp_dict,"HaveCustomButton1", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QWizard_WizardOption,(long) QWizard::HaveCustomButton2, "HaveCustomButton2");
    PyDict_SetItemString(Sbk_QWizard_Type.super.ht_type.tp_dict,"HaveCustomButton2", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QWizard_WizardOption->tp_dict,"HaveCustomButton2", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QWizard_WizardOption,(long) QWizard::HaveCustomButton3, "HaveCustomButton3");
    PyDict_SetItemString(Sbk_QWizard_Type.super.ht_type.tp_dict,"HaveCustomButton3", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QWizard_WizardOption->tp_dict,"HaveCustomButton3", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QWizard::WizardOption");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::WizardOption");
    // end of enum WizardOption

    // Initialize signals
    PySideSignal* signal_item;

    signal_item = PySide::Signal::newObject("currentIdChanged", "int", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QWizard_Type, "currentIdChanged", signal_item);
    Py_DECREF((PyObject*) signal_item);
    signal_item = PySide::Signal::newObject("customButtonClicked", "int", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QWizard_Type, "customButtonClicked", signal_item);
    Py_DECREF((PyObject*) signal_item);
    signal_item = PySide::Signal::newObject("pageRemoved", "int", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QWizard_Type, "pageRemoved", signal_item);
    Py_DECREF((PyObject*) signal_item);
    signal_item = PySide::Signal::newObject("pageAdded", "int", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QWizard_Type, "pageAdded", signal_item);
    Py_DECREF((PyObject*) signal_item);
    signal_item = PySide::Signal::newObject("helpRequested", "void", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QWizard_Type, "helpRequested", signal_item);
    Py_DECREF((PyObject*) signal_item);


    Shiboken::TypeResolver::createObjectTypeResolver<QWizard >("QWizard*");
    Shiboken::TypeResolver::createObjectTypeResolver<QWizard >(typeid(QWizard).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QWizard >(typeid(QWizardWrapper).name());
    PySide::initQtMetaType< ::QWizard* >();
    qRegisterMetaType< ::QWizard::WizardButton >("QWizard::WizardButton");
    qRegisterMetaType< ::QWizard::WizardStyle >("QWizard::WizardStyle");
    qRegisterMetaType< ::QWizard::WizardPixmap >("QWizard::WizardPixmap");
    qRegisterMetaType< ::QWizard::WizardOption >("QWizard::WizardOption");
    qRegisterMetaType< ::QWizard::WizardOptions >("QWizard::WizardOptions");
}

