/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qx11info_wrapper.h"

// Extra includes
#include <qpaintdevice.h>
#include <qx11info_x11.h>



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QX11Info_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QX11Info >()))
        return -1;

    QX11Info* cptr = 0;
    int overloadId = -1;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QX11Info", 0, 1, &(pyargs[0])))
        return -1;

    // Overloaded function decisor
    // 0: QX11Info()
    // 1: QX11Info(QX11Info)
    if (numArgs == 0) {
        overloadId = 0; // QX11Info()
    } else if (numArgs == 1 && Shiboken::Converter< ::QX11Info >::isConvertible(pyargs[0])) {
        overloadId = 1; // QX11Info(QX11Info)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QX11Info_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QX11Info()
            {

                if(!PyErr_Occurred()) {
                    // QX11Info()
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QX11Info();
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // QX11Info(QX11Info)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QX11Info cppArg0 = Shiboken::Converter<QX11Info >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QX11Info(QX11Info)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QX11Info(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QX11Info >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QX11Info_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QX11Info_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtGui.QX11Info", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QX11Info", overloads);
        return -1;
}

static PyObject* Sbk_QX11InfoFunc_appCells(PyObject* self, PyObject* args, PyObject* kwds)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QX11Info.appCells(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:appCells", &(pyargs[0])))
        return 0;


    // Overloaded function decisor
    // 0: appCells(int)
    if (numArgs == 0) {
        overloadId = 0; // appCells(int)
    } else if (SbkNumber_Check(pyargs[0])) {
        overloadId = 0; // appCells(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QX11InfoFunc_appCells_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "screen");
                if (value) {
                    if (pyargs[0])
                        errorArgName = "screen";
                    else if (SbkNumber_Check(value))
                        pyargs[0] = value;
                    else
                        goto Sbk_QX11InfoFunc_appCells_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QX11Info.appCells(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            int cppArg0 = pyargs[0] ? Shiboken::Converter<int >::toCpp(pyargs[0]) : -1;

            if(!PyErr_Occurred()) {
                // appCells(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = QX11Info::appCells(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QX11InfoFunc_appCells_TypeError:
        const char* overloads[] = {"int = -1", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QX11Info.appCells", overloads);
        return 0;
}

static PyObject* Sbk_QX11InfoFunc_appClass(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // appClass()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                const char * cppResult = QX11Info::appClass();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< const char * >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QX11InfoFunc_appColormap(PyObject* self, PyObject* args, PyObject* kwds)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QX11Info.appColormap(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:appColormap", &(pyargs[0])))
        return 0;


    // Overloaded function decisor
    // 0: appColormap(int)
    if (numArgs == 0) {
        overloadId = 0; // appColormap(int)
    } else if (SbkNumber_Check(pyargs[0])) {
        overloadId = 0; // appColormap(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QX11InfoFunc_appColormap_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "screen");
                if (value) {
                    if (pyargs[0])
                        errorArgName = "screen";
                    else if (SbkNumber_Check(value))
                        pyargs[0] = value;
                    else
                        goto Sbk_QX11InfoFunc_appColormap_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QX11Info.appColormap(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            int cppArg0 = pyargs[0] ? Shiboken::Converter<int >::toCpp(pyargs[0]) : -1;

            if(!PyErr_Occurred()) {
                // appColormap(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                Qt::HANDLE cppResult = QX11Info::appColormap(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< Qt::HANDLE >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QX11InfoFunc_appColormap_TypeError:
        const char* overloads[] = {"int = -1", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QX11Info.appColormap", overloads);
        return 0;
}

static PyObject* Sbk_QX11InfoFunc_appDefaultColormap(PyObject* self, PyObject* args, PyObject* kwds)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QX11Info.appDefaultColormap(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:appDefaultColormap", &(pyargs[0])))
        return 0;


    // Overloaded function decisor
    // 0: appDefaultColormap(int)
    if (numArgs == 0) {
        overloadId = 0; // appDefaultColormap(int)
    } else if (SbkNumber_Check(pyargs[0])) {
        overloadId = 0; // appDefaultColormap(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QX11InfoFunc_appDefaultColormap_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "screen");
                if (value) {
                    if (pyargs[0])
                        errorArgName = "screen";
                    else if (SbkNumber_Check(value))
                        pyargs[0] = value;
                    else
                        goto Sbk_QX11InfoFunc_appDefaultColormap_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QX11Info.appDefaultColormap(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            int cppArg0 = pyargs[0] ? Shiboken::Converter<int >::toCpp(pyargs[0]) : -1;

            if(!PyErr_Occurred()) {
                // appDefaultColormap(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = QX11Info::appDefaultColormap(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QX11InfoFunc_appDefaultColormap_TypeError:
        const char* overloads[] = {"int = -1", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QX11Info.appDefaultColormap", overloads);
        return 0;
}

static PyObject* Sbk_QX11InfoFunc_appDefaultVisual(PyObject* self, PyObject* args, PyObject* kwds)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QX11Info.appDefaultVisual(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:appDefaultVisual", &(pyargs[0])))
        return 0;


    // Overloaded function decisor
    // 0: appDefaultVisual(int)
    if (numArgs == 0) {
        overloadId = 0; // appDefaultVisual(int)
    } else if (SbkNumber_Check(pyargs[0])) {
        overloadId = 0; // appDefaultVisual(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QX11InfoFunc_appDefaultVisual_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "screen");
                if (value) {
                    if (pyargs[0])
                        errorArgName = "screen";
                    else if (SbkNumber_Check(value))
                        pyargs[0] = value;
                    else
                        goto Sbk_QX11InfoFunc_appDefaultVisual_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QX11Info.appDefaultVisual(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            int cppArg0 = pyargs[0] ? Shiboken::Converter<int >::toCpp(pyargs[0]) : -1;

            if(!PyErr_Occurred()) {
                // appDefaultVisual(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = QX11Info::appDefaultVisual(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QX11InfoFunc_appDefaultVisual_TypeError:
        const char* overloads[] = {"int = -1", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QX11Info.appDefaultVisual", overloads);
        return 0;
}

static PyObject* Sbk_QX11InfoFunc_appDepth(PyObject* self, PyObject* args, PyObject* kwds)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QX11Info.appDepth(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:appDepth", &(pyargs[0])))
        return 0;


    // Overloaded function decisor
    // 0: appDepth(int)
    if (numArgs == 0) {
        overloadId = 0; // appDepth(int)
    } else if (SbkNumber_Check(pyargs[0])) {
        overloadId = 0; // appDepth(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QX11InfoFunc_appDepth_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "screen");
                if (value) {
                    if (pyargs[0])
                        errorArgName = "screen";
                    else if (SbkNumber_Check(value))
                        pyargs[0] = value;
                    else
                        goto Sbk_QX11InfoFunc_appDepth_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QX11Info.appDepth(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            int cppArg0 = pyargs[0] ? Shiboken::Converter<int >::toCpp(pyargs[0]) : -1;

            if(!PyErr_Occurred()) {
                // appDepth(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = QX11Info::appDepth(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QX11InfoFunc_appDepth_TypeError:
        const char* overloads[] = {"int = -1", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QX11Info.appDepth", overloads);
        return 0;
}

static PyObject* Sbk_QX11InfoFunc_appDpiX(PyObject* self, PyObject* args, PyObject* kwds)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QX11Info.appDpiX(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:appDpiX", &(pyargs[0])))
        return 0;


    // Overloaded function decisor
    // 0: appDpiX(int)
    if (numArgs == 0) {
        overloadId = 0; // appDpiX(int)
    } else if (SbkNumber_Check(pyargs[0])) {
        overloadId = 0; // appDpiX(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QX11InfoFunc_appDpiX_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "screen");
                if (value) {
                    if (pyargs[0])
                        errorArgName = "screen";
                    else if (SbkNumber_Check(value))
                        pyargs[0] = value;
                    else
                        goto Sbk_QX11InfoFunc_appDpiX_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QX11Info.appDpiX(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            int cppArg0 = pyargs[0] ? Shiboken::Converter<int >::toCpp(pyargs[0]) : -1;

            if(!PyErr_Occurred()) {
                // appDpiX(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = QX11Info::appDpiX(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QX11InfoFunc_appDpiX_TypeError:
        const char* overloads[] = {"int = -1", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QX11Info.appDpiX", overloads);
        return 0;
}

static PyObject* Sbk_QX11InfoFunc_appDpiY(PyObject* self, PyObject* args, PyObject* kwds)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QX11Info.appDpiY(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:appDpiY", &(pyargs[0])))
        return 0;


    // Overloaded function decisor
    // 0: appDpiY(int)
    if (numArgs == 0) {
        overloadId = 0; // appDpiY(int)
    } else if (SbkNumber_Check(pyargs[0])) {
        overloadId = 0; // appDpiY(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QX11InfoFunc_appDpiY_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "screen");
                if (value) {
                    if (pyargs[0])
                        errorArgName = "screen";
                    else if (SbkNumber_Check(value))
                        pyargs[0] = value;
                    else
                        goto Sbk_QX11InfoFunc_appDpiY_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QX11Info.appDpiY(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            int cppArg0 = pyargs[0] ? Shiboken::Converter<int >::toCpp(pyargs[0]) : -1;

            if(!PyErr_Occurred()) {
                // appDpiY(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = QX11Info::appDpiY(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QX11InfoFunc_appDpiY_TypeError:
        const char* overloads[] = {"int = -1", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QX11Info.appDpiY", overloads);
        return 0;
}

static PyObject* Sbk_QX11InfoFunc_appRootWindow(PyObject* self, PyObject* args, PyObject* kwds)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QX11Info.appRootWindow(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:appRootWindow", &(pyargs[0])))
        return 0;


    // Overloaded function decisor
    // 0: appRootWindow(int)
    if (numArgs == 0) {
        overloadId = 0; // appRootWindow(int)
    } else if (SbkNumber_Check(pyargs[0])) {
        overloadId = 0; // appRootWindow(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QX11InfoFunc_appRootWindow_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "screen");
                if (value) {
                    if (pyargs[0])
                        errorArgName = "screen";
                    else if (SbkNumber_Check(value))
                        pyargs[0] = value;
                    else
                        goto Sbk_QX11InfoFunc_appRootWindow_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QX11Info.appRootWindow(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            int cppArg0 = pyargs[0] ? Shiboken::Converter<int >::toCpp(pyargs[0]) : -1;

            if(!PyErr_Occurred()) {
                // appRootWindow(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                Qt::HANDLE cppResult = QX11Info::appRootWindow(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< Qt::HANDLE >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QX11InfoFunc_appRootWindow_TypeError:
        const char* overloads[] = {"int = -1", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QX11Info.appRootWindow", overloads);
        return 0;
}

static PyObject* Sbk_QX11InfoFunc_appScreen(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // appScreen()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = QX11Info::appScreen();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QX11InfoFunc_appTime(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // appTime()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                unsigned long cppResult = QX11Info::appTime();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< unsigned long >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QX11InfoFunc_appUserTime(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // appUserTime()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                unsigned long cppResult = QX11Info::appUserTime();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< unsigned long >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QX11InfoFunc_cells(PyObject* self)
{
    QX11Info* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QX11Info* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // cells()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QX11Info*>(cppSelf)->cells();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QX11InfoFunc_cloneX11Data(PyObject* self, PyObject* arg)
{
    QX11Info* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QX11Info* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: cloneX11Data(const QPaintDevice*)
    if (Shiboken::Converter< ::QPaintDevice * >::isConvertible(arg)) {
        overloadId = 0; // cloneX11Data(const QPaintDevice*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QX11InfoFunc_cloneX11Data_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QPaintDevice * cppArg0 = Shiboken::Converter<QPaintDevice * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // cloneX11Data(const QPaintDevice*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->cloneX11Data(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QX11InfoFunc_cloneX11Data_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPaintDevice", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QX11Info.cloneX11Data", overloads);
        return 0;
}

static PyObject* Sbk_QX11InfoFunc_colormap(PyObject* self)
{
    QX11Info* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QX11Info* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // colormap()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                Qt::HANDLE cppResult = const_cast<const QX11Info*>(cppSelf)->colormap();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< Qt::HANDLE >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QX11InfoFunc_copyX11Data(PyObject* self, PyObject* arg)
{
    QX11Info* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QX11Info* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: copyX11Data(const QPaintDevice*)
    if (Shiboken::Converter< ::QPaintDevice * >::isConvertible(arg)) {
        overloadId = 0; // copyX11Data(const QPaintDevice*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QX11InfoFunc_copyX11Data_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QPaintDevice * cppArg0 = Shiboken::Converter<QPaintDevice * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // copyX11Data(const QPaintDevice*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->copyX11Data(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QX11InfoFunc_copyX11Data_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPaintDevice", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QX11Info.copyX11Data", overloads);
        return 0;
}

static PyObject* Sbk_QX11InfoFunc_defaultColormap(PyObject* self)
{
    QX11Info* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QX11Info* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // defaultColormap()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QX11Info*>(cppSelf)->defaultColormap();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QX11InfoFunc_defaultVisual(PyObject* self)
{
    QX11Info* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QX11Info* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // defaultVisual()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QX11Info*>(cppSelf)->defaultVisual();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QX11InfoFunc_depth(PyObject* self)
{
    QX11Info* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QX11Info* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // depth()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QX11Info*>(cppSelf)->depth();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QX11InfoFunc_isCompositingManagerRunning(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isCompositingManagerRunning()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = QX11Info::isCompositingManagerRunning();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QX11InfoFunc_screen(PyObject* self)
{
    QX11Info* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QX11Info* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // screen()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QX11Info*>(cppSelf)->screen();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QX11InfoFunc_setAppDpiX(PyObject* self, PyObject* args)
{
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setAppDpiX", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setAppDpiX(int,int)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 0; // setAppDpiX(int,int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QX11InfoFunc_setAppDpiX_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // setAppDpiX(int,int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QX11Info::setAppDpiX(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QX11InfoFunc_setAppDpiX_TypeError:
        const char* overloads[] = {"int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QX11Info.setAppDpiX", overloads);
        return 0;
}

static PyObject* Sbk_QX11InfoFunc_setAppDpiY(PyObject* self, PyObject* args)
{
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setAppDpiY", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setAppDpiY(int,int)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 0; // setAppDpiY(int,int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QX11InfoFunc_setAppDpiY_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // setAppDpiY(int,int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QX11Info::setAppDpiY(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QX11InfoFunc_setAppDpiY_TypeError:
        const char* overloads[] = {"int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QX11Info.setAppDpiY", overloads);
        return 0;
}

static PyObject* Sbk_QX11InfoFunc_setAppTime(PyObject* self, PyObject* arg)
{
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setAppTime(ulong)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setAppTime(ulong)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QX11InfoFunc_setAppTime_TypeError;

    // Call function/method
    {
        {
            unsigned long cppArg0 = Shiboken::Converter<unsigned long >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setAppTime(ulong)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QX11Info::setAppTime(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QX11InfoFunc_setAppTime_TypeError:
        const char* overloads[] = {"unsigned long", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QX11Info.setAppTime", overloads);
        return 0;
}

static PyObject* Sbk_QX11InfoFunc_setAppUserTime(PyObject* self, PyObject* arg)
{
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setAppUserTime(ulong)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setAppUserTime(ulong)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QX11InfoFunc_setAppUserTime_TypeError;

    // Call function/method
    {
        {
            unsigned long cppArg0 = Shiboken::Converter<unsigned long >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setAppUserTime(ulong)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QX11Info::setAppUserTime(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QX11InfoFunc_setAppUserTime_TypeError:
        const char* overloads[] = {"unsigned long", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QX11Info.setAppUserTime", overloads);
        return 0;
}

static PyObject *Sbk_QX11Info___copy__(PyObject *self)
{
        QX11Info* cppSelf = 0;
        if (!Shiboken::Object::isValid(self))
            return 0;
        cppSelf = Shiboken::Converter<QX11Info*>::toCpp(self);
        PyObject* pyResult = 0;
        QX11Info* copy = new QX11Info(*cppSelf);
        pyResult = Shiboken::Converter<QX11Info*>::toPython(copy);
        Shiboken::Object::getOwnership(pyResult);

        if (PyErr_Occurred() || !pyResult) {
            Py_XDECREF(pyResult);
            return 0;
        }
        return pyResult;
}

static PyMethodDef Sbk_QX11Info_methods[] = {
    {"appCells", (PyCFunction)Sbk_QX11InfoFunc_appCells, METH_VARARGS|METH_KEYWORDS|METH_STATIC},
    {"appClass", (PyCFunction)Sbk_QX11InfoFunc_appClass, METH_NOARGS|METH_STATIC},
    {"appColormap", (PyCFunction)Sbk_QX11InfoFunc_appColormap, METH_VARARGS|METH_KEYWORDS|METH_STATIC},
    {"appDefaultColormap", (PyCFunction)Sbk_QX11InfoFunc_appDefaultColormap, METH_VARARGS|METH_KEYWORDS|METH_STATIC},
    {"appDefaultVisual", (PyCFunction)Sbk_QX11InfoFunc_appDefaultVisual, METH_VARARGS|METH_KEYWORDS|METH_STATIC},
    {"appDepth", (PyCFunction)Sbk_QX11InfoFunc_appDepth, METH_VARARGS|METH_KEYWORDS|METH_STATIC},
    {"appDpiX", (PyCFunction)Sbk_QX11InfoFunc_appDpiX, METH_VARARGS|METH_KEYWORDS|METH_STATIC},
    {"appDpiY", (PyCFunction)Sbk_QX11InfoFunc_appDpiY, METH_VARARGS|METH_KEYWORDS|METH_STATIC},
    {"appRootWindow", (PyCFunction)Sbk_QX11InfoFunc_appRootWindow, METH_VARARGS|METH_KEYWORDS|METH_STATIC},
    {"appScreen", (PyCFunction)Sbk_QX11InfoFunc_appScreen, METH_NOARGS|METH_STATIC},
    {"appTime", (PyCFunction)Sbk_QX11InfoFunc_appTime, METH_NOARGS|METH_STATIC},
    {"appUserTime", (PyCFunction)Sbk_QX11InfoFunc_appUserTime, METH_NOARGS|METH_STATIC},
    {"cells", (PyCFunction)Sbk_QX11InfoFunc_cells, METH_NOARGS},
    {"cloneX11Data", (PyCFunction)Sbk_QX11InfoFunc_cloneX11Data, METH_O},
    {"colormap", (PyCFunction)Sbk_QX11InfoFunc_colormap, METH_NOARGS},
    {"copyX11Data", (PyCFunction)Sbk_QX11InfoFunc_copyX11Data, METH_O},
    {"defaultColormap", (PyCFunction)Sbk_QX11InfoFunc_defaultColormap, METH_NOARGS},
    {"defaultVisual", (PyCFunction)Sbk_QX11InfoFunc_defaultVisual, METH_NOARGS},
    {"depth", (PyCFunction)Sbk_QX11InfoFunc_depth, METH_NOARGS},
    {"isCompositingManagerRunning", (PyCFunction)Sbk_QX11InfoFunc_isCompositingManagerRunning, METH_NOARGS|METH_STATIC},
    {"screen", (PyCFunction)Sbk_QX11InfoFunc_screen, METH_NOARGS},
    {"setAppDpiX", (PyCFunction)Sbk_QX11InfoFunc_setAppDpiX, METH_VARARGS|METH_STATIC},
    {"setAppDpiY", (PyCFunction)Sbk_QX11InfoFunc_setAppDpiY, METH_VARARGS|METH_STATIC},
    {"setAppTime", (PyCFunction)Sbk_QX11InfoFunc_setAppTime, METH_O|METH_STATIC},
    {"setAppUserTime", (PyCFunction)Sbk_QX11InfoFunc_setAppUserTime, METH_O|METH_STATIC},

    {"__copy__", (PyCFunction)Sbk_QX11Info___copy__, METH_NOARGS},
    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QX11Info_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QX11Info",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QX11Info_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QX11Info_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QX11Info(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QX11INFO_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QX11Info_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QX11Info_Type);
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QX11Info_Type, &Shiboken::callCppDestructor<QX11Info >);
    if (PyType_Ready((PyTypeObject*)&Sbk_QX11Info_Type) < 0)
        return;

    Shiboken::ObjectType::setOriginalName(&Sbk_QX11Info_Type, "QX11Info");
    PyModule_AddObject(module, "QX11Info",
        ((PyObject*)&Sbk_QX11Info_Type));


    Shiboken::TypeResolver::createValueTypeResolver<QX11Info >("QX11Info");
    Shiboken::TypeResolver::createObjectTypeResolver<QX11Info >("QX11Info*");
    Shiboken::TypeResolver::createValueTypeResolver<QX11Info >(typeid(QX11Info).name());
    PySide::initQtMetaType< ::QX11Info >();
}

