/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


#include <Python.h>
#include <shiboken.h>
#include <algorithm>
#include "pyside_qthelp_python.h"



// Extra includes

// Global functions ------------------------------------------------------------

static PyMethodDef QtHelp_methods[] = {
    {0} // Sentinel
};

// Classes initialization functions ------------------------------------------------------------
void init_QHelpSearchQuery(PyObject* module);
void init_QHelpContentItem(PyObject* module);
void init_QHelpContentModel(PyObject* module);
void init_QHelpIndexModel(PyObject* module);
void init_QHelpContentWidget(PyObject* module);
void init_QHelpSearchResultWidget(PyObject* module);
void init_QHelpSearchQueryWidget(PyObject* module);
void init_QHelpIndexWidget(PyObject* module);
void init_QHelpEngineCore(PyObject* module);
void init_QHelpEngine(PyObject* module);
void init_QHelpSearchEngine(PyObject* module);

PyTypeObject** SbkPySide_QtHelpTypes;

PyTypeObject** SbkPySide_QtGuiTypes;

PyTypeObject** SbkPySide_QtCoreTypes;

// Module initialization ------------------------------------------------------------

#if defined _WIN32 || defined __CYGWIN__
    #define SBK_EXPORT_MODULE __declspec(dllexport)
#elif __GNUC__ >= 4
    #define SBK_EXPORT_MODULE __attribute__ ((visibility("default")))
#else
    #define SBK_EXPORT_MODULE
#endif

extern "C" SBK_EXPORT_MODULE void initQtHelp()
{
    if (!Shiboken::importModule("PySide.QtGui", &SbkPySide_QtGuiTypes)) {
        PyErr_SetString(PyExc_ImportError,"could not import PySide.QtGui");
        return;
    }

    if (!Shiboken::importModule("PySide.QtCore", &SbkPySide_QtCoreTypes)) {
        PyErr_SetString(PyExc_ImportError,"could not import PySide.QtCore");
        return;
    }

    Shiboken::init();
    PyObject* module = Py_InitModule("QtHelp", QtHelp_methods);

    // Create a CObject containing the API pointer array's address
    static PyTypeObject* cppApi[SBK_QtHelp_IDX_COUNT];
    SbkPySide_QtHelpTypes = cppApi;
    PyObject* cppApiObject = PyCObject_FromVoidPtr(reinterpret_cast<void*>(cppApi), 0);
    PyModule_AddObject(module, "_Cpp_Api", cppApiObject);

    // Initialize classes in the type system
    init_QHelpSearchQuery(module);
    init_QHelpContentItem(module);
    init_QHelpContentModel(module);
    init_QHelpIndexModel(module);
    init_QHelpContentWidget(module);
    init_QHelpSearchResultWidget(module);
    init_QHelpSearchQueryWidget(module);
    init_QHelpIndexWidget(module);
    init_QHelpEngineCore(module);
    init_QHelpEngine(module);
    init_QHelpSearchEngine(module);

    // Register primitive types on TypeResolver
    Shiboken::TypeResolver::createValueTypeResolver<QMap<QString,QUrl> >("QMap<QString,QUrl>");
    Shiboken::TypeResolver::createValueTypeResolver<QList<QModelIndex> >("QList<QModelIndex>");

    if (PyErr_Occurred()) {
        PyErr_Print();
        Py_FatalError("can't initialize module QtHelp");
    }
}

