/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtmultimedia_python.h"

#include "qabstractvideobuffer_wrapper.h"

// Extra includes
#include <qabstractvideobuffer.h>


// Native ---------------------------------------------------------

QAbstractVideoBufferWrapper::QAbstractVideoBufferWrapper(QAbstractVideoBuffer::HandleType type) : QAbstractVideoBuffer(type) {
    // ... middle
}

QVariant QAbstractVideoBufferWrapper::handle() const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return QVariant(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "handle"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractVideoBuffer::handle();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QVariant(0);
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< QVariant >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QAbstractVideoBuffer.handle", "QVariant", pyResult->ob_type->tp_name);
        return QVariant(0);
    }
    QVariant cppResult(Shiboken::Converter< QVariant >::toCpp(pyResult));
    return cppResult;
}

uchar * QAbstractVideoBufferWrapper::map(QAbstractVideoBuffer::MapMode mode, int * numBytes, int * bytesPerLine)
{

    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return uchar(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "map"));
    if (py_override.isNull()) {

        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QAbstractVideoBuffer.map()' not implemented.");
        return uchar(0);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QAbstractVideoBuffer::MapMode >::toPython(mode)
    ));


    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return uchar(0);
    }
    uchar * cppResult(Shiboken::Converter< ::uchar * >::toCpp(pyResult));

    return cppResult;
}

QAbstractVideoBuffer::MapMode QAbstractVideoBufferWrapper::mapMode() const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return QAbstractVideoBuffer::MapMode();
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "mapMode"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QAbstractVideoBuffer.mapMode()' not implemented.");
        return QAbstractVideoBuffer::MapMode();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QAbstractVideoBuffer::MapMode();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QAbstractVideoBuffer::MapMode >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QAbstractVideoBuffer.mapMode", Shiboken::SbkType<QAbstractVideoBuffer::MapMode >()->tp_name, pyResult->ob_type->tp_name);
        return QAbstractVideoBuffer::MapMode();
    }
    QAbstractVideoBuffer::MapMode cppResult(Shiboken::Converter< ::QAbstractVideoBuffer::MapMode >::toCpp(pyResult));
    return cppResult;
}

void QAbstractVideoBufferWrapper::unmap()
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "unmap"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QAbstractVideoBuffer.unmap()' not implemented.");
        return ;
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

QAbstractVideoBufferWrapper::~QAbstractVideoBufferWrapper()
{
    SbkObject* wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QAbstractVideoBuffer_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QAbstractVideoBuffer >()))
        return -1;

    QAbstractVideoBufferWrapper* cptr = 0;
    int overloadId = -1;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);
    SbkObjectType* type = reinterpret_cast<SbkObjectType*>(self->ob_type);
    SbkObjectType* myType = reinterpret_cast<SbkObjectType*>(SbkPySide_QtMultimediaTypes[SBK_QABSTRACTVIDEOBUFFER_IDX]);
    if (type == myType) {
        PyErr_SetString(PyExc_NotImplementedError,
            "'QAbstractVideoBuffer' represents a C++ abstract class and cannot be instantiated");
        return -1;
    }



    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QAbstractVideoBuffer", 1, 1, &(pyargs[0])))
        return -1;

    // Overloaded function decisor
    // 0: QAbstractVideoBuffer(QAbstractVideoBuffer::HandleType)
    if (numArgs == 1 && Shiboken::Converter< ::QAbstractVideoBuffer::HandleType >::isConvertible(pyargs[0])) {
        overloadId = 0; // QAbstractVideoBuffer(QAbstractVideoBuffer::HandleType)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QAbstractVideoBuffer_Init_TypeError;

    // Call function/method
    {
        {
            QAbstractVideoBuffer::HandleType cppArg0 = Shiboken::Converter<QAbstractVideoBuffer::HandleType >::toCpp(pyargs[0]);

            if(!PyErr_Occurred()) {
                // QAbstractVideoBuffer(QAbstractVideoBuffer::HandleType)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new QAbstractVideoBufferWrapper(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QAbstractVideoBuffer >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QAbstractVideoBuffer_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QAbstractVideoBuffer_Init_TypeError:
        const char* overloads[] = {"PySide.QtMultimedia.QAbstractVideoBuffer.HandleType", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtMultimedia.QAbstractVideoBuffer", overloads);
        return -1;
}

static PyObject* Sbk_QAbstractVideoBufferFunc_handle(PyObject* self)
{
    QAbstractVideoBuffer* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QAbstractVideoBuffer* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // handle()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QVariant cppResult = (Shiboken::Object::isUserType(self) ? const_cast<const QAbstractVideoBuffer*>(cppSelf)->::QAbstractVideoBuffer::handle() : const_cast<const QAbstractVideoBuffer*>(cppSelf)->handle());
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QVariant >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QAbstractVideoBufferFunc_handleType(PyObject* self)
{
    QAbstractVideoBuffer* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QAbstractVideoBuffer* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // handleType()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QAbstractVideoBuffer::HandleType cppResult = const_cast<const QAbstractVideoBuffer*>(cppSelf)->handleType();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QAbstractVideoBuffer::HandleType >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QAbstractVideoBufferFunc_map(PyObject* self, PyObject* arg)
{
    QAbstractVideoBuffer* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QAbstractVideoBuffer* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: map(QAbstractVideoBuffer::MapMode,int*,int*)
    if (Shiboken::Converter< ::QAbstractVideoBuffer::MapMode >::isConvertible(arg)) {
        overloadId = 0; // map(QAbstractVideoBuffer::MapMode,int*,int*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QAbstractVideoBufferFunc_map_TypeError;

    // Call function/method
    {
        {
            QAbstractVideoBuffer::MapMode cppArg0 = Shiboken::Converter<QAbstractVideoBuffer::MapMode >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // map(QAbstractVideoBuffer::MapMode,int*,int*)
                if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self))) {
                    PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QAbstractVideoBuffer.map()' not implemented.");
                    return 0;
                }
                // Begin code injection

                // TEMPLATE - fix_arg,int*,int* - START
                uchar * _ret;
                int a, b;
                _ret = cppSelf->map(cppArg0, &a, &b);
                pyResult = Shiboken::makeTuple(_ret, a, b);
                // TEMPLATE - fix_arg,int*,int* - END

                // End of code injection


            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QAbstractVideoBufferFunc_map_TypeError:
        const char* overloads[] = {"PySide.QtMultimedia.QAbstractVideoBuffer.MapMode, int, int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtMultimedia.QAbstractVideoBuffer.map", overloads);
        return 0;
}

static PyObject* Sbk_QAbstractVideoBufferFunc_mapMode(PyObject* self)
{
    QAbstractVideoBuffer* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QAbstractVideoBuffer* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // mapMode()const
                if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self))) {
                    PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QAbstractVideoBuffer.mapMode()' not implemented.");
                    return 0;
                }
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QAbstractVideoBuffer::MapMode cppResult = const_cast<const QAbstractVideoBuffer*>(cppSelf)->mapMode();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QAbstractVideoBuffer::MapMode >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QAbstractVideoBufferFunc_unmap(PyObject* self)
{
    QAbstractVideoBuffer* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QAbstractVideoBuffer* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // unmap()
                if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self))) {
                    PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QAbstractVideoBuffer.unmap()' not implemented.");
                    return 0;
                }
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->unmap();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyMethodDef Sbk_QAbstractVideoBuffer_methods[] = {
    {"handle", (PyCFunction)Sbk_QAbstractVideoBufferFunc_handle, METH_NOARGS},
    {"handleType", (PyCFunction)Sbk_QAbstractVideoBufferFunc_handleType, METH_NOARGS},
    {"map", (PyCFunction)Sbk_QAbstractVideoBufferFunc_map, METH_O},
    {"mapMode", (PyCFunction)Sbk_QAbstractVideoBufferFunc_mapMode, METH_NOARGS},
    {"unmap", (PyCFunction)Sbk_QAbstractVideoBufferFunc_unmap, METH_NOARGS},

    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QAbstractVideoBuffer_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtMultimedia.QAbstractVideoBuffer",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QAbstractVideoBuffer_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QAbstractVideoBuffer_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QAbstractVideoBuffer(PyObject* module)
{
    SbkPySide_QtMultimediaTypes[SBK_QABSTRACTVIDEOBUFFER_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QAbstractVideoBuffer_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QAbstractVideoBuffer_Type);
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QAbstractVideoBuffer_Type, &Shiboken::callCppDestructor<QAbstractVideoBuffer >);
    if (PyType_Ready((PyTypeObject*)&Sbk_QAbstractVideoBuffer_Type) < 0)
        return;

    // Fill type discovery information

    Shiboken::ObjectType::setOriginalName(&Sbk_QAbstractVideoBuffer_Type, "QAbstractVideoBuffer*");
    PyModule_AddObject(module, "QAbstractVideoBuffer",
        ((PyObject*)&Sbk_QAbstractVideoBuffer_Type));

    // Initialize enums
    PyObject* enumItem;

    // init enum: MapMode
    PyTypeObject* SbkPySide_QtMultimedia_QAbstractVideoBuffer_MapMode = Shiboken::Enum::newType("PySide.QtMultimedia.QAbstractVideoBuffer.MapMode");
    SbkPySide_QtMultimediaTypes[SBK_QABSTRACTVIDEOBUFFER_MAPMODE_IDX] = SbkPySide_QtMultimedia_QAbstractVideoBuffer_MapMode;
    if (PyType_Ready(SbkPySide_QtMultimedia_QAbstractVideoBuffer_MapMode) < 0)
        return;
    PyDict_SetItemString(Sbk_QAbstractVideoBuffer_Type.super.ht_type.tp_dict,
            "MapMode",((PyObject*)SbkPySide_QtMultimedia_QAbstractVideoBuffer_MapMode));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtMultimedia_QAbstractVideoBuffer_MapMode,(long) QAbstractVideoBuffer::NotMapped, "NotMapped");
    PyDict_SetItemString(Sbk_QAbstractVideoBuffer_Type.super.ht_type.tp_dict,"NotMapped", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtMultimedia_QAbstractVideoBuffer_MapMode->tp_dict,"NotMapped", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtMultimedia_QAbstractVideoBuffer_MapMode,(long) QAbstractVideoBuffer::ReadOnly, "ReadOnly");
    PyDict_SetItemString(Sbk_QAbstractVideoBuffer_Type.super.ht_type.tp_dict,"ReadOnly", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtMultimedia_QAbstractVideoBuffer_MapMode->tp_dict,"ReadOnly", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtMultimedia_QAbstractVideoBuffer_MapMode,(long) QAbstractVideoBuffer::WriteOnly, "WriteOnly");
    PyDict_SetItemString(Sbk_QAbstractVideoBuffer_Type.super.ht_type.tp_dict,"WriteOnly", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtMultimedia_QAbstractVideoBuffer_MapMode->tp_dict,"WriteOnly", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtMultimedia_QAbstractVideoBuffer_MapMode,(long) QAbstractVideoBuffer::ReadWrite, "ReadWrite");
    PyDict_SetItemString(Sbk_QAbstractVideoBuffer_Type.super.ht_type.tp_dict,"ReadWrite", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtMultimedia_QAbstractVideoBuffer_MapMode->tp_dict,"ReadWrite", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QAbstractVideoBuffer::MapMode");
    Shiboken::TypeResolver::createValueTypeResolver<int>("QAbstractVideoBuffer$ConcreteWrapper::MapMode");
    // end of enum MapMode

    // init enum: HandleType
    PyTypeObject* SbkPySide_QtMultimedia_QAbstractVideoBuffer_HandleType = Shiboken::Enum::newType("PySide.QtMultimedia.QAbstractVideoBuffer.HandleType");
    SbkPySide_QtMultimediaTypes[SBK_QABSTRACTVIDEOBUFFER_HANDLETYPE_IDX] = SbkPySide_QtMultimedia_QAbstractVideoBuffer_HandleType;
    if (PyType_Ready(SbkPySide_QtMultimedia_QAbstractVideoBuffer_HandleType) < 0)
        return;
    PyDict_SetItemString(Sbk_QAbstractVideoBuffer_Type.super.ht_type.tp_dict,
            "HandleType",((PyObject*)SbkPySide_QtMultimedia_QAbstractVideoBuffer_HandleType));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtMultimedia_QAbstractVideoBuffer_HandleType,(long) QAbstractVideoBuffer::NoHandle, "NoHandle");
    PyDict_SetItemString(Sbk_QAbstractVideoBuffer_Type.super.ht_type.tp_dict,"NoHandle", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtMultimedia_QAbstractVideoBuffer_HandleType->tp_dict,"NoHandle", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtMultimedia_QAbstractVideoBuffer_HandleType,(long) QAbstractVideoBuffer::GLTextureHandle, "GLTextureHandle");
    PyDict_SetItemString(Sbk_QAbstractVideoBuffer_Type.super.ht_type.tp_dict,"GLTextureHandle", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtMultimedia_QAbstractVideoBuffer_HandleType->tp_dict,"GLTextureHandle", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtMultimedia_QAbstractVideoBuffer_HandleType,(long) QAbstractVideoBuffer::XvShmImageHandle, "XvShmImageHandle");
    PyDict_SetItemString(Sbk_QAbstractVideoBuffer_Type.super.ht_type.tp_dict,"XvShmImageHandle", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtMultimedia_QAbstractVideoBuffer_HandleType->tp_dict,"XvShmImageHandle", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtMultimedia_QAbstractVideoBuffer_HandleType,(long) QAbstractVideoBuffer::CoreImageHandle, "CoreImageHandle");
    PyDict_SetItemString(Sbk_QAbstractVideoBuffer_Type.super.ht_type.tp_dict,"CoreImageHandle", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtMultimedia_QAbstractVideoBuffer_HandleType->tp_dict,"CoreImageHandle", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtMultimedia_QAbstractVideoBuffer_HandleType,(long) QAbstractVideoBuffer::QPixmapHandle, "QPixmapHandle");
    PyDict_SetItemString(Sbk_QAbstractVideoBuffer_Type.super.ht_type.tp_dict,"QPixmapHandle", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtMultimedia_QAbstractVideoBuffer_HandleType->tp_dict,"QPixmapHandle", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtMultimedia_QAbstractVideoBuffer_HandleType,(long) QAbstractVideoBuffer::UserHandle, "UserHandle");
    PyDict_SetItemString(Sbk_QAbstractVideoBuffer_Type.super.ht_type.tp_dict,"UserHandle", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtMultimedia_QAbstractVideoBuffer_HandleType->tp_dict,"UserHandle", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QAbstractVideoBuffer::HandleType");
    Shiboken::TypeResolver::createValueTypeResolver<int>("QAbstractVideoBuffer$ConcreteWrapper::HandleType");
    // end of enum HandleType


    Shiboken::TypeResolver::createObjectTypeResolver<QAbstractVideoBuffer >("QAbstractVideoBuffer*");
    Shiboken::TypeResolver::createObjectTypeResolver<QAbstractVideoBuffer >("QAbstractVideoBuffer$ConcreteWrapper*");
    Shiboken::TypeResolver::createObjectTypeResolver<QAbstractVideoBuffer >(typeid(QAbstractVideoBuffer).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QAbstractVideoBuffer >(typeid(QAbstractVideoBufferWrapper).name());
    PySide::initQtMetaType< ::QAbstractVideoBuffer* >();
    qRegisterMetaType< ::QAbstractVideoBuffer::MapMode >("QAbstractVideoBuffer::MapMode");
    qRegisterMetaType< ::QAbstractVideoBuffer::HandleType >("QAbstractVideoBuffer::HandleType");
}

