/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include "pyside_qtnetwork_python.h"

#include "qhttp_wrapper.h"

// Extra includes
#include <QList>
#include <autoarraypointer.h>
#include <qauthenticator.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qhttp.h>
#include <qiodevice.h>
#include <qnetworkproxy.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qsslerror.h>
#include <qtcpsocket.h>
#include <qthread.h>


// Native ---------------------------------------------------------

QHttpWrapper::QHttpWrapper(QObject * parent) : QHttp(parent) {
    // ... middle
}

QHttpWrapper::QHttpWrapper(const QString & hostname, QHttp::ConnectionMode mode, quint16 port, QObject * parent) : QHttp(hostname, mode, port, parent) {
    // ... middle
}

QHttpWrapper::QHttpWrapper(const QString & hostname, quint16 port, QObject * parent) : QHttp(hostname, port, parent) {
    // ... middle
}

void QHttpWrapper::childEvent(QChildEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "childEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::childEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QChildEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QHttpWrapper::connectNotify(const char * signal)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "connectNotify"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QHttpWrapper::customEvent(QEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "customEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::customEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QHttpWrapper::disconnectNotify(const char * signal)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "disconnectNotify"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

bool QHttpWrapper::event(QEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return bool(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "event"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::event(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QHttp.event", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
    return cppResult;
}

bool QHttpWrapper::eventFilter(QObject * arg__1, QEvent * arg__2)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return bool(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "eventFilter"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::eventFilter(arg__1, arg__2);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter< ::QObject * >::toPython(arg__1),
        Shiboken::Converter< ::QEvent * >::toPython(arg__2)
    ));
    bool invalidadeArg2 = PyTuple_GET_ITEM(pyargs, 1)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QHttp.eventFilter", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    if (invalidadeArg2)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 1));
    return cppResult;
}

void QHttpWrapper::timerEvent(QTimerEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "timerEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::timerEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QTimerEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

const QMetaObject* QHttpWrapper::metaObject() const
{
    SbkObject* pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    return reinterpret_cast<QMetaObject*>(Shiboken::Object::getTypeUserData(pySelf));
}

int QHttpWrapper::qt_metacall(QMetaObject::Call call, int id, void** args)
{
    int result = QHttp::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

QHttpWrapper::~QHttpWrapper()
{
    SbkObject* wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QHttp_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QHttp >()))
        return -1;

    QHttpWrapper* cptr = 0;
    int overloadId = -1;
    const char* argNames[] = {"parent", "port"};
    const QMetaObject* metaObject;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths


    if (!PyArg_ParseTuple(args, "|OOOO:QHttp", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return -1;

    // Overloaded function decisor
    // 0: QHttp(QObject*)
    // 1: QHttp(QString,QHttp::ConnectionMode,quint16,QObject*)
    // 2: QHttp(QString,quint16,QObject*)
    if (numArgs == 0) {
        overloadId = 0; // QHttp(QObject*)
    } else if (Shiboken::Converter< ::QObject * >::isConvertible(pyargs[0])) {
        overloadId = 0; // QHttp(QObject*)
    } else if (Shiboken::Converter< QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 2; // QHttp(QString,quint16,QObject*)
        } else if (Shiboken::Converter< ::QHttp::ConnectionMode >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 1; // QHttp(QString,QHttp::ConnectionMode,quint16,QObject*)
            } else if (SbkNumber_Check(pyargs[2])) {
                if (numArgs == 3) {
                    overloadId = 1; // QHttp(QString,QHttp::ConnectionMode,quint16,QObject*)
                } else if (Shiboken::Converter< ::QObject * >::isConvertible(pyargs[3])) {
                    overloadId = 1; // QHttp(QString,QHttp::ConnectionMode,quint16,QObject*)
                }
            }
        } else if (SbkNumber_Check(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 2; // QHttp(QString,quint16,QObject*)
            } else if (Shiboken::Converter< ::QObject * >::isConvertible(pyargs[2])) {
                overloadId = 2; // QHttp(QString,quint16,QObject*)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QHttp_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QHttp(QObject*)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "parent");
                    if (value) {
                        if (pyargs[0])
                            errorArgName = "parent";
                        else if (Shiboken::Converter< ::QObject * >::isConvertible(value))
                            pyargs[0] = value;
                        else
                            goto Sbk_QHttp_Init_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtNetwork.QHttp(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QObject * cppArg0 = pyargs[0] ? Shiboken::Converter<QObject * >::toCpp(pyargs[0]) : 0;

                if(!PyErr_Occurred()) {
                    // QHttp(QObject*)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QHttpWrapper(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    Shiboken::Object::setParent(pyargs[0], self);
                }
                break;
            }
            case 1: // QHttp(QString,QHttp::ConnectionMode,quint16,QObject*)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "port");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "port";
                        else if (SbkNumber_Check(value))
                            pyargs[2] = value;
                        else
                            goto Sbk_QHttp_Init_TypeError;
                    }
                    value = PyDict_GetItemString(kwds, "parent");
                    if (value) {
                        if (pyargs[3])
                            errorArgName = "parent";
                        else if (Shiboken::Converter< ::QObject * >::isConvertible(value))
                            pyargs[3] = value;
                        else
                            goto Sbk_QHttp_Init_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtNetwork.QHttp(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                QHttp::ConnectionMode cppArg1 = Shiboken::Converter<QHttp::ConnectionMode >::toCpp(pyargs[1]);
                quint16 cppArg2 = pyargs[2] ? Shiboken::Converter<quint16 >::toCpp(pyargs[2]) : 0;
                if (!Shiboken::Object::isValid(pyargs[3]))
                    return -1;
                QObject * cppArg3 = pyargs[3] ? Shiboken::Converter<QObject * >::toCpp(pyargs[3]) : 0;

                if(!PyErr_Occurred()) {
                    // QHttp(QString,QHttp::ConnectionMode,quint16,QObject*)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QHttpWrapper(cppArg0, cppArg1, cppArg2, cppArg3);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    Shiboken::Object::setParent(pyargs[3], self);
                }
                break;
            }
            case 2: // QHttp(QString,quint16,QObject*)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "port");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "port";
                        else if (SbkNumber_Check(value))
                            pyargs[1] = value;
                        else
                            goto Sbk_QHttp_Init_TypeError;
                    }
                    value = PyDict_GetItemString(kwds, "parent");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "parent";
                        else if (Shiboken::Converter< ::QObject * >::isConvertible(value))
                            pyargs[2] = value;
                        else
                            goto Sbk_QHttp_Init_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtNetwork.QHttp(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                quint16 cppArg1 = pyargs[1] ? Shiboken::Converter<quint16 >::toCpp(pyargs[1]) : 80;
                if (!Shiboken::Object::isValid(pyargs[2]))
                    return -1;
                QObject * cppArg2 = pyargs[2] ? Shiboken::Converter<QObject * >::toCpp(pyargs[2]) : 0;

                if(!PyErr_Occurred()) {
                    // QHttp(QString,quint16,QObject*)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QHttpWrapper(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    Shiboken::Object::setParent(pyargs[2], self);
                }
                break;
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QHttp >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QHttp_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    metaObject = cptr->metaObject(); // <- init python qt properties
    if (kwds && !PySide::fillQtProperties(self, metaObject, kwds, argNames, 2))
        return -1;


    return 1;

    Sbk_QHttp_Init_TypeError:
        const char* overloads[] = {"PySide.QtCore.QObject = None", "QString, PySide.QtNetwork.QHttp.ConnectionMode, unsigned short = 0, PySide.QtCore.QObject = None", "QString, unsigned short = 80, PySide.QtCore.QObject = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtNetwork.QHttp", overloads);
        return -1;
}

static PyObject* Sbk_QHttpFunc_abort(PyObject* self)
{
    QHttp* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QHttp* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // abort()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->abort();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QHttpFunc_bytesAvailable(PyObject* self)
{
    QHttp* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QHttp* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // bytesAvailable()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                qint64 cppResult = const_cast<const QHttp*>(cppSelf)->bytesAvailable();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< long long >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QHttpFunc_clearPendingRequests(PyObject* self)
{
    QHttp* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QHttp* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // clearPendingRequests()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->clearPendingRequests();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QHttpFunc_close(PyObject* self)
{
    QHttp* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QHttp* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // close()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = cppSelf->close();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QHttpFunc_currentDestinationDevice(PyObject* self)
{
    QHttp* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QHttp* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // currentDestinationDevice()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QIODevice * cppResult = const_cast<const QHttp*>(cppSelf)->currentDestinationDevice();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QIODevice * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QHttpFunc_currentId(PyObject* self)
{
    QHttp* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QHttp* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // currentId()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QHttp*>(cppSelf)->currentId();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QHttpFunc_currentRequest(PyObject* self)
{
    QHttp* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QHttp* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // currentRequest()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QHttpRequestHeader cppResult = const_cast<const QHttp*>(cppSelf)->currentRequest();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QHttpRequestHeader >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QHttpFunc_currentSourceDevice(PyObject* self)
{
    QHttp* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QHttp* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // currentSourceDevice()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QIODevice * cppResult = const_cast<const QHttp*>(cppSelf)->currentSourceDevice();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QIODevice * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QHttpFunc_error(PyObject* self)
{
    QHttp* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QHttp* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // error()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QHttp::Error cppResult = const_cast<const QHttp*>(cppSelf)->error();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QHttp::Error >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QHttpFunc_errorString(PyObject* self)
{
    QHttp* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QHttp* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // errorString()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QHttp*>(cppSelf)->errorString();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QHttpFunc_get(PyObject* self, PyObject* args, PyObject* kwds)
{
    QHttp* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QHttp* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtNetwork.QHttp.get(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtNetwork.QHttp.get(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:get", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: get(QString,QIODevice*)
    if (Shiboken::Converter< QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // get(QString,QIODevice*)
        } else if (Shiboken::Converter< ::QIODevice * >::isConvertible(pyargs[1])) {
            overloadId = 0; // get(QString,QIODevice*)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QHttpFunc_get_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "to");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "to";
                    else if (Shiboken::Converter< ::QIODevice * >::isConvertible(value))
                        pyargs[1] = value;
                    else
                        goto Sbk_QHttpFunc_get_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtNetwork.QHttp.get(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            QIODevice * cppArg1 = pyargs[1] ? Shiboken::Converter<QIODevice * >::toCpp(pyargs[1]) : 0;

            if(!PyErr_Occurred()) {
                // get(QString,QIODevice*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = cppSelf->get(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QHttpFunc_get_TypeError:
        const char* overloads[] = {"QString, PySide.QtCore.QIODevice = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtNetwork.QHttp.get", overloads);
        return 0;
}

static PyObject* Sbk_QHttpFunc_hasPendingRequests(PyObject* self)
{
    QHttp* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QHttp* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // hasPendingRequests()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QHttp*>(cppSelf)->hasPendingRequests();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QHttpFunc_head(PyObject* self, PyObject* arg)
{
    QHttp* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QHttp* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: head(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // head(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QHttpFunc_head_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // head(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = cppSelf->head(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QHttpFunc_head_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QHttp.head", overloads);
        return 0;
}

static PyObject* Sbk_QHttpFunc_ignoreSslErrors(PyObject* self)
{
    QHttp* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QHttp* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // ignoreSslErrors()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->ignoreSslErrors();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QHttpFunc_lastResponse(PyObject* self)
{
    QHttp* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QHttp* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // lastResponse()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QHttpResponseHeader cppResult = const_cast<const QHttp*>(cppSelf)->lastResponse();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QHttpResponseHeader >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QHttpFunc_post(PyObject* self, PyObject* args, PyObject* kwds)
{
    QHttp* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QHttp* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtNetwork.QHttp.post(): too many arguments");
        return 0;
    } else if (numArgs < 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtNetwork.QHttp.post(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOO:post", &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: post(QString,QIODevice*,QIODevice*)
    // 1: post(QString,QByteArray,QIODevice*)
    if (Shiboken::Converter< QString >::isConvertible(pyargs[0])) {
        if (Shiboken::Converter< ::QByteArray >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 1; // post(QString,QByteArray,QIODevice*)
            } else if (Shiboken::Converter< ::QIODevice * >::isConvertible(pyargs[2])) {
                overloadId = 1; // post(QString,QByteArray,QIODevice*)
            }
        } else if (Shiboken::Converter< ::QIODevice * >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 0; // post(QString,QIODevice*,QIODevice*)
            } else if (Shiboken::Converter< ::QIODevice * >::isConvertible(pyargs[2])) {
                overloadId = 0; // post(QString,QIODevice*,QIODevice*)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QHttpFunc_post_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // post(QString,QIODevice*,QIODevice*)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "to");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "to";
                        else if (Shiboken::Converter< ::QIODevice * >::isConvertible(value))
                            pyargs[2] = value;
                        else
                            goto Sbk_QHttpFunc_post_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtNetwork.QHttp.post(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QIODevice * cppArg1 = Shiboken::Converter<QIODevice * >::toCpp(pyargs[1]);
                if (!Shiboken::Object::isValid(pyargs[2]))
                    return 0;
                QIODevice * cppArg2 = pyargs[2] ? Shiboken::Converter<QIODevice * >::toCpp(pyargs[2]) : 0;

                if(!PyErr_Occurred()) {
                    // post(QString,QIODevice*,QIODevice*)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    int cppResult = cppSelf->post(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< int >::toPython(cppResult);
                }
                break;
            }
            case 1: // post(QString,QByteArray,QIODevice*)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "to");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "to";
                        else if (Shiboken::Converter< ::QIODevice * >::isConvertible(value))
                            pyargs[2] = value;
                        else
                            goto Sbk_QHttpFunc_post_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtNetwork.QHttp.post(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QByteArray cppArg1 = Shiboken::Converter<QByteArray >::toCpp(pyargs[1]);
                if (!Shiboken::Object::isValid(pyargs[2]))
                    return 0;
                QIODevice * cppArg2 = pyargs[2] ? Shiboken::Converter<QIODevice * >::toCpp(pyargs[2]) : 0;

                if(!PyErr_Occurred()) {
                    // post(QString,QByteArray,QIODevice*)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    int cppResult = cppSelf->post(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< int >::toPython(cppResult);
                }
                break;
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QHttpFunc_post_TypeError:
        const char* overloads[] = {"QString, PySide.QtCore.QIODevice, PySide.QtCore.QIODevice = None", "QString, PySide.QtCore.QByteArray, PySide.QtCore.QIODevice = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtNetwork.QHttp.post", overloads);
        return 0;
}

static PyObject* Sbk_QHttpFunc_read(PyObject* self, PyObject* arg)
{
    QHttp* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QHttp* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: read(char*,qint64)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // read(char*,qint64)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QHttpFunc_read_TypeError;

    // Call function/method
    {
        {
            qint64 cppArg0 = Shiboken::Converter<qint64 >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // read(char*,qint64)
                // Begin code injection

                // TEMPLATE - read_wrapper - START
                PySide::AutoArrayPointer<char> _data(cppArg0);
                qint64 _size = cppSelf->read(_data, cppArg0);
                if (_size > 0)
                pyResult = Shiboken::Converter<QByteArray >::toPython(QByteArray(_data, _size));
                else
                pyResult = Shiboken::Converter<QByteArray >::toPython(QByteArray());
                // TEMPLATE - read_wrapper - END

                // End of code injection


            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QHttpFunc_read_TypeError:
        const char* overloads[] = {"str, long long", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QHttp.read", overloads);
        return 0;
}

static PyObject* Sbk_QHttpFunc_readAll(PyObject* self)
{
    QHttp* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QHttp* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // readAll()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QByteArray cppResult = cppSelf->readAll();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QByteArray >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QHttpFunc_request(PyObject* self, PyObject* args, PyObject* kwds)
{
    QHttp* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QHttp* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtNetwork.QHttp.request(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtNetwork.QHttp.request(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOO:request", &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: request(QHttpRequestHeader,QIODevice*,QIODevice*)
    // 1: request(QHttpRequestHeader,QByteArray,QIODevice*)
    if (Shiboken::Converter< ::QHttpRequestHeader >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // request(QHttpRequestHeader,QIODevice*,QIODevice*)
        } else if (Shiboken::Converter< ::QByteArray >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 1; // request(QHttpRequestHeader,QByteArray,QIODevice*)
            } else if (Shiboken::Converter< ::QIODevice * >::isConvertible(pyargs[2])) {
                overloadId = 1; // request(QHttpRequestHeader,QByteArray,QIODevice*)
            }
        } else if (Shiboken::Converter< ::QIODevice * >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 0; // request(QHttpRequestHeader,QIODevice*,QIODevice*)
            } else if (Shiboken::Converter< ::QIODevice * >::isConvertible(pyargs[2])) {
                overloadId = 0; // request(QHttpRequestHeader,QIODevice*,QIODevice*)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QHttpFunc_request_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // request(QHttpRequestHeader,QIODevice*,QIODevice*)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "device");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "device";
                        else if (Shiboken::Converter< ::QIODevice * >::isConvertible(value))
                            pyargs[1] = value;
                        else
                            goto Sbk_QHttpFunc_request_TypeError;
                    }
                    value = PyDict_GetItemString(kwds, "to");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "to";
                        else if (Shiboken::Converter< ::QIODevice * >::isConvertible(value))
                            pyargs[2] = value;
                        else
                            goto Sbk_QHttpFunc_request_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtNetwork.QHttp.request(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QHttpRequestHeader cppArg0 = Shiboken::Converter<QHttpRequestHeader >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QIODevice * cppArg1 = pyargs[1] ? Shiboken::Converter<QIODevice * >::toCpp(pyargs[1]) : 0;
                if (!Shiboken::Object::isValid(pyargs[2]))
                    return 0;
                QIODevice * cppArg2 = pyargs[2] ? Shiboken::Converter<QIODevice * >::toCpp(pyargs[2]) : 0;

                if(!PyErr_Occurred()) {
                    // request(QHttpRequestHeader,QIODevice*,QIODevice*)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    int cppResult = cppSelf->request(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< int >::toPython(cppResult);
                }
                break;
            }
            case 1: // request(QHttpRequestHeader,QByteArray,QIODevice*)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "to");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "to";
                        else if (Shiboken::Converter< ::QIODevice * >::isConvertible(value))
                            pyargs[2] = value;
                        else
                            goto Sbk_QHttpFunc_request_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtNetwork.QHttp.request(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QHttpRequestHeader cppArg0 = Shiboken::Converter<QHttpRequestHeader >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QByteArray cppArg1 = Shiboken::Converter<QByteArray >::toCpp(pyargs[1]);
                if (!Shiboken::Object::isValid(pyargs[2]))
                    return 0;
                QIODevice * cppArg2 = pyargs[2] ? Shiboken::Converter<QIODevice * >::toCpp(pyargs[2]) : 0;

                if(!PyErr_Occurred()) {
                    // request(QHttpRequestHeader,QByteArray,QIODevice*)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    int cppResult = cppSelf->request(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< int >::toPython(cppResult);
                }
                break;
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QHttpFunc_request_TypeError:
        const char* overloads[] = {"PySide.QtNetwork.QHttpRequestHeader, PySide.QtCore.QIODevice = None, PySide.QtCore.QIODevice = None", "PySide.QtNetwork.QHttpRequestHeader, PySide.QtCore.QByteArray, PySide.QtCore.QIODevice = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtNetwork.QHttp.request", overloads);
        return 0;
}

static PyObject* Sbk_QHttpFunc_setHost(PyObject* self, PyObject* args, PyObject* kwds)
{
    QHttp* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QHttp* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtNetwork.QHttp.setHost(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtNetwork.QHttp.setHost(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOO:setHost", &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: setHost(QString,QHttp::ConnectionMode,quint16)
    // 1: setHost(QString,quint16)
    if (Shiboken::Converter< QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 1; // setHost(QString,quint16)
        } else if (Shiboken::Converter< ::QHttp::ConnectionMode >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 0; // setHost(QString,QHttp::ConnectionMode,quint16)
            } else if (SbkNumber_Check(pyargs[2])) {
                overloadId = 0; // setHost(QString,QHttp::ConnectionMode,quint16)
            }
        } else if (SbkNumber_Check(pyargs[1])) {
            overloadId = 1; // setHost(QString,quint16)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QHttpFunc_setHost_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // setHost(QString,QHttp::ConnectionMode,quint16)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "port");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "port";
                        else if (SbkNumber_Check(value))
                            pyargs[2] = value;
                        else
                            goto Sbk_QHttpFunc_setHost_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtNetwork.QHttp.setHost(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                QHttp::ConnectionMode cppArg1 = Shiboken::Converter<QHttp::ConnectionMode >::toCpp(pyargs[1]);
                quint16 cppArg2 = pyargs[2] ? Shiboken::Converter<quint16 >::toCpp(pyargs[2]) : 0;

                if(!PyErr_Occurred()) {
                    // setHost(QString,QHttp::ConnectionMode,quint16)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    int cppResult = cppSelf->setHost(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< int >::toPython(cppResult);
                }
                break;
            }
            case 1: // setHost(QString,quint16)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "port");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "port";
                        else if (SbkNumber_Check(value))
                            pyargs[1] = value;
                        else
                            goto Sbk_QHttpFunc_setHost_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtNetwork.QHttp.setHost(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                quint16 cppArg1 = pyargs[1] ? Shiboken::Converter<quint16 >::toCpp(pyargs[1]) : 80;

                if(!PyErr_Occurred()) {
                    // setHost(QString,quint16)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    int cppResult = cppSelf->setHost(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< int >::toPython(cppResult);
                }
                break;
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QHttpFunc_setHost_TypeError:
        const char* overloads[] = {"QString, PySide.QtNetwork.QHttp.ConnectionMode, unsigned short = 0", "QString, unsigned short = 80", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtNetwork.QHttp.setHost", overloads);
        return 0;
}

static PyObject* Sbk_QHttpFunc_setProxy(PyObject* self, PyObject* args, PyObject* kwds)
{
    QHttp* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QHttp* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 4) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtNetwork.QHttp.setProxy(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtNetwork.QHttp.setProxy(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOOO:setProxy", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: setProxy(QNetworkProxy)
    // 1: setProxy(QString,int,QString,QString)
    if (numArgs >= 2 && Shiboken::Converter< QString >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 1; // setProxy(QString,int,QString,QString)
        } else if (Shiboken::Converter< QString >::isConvertible(pyargs[2])) {
            if (numArgs == 3) {
                overloadId = 1; // setProxy(QString,int,QString,QString)
            } else if (Shiboken::Converter< QString >::isConvertible(pyargs[3])) {
                overloadId = 1; // setProxy(QString,int,QString,QString)
            }
        }
    } else if (numArgs == 1 && Shiboken::Converter< ::QNetworkProxy >::isConvertible(pyargs[0])) {
        overloadId = 0; // setProxy(QNetworkProxy)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QHttpFunc_setProxy_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // setProxy(QNetworkProxy)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QNetworkProxy cppArg0 = Shiboken::Converter<QNetworkProxy >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // setProxy(QNetworkProxy)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    int cppResult = cppSelf->setProxy(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< int >::toPython(cppResult);
                }
                break;
            }
            case 1: // setProxy(QString,int,QString,QString)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "username");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "username";
                        else if (Shiboken::Converter< QString >::isConvertible(value))
                            pyargs[2] = value;
                        else
                            goto Sbk_QHttpFunc_setProxy_TypeError;
                    }
                    value = PyDict_GetItemString(kwds, "password");
                    if (value) {
                        if (pyargs[3])
                            errorArgName = "password";
                        else if (Shiboken::Converter< QString >::isConvertible(value))
                            pyargs[3] = value;
                        else
                            goto Sbk_QHttpFunc_setProxy_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtNetwork.QHttp.setProxy(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                QString cppArg2 = pyargs[2] ? Shiboken::Converter<QString >::toCpp(pyargs[2]) : QString();
                QString cppArg3 = pyargs[3] ? Shiboken::Converter<QString >::toCpp(pyargs[3]) : QString();

                if(!PyErr_Occurred()) {
                    // setProxy(QString,int,QString,QString)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    int cppResult = cppSelf->setProxy(cppArg0, cppArg1, cppArg2, cppArg3);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< int >::toPython(cppResult);
                }
                break;
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QHttpFunc_setProxy_TypeError:
        const char* overloads[] = {"PySide.QtNetwork.QNetworkProxy", "QString, int, QString = QString(), QString = QString()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtNetwork.QHttp.setProxy", overloads);
        return 0;
}

static PyObject* Sbk_QHttpFunc_setSocket(PyObject* self, PyObject* arg)
{
    QHttp* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QHttp* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setSocket(QTcpSocket*)
    if (Shiboken::Converter< ::QTcpSocket * >::isConvertible(arg)) {
        overloadId = 0; // setSocket(QTcpSocket*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QHttpFunc_setSocket_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QTcpSocket * cppArg0 = Shiboken::Converter<QTcpSocket * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setSocket(QTcpSocket*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = cppSelf->setSocket(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QHttpFunc_setSocket_TypeError:
        const char* overloads[] = {"PySide.QtNetwork.QTcpSocket", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QHttp.setSocket", overloads);
        return 0;
}

static PyObject* Sbk_QHttpFunc_setUser(PyObject* self, PyObject* args, PyObject* kwds)
{
    QHttp* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QHttp* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtNetwork.QHttp.setUser(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtNetwork.QHttp.setUser(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:setUser", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setUser(QString,QString)
    if (Shiboken::Converter< QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // setUser(QString,QString)
        } else if (Shiboken::Converter< QString >::isConvertible(pyargs[1])) {
            overloadId = 0; // setUser(QString,QString)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QHttpFunc_setUser_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "password");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "password";
                    else if (Shiboken::Converter< QString >::isConvertible(value))
                        pyargs[1] = value;
                    else
                        goto Sbk_QHttpFunc_setUser_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtNetwork.QHttp.setUser(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            QString cppArg1 = pyargs[1] ? Shiboken::Converter<QString >::toCpp(pyargs[1]) : QString();

            if(!PyErr_Occurred()) {
                // setUser(QString,QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = cppSelf->setUser(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QHttpFunc_setUser_TypeError:
        const char* overloads[] = {"QString, QString = QString()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtNetwork.QHttp.setUser", overloads);
        return 0;
}

static PyObject* Sbk_QHttpFunc_state(PyObject* self)
{
    QHttp* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QHttp* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // state()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QHttp::State cppResult = const_cast<const QHttp*>(cppSelf)->state();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QHttp::State >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef Sbk_QHttp_methods[] = {
    {"abort", (PyCFunction)Sbk_QHttpFunc_abort, METH_NOARGS},
    {"bytesAvailable", (PyCFunction)Sbk_QHttpFunc_bytesAvailable, METH_NOARGS},
    {"clearPendingRequests", (PyCFunction)Sbk_QHttpFunc_clearPendingRequests, METH_NOARGS},
    {"close", (PyCFunction)Sbk_QHttpFunc_close, METH_NOARGS},
    {"currentDestinationDevice", (PyCFunction)Sbk_QHttpFunc_currentDestinationDevice, METH_NOARGS},
    {"currentId", (PyCFunction)Sbk_QHttpFunc_currentId, METH_NOARGS},
    {"currentRequest", (PyCFunction)Sbk_QHttpFunc_currentRequest, METH_NOARGS},
    {"currentSourceDevice", (PyCFunction)Sbk_QHttpFunc_currentSourceDevice, METH_NOARGS},
    {"error", (PyCFunction)Sbk_QHttpFunc_error, METH_NOARGS},
    {"errorString", (PyCFunction)Sbk_QHttpFunc_errorString, METH_NOARGS},
    {"get", (PyCFunction)Sbk_QHttpFunc_get, METH_VARARGS|METH_KEYWORDS},
    {"hasPendingRequests", (PyCFunction)Sbk_QHttpFunc_hasPendingRequests, METH_NOARGS},
    {"head", (PyCFunction)Sbk_QHttpFunc_head, METH_O},
    {"ignoreSslErrors", (PyCFunction)Sbk_QHttpFunc_ignoreSslErrors, METH_NOARGS},
    {"lastResponse", (PyCFunction)Sbk_QHttpFunc_lastResponse, METH_NOARGS},
    {"post", (PyCFunction)Sbk_QHttpFunc_post, METH_VARARGS|METH_KEYWORDS},
    {"read", (PyCFunction)Sbk_QHttpFunc_read, METH_O},
    {"readAll", (PyCFunction)Sbk_QHttpFunc_readAll, METH_NOARGS},
    {"request", (PyCFunction)Sbk_QHttpFunc_request, METH_VARARGS|METH_KEYWORDS},
    {"setHost", (PyCFunction)Sbk_QHttpFunc_setHost, METH_VARARGS|METH_KEYWORDS},
    {"setProxy", (PyCFunction)Sbk_QHttpFunc_setProxy, METH_VARARGS|METH_KEYWORDS},
    {"setSocket", (PyCFunction)Sbk_QHttpFunc_setSocket, METH_O},
    {"setUser", (PyCFunction)Sbk_QHttpFunc_setUser, METH_VARARGS|METH_KEYWORDS},
    {"state", (PyCFunction)Sbk_QHttpFunc_state, METH_NOARGS},

    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QHttp_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtNetwork.QHttp",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QHttp_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QHttp_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern

static SbkObjectType* Sbk_QHttp_typeDiscovery(void* cptr, SbkObjectType* instanceType)
{
    if (instanceType == reinterpret_cast<SbkObjectType*>(Shiboken::SbkType<QObject >()) && dynamic_cast<QHttp*>(reinterpret_cast<QObject*>(cptr)))
        return &Sbk_QHttp_Type;
    return 0;
}


void init_QHttp(PyObject* module)
{
    SbkPySide_QtNetworkTypes[SBK_QHTTP_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QHttp_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QHttp_Type);
    Shiboken::ObjectType::setSubTypeInitHook(&Sbk_QHttp_Type, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(&Sbk_QHttp_Type, &QHttp::staticMetaObject);    Sbk_QHttp_Type.super.ht_type.tp_base = SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX];
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QHttp_Type, &Shiboken::callCppDestructor<QHttp >);
    if (PyType_Ready((PyTypeObject*)&Sbk_QHttp_Type) < 0)
        return;

    // Fill type discovery information
    Shiboken::ObjectType::setTypeDiscoveryFunction(&Sbk_QHttp_Type, &Sbk_QHttp_typeDiscovery);
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkObjectType*>(SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX]), &Sbk_QHttp_Type);

    Shiboken::ObjectType::setOriginalName(&Sbk_QHttp_Type, "QHttp*");
    PyModule_AddObject(module, "QHttp",
        ((PyObject*)&Sbk_QHttp_Type));

    // Initialize enums
    PyObject* enumItem;

    // init enum: Error
    PyTypeObject* SbkPySide_QtNetwork_QHttp_Error = Shiboken::Enum::newType("PySide.QtNetwork.QHttp.Error");
    SbkPySide_QtNetworkTypes[SBK_QHTTP_ERROR_IDX] = SbkPySide_QtNetwork_QHttp_Error;
    if (PyType_Ready(SbkPySide_QtNetwork_QHttp_Error) < 0)
        return;
    PyDict_SetItemString(Sbk_QHttp_Type.super.ht_type.tp_dict,
            "Error",((PyObject*)SbkPySide_QtNetwork_QHttp_Error));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QHttp_Error,(long) QHttp::NoError, "NoError");
    PyDict_SetItemString(Sbk_QHttp_Type.super.ht_type.tp_dict,"NoError", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QHttp_Error->tp_dict,"NoError", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QHttp_Error,(long) QHttp::UnknownError, "UnknownError");
    PyDict_SetItemString(Sbk_QHttp_Type.super.ht_type.tp_dict,"UnknownError", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QHttp_Error->tp_dict,"UnknownError", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QHttp_Error,(long) QHttp::HostNotFound, "HostNotFound");
    PyDict_SetItemString(Sbk_QHttp_Type.super.ht_type.tp_dict,"HostNotFound", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QHttp_Error->tp_dict,"HostNotFound", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QHttp_Error,(long) QHttp::ConnectionRefused, "ConnectionRefused");
    PyDict_SetItemString(Sbk_QHttp_Type.super.ht_type.tp_dict,"ConnectionRefused", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QHttp_Error->tp_dict,"ConnectionRefused", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QHttp_Error,(long) QHttp::UnexpectedClose, "UnexpectedClose");
    PyDict_SetItemString(Sbk_QHttp_Type.super.ht_type.tp_dict,"UnexpectedClose", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QHttp_Error->tp_dict,"UnexpectedClose", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QHttp_Error,(long) QHttp::InvalidResponseHeader, "InvalidResponseHeader");
    PyDict_SetItemString(Sbk_QHttp_Type.super.ht_type.tp_dict,"InvalidResponseHeader", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QHttp_Error->tp_dict,"InvalidResponseHeader", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QHttp_Error,(long) QHttp::WrongContentLength, "WrongContentLength");
    PyDict_SetItemString(Sbk_QHttp_Type.super.ht_type.tp_dict,"WrongContentLength", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QHttp_Error->tp_dict,"WrongContentLength", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QHttp_Error,(long) QHttp::Aborted, "Aborted");
    PyDict_SetItemString(Sbk_QHttp_Type.super.ht_type.tp_dict,"Aborted", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QHttp_Error->tp_dict,"Aborted", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QHttp_Error,(long) QHttp::AuthenticationRequiredError, "AuthenticationRequiredError");
    PyDict_SetItemString(Sbk_QHttp_Type.super.ht_type.tp_dict,"AuthenticationRequiredError", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QHttp_Error->tp_dict,"AuthenticationRequiredError", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QHttp_Error,(long) QHttp::ProxyAuthenticationRequiredError, "ProxyAuthenticationRequiredError");
    PyDict_SetItemString(Sbk_QHttp_Type.super.ht_type.tp_dict,"ProxyAuthenticationRequiredError", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QHttp_Error->tp_dict,"ProxyAuthenticationRequiredError", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QHttp::Error");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::Error");
    // end of enum Error

    // init enum: ConnectionMode
    PyTypeObject* SbkPySide_QtNetwork_QHttp_ConnectionMode = Shiboken::Enum::newType("PySide.QtNetwork.QHttp.ConnectionMode");
    SbkPySide_QtNetworkTypes[SBK_QHTTP_CONNECTIONMODE_IDX] = SbkPySide_QtNetwork_QHttp_ConnectionMode;
    if (PyType_Ready(SbkPySide_QtNetwork_QHttp_ConnectionMode) < 0)
        return;
    PyDict_SetItemString(Sbk_QHttp_Type.super.ht_type.tp_dict,
            "ConnectionMode",((PyObject*)SbkPySide_QtNetwork_QHttp_ConnectionMode));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QHttp_ConnectionMode,(long) QHttp::ConnectionModeHttp, "ConnectionModeHttp");
    PyDict_SetItemString(Sbk_QHttp_Type.super.ht_type.tp_dict,"ConnectionModeHttp", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QHttp_ConnectionMode->tp_dict,"ConnectionModeHttp", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QHttp_ConnectionMode,(long) QHttp::ConnectionModeHttps, "ConnectionModeHttps");
    PyDict_SetItemString(Sbk_QHttp_Type.super.ht_type.tp_dict,"ConnectionModeHttps", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QHttp_ConnectionMode->tp_dict,"ConnectionModeHttps", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QHttp::ConnectionMode");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::ConnectionMode");
    // end of enum ConnectionMode

    // init enum: State
    PyTypeObject* SbkPySide_QtNetwork_QHttp_State = Shiboken::Enum::newType("PySide.QtNetwork.QHttp.State");
    SbkPySide_QtNetworkTypes[SBK_QHTTP_STATE_IDX] = SbkPySide_QtNetwork_QHttp_State;
    if (PyType_Ready(SbkPySide_QtNetwork_QHttp_State) < 0)
        return;
    PyDict_SetItemString(Sbk_QHttp_Type.super.ht_type.tp_dict,
            "State",((PyObject*)SbkPySide_QtNetwork_QHttp_State));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QHttp_State,(long) QHttp::Unconnected, "Unconnected");
    PyDict_SetItemString(Sbk_QHttp_Type.super.ht_type.tp_dict,"Unconnected", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QHttp_State->tp_dict,"Unconnected", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QHttp_State,(long) QHttp::HostLookup, "HostLookup");
    PyDict_SetItemString(Sbk_QHttp_Type.super.ht_type.tp_dict,"HostLookup", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QHttp_State->tp_dict,"HostLookup", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QHttp_State,(long) QHttp::Connecting, "Connecting");
    PyDict_SetItemString(Sbk_QHttp_Type.super.ht_type.tp_dict,"Connecting", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QHttp_State->tp_dict,"Connecting", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QHttp_State,(long) QHttp::Sending, "Sending");
    PyDict_SetItemString(Sbk_QHttp_Type.super.ht_type.tp_dict,"Sending", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QHttp_State->tp_dict,"Sending", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QHttp_State,(long) QHttp::Reading, "Reading");
    PyDict_SetItemString(Sbk_QHttp_Type.super.ht_type.tp_dict,"Reading", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QHttp_State->tp_dict,"Reading", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QHttp_State,(long) QHttp::Connected, "Connected");
    PyDict_SetItemString(Sbk_QHttp_Type.super.ht_type.tp_dict,"Connected", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QHttp_State->tp_dict,"Connected", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QHttp_State,(long) QHttp::Closing, "Closing");
    PyDict_SetItemString(Sbk_QHttp_Type.super.ht_type.tp_dict,"Closing", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QHttp_State->tp_dict,"Closing", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QHttp::State");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::State");
    // end of enum State

    // Initialize signals
    PySideSignal* signal_item;

    signal_item = PySide::Signal::newObject("requestStarted", "int", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QHttp_Type, "requestStarted", signal_item);
    Py_DECREF((PyObject*) signal_item);
    signal_item = PySide::Signal::newObject("sslErrors", "QList<QSslError>", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QHttp_Type, "sslErrors", signal_item);
    Py_DECREF((PyObject*) signal_item);
    signal_item = PySide::Signal::newObject("dataSendProgress", "int,int", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QHttp_Type, "dataSendProgress", signal_item);
    Py_DECREF((PyObject*) signal_item);
    signal_item = PySide::Signal::newObject("done", "bool", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QHttp_Type, "done", signal_item);
    Py_DECREF((PyObject*) signal_item);
    signal_item = PySide::Signal::newObject("authenticationRequired", "QString,quint16,QAuthenticator*", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QHttp_Type, "authenticationRequired", signal_item);
    Py_DECREF((PyObject*) signal_item);
    signal_item = PySide::Signal::newObject("responseHeaderReceived", "QHttpResponseHeader", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QHttp_Type, "responseHeaderReceived", signal_item);
    Py_DECREF((PyObject*) signal_item);
    signal_item = PySide::Signal::newObject("dataReadProgress", "int,int", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QHttp_Type, "dataReadProgress", signal_item);
    Py_DECREF((PyObject*) signal_item);
    signal_item = PySide::Signal::newObject("proxyAuthenticationRequired", "QNetworkProxy,QAuthenticator*", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QHttp_Type, "proxyAuthenticationRequired", signal_item);
    Py_DECREF((PyObject*) signal_item);
    signal_item = PySide::Signal::newObject("requestFinished", "int,bool", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QHttp_Type, "requestFinished", signal_item);
    Py_DECREF((PyObject*) signal_item);
    signal_item = PySide::Signal::newObject("stateChanged", "int", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QHttp_Type, "stateChanged", signal_item);
    Py_DECREF((PyObject*) signal_item);
    signal_item = PySide::Signal::newObject("readyRead", "QHttpResponseHeader", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QHttp_Type, "readyRead", signal_item);
    Py_DECREF((PyObject*) signal_item);


    Shiboken::TypeResolver::createObjectTypeResolver<QHttp >("QHttp*");
    Shiboken::TypeResolver::createObjectTypeResolver<QHttp >(typeid(QHttp).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QHttp >(typeid(QHttpWrapper).name());
    PySide::initQtMetaType< ::QHttp* >();
    qRegisterMetaType< ::QHttp::Error >("QHttp::Error");
    qRegisterMetaType< ::QHttp::ConnectionMode >("QHttp::ConnectionMode");
    qRegisterMetaType< ::QHttp::State >("QHttp::State");
}

