/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtnetwork_python.h"

#include "qnetworkcookie_wrapper.h"

// Extra includes
#include <QDateTime>
#include <QList>
#include <qbytearray.h>
#include <qdatetime.h>
#include <qnetworkcookie.h>



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QNetworkCookie_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QNetworkCookie >()))
        return -1;

    QNetworkCookie* cptr = 0;
    int overloadId = -1;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);

    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtNetwork.QNetworkCookie(): too many arguments");
        return -1;
    }

    if (!PyArg_ParseTuple(args, "|OO:QNetworkCookie", &(pyargs[0]), &(pyargs[1])))
        return -1;

    // Overloaded function decisor
    // 0: QNetworkCookie(QByteArray,QByteArray)
    // 1: QNetworkCookie(QNetworkCookie)
    if (numArgs == 0) {
        overloadId = 0; // QNetworkCookie(QByteArray,QByteArray)
    } else if (numArgs == 1 && Shiboken::Converter< ::QNetworkCookie >::isConvertible(pyargs[0])) {
        overloadId = 1; // QNetworkCookie(QNetworkCookie)
    } else if (Shiboken::Converter< ::QByteArray >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // QNetworkCookie(QByteArray,QByteArray)
        } else if (Shiboken::Converter< ::QByteArray >::isConvertible(pyargs[1])) {
            overloadId = 0; // QNetworkCookie(QByteArray,QByteArray)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QNetworkCookie_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QNetworkCookie(QByteArray,QByteArray)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "name");
                    if (value) {
                        if (pyargs[0])
                            errorArgName = "name";
                        else if (Shiboken::Converter< ::QByteArray >::isConvertible(value))
                            pyargs[0] = value;
                        else
                            goto Sbk_QNetworkCookie_Init_TypeError;
                    }
                    value = PyDict_GetItemString(kwds, "value");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "value";
                        else if (Shiboken::Converter< ::QByteArray >::isConvertible(value))
                            pyargs[1] = value;
                        else
                            goto Sbk_QNetworkCookie_Init_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtNetwork.QNetworkCookie(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QByteArray cppArg0_tmp = QByteArray();
                QByteArray cppArg0 = pyargs[0] ? Shiboken::Converter<QByteArray >::toCpp(pyargs[0]) : cppArg0_tmp;
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return -1;
                QByteArray cppArg1_tmp = QByteArray();
                QByteArray cppArg1 = pyargs[1] ? Shiboken::Converter<QByteArray >::toCpp(pyargs[1]) : cppArg1_tmp;

                if(!PyErr_Occurred()) {
                    // QNetworkCookie(QByteArray,QByteArray)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QNetworkCookie(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // QNetworkCookie(QNetworkCookie)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QNetworkCookie cppArg0 = Shiboken::Converter<QNetworkCookie >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QNetworkCookie(QNetworkCookie)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QNetworkCookie(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QNetworkCookie >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QNetworkCookie_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QNetworkCookie_Init_TypeError:
        const char* overloads[] = {"PySide.QtCore.QByteArray = QByteArray(), PySide.QtCore.QByteArray = QByteArray()", "PySide.QtNetwork.QNetworkCookie", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtNetwork.QNetworkCookie", overloads);
        return -1;
}

static PyObject* Sbk_QNetworkCookieFunc_domain(PyObject* self)
{
    QNetworkCookie* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QNetworkCookie* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // domain()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QNetworkCookie*>(cppSelf)->domain();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QNetworkCookieFunc_expirationDate(PyObject* self)
{
    QNetworkCookie* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QNetworkCookie* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // expirationDate()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QDateTime cppResult = const_cast<const QNetworkCookie*>(cppSelf)->expirationDate();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QDateTime >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QNetworkCookieFunc_isHttpOnly(PyObject* self)
{
    QNetworkCookie* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QNetworkCookie* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isHttpOnly()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QNetworkCookie*>(cppSelf)->isHttpOnly();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QNetworkCookieFunc_isSecure(PyObject* self)
{
    QNetworkCookie* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QNetworkCookie* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isSecure()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QNetworkCookie*>(cppSelf)->isSecure();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QNetworkCookieFunc_isSessionCookie(PyObject* self)
{
    QNetworkCookie* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QNetworkCookie* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isSessionCookie()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QNetworkCookie*>(cppSelf)->isSessionCookie();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QNetworkCookieFunc_name(PyObject* self)
{
    QNetworkCookie* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QNetworkCookie* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // name()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QByteArray cppResult = const_cast<const QNetworkCookie*>(cppSelf)->name();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QByteArray >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QNetworkCookieFunc_parseCookies(PyObject* self, PyObject* arg)
{
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: parseCookies(QByteArray)
    if (Shiboken::Converter< ::QByteArray >::isConvertible(arg)) {
        overloadId = 0; // parseCookies(QByteArray)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QNetworkCookieFunc_parseCookies_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QByteArray cppArg0 = Shiboken::Converter<QByteArray >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // parseCookies(QByteArray)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QList<QNetworkCookie > cppResult = QNetworkCookie::parseCookies(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QList<QNetworkCookie > >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QNetworkCookieFunc_parseCookies_TypeError:
        const char* overloads[] = {"PySide.QtCore.QByteArray", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QNetworkCookie.parseCookies", overloads);
        return 0;
}

static PyObject* Sbk_QNetworkCookieFunc_path(PyObject* self)
{
    QNetworkCookie* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QNetworkCookie* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // path()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QNetworkCookie*>(cppSelf)->path();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QNetworkCookieFunc_setDomain(PyObject* self, PyObject* arg)
{
    QNetworkCookie* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QNetworkCookie* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setDomain(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // setDomain(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QNetworkCookieFunc_setDomain_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setDomain(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setDomain(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QNetworkCookieFunc_setDomain_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QNetworkCookie.setDomain", overloads);
        return 0;
}

static PyObject* Sbk_QNetworkCookieFunc_setExpirationDate(PyObject* self, PyObject* arg)
{
    QNetworkCookie* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QNetworkCookie* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setExpirationDate(QDateTime)
    if (Shiboken::Converter< ::QDateTime >::isConvertible(arg)) {
        overloadId = 0; // setExpirationDate(QDateTime)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QNetworkCookieFunc_setExpirationDate_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QDateTime cppArg0 = Shiboken::Converter<QDateTime >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setExpirationDate(QDateTime)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setExpirationDate(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QNetworkCookieFunc_setExpirationDate_TypeError:
        const char* overloads[] = {"PySide.QtCore.QDateTime", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QNetworkCookie.setExpirationDate", overloads);
        return 0;
}

static PyObject* Sbk_QNetworkCookieFunc_setHttpOnly(PyObject* self, PyObject* arg)
{
    QNetworkCookie* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QNetworkCookie* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setHttpOnly(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setHttpOnly(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QNetworkCookieFunc_setHttpOnly_TypeError;

    // Call function/method
    {
        {
            bool cppArg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setHttpOnly(bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setHttpOnly(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QNetworkCookieFunc_setHttpOnly_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QNetworkCookie.setHttpOnly", overloads);
        return 0;
}

static PyObject* Sbk_QNetworkCookieFunc_setName(PyObject* self, PyObject* arg)
{
    QNetworkCookie* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QNetworkCookie* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setName(QByteArray)
    if (Shiboken::Converter< ::QByteArray >::isConvertible(arg)) {
        overloadId = 0; // setName(QByteArray)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QNetworkCookieFunc_setName_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QByteArray cppArg0 = Shiboken::Converter<QByteArray >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setName(QByteArray)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setName(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QNetworkCookieFunc_setName_TypeError:
        const char* overloads[] = {"PySide.QtCore.QByteArray", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QNetworkCookie.setName", overloads);
        return 0;
}

static PyObject* Sbk_QNetworkCookieFunc_setPath(PyObject* self, PyObject* arg)
{
    QNetworkCookie* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QNetworkCookie* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setPath(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // setPath(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QNetworkCookieFunc_setPath_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setPath(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setPath(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QNetworkCookieFunc_setPath_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QNetworkCookie.setPath", overloads);
        return 0;
}

static PyObject* Sbk_QNetworkCookieFunc_setSecure(PyObject* self, PyObject* arg)
{
    QNetworkCookie* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QNetworkCookie* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setSecure(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setSecure(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QNetworkCookieFunc_setSecure_TypeError;

    // Call function/method
    {
        {
            bool cppArg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setSecure(bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setSecure(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QNetworkCookieFunc_setSecure_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QNetworkCookie.setSecure", overloads);
        return 0;
}

static PyObject* Sbk_QNetworkCookieFunc_setValue(PyObject* self, PyObject* arg)
{
    QNetworkCookie* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QNetworkCookie* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setValue(QByteArray)
    if (Shiboken::Converter< ::QByteArray >::isConvertible(arg)) {
        overloadId = 0; // setValue(QByteArray)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QNetworkCookieFunc_setValue_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QByteArray cppArg0 = Shiboken::Converter<QByteArray >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setValue(QByteArray)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setValue(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QNetworkCookieFunc_setValue_TypeError:
        const char* overloads[] = {"PySide.QtCore.QByteArray", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QNetworkCookie.setValue", overloads);
        return 0;
}

static PyObject* Sbk_QNetworkCookieFunc_toRawForm(PyObject* self, PyObject* args, PyObject* kwds)
{
    QNetworkCookie* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QNetworkCookie* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtNetwork.QNetworkCookie.toRawForm(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:toRawForm", &(pyargs[0])))
        return 0;


    // Overloaded function decisor
    // 0: toRawForm(QNetworkCookie::RawForm)const
    if (numArgs == 0) {
        overloadId = 0; // toRawForm(QNetworkCookie::RawForm)const
    } else if (Shiboken::Converter< ::QNetworkCookie::RawForm >::isConvertible(pyargs[0])) {
        overloadId = 0; // toRawForm(QNetworkCookie::RawForm)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QNetworkCookieFunc_toRawForm_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "form");
                if (value) {
                    if (pyargs[0])
                        errorArgName = "form";
                    else if (Shiboken::Converter< ::QNetworkCookie::RawForm >::isConvertible(value))
                        pyargs[0] = value;
                    else
                        goto Sbk_QNetworkCookieFunc_toRawForm_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtNetwork.QNetworkCookie.toRawForm(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QNetworkCookie::RawForm cppArg0 = pyargs[0] ? Shiboken::Converter<QNetworkCookie::RawForm >::toCpp(pyargs[0]) : QNetworkCookie::Full;

            if(!PyErr_Occurred()) {
                // toRawForm(QNetworkCookie::RawForm)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QByteArray cppResult = const_cast<const QNetworkCookie*>(cppSelf)->toRawForm(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QByteArray >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QNetworkCookieFunc_toRawForm_TypeError:
        const char* overloads[] = {"PySide.QtNetwork.QNetworkCookie.RawForm = Full", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtNetwork.QNetworkCookie.toRawForm", overloads);
        return 0;
}

static PyObject* Sbk_QNetworkCookieFunc_value(PyObject* self)
{
    QNetworkCookie* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QNetworkCookie* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // value()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QByteArray cppResult = const_cast<const QNetworkCookie*>(cppSelf)->value();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QByteArray >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject *Sbk_QNetworkCookie___copy__(PyObject *self)
{
        QNetworkCookie* cppSelf = 0;
        if (!Shiboken::Object::isValid(self))
            return 0;
        cppSelf = Shiboken::Converter<QNetworkCookie*>::toCpp(self);
        PyObject* pyResult = 0;
        QNetworkCookie* copy = new QNetworkCookie(*cppSelf);
        pyResult = Shiboken::Converter<QNetworkCookie*>::toPython(copy);
        Shiboken::Object::getOwnership(pyResult);

        if (PyErr_Occurred() || !pyResult) {
            Py_XDECREF(pyResult);
            return 0;
        }
        return pyResult;
}

static PyMethodDef Sbk_QNetworkCookie_methods[] = {
    {"domain", (PyCFunction)Sbk_QNetworkCookieFunc_domain, METH_NOARGS},
    {"expirationDate", (PyCFunction)Sbk_QNetworkCookieFunc_expirationDate, METH_NOARGS},
    {"isHttpOnly", (PyCFunction)Sbk_QNetworkCookieFunc_isHttpOnly, METH_NOARGS},
    {"isSecure", (PyCFunction)Sbk_QNetworkCookieFunc_isSecure, METH_NOARGS},
    {"isSessionCookie", (PyCFunction)Sbk_QNetworkCookieFunc_isSessionCookie, METH_NOARGS},
    {"name", (PyCFunction)Sbk_QNetworkCookieFunc_name, METH_NOARGS},
    {"parseCookies", (PyCFunction)Sbk_QNetworkCookieFunc_parseCookies, METH_O|METH_STATIC},
    {"path", (PyCFunction)Sbk_QNetworkCookieFunc_path, METH_NOARGS},
    {"setDomain", (PyCFunction)Sbk_QNetworkCookieFunc_setDomain, METH_O},
    {"setExpirationDate", (PyCFunction)Sbk_QNetworkCookieFunc_setExpirationDate, METH_O},
    {"setHttpOnly", (PyCFunction)Sbk_QNetworkCookieFunc_setHttpOnly, METH_O},
    {"setName", (PyCFunction)Sbk_QNetworkCookieFunc_setName, METH_O},
    {"setPath", (PyCFunction)Sbk_QNetworkCookieFunc_setPath, METH_O},
    {"setSecure", (PyCFunction)Sbk_QNetworkCookieFunc_setSecure, METH_O},
    {"setValue", (PyCFunction)Sbk_QNetworkCookieFunc_setValue, METH_O},
    {"toRawForm", (PyCFunction)Sbk_QNetworkCookieFunc_toRawForm, METH_VARARGS|METH_KEYWORDS},
    {"value", (PyCFunction)Sbk_QNetworkCookieFunc_value, METH_NOARGS},

    {"__copy__", (PyCFunction)Sbk_QNetworkCookie___copy__, METH_NOARGS},
    {0} // Sentinel
};

// Rich comparison
static PyObject* Sbk_QNetworkCookie_richcompare(PyObject* self, PyObject* arg, int op)
{
    PyObject* pyResult = 0;
    QNetworkCookie& cppSelf = *Shiboken::Converter< QNetworkCookie* >::toCpp(self);

    switch (op) {
        case Py_NE:
            if (Shiboken::Converter< ::QNetworkCookie >::isConvertible(arg)) {
                // operator!=(const QNetworkCookie & other) const
                QNetworkCookie cppArg0 = Shiboken::Converter< ::QNetworkCookie >::toCpp(arg);
                pyResult = Shiboken::Converter< bool >::toPython(cppSelf != cppArg0);
            } else goto Sbk_QNetworkCookie_RichComparison_TypeError;

            break;
        case Py_EQ:
            if (Shiboken::Converter< ::QNetworkCookie >::isConvertible(arg)) {
                // operator==(const QNetworkCookie & other) const
                QNetworkCookie cppArg0 = Shiboken::Converter< ::QNetworkCookie >::toCpp(arg);
                pyResult = Shiboken::Converter< bool >::toPython(cppSelf == cppArg0);
            } else goto Sbk_QNetworkCookie_RichComparison_TypeError;

            break;
        default:
            goto Sbk_QNetworkCookie_RichComparison_TypeError;
    }

    if (pyResult && !PyErr_Occurred())
        return pyResult;
    Sbk_QNetworkCookie_RichComparison_TypeError:
    PyErr_SetString(PyExc_NotImplementedError, "operator not implemented.");
    return 0;

}

} // extern "C"

extern "C"
{
static PyObject* Sbk_QNetworkCookie__repr__(PyObject* pyObj)
{
    QBuffer buffer;
    buffer.open(QBuffer::ReadWrite);
    QDebug dbg(&buffer);
    dbg << Shiboken::Converter< ::QNetworkCookie >::toCpp(pyObj);
    buffer.close();
    return PyString_FromFormat("<PySide.QtNetwork.%s at %p>", buffer.data().constData(), pyObj);
}
} // extern C

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QNetworkCookie_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtNetwork.QNetworkCookie",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Sbk_QNetworkCookie__repr__,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      Sbk_QNetworkCookie_richcompare,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QNetworkCookie_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QNetworkCookie_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QNetworkCookie(PyObject* module)
{
    SbkPySide_QtNetworkTypes[SBK_QNETWORKCOOKIE_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QNetworkCookie_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QNetworkCookie_Type);
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QNetworkCookie_Type, &Shiboken::callCppDestructor<QNetworkCookie >);
    if (PyType_Ready((PyTypeObject*)&Sbk_QNetworkCookie_Type) < 0)
        return;

    Shiboken::ObjectType::setOriginalName(&Sbk_QNetworkCookie_Type, "QNetworkCookie");
    PyModule_AddObject(module, "QNetworkCookie",
        ((PyObject*)&Sbk_QNetworkCookie_Type));

    // Initialize enums
    PyObject* enumItem;

    // init enum: RawForm
    PyTypeObject* SbkPySide_QtNetwork_QNetworkCookie_RawForm = Shiboken::Enum::newType("PySide.QtNetwork.QNetworkCookie.RawForm");
    SbkPySide_QtNetworkTypes[SBK_QNETWORKCOOKIE_RAWFORM_IDX] = SbkPySide_QtNetwork_QNetworkCookie_RawForm;
    if (PyType_Ready(SbkPySide_QtNetwork_QNetworkCookie_RawForm) < 0)
        return;
    PyDict_SetItemString(Sbk_QNetworkCookie_Type.super.ht_type.tp_dict,
            "RawForm",((PyObject*)SbkPySide_QtNetwork_QNetworkCookie_RawForm));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QNetworkCookie_RawForm,(long) QNetworkCookie::NameAndValueOnly, "NameAndValueOnly");
    PyDict_SetItemString(Sbk_QNetworkCookie_Type.super.ht_type.tp_dict,"NameAndValueOnly", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QNetworkCookie_RawForm->tp_dict,"NameAndValueOnly", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QNetworkCookie_RawForm,(long) QNetworkCookie::Full, "Full");
    PyDict_SetItemString(Sbk_QNetworkCookie_Type.super.ht_type.tp_dict,"Full", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QNetworkCookie_RawForm->tp_dict,"Full", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QNetworkCookie::RawForm");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::RawForm");
    // end of enum RawForm


    Shiboken::TypeResolver::createValueTypeResolver<QNetworkCookie >("QNetworkCookie");
    Shiboken::TypeResolver::createObjectTypeResolver<QNetworkCookie >("QNetworkCookie*");
    Shiboken::TypeResolver::createValueTypeResolver<QNetworkCookie >(typeid(QNetworkCookie).name());
    PySide::initQtMetaType< ::QNetworkCookie >();
    qRegisterMetaType< ::QNetworkCookie::RawForm >("QNetworkCookie::RawForm");
}

