/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtnetwork_python.h"

#include "qnetworkproxyquery_wrapper.h"

// Extra includes
#include <qnetworkproxy.h>
#include <qurl.h>



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QNetworkProxyQuery_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QNetworkProxyQuery >()))
        return -1;

    QNetworkProxyQuery* cptr = 0;
    int overloadId = -1;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);

    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 4) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtNetwork.QNetworkProxyQuery(): too many arguments");
        return -1;
    }

    if (!PyArg_ParseTuple(args, "|OOOO:QNetworkProxyQuery", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return -1;

    // Overloaded function decisor
    // 0: QNetworkProxyQuery()
    // 1: QNetworkProxyQuery(QNetworkProxyQuery)
    // 2: QNetworkProxyQuery(QString,int,QString,QNetworkProxyQuery::QueryType)
    // 3: QNetworkProxyQuery(QUrl,QNetworkProxyQuery::QueryType)
    // 4: QNetworkProxyQuery(quint16,QString,QNetworkProxyQuery::QueryType)
    if (numArgs == 0) {
        overloadId = 0; // QNetworkProxyQuery()
    } else if (SbkNumber_Check(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 4; // QNetworkProxyQuery(quint16,QString,QNetworkProxyQuery::QueryType)
        } else if (Shiboken::Converter< QString >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 4; // QNetworkProxyQuery(quint16,QString,QNetworkProxyQuery::QueryType)
            } else if (Shiboken::Converter< ::QNetworkProxyQuery::QueryType >::isConvertible(pyargs[2])) {
                overloadId = 4; // QNetworkProxyQuery(quint16,QString,QNetworkProxyQuery::QueryType)
            }
        }
    } else if (numArgs >= 2 && Shiboken::Converter< QString >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 2; // QNetworkProxyQuery(QString,int,QString,QNetworkProxyQuery::QueryType)
        } else if (Shiboken::Converter< QString >::isConvertible(pyargs[2])) {
            if (numArgs == 3) {
                overloadId = 2; // QNetworkProxyQuery(QString,int,QString,QNetworkProxyQuery::QueryType)
            } else if (Shiboken::Converter< ::QNetworkProxyQuery::QueryType >::isConvertible(pyargs[3])) {
                overloadId = 2; // QNetworkProxyQuery(QString,int,QString,QNetworkProxyQuery::QueryType)
            }
        }
    } else if (Shiboken::Converter< ::QUrl >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 3; // QNetworkProxyQuery(QUrl,QNetworkProxyQuery::QueryType)
        } else if (Shiboken::Converter< ::QNetworkProxyQuery::QueryType >::isConvertible(pyargs[1])) {
            overloadId = 3; // QNetworkProxyQuery(QUrl,QNetworkProxyQuery::QueryType)
        }
    } else if (numArgs == 1 && Shiboken::Converter< ::QNetworkProxyQuery >::isConvertible(pyargs[0])) {
        overloadId = 1; // QNetworkProxyQuery(QNetworkProxyQuery)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QNetworkProxyQuery_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QNetworkProxyQuery()
            {

                if(!PyErr_Occurred()) {
                    // QNetworkProxyQuery()
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QNetworkProxyQuery();
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // QNetworkProxyQuery(QNetworkProxyQuery)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QNetworkProxyQuery cppArg0 = Shiboken::Converter<QNetworkProxyQuery >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QNetworkProxyQuery(QNetworkProxyQuery)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QNetworkProxyQuery(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 2: // QNetworkProxyQuery(QString,int,QString,QNetworkProxyQuery::QueryType)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "protocolTag");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "protocolTag";
                        else if (Shiboken::Converter< QString >::isConvertible(value))
                            pyargs[2] = value;
                        else
                            goto Sbk_QNetworkProxyQuery_Init_TypeError;
                    }
                    value = PyDict_GetItemString(kwds, "queryType");
                    if (value) {
                        if (pyargs[3])
                            errorArgName = "queryType";
                        else if (Shiboken::Converter< ::QNetworkProxyQuery::QueryType >::isConvertible(value))
                            pyargs[3] = value;
                        else
                            goto Sbk_QNetworkProxyQuery_Init_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtNetwork.QNetworkProxyQuery(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                QString cppArg2 = pyargs[2] ? Shiboken::Converter<QString >::toCpp(pyargs[2]) : QString();
                QNetworkProxyQuery::QueryType cppArg3 = pyargs[3] ? Shiboken::Converter<QNetworkProxyQuery::QueryType >::toCpp(pyargs[3]) : QNetworkProxyQuery::TcpSocket;

                if(!PyErr_Occurred()) {
                    // QNetworkProxyQuery(QString,int,QString,QNetworkProxyQuery::QueryType)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QNetworkProxyQuery(cppArg0, cppArg1, cppArg2, cppArg3);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 3: // QNetworkProxyQuery(QUrl,QNetworkProxyQuery::QueryType)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "queryType");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "queryType";
                        else if (Shiboken::Converter< ::QNetworkProxyQuery::QueryType >::isConvertible(value))
                            pyargs[1] = value;
                        else
                            goto Sbk_QNetworkProxyQuery_Init_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtNetwork.QNetworkProxyQuery(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QUrl cppArg0 = Shiboken::Converter<QUrl >::toCpp(pyargs[0]);
                QNetworkProxyQuery::QueryType cppArg1 = pyargs[1] ? Shiboken::Converter<QNetworkProxyQuery::QueryType >::toCpp(pyargs[1]) : QNetworkProxyQuery::UrlRequest;

                if(!PyErr_Occurred()) {
                    // QNetworkProxyQuery(QUrl,QNetworkProxyQuery::QueryType)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QNetworkProxyQuery(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 4: // QNetworkProxyQuery(quint16,QString,QNetworkProxyQuery::QueryType)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "protocolTag");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "protocolTag";
                        else if (Shiboken::Converter< QString >::isConvertible(value))
                            pyargs[1] = value;
                        else
                            goto Sbk_QNetworkProxyQuery_Init_TypeError;
                    }
                    value = PyDict_GetItemString(kwds, "queryType");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "queryType";
                        else if (Shiboken::Converter< ::QNetworkProxyQuery::QueryType >::isConvertible(value))
                            pyargs[2] = value;
                        else
                            goto Sbk_QNetworkProxyQuery_Init_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtNetwork.QNetworkProxyQuery(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                quint16 cppArg0 = Shiboken::Converter<quint16 >::toCpp(pyargs[0]);
                QString cppArg1 = pyargs[1] ? Shiboken::Converter<QString >::toCpp(pyargs[1]) : QString();
                QNetworkProxyQuery::QueryType cppArg2 = pyargs[2] ? Shiboken::Converter<QNetworkProxyQuery::QueryType >::toCpp(pyargs[2]) : QNetworkProxyQuery::TcpServer;

                if(!PyErr_Occurred()) {
                    // QNetworkProxyQuery(quint16,QString,QNetworkProxyQuery::QueryType)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QNetworkProxyQuery(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QNetworkProxyQuery >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QNetworkProxyQuery_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QNetworkProxyQuery_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtNetwork.QNetworkProxyQuery", "QString, int, QString = QString(), PySide.QtNetwork.QNetworkProxyQuery.QueryType = TcpSocket", "PySide.QtCore.QUrl, PySide.QtNetwork.QNetworkProxyQuery.QueryType = UrlRequest", "unsigned short, QString = QString(), PySide.QtNetwork.QNetworkProxyQuery.QueryType = TcpServer", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtNetwork.QNetworkProxyQuery", overloads);
        return -1;
}

static PyObject* Sbk_QNetworkProxyQueryFunc_localPort(PyObject* self)
{
    QNetworkProxyQuery* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QNetworkProxyQuery* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // localPort()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QNetworkProxyQuery*>(cppSelf)->localPort();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QNetworkProxyQueryFunc_peerHostName(PyObject* self)
{
    QNetworkProxyQuery* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QNetworkProxyQuery* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // peerHostName()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QNetworkProxyQuery*>(cppSelf)->peerHostName();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QNetworkProxyQueryFunc_peerPort(PyObject* self)
{
    QNetworkProxyQuery* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QNetworkProxyQuery* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // peerPort()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QNetworkProxyQuery*>(cppSelf)->peerPort();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QNetworkProxyQueryFunc_protocolTag(PyObject* self)
{
    QNetworkProxyQuery* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QNetworkProxyQuery* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // protocolTag()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QNetworkProxyQuery*>(cppSelf)->protocolTag();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QNetworkProxyQueryFunc_queryType(PyObject* self)
{
    QNetworkProxyQuery* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QNetworkProxyQuery* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // queryType()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QNetworkProxyQuery::QueryType cppResult = const_cast<const QNetworkProxyQuery*>(cppSelf)->queryType();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QNetworkProxyQuery::QueryType >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QNetworkProxyQueryFunc_setLocalPort(PyObject* self, PyObject* arg)
{
    QNetworkProxyQuery* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QNetworkProxyQuery* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setLocalPort(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setLocalPort(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QNetworkProxyQueryFunc_setLocalPort_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setLocalPort(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setLocalPort(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QNetworkProxyQueryFunc_setLocalPort_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QNetworkProxyQuery.setLocalPort", overloads);
        return 0;
}

static PyObject* Sbk_QNetworkProxyQueryFunc_setPeerHostName(PyObject* self, PyObject* arg)
{
    QNetworkProxyQuery* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QNetworkProxyQuery* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setPeerHostName(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // setPeerHostName(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QNetworkProxyQueryFunc_setPeerHostName_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setPeerHostName(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setPeerHostName(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QNetworkProxyQueryFunc_setPeerHostName_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QNetworkProxyQuery.setPeerHostName", overloads);
        return 0;
}

static PyObject* Sbk_QNetworkProxyQueryFunc_setPeerPort(PyObject* self, PyObject* arg)
{
    QNetworkProxyQuery* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QNetworkProxyQuery* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setPeerPort(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setPeerPort(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QNetworkProxyQueryFunc_setPeerPort_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setPeerPort(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setPeerPort(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QNetworkProxyQueryFunc_setPeerPort_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QNetworkProxyQuery.setPeerPort", overloads);
        return 0;
}

static PyObject* Sbk_QNetworkProxyQueryFunc_setProtocolTag(PyObject* self, PyObject* arg)
{
    QNetworkProxyQuery* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QNetworkProxyQuery* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setProtocolTag(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // setProtocolTag(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QNetworkProxyQueryFunc_setProtocolTag_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setProtocolTag(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setProtocolTag(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QNetworkProxyQueryFunc_setProtocolTag_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QNetworkProxyQuery.setProtocolTag", overloads);
        return 0;
}

static PyObject* Sbk_QNetworkProxyQueryFunc_setQueryType(PyObject* self, PyObject* arg)
{
    QNetworkProxyQuery* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QNetworkProxyQuery* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setQueryType(QNetworkProxyQuery::QueryType)
    if (Shiboken::Converter< ::QNetworkProxyQuery::QueryType >::isConvertible(arg)) {
        overloadId = 0; // setQueryType(QNetworkProxyQuery::QueryType)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QNetworkProxyQueryFunc_setQueryType_TypeError;

    // Call function/method
    {
        {
            QNetworkProxyQuery::QueryType cppArg0 = Shiboken::Converter<QNetworkProxyQuery::QueryType >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setQueryType(QNetworkProxyQuery::QueryType)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setQueryType(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QNetworkProxyQueryFunc_setQueryType_TypeError:
        const char* overloads[] = {"PySide.QtNetwork.QNetworkProxyQuery.QueryType", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QNetworkProxyQuery.setQueryType", overloads);
        return 0;
}

static PyObject* Sbk_QNetworkProxyQueryFunc_setUrl(PyObject* self, PyObject* arg)
{
    QNetworkProxyQuery* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QNetworkProxyQuery* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setUrl(QUrl)
    if (Shiboken::Converter< ::QUrl >::isConvertible(arg)) {
        overloadId = 0; // setUrl(QUrl)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QNetworkProxyQueryFunc_setUrl_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QUrl cppArg0 = Shiboken::Converter<QUrl >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setUrl(QUrl)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setUrl(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QNetworkProxyQueryFunc_setUrl_TypeError:
        const char* overloads[] = {"PySide.QtCore.QUrl", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QNetworkProxyQuery.setUrl", overloads);
        return 0;
}

static PyObject* Sbk_QNetworkProxyQueryFunc_url(PyObject* self)
{
    QNetworkProxyQuery* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QNetworkProxyQuery* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // url()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QUrl cppResult = const_cast<const QNetworkProxyQuery*>(cppSelf)->url();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QUrl >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject *Sbk_QNetworkProxyQuery___copy__(PyObject *self)
{
        QNetworkProxyQuery* cppSelf = 0;
        if (!Shiboken::Object::isValid(self))
            return 0;
        cppSelf = Shiboken::Converter<QNetworkProxyQuery*>::toCpp(self);
        PyObject* pyResult = 0;
        QNetworkProxyQuery* copy = new QNetworkProxyQuery(*cppSelf);
        pyResult = Shiboken::Converter<QNetworkProxyQuery*>::toPython(copy);
        Shiboken::Object::getOwnership(pyResult);

        if (PyErr_Occurred() || !pyResult) {
            Py_XDECREF(pyResult);
            return 0;
        }
        return pyResult;
}

static PyMethodDef Sbk_QNetworkProxyQuery_methods[] = {
    {"localPort", (PyCFunction)Sbk_QNetworkProxyQueryFunc_localPort, METH_NOARGS},
    {"peerHostName", (PyCFunction)Sbk_QNetworkProxyQueryFunc_peerHostName, METH_NOARGS},
    {"peerPort", (PyCFunction)Sbk_QNetworkProxyQueryFunc_peerPort, METH_NOARGS},
    {"protocolTag", (PyCFunction)Sbk_QNetworkProxyQueryFunc_protocolTag, METH_NOARGS},
    {"queryType", (PyCFunction)Sbk_QNetworkProxyQueryFunc_queryType, METH_NOARGS},
    {"setLocalPort", (PyCFunction)Sbk_QNetworkProxyQueryFunc_setLocalPort, METH_O},
    {"setPeerHostName", (PyCFunction)Sbk_QNetworkProxyQueryFunc_setPeerHostName, METH_O},
    {"setPeerPort", (PyCFunction)Sbk_QNetworkProxyQueryFunc_setPeerPort, METH_O},
    {"setProtocolTag", (PyCFunction)Sbk_QNetworkProxyQueryFunc_setProtocolTag, METH_O},
    {"setQueryType", (PyCFunction)Sbk_QNetworkProxyQueryFunc_setQueryType, METH_O},
    {"setUrl", (PyCFunction)Sbk_QNetworkProxyQueryFunc_setUrl, METH_O},
    {"url", (PyCFunction)Sbk_QNetworkProxyQueryFunc_url, METH_NOARGS},

    {"__copy__", (PyCFunction)Sbk_QNetworkProxyQuery___copy__, METH_NOARGS},
    {0} // Sentinel
};

// Rich comparison
static PyObject* Sbk_QNetworkProxyQuery_richcompare(PyObject* self, PyObject* arg, int op)
{
    PyObject* pyResult = 0;
    QNetworkProxyQuery& cppSelf = *Shiboken::Converter< QNetworkProxyQuery* >::toCpp(self);

    switch (op) {
        case Py_NE:
            if (Shiboken::Converter< ::QNetworkProxyQuery >::isConvertible(arg)) {
                // operator!=(const QNetworkProxyQuery & other) const
                QNetworkProxyQuery cppArg0 = Shiboken::Converter< ::QNetworkProxyQuery >::toCpp(arg);
                pyResult = Shiboken::Converter< bool >::toPython(cppSelf != cppArg0);
            } else goto Sbk_QNetworkProxyQuery_RichComparison_TypeError;

            break;
        case Py_EQ:
            if (Shiboken::Converter< ::QNetworkProxyQuery >::isConvertible(arg)) {
                // operator==(const QNetworkProxyQuery & other) const
                QNetworkProxyQuery cppArg0 = Shiboken::Converter< ::QNetworkProxyQuery >::toCpp(arg);
                pyResult = Shiboken::Converter< bool >::toPython(cppSelf == cppArg0);
            } else goto Sbk_QNetworkProxyQuery_RichComparison_TypeError;

            break;
        default:
            goto Sbk_QNetworkProxyQuery_RichComparison_TypeError;
    }

    if (pyResult && !PyErr_Occurred())
        return pyResult;
    Sbk_QNetworkProxyQuery_RichComparison_TypeError:
    PyErr_SetString(PyExc_NotImplementedError, "operator not implemented.");
    return 0;

}

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QNetworkProxyQuery_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtNetwork.QNetworkProxyQuery",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      Sbk_QNetworkProxyQuery_richcompare,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QNetworkProxyQuery_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QNetworkProxyQuery_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QNetworkProxyQuery(PyObject* module)
{
    SbkPySide_QtNetworkTypes[SBK_QNETWORKPROXYQUERY_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QNetworkProxyQuery_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QNetworkProxyQuery_Type);
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QNetworkProxyQuery_Type, &Shiboken::callCppDestructor<QNetworkProxyQuery >);
    if (PyType_Ready((PyTypeObject*)&Sbk_QNetworkProxyQuery_Type) < 0)
        return;

    Shiboken::ObjectType::setOriginalName(&Sbk_QNetworkProxyQuery_Type, "QNetworkProxyQuery");
    PyModule_AddObject(module, "QNetworkProxyQuery",
        ((PyObject*)&Sbk_QNetworkProxyQuery_Type));

    // Initialize enums
    PyObject* enumItem;

    // init enum: QueryType
    PyTypeObject* SbkPySide_QtNetwork_QNetworkProxyQuery_QueryType = Shiboken::Enum::newType("PySide.QtNetwork.QNetworkProxyQuery.QueryType");
    SbkPySide_QtNetworkTypes[SBK_QNETWORKPROXYQUERY_QUERYTYPE_IDX] = SbkPySide_QtNetwork_QNetworkProxyQuery_QueryType;
    if (PyType_Ready(SbkPySide_QtNetwork_QNetworkProxyQuery_QueryType) < 0)
        return;
    PyDict_SetItemString(Sbk_QNetworkProxyQuery_Type.super.ht_type.tp_dict,
            "QueryType",((PyObject*)SbkPySide_QtNetwork_QNetworkProxyQuery_QueryType));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QNetworkProxyQuery_QueryType,(long) QNetworkProxyQuery::TcpSocket, "TcpSocket");
    PyDict_SetItemString(Sbk_QNetworkProxyQuery_Type.super.ht_type.tp_dict,"TcpSocket", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QNetworkProxyQuery_QueryType->tp_dict,"TcpSocket", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QNetworkProxyQuery_QueryType,(long) QNetworkProxyQuery::UdpSocket, "UdpSocket");
    PyDict_SetItemString(Sbk_QNetworkProxyQuery_Type.super.ht_type.tp_dict,"UdpSocket", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QNetworkProxyQuery_QueryType->tp_dict,"UdpSocket", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QNetworkProxyQuery_QueryType,(long) QNetworkProxyQuery::TcpServer, "TcpServer");
    PyDict_SetItemString(Sbk_QNetworkProxyQuery_Type.super.ht_type.tp_dict,"TcpServer", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QNetworkProxyQuery_QueryType->tp_dict,"TcpServer", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QNetworkProxyQuery_QueryType,(long) QNetworkProxyQuery::UrlRequest, "UrlRequest");
    PyDict_SetItemString(Sbk_QNetworkProxyQuery_Type.super.ht_type.tp_dict,"UrlRequest", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QNetworkProxyQuery_QueryType->tp_dict,"UrlRequest", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QNetworkProxyQuery::QueryType");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::QueryType");
    // end of enum QueryType


    Shiboken::TypeResolver::createValueTypeResolver<QNetworkProxyQuery >("QNetworkProxyQuery");
    Shiboken::TypeResolver::createObjectTypeResolver<QNetworkProxyQuery >("QNetworkProxyQuery*");
    Shiboken::TypeResolver::createValueTypeResolver<QNetworkProxyQuery >(typeid(QNetworkProxyQuery).name());
    PySide::initQtMetaType< ::QNetworkProxyQuery >();
    qRegisterMetaType< ::QNetworkProxyQuery::QueryType >("QNetworkProxyQuery::QueryType");
}

