/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


#include <Python.h>
#include <shiboken.h>
#include <algorithm>
#include "pyside_qtnetwork_python.h"



// Extra includes

// Global functions ------------------------------------------------------------

static PyMethodDef QtNetwork_methods[] = {
    {0} // Sentinel
};

// Classes initialization functions ------------------------------------------------------------
void init_QSsl(PyObject* module);
void init_QSslConfiguration(PyObject* module);
void init_QSslError(PyObject* module);
void init_QSslCipher(PyObject* module);
void init_QNetworkProxy(PyObject* module);
void init_QNetworkProxyQuery(PyObject* module);
void init_QNetworkProxyFactory(PyObject* module);
void init_QHostInfo(PyObject* module);
void init_QAuthenticator(PyObject* module);
void init_QNetworkInterface(PyObject* module);
void init_QNetworkAddressEntry(PyObject* module);
void init_QNetworkConfiguration(PyObject* module);
void init_QHostAddress(PyObject* module);
void init_QIPv6Address(PyObject* module);
void init_QHttpHeader(PyObject* module);
void init_QHttpRequestHeader(PyObject* module);
void init_QHttpResponseHeader(PyObject* module);
void init_QUrlInfo(PyObject* module);
void init_QNetworkCacheMetaData(PyObject* module);
void init_QNetworkRequest(PyObject* module);
void init_QLocalSocket(PyObject* module);
void init_QAbstractSocket(PyObject* module);
void init_QUdpSocket(PyObject* module);
void init_QTcpSocket(PyObject* module);
void init_QNetworkReply(PyObject* module);
void init_QFtp(PyObject* module);
void init_QTcpServer(PyObject* module);
void init_QAbstractNetworkCache(PyObject* module);
void init_QNetworkDiskCache(PyObject* module);
void init_QLocalServer(PyObject* module);
void init_QNetworkCookieJar(PyObject* module);
void init_QNetworkSession(PyObject* module);
void init_QNetworkAccessManager(PyObject* module);
void init_QHttp(PyObject* module);
void init_QNetworkConfigurationManager(PyObject* module);
void init_QSslKey(PyObject* module);
void init_QSslSocket(PyObject* module);
void init_QSslCertificate(PyObject* module);
void init_QNetworkCookie(PyObject* module);

PyTypeObject** SbkPySide_QtNetworkTypes;

PyTypeObject** SbkPySide_QtCoreTypes;

// Module initialization ------------------------------------------------------------

#if defined _WIN32 || defined __CYGWIN__
    #define SBK_EXPORT_MODULE __declspec(dllexport)
#elif __GNUC__ >= 4
    #define SBK_EXPORT_MODULE __attribute__ ((visibility("default")))
#else
    #define SBK_EXPORT_MODULE
#endif

extern "C" SBK_EXPORT_MODULE void initQtNetwork()
{
    if (!Shiboken::importModule("PySide.QtCore", &SbkPySide_QtCoreTypes)) {
        PyErr_SetString(PyExc_ImportError,"could not import PySide.QtCore");
        return;
    }

    Shiboken::init();
    PyObject* module = Py_InitModule("QtNetwork", QtNetwork_methods);

    // Create a CObject containing the API pointer array's address
    static PyTypeObject* cppApi[SBK_QtNetwork_IDX_COUNT];
    SbkPySide_QtNetworkTypes = cppApi;
    PyObject* cppApiObject = PyCObject_FromVoidPtr(reinterpret_cast<void*>(cppApi), 0);
    PyModule_AddObject(module, "_Cpp_Api", cppApiObject);

    // Initialize classes in the type system
    init_QSsl(module);
    init_QSslConfiguration(module);
    init_QSslError(module);
    init_QSslCipher(module);
    init_QNetworkProxy(module);
    init_QNetworkProxyQuery(module);
    init_QNetworkProxyFactory(module);
    init_QHostInfo(module);
    init_QAuthenticator(module);
    init_QNetworkInterface(module);
    init_QNetworkAddressEntry(module);
    init_QNetworkConfiguration(module);
    init_QHostAddress(module);
    init_QIPv6Address(module);
    init_QHttpHeader(module);
    init_QHttpRequestHeader(module);
    init_QHttpResponseHeader(module);
    init_QUrlInfo(module);
    init_QNetworkCacheMetaData(module);
    init_QNetworkRequest(module);
    init_QLocalSocket(module);
    init_QAbstractSocket(module);
    init_QUdpSocket(module);
    init_QTcpSocket(module);
    init_QNetworkReply(module);
    init_QFtp(module);
    init_QTcpServer(module);
    init_QAbstractNetworkCache(module);
    init_QNetworkDiskCache(module);
    init_QLocalServer(module);
    init_QNetworkCookieJar(module);
    init_QNetworkSession(module);
    init_QNetworkAccessManager(module);
    init_QHttp(module);
    init_QNetworkConfigurationManager(module);
    init_QSslKey(module);
    init_QSslSocket(module);
    init_QSslCertificate(module);
    init_QNetworkCookie(module);

    // Register primitive types on TypeResolver
    Shiboken::TypeResolver::createValueTypeResolver<QList<QSslError> >("QList<QSslError>");

    if (PyErr_Occurred()) {
        PyErr_Print();
        Py_FatalError("can't initialize module QtNetwork");
    }
}

