/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtopengl_python.h"

#include "qglbuffer_wrapper.h"

// Extra includes
#include <qglbuffer.h>



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QGLBuffer_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QGLBuffer >()))
        return -1;

    QGLBuffer* cptr = 0;
    int overloadId = -1;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QGLBuffer", 0, 1, &(pyargs[0])))
        return -1;

    // Overloaded function decisor
    // 0: QGLBuffer()
    // 1: QGLBuffer(QGLBuffer::Type)
    // 2: QGLBuffer(QGLBuffer)
    if (numArgs == 0) {
        overloadId = 0; // QGLBuffer()
    } else if (numArgs == 1 && Shiboken::Converter< ::QGLBuffer >::isConvertible(pyargs[0])) {
        overloadId = 2; // QGLBuffer(QGLBuffer)
    } else if (numArgs == 1 && Shiboken::Converter< ::QGLBuffer::Type >::isConvertible(pyargs[0])) {
        overloadId = 1; // QGLBuffer(QGLBuffer::Type)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGLBuffer_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QGLBuffer()
            {

                if(!PyErr_Occurred()) {
                    // QGLBuffer()
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QGLBuffer();
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // QGLBuffer(QGLBuffer::Type)
            {
                QGLBuffer::Type cppArg0 = Shiboken::Converter<QGLBuffer::Type >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QGLBuffer(QGLBuffer::Type)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QGLBuffer(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 2: // QGLBuffer(QGLBuffer)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                const QGLBuffer & cppArg0 = Shiboken::Converter<const QGLBuffer & >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QGLBuffer(QGLBuffer)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QGLBuffer(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QGLBuffer >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QGLBuffer_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QGLBuffer_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtOpenGL.QGLBuffer.Type", "PySide.QtOpenGL.QGLBuffer", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtOpenGL.QGLBuffer", overloads);
        return -1;
}

static PyObject* Sbk_QGLBufferFunc_allocate(PyObject* self, PyObject* args, PyObject* kwds)
{
    QGLBuffer* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLBuffer* >::toCpp(self);

    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtOpenGL.QGLBuffer.allocate(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtOpenGL.QGLBuffer.allocate(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:allocate", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: allocate(const void*,int)
    // 1: allocate(int)
    if (numArgs == 1 && SbkNumber_Check(pyargs[0])) {
        overloadId = 1; // allocate(int)
    } else if (Shiboken::Converter< ::QByteArray >::checkType(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // allocate(const void*,int)
        } else if (SbkNumber_Check(pyargs[1])) {
            overloadId = 0; // allocate(const void*,int)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGLBufferFunc_allocate_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // allocate(const void*,int)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "count");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "count";
                        else if (SbkNumber_Check(value))
                            pyargs[1] = value;
                        else
                            goto Sbk_QGLBufferFunc_allocate_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtOpenGL.QGLBuffer.allocate(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QByteArray cppArg0 = Shiboken::Converter<QByteArray >::toCpp(pyargs[0]);
                int cppArg1 = pyargs[1] ? Shiboken::Converter<int >::toCpp(pyargs[1]) : -1;

                if(!PyErr_Occurred()) {
                    // allocate(const void*,int)
                    // Begin code injection

                    int size = cppArg1;
                    if (size < 0)
                        size = cppArg0.size();
                    cppSelf->allocate((const void*) cppArg0.data(), size);

                    // End of code injection


                }
                break;
            }
            case 1: // allocate(int)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // allocate(int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->allocate(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGLBufferFunc_allocate_TypeError:
        const char* overloads[] = {"void, int = -1", "int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtOpenGL.QGLBuffer.allocate", overloads);
        return 0;
}

static PyObject* Sbk_QGLBufferFunc_bind(PyObject* self)
{
    QGLBuffer* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLBuffer* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // bind()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->bind();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGLBufferFunc_bufferId(PyObject* self)
{
    QGLBuffer* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLBuffer* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // bufferId()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                unsigned int cppResult = const_cast<const QGLBuffer*>(cppSelf)->bufferId();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< unsigned int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGLBufferFunc_create(PyObject* self)
{
    QGLBuffer* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLBuffer* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // create()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->create();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGLBufferFunc_destroy(PyObject* self)
{
    QGLBuffer* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLBuffer* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // destroy()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->destroy();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QGLBufferFunc_isCreated(PyObject* self)
{
    QGLBuffer* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLBuffer* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isCreated()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QGLBuffer*>(cppSelf)->isCreated();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGLBufferFunc_map(PyObject* self, PyObject* arg)
{
    QGLBuffer* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLBuffer* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: map(QGLBuffer::Access)
    if (Shiboken::Converter< ::QGLBuffer::Access >::isConvertible(arg)) {
        overloadId = 0; // map(QGLBuffer::Access)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGLBufferFunc_map_TypeError;

    // Call function/method
    {
        {
            QGLBuffer::Access cppArg0 = Shiboken::Converter<QGLBuffer::Access >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // map(QGLBuffer::Access)
                // Begin code injection

                Py_ssize_t dataSize = cppSelf->size();
                void* data = cppSelf->map(cppArg0);

                if (!data) {
                    Py_INCREF(Py_None);
                    pyResult = Py_None;
                } else if (cppArg0 == QGLBuffer::ReadOnly) {
                    pyResult = PyBuffer_FromMemory(data, dataSize);
                } else {
                    pyResult = PyBuffer_FromReadWriteMemory(data, dataSize);
                }

                // End of code injection


            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QGLBufferFunc_map_TypeError:
        const char* overloads[] = {"PySide.QtOpenGL.QGLBuffer.Access", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtOpenGL.QGLBuffer.map", overloads);
        return 0;
}

static PyObject* Sbk_QGLBufferFunc_read(PyObject* self, PyObject* args)
{
    QGLBuffer* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLBuffer* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "read", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: read(int,void*,int)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 0; // read(int,void*,int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGLBufferFunc_read_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // read(int,void*,int)
                // Begin code injection

                char *data = new char[cppArg1];
                bool result = cppSelf->read(cppArg0, data, cppArg1);
                QByteArray ret;
                if (result)
                    ret.append((const char*)data, cppArg1);
                pyResult = Shiboken::makeTuple(result, ret);
                delete[] data;

                // End of code injection


            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QGLBufferFunc_read_TypeError:
        const char* overloads[] = {"int, void, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtOpenGL.QGLBuffer.read", overloads);
        return 0;
}

static PyObject* Sbk_QGLBufferFunc_release(PyObject* self, PyObject* args)
{
    QGLBuffer* cppSelf = 0;
    if (self) {
        if (!Shiboken::Object::isValid(self))
            return 0;
        cppSelf = Shiboken::Converter< QGLBuffer* >::toCpp(self);
    }

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "release", 0, 1, &(pyargs[0])))
        return 0;


    // Overloaded function decisor
    // 0: release()
    // 1: release(QGLBuffer::Type)
    if (numArgs == 0) {
        overloadId = 0; // release()
    } else if (numArgs == 1 && Shiboken::Converter< ::QGLBuffer::Type >::isConvertible(pyargs[0])) {
        overloadId = 1; // release(QGLBuffer::Type)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGLBufferFunc_release_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // release()
            {

                if(!PyErr_Occurred()) {
                    // release()
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->release();
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // release(QGLBuffer::Type)
            {
                QGLBuffer::Type cppArg0 = Shiboken::Converter<QGLBuffer::Type >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // release(QGLBuffer::Type)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QGLBuffer::release(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGLBufferFunc_release_TypeError:
        const char* overloads[] = {"", "PySide.QtOpenGL.QGLBuffer.Type", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtOpenGL.QGLBuffer.release", overloads);
        return 0;
}

static PyObject* Sbk_QGLBufferFunc_setUsagePattern(PyObject* self, PyObject* arg)
{
    QGLBuffer* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLBuffer* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setUsagePattern(QGLBuffer::UsagePattern)
    if (Shiboken::Converter< ::QGLBuffer::UsagePattern >::isConvertible(arg)) {
        overloadId = 0; // setUsagePattern(QGLBuffer::UsagePattern)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGLBufferFunc_setUsagePattern_TypeError;

    // Call function/method
    {
        {
            QGLBuffer::UsagePattern cppArg0 = Shiboken::Converter<QGLBuffer::UsagePattern >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setUsagePattern(QGLBuffer::UsagePattern)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setUsagePattern(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGLBufferFunc_setUsagePattern_TypeError:
        const char* overloads[] = {"PySide.QtOpenGL.QGLBuffer.UsagePattern", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtOpenGL.QGLBuffer.setUsagePattern", overloads);
        return 0;
}

static PyObject* Sbk_QGLBufferFunc_size(PyObject* self)
{
    QGLBuffer* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLBuffer* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // size()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QGLBuffer*>(cppSelf)->size();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGLBufferFunc_type(PyObject* self)
{
    QGLBuffer* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLBuffer* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // type()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QGLBuffer::Type cppResult = const_cast<const QGLBuffer*>(cppSelf)->type();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QGLBuffer::Type >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGLBufferFunc_unmap(PyObject* self)
{
    QGLBuffer* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLBuffer* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // unmap()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->unmap();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGLBufferFunc_usagePattern(PyObject* self)
{
    QGLBuffer* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLBuffer* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // usagePattern()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QGLBuffer::UsagePattern cppResult = const_cast<const QGLBuffer*>(cppSelf)->usagePattern();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QGLBuffer::UsagePattern >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGLBufferFunc_write(PyObject* self, PyObject* args, PyObject* kwds)
{
    QGLBuffer* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLBuffer* >::toCpp(self);

    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtOpenGL.QGLBuffer.write(): too many arguments");
        return 0;
    } else if (numArgs < 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtOpenGL.QGLBuffer.write(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOO:write", &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: write(int,const void*,int)
    if (numArgs >= 2 && SbkNumber_Check(pyargs[0]) && Shiboken::Converter< ::QByteArray >::checkType(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 0; // write(int,const void*,int)
        } else if (SbkNumber_Check(pyargs[2])) {
            overloadId = 0; // write(int,const void*,int)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGLBufferFunc_write_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "count");
                if (value) {
                    if (pyargs[2])
                        errorArgName = "count";
                    else if (SbkNumber_Check(value))
                        pyargs[2] = value;
                    else
                        goto Sbk_QGLBufferFunc_write_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtOpenGL.QGLBuffer.write(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            QByteArray cppArg1 = Shiboken::Converter<QByteArray >::toCpp(pyargs[1]);
            int cppArg2 = pyargs[2] ? Shiboken::Converter<int >::toCpp(pyargs[2]) : -1;

            if(!PyErr_Occurred()) {
                // write(int,const void*,int)
                // Begin code injection

                int size = cppArg2;
                if (size < 0)
                    size = cppArg1.size();
                cppSelf->write(cppArg0, (const void*) cppArg1.data(), size);

                // End of code injection


            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGLBufferFunc_write_TypeError:
        const char* overloads[] = {"int, void, int = -1", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtOpenGL.QGLBuffer.write", overloads);
        return 0;
}

static PyMethodDef Sbk_QGLBufferMethod_release = {
    "release", (PyCFunction)Sbk_QGLBufferFunc_release, METH_VARARGS|METH_STATIC
};

static PyMethodDef Sbk_QGLBuffer_methods[] = {
    {"allocate", (PyCFunction)Sbk_QGLBufferFunc_allocate, METH_VARARGS|METH_KEYWORDS},
    {"bind", (PyCFunction)Sbk_QGLBufferFunc_bind, METH_NOARGS},
    {"bufferId", (PyCFunction)Sbk_QGLBufferFunc_bufferId, METH_NOARGS},
    {"create", (PyCFunction)Sbk_QGLBufferFunc_create, METH_NOARGS},
    {"destroy", (PyCFunction)Sbk_QGLBufferFunc_destroy, METH_NOARGS},
    {"isCreated", (PyCFunction)Sbk_QGLBufferFunc_isCreated, METH_NOARGS},
    {"map", (PyCFunction)Sbk_QGLBufferFunc_map, METH_O},
    {"read", (PyCFunction)Sbk_QGLBufferFunc_read, METH_VARARGS},
    Sbk_QGLBufferMethod_release,
    {"setUsagePattern", (PyCFunction)Sbk_QGLBufferFunc_setUsagePattern, METH_O},
    {"size", (PyCFunction)Sbk_QGLBufferFunc_size, METH_NOARGS},
    {"type", (PyCFunction)Sbk_QGLBufferFunc_type, METH_NOARGS},
    {"unmap", (PyCFunction)Sbk_QGLBufferFunc_unmap, METH_NOARGS},
    {"usagePattern", (PyCFunction)Sbk_QGLBufferFunc_usagePattern, METH_NOARGS},
    {"write", (PyCFunction)Sbk_QGLBufferFunc_write, METH_VARARGS|METH_KEYWORDS},

    {0} // Sentinel
};

static PyObject* Sbk_QGLBuffer_getattro(PyObject* self, PyObject* name)
{
    if (self) {
        if (reinterpret_cast<SbkObject*>(self)->ob_dict) {
            PyObject* meth = PyDict_GetItem(reinterpret_cast<SbkObject*>(self)->ob_dict, name);
            if (meth) {
                Py_INCREF(meth);
                return meth;
            }
        }
        const char* cname = PyString_AS_STRING(name);
        if (strcmp(cname, "release") == 0)
            return PyCFunction_NewEx(&Sbk_QGLBufferMethod_release, self, 0);
    }
    return PyObject_GenericGetAttr(self, name);
}

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QGLBuffer_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtOpenGL.QGLBuffer",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         Sbk_QGLBuffer_getattro,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QGLBuffer_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QGLBuffer_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QGLBuffer(PyObject* module)
{
    SbkPySide_QtOpenGLTypes[SBK_QGLBUFFER_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QGLBuffer_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QGLBuffer_Type);
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QGLBuffer_Type, &Shiboken::callCppDestructor<QGLBuffer >);
    if (PyType_Ready((PyTypeObject*)&Sbk_QGLBuffer_Type) < 0)
        return;

    Shiboken::ObjectType::setOriginalName(&Sbk_QGLBuffer_Type, "QGLBuffer*");
    PyModule_AddObject(module, "QGLBuffer",
        ((PyObject*)&Sbk_QGLBuffer_Type));

    // Initialize enums
    PyObject* enumItem;

    // init enum: Access
    PyTypeObject* SbkPySide_QtOpenGL_QGLBuffer_Access = Shiboken::Enum::newType("PySide.QtOpenGL.QGLBuffer.Access");
    SbkPySide_QtOpenGLTypes[SBK_QGLBUFFER_ACCESS_IDX] = SbkPySide_QtOpenGL_QGLBuffer_Access;
    if (PyType_Ready(SbkPySide_QtOpenGL_QGLBuffer_Access) < 0)
        return;
    PyDict_SetItemString(Sbk_QGLBuffer_Type.super.ht_type.tp_dict,
            "Access",((PyObject*)SbkPySide_QtOpenGL_QGLBuffer_Access));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtOpenGL_QGLBuffer_Access,(long) QGLBuffer::ReadOnly, "ReadOnly");
    PyDict_SetItemString(Sbk_QGLBuffer_Type.super.ht_type.tp_dict,"ReadOnly", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtOpenGL_QGLBuffer_Access->tp_dict,"ReadOnly", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtOpenGL_QGLBuffer_Access,(long) QGLBuffer::WriteOnly, "WriteOnly");
    PyDict_SetItemString(Sbk_QGLBuffer_Type.super.ht_type.tp_dict,"WriteOnly", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtOpenGL_QGLBuffer_Access->tp_dict,"WriteOnly", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtOpenGL_QGLBuffer_Access,(long) QGLBuffer::ReadWrite, "ReadWrite");
    PyDict_SetItemString(Sbk_QGLBuffer_Type.super.ht_type.tp_dict,"ReadWrite", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtOpenGL_QGLBuffer_Access->tp_dict,"ReadWrite", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QGLBuffer::Access");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::Access");
    // end of enum Access

    // init enum: UsagePattern
    PyTypeObject* SbkPySide_QtOpenGL_QGLBuffer_UsagePattern = Shiboken::Enum::newType("PySide.QtOpenGL.QGLBuffer.UsagePattern");
    SbkPySide_QtOpenGLTypes[SBK_QGLBUFFER_USAGEPATTERN_IDX] = SbkPySide_QtOpenGL_QGLBuffer_UsagePattern;
    if (PyType_Ready(SbkPySide_QtOpenGL_QGLBuffer_UsagePattern) < 0)
        return;
    PyDict_SetItemString(Sbk_QGLBuffer_Type.super.ht_type.tp_dict,
            "UsagePattern",((PyObject*)SbkPySide_QtOpenGL_QGLBuffer_UsagePattern));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtOpenGL_QGLBuffer_UsagePattern,(long) QGLBuffer::StreamDraw, "StreamDraw");
    PyDict_SetItemString(Sbk_QGLBuffer_Type.super.ht_type.tp_dict,"StreamDraw", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtOpenGL_QGLBuffer_UsagePattern->tp_dict,"StreamDraw", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtOpenGL_QGLBuffer_UsagePattern,(long) QGLBuffer::StreamRead, "StreamRead");
    PyDict_SetItemString(Sbk_QGLBuffer_Type.super.ht_type.tp_dict,"StreamRead", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtOpenGL_QGLBuffer_UsagePattern->tp_dict,"StreamRead", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtOpenGL_QGLBuffer_UsagePattern,(long) QGLBuffer::StreamCopy, "StreamCopy");
    PyDict_SetItemString(Sbk_QGLBuffer_Type.super.ht_type.tp_dict,"StreamCopy", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtOpenGL_QGLBuffer_UsagePattern->tp_dict,"StreamCopy", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtOpenGL_QGLBuffer_UsagePattern,(long) QGLBuffer::StaticDraw, "StaticDraw");
    PyDict_SetItemString(Sbk_QGLBuffer_Type.super.ht_type.tp_dict,"StaticDraw", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtOpenGL_QGLBuffer_UsagePattern->tp_dict,"StaticDraw", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtOpenGL_QGLBuffer_UsagePattern,(long) QGLBuffer::StaticRead, "StaticRead");
    PyDict_SetItemString(Sbk_QGLBuffer_Type.super.ht_type.tp_dict,"StaticRead", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtOpenGL_QGLBuffer_UsagePattern->tp_dict,"StaticRead", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtOpenGL_QGLBuffer_UsagePattern,(long) QGLBuffer::StaticCopy, "StaticCopy");
    PyDict_SetItemString(Sbk_QGLBuffer_Type.super.ht_type.tp_dict,"StaticCopy", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtOpenGL_QGLBuffer_UsagePattern->tp_dict,"StaticCopy", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtOpenGL_QGLBuffer_UsagePattern,(long) QGLBuffer::DynamicDraw, "DynamicDraw");
    PyDict_SetItemString(Sbk_QGLBuffer_Type.super.ht_type.tp_dict,"DynamicDraw", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtOpenGL_QGLBuffer_UsagePattern->tp_dict,"DynamicDraw", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtOpenGL_QGLBuffer_UsagePattern,(long) QGLBuffer::DynamicRead, "DynamicRead");
    PyDict_SetItemString(Sbk_QGLBuffer_Type.super.ht_type.tp_dict,"DynamicRead", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtOpenGL_QGLBuffer_UsagePattern->tp_dict,"DynamicRead", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtOpenGL_QGLBuffer_UsagePattern,(long) QGLBuffer::DynamicCopy, "DynamicCopy");
    PyDict_SetItemString(Sbk_QGLBuffer_Type.super.ht_type.tp_dict,"DynamicCopy", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtOpenGL_QGLBuffer_UsagePattern->tp_dict,"DynamicCopy", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QGLBuffer::UsagePattern");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::UsagePattern");
    // end of enum UsagePattern

    // init enum: Type
    PyTypeObject* SbkPySide_QtOpenGL_QGLBuffer_Type = Shiboken::Enum::newType("PySide.QtOpenGL.QGLBuffer.Type");
    SbkPySide_QtOpenGLTypes[SBK_QGLBUFFER_TYPE_IDX] = SbkPySide_QtOpenGL_QGLBuffer_Type;
    if (PyType_Ready(SbkPySide_QtOpenGL_QGLBuffer_Type) < 0)
        return;
    PyDict_SetItemString(Sbk_QGLBuffer_Type.super.ht_type.tp_dict,
            "Type",((PyObject*)SbkPySide_QtOpenGL_QGLBuffer_Type));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtOpenGL_QGLBuffer_Type,(long) QGLBuffer::VertexBuffer, "VertexBuffer");
    PyDict_SetItemString(Sbk_QGLBuffer_Type.super.ht_type.tp_dict,"VertexBuffer", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtOpenGL_QGLBuffer_Type->tp_dict,"VertexBuffer", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtOpenGL_QGLBuffer_Type,(long) QGLBuffer::IndexBuffer, "IndexBuffer");
    PyDict_SetItemString(Sbk_QGLBuffer_Type.super.ht_type.tp_dict,"IndexBuffer", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtOpenGL_QGLBuffer_Type->tp_dict,"IndexBuffer", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtOpenGL_QGLBuffer_Type,(long) QGLBuffer::PixelPackBuffer, "PixelPackBuffer");
    PyDict_SetItemString(Sbk_QGLBuffer_Type.super.ht_type.tp_dict,"PixelPackBuffer", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtOpenGL_QGLBuffer_Type->tp_dict,"PixelPackBuffer", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtOpenGL_QGLBuffer_Type,(long) QGLBuffer::PixelUnpackBuffer, "PixelUnpackBuffer");
    PyDict_SetItemString(Sbk_QGLBuffer_Type.super.ht_type.tp_dict,"PixelUnpackBuffer", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtOpenGL_QGLBuffer_Type->tp_dict,"PixelUnpackBuffer", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QGLBuffer::Type");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::Type");
    // end of enum Type


    Shiboken::TypeResolver::createObjectTypeResolver<QGLBuffer >("QGLBuffer*");
    Shiboken::TypeResolver::createObjectTypeResolver<QGLBuffer >(typeid(QGLBuffer).name());
    PySide::initQtMetaType< ::QGLBuffer* >();
    qRegisterMetaType< ::QGLBuffer::Access >("QGLBuffer::Access");
    qRegisterMetaType< ::QGLBuffer::UsagePattern >("QGLBuffer::UsagePattern");
    qRegisterMetaType< ::QGLBuffer::Type >("QGLBuffer::Type");
}

