/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtopengl_python.h"

#include "qglframebufferobject_wrapper.h"

// Extra includes
#include <qglframebufferobject.h>
#include <qimage.h>
#include <qpaintengine.h>
#include <qpoint.h>
#include <qrect.h>
#include <qsize.h>


// Native ---------------------------------------------------------

QGLFramebufferObjectWrapper::QGLFramebufferObjectWrapper(const QSize & size, QGLFramebufferObject::Attachment attachment, unsigned int target, unsigned int internal_format) : QGLFramebufferObject(size, attachment, target, internal_format) {
    // ... middle
}

QGLFramebufferObjectWrapper::QGLFramebufferObjectWrapper(const QSize & size, const QGLFramebufferObjectFormat & format) : QGLFramebufferObject(size, format) {
    // ... middle
}

QGLFramebufferObjectWrapper::QGLFramebufferObjectWrapper(const QSize & size, unsigned int target) : QGLFramebufferObject(size, target) {
    // ... middle
}

QGLFramebufferObjectWrapper::QGLFramebufferObjectWrapper(int width, int height, QGLFramebufferObject::Attachment attachment, unsigned int target, unsigned int internal_format) : QGLFramebufferObject(width, height, attachment, target, internal_format) {
    // ... middle
}

QGLFramebufferObjectWrapper::QGLFramebufferObjectWrapper(int width, int height, const QGLFramebufferObjectFormat & format) : QGLFramebufferObject(width, height, format) {
    // ... middle
}

QGLFramebufferObjectWrapper::QGLFramebufferObjectWrapper(int width, int height, unsigned int target) : QGLFramebufferObject(width, height, target) {
    // ... middle
}

int QGLFramebufferObjectWrapper::devType() const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return int(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "devType"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QGLFramebufferObject::devType();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return int(0);
    }
    // Check return type
    bool typeIsValid = PyInt_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QGLFramebufferObject.devType", "int", pyResult->ob_type->tp_name);
        return int(0);
    }
    int cppResult(Shiboken::Converter< int >::toCpp(pyResult));
    return cppResult;
}

int QGLFramebufferObjectWrapper::metric(QPaintDevice::PaintDeviceMetric metric) const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return int(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "metric"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QGLFramebufferObject::metric(metric);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QPaintDevice::PaintDeviceMetric >::toPython(metric)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return int(0);
    }
    // Check return type
    bool typeIsValid = PyInt_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QGLFramebufferObject.metric", "int", pyResult->ob_type->tp_name);
        return int(0);
    }
    int cppResult(Shiboken::Converter< int >::toCpp(pyResult));
    return cppResult;
}

QPaintEngine * QGLFramebufferObjectWrapper::paintEngine() const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return 0;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "paintEngine"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QGLFramebufferObject::paintEngine();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return 0;
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QPaintEngine * >::isConvertible(pyResult);
    typeIsValid = typeIsValid || (pyResult == Py_None);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QGLFramebufferObject.paintEngine", Shiboken::SbkType<QPaintEngine >()->tp_name, pyResult->ob_type->tp_name);
        return 0;
    }
    QPaintEngine * cppResult(Shiboken::Converter< ::QPaintEngine * >::toCpp(pyResult));
    return cppResult;
}

QGLFramebufferObjectWrapper::~QGLFramebufferObjectWrapper()
{
    SbkObject* wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QGLFramebufferObject_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QGLFramebufferObject >()))
        return -1;

    QGLFramebufferObjectWrapper* cptr = 0;
    int overloadId = -1;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);

    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 5) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtOpenGL.QGLFramebufferObject(): too many arguments");
        return -1;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtOpenGL.QGLFramebufferObject(): not enough arguments");
        return -1;
    }

    if (!PyArg_ParseTuple(args, "|OOOOO:QGLFramebufferObject", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4])))
        return -1;

    // Overloaded function decisor
    // 0: QGLFramebufferObject(QSize,QGLFramebufferObject::Attachment,uint,uint)
    // 1: QGLFramebufferObject(QSize,QGLFramebufferObjectFormat)
    // 2: QGLFramebufferObject(QSize,uint)
    // 3: QGLFramebufferObject(int,int,QGLFramebufferObject::Attachment,uint,uint)
    // 4: QGLFramebufferObject(int,int,QGLFramebufferObjectFormat)
    // 5: QGLFramebufferObject(int,int,uint)
    if (numArgs >= 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 5; // QGLFramebufferObject(int,int,uint)
        } else if (numArgs == 3 && Shiboken::Converter< ::QGLFramebufferObjectFormat >::isConvertible(pyargs[2])) {
            overloadId = 4; // QGLFramebufferObject(int,int,QGLFramebufferObjectFormat)
        } else if (Shiboken::Converter< ::QGLFramebufferObject::Attachment >::isConvertible(pyargs[2])) {
            if (numArgs == 3) {
                overloadId = 3; // QGLFramebufferObject(int,int,QGLFramebufferObject::Attachment,uint,uint)
            } else if (SbkNumber_Check(pyargs[3])) {
                if (numArgs == 4) {
                    overloadId = 3; // QGLFramebufferObject(int,int,QGLFramebufferObject::Attachment,uint,uint)
                } else if (SbkNumber_Check(pyargs[4])) {
                    overloadId = 3; // QGLFramebufferObject(int,int,QGLFramebufferObject::Attachment,uint,uint)
                }
            }
        } else if (SbkNumber_Check(pyargs[2])) {
            overloadId = 5; // QGLFramebufferObject(int,int,uint)
        }
    } else if (Shiboken::Converter< ::QSize >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 2; // QGLFramebufferObject(QSize,uint)
        } else if (numArgs == 2 && Shiboken::Converter< ::QGLFramebufferObjectFormat >::isConvertible(pyargs[1])) {
            overloadId = 1; // QGLFramebufferObject(QSize,QGLFramebufferObjectFormat)
        } else if (Shiboken::Converter< ::QGLFramebufferObject::Attachment >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 0; // QGLFramebufferObject(QSize,QGLFramebufferObject::Attachment,uint,uint)
            } else if (SbkNumber_Check(pyargs[2])) {
                if (numArgs == 3) {
                    overloadId = 0; // QGLFramebufferObject(QSize,QGLFramebufferObject::Attachment,uint,uint)
                } else if (SbkNumber_Check(pyargs[3])) {
                    overloadId = 0; // QGLFramebufferObject(QSize,QGLFramebufferObject::Attachment,uint,uint)
                }
            }
        } else if (SbkNumber_Check(pyargs[1])) {
            overloadId = 2; // QGLFramebufferObject(QSize,uint)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGLFramebufferObject_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QGLFramebufferObject(QSize,QGLFramebufferObject::Attachment,uint,uint)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "target");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "target";
                        else if (SbkNumber_Check(value))
                            pyargs[2] = value;
                        else
                            goto Sbk_QGLFramebufferObject_Init_TypeError;
                    }
                    value = PyDict_GetItemString(kwds, "internal_format");
                    if (value) {
                        if (pyargs[3])
                            errorArgName = "internal_format";
                        else if (SbkNumber_Check(value))
                            pyargs[3] = value;
                        else
                            goto Sbk_QGLFramebufferObject_Init_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtOpenGL.QGLFramebufferObject(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QSize cppArg0 = Shiboken::Converter<QSize >::toCpp(pyargs[0]);
                QGLFramebufferObject::Attachment cppArg1 = Shiboken::Converter<QGLFramebufferObject::Attachment >::toCpp(pyargs[1]);
                unsigned int cppArg2 = pyargs[2] ? Shiboken::Converter<unsigned int >::toCpp(pyargs[2]) : 0x0DE1;
                unsigned int cppArg3 = pyargs[3] ? Shiboken::Converter<unsigned int >::toCpp(pyargs[3]) : 0x8058;

                if(!PyErr_Occurred()) {
                    // QGLFramebufferObject(QSize,QGLFramebufferObject::Attachment,uint,uint)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QGLFramebufferObjectWrapper(cppArg0, cppArg1, cppArg2, cppArg3);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // QGLFramebufferObject(QSize,QGLFramebufferObjectFormat)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QSize cppArg0 = Shiboken::Converter<QSize >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return -1;
                QGLFramebufferObjectFormat cppArg1 = Shiboken::Converter<QGLFramebufferObjectFormat >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // QGLFramebufferObject(QSize,QGLFramebufferObjectFormat)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QGLFramebufferObjectWrapper(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 2: // QGLFramebufferObject(QSize,uint)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "target");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "target";
                        else if (SbkNumber_Check(value))
                            pyargs[1] = value;
                        else
                            goto Sbk_QGLFramebufferObject_Init_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtOpenGL.QGLFramebufferObject(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QSize cppArg0 = Shiboken::Converter<QSize >::toCpp(pyargs[0]);
                unsigned int cppArg1 = pyargs[1] ? Shiboken::Converter<unsigned int >::toCpp(pyargs[1]) : 0x0DE1;

                if(!PyErr_Occurred()) {
                    // QGLFramebufferObject(QSize,uint)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QGLFramebufferObjectWrapper(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 3: // QGLFramebufferObject(int,int,QGLFramebufferObject::Attachment,uint,uint)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "target");
                    if (value) {
                        if (pyargs[3])
                            errorArgName = "target";
                        else if (SbkNumber_Check(value))
                            pyargs[3] = value;
                        else
                            goto Sbk_QGLFramebufferObject_Init_TypeError;
                    }
                    value = PyDict_GetItemString(kwds, "internal_format");
                    if (value) {
                        if (pyargs[4])
                            errorArgName = "internal_format";
                        else if (SbkNumber_Check(value))
                            pyargs[4] = value;
                        else
                            goto Sbk_QGLFramebufferObject_Init_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtOpenGL.QGLFramebufferObject(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                QGLFramebufferObject::Attachment cppArg2 = Shiboken::Converter<QGLFramebufferObject::Attachment >::toCpp(pyargs[2]);
                unsigned int cppArg3 = pyargs[3] ? Shiboken::Converter<unsigned int >::toCpp(pyargs[3]) : 0x0DE1;
                unsigned int cppArg4 = pyargs[4] ? Shiboken::Converter<unsigned int >::toCpp(pyargs[4]) : 0x8058;

                if(!PyErr_Occurred()) {
                    // QGLFramebufferObject(int,int,QGLFramebufferObject::Attachment,uint,uint)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QGLFramebufferObjectWrapper(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 4: // QGLFramebufferObject(int,int,QGLFramebufferObjectFormat)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                if (!Shiboken::Object::isValid(pyargs[2]))
                    return -1;
                QGLFramebufferObjectFormat cppArg2 = Shiboken::Converter<QGLFramebufferObjectFormat >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                    // QGLFramebufferObject(int,int,QGLFramebufferObjectFormat)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QGLFramebufferObjectWrapper(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 5: // QGLFramebufferObject(int,int,uint)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "target");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "target";
                        else if (SbkNumber_Check(value))
                            pyargs[2] = value;
                        else
                            goto Sbk_QGLFramebufferObject_Init_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtOpenGL.QGLFramebufferObject(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                unsigned int cppArg2 = pyargs[2] ? Shiboken::Converter<unsigned int >::toCpp(pyargs[2]) : 0x0DE1;

                if(!PyErr_Occurred()) {
                    // QGLFramebufferObject(int,int,uint)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QGLFramebufferObjectWrapper(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QGLFramebufferObject >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QGLFramebufferObject_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QGLFramebufferObject_Init_TypeError:
        const char* overloads[] = {"PySide.QtCore.QSize, PySide.QtOpenGL.QGLFramebufferObject.Attachment, unsigned int = 0x0DE1, unsigned int = 0x8058", "PySide.QtCore.QSize, PySide.QtOpenGL.QGLFramebufferObjectFormat", "PySide.QtCore.QSize, unsigned int = 0x0DE1", "int, int, PySide.QtOpenGL.QGLFramebufferObject.Attachment, unsigned int = 0x0DE1, unsigned int = 0x8058", "int, int, PySide.QtOpenGL.QGLFramebufferObjectFormat", "int, int, unsigned int = 0x0DE1", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtOpenGL.QGLFramebufferObject", overloads);
        return -1;
}

static PyObject* Sbk_QGLFramebufferObjectFunc_attachment(PyObject* self)
{
    QGLFramebufferObject* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLFramebufferObject* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // attachment()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QGLFramebufferObject::Attachment cppResult = const_cast<const QGLFramebufferObject*>(cppSelf)->attachment();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QGLFramebufferObject::Attachment >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGLFramebufferObjectFunc_bind(PyObject* self)
{
    QGLFramebufferObject* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLFramebufferObject* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // bind()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->bind();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGLFramebufferObjectFunc_bindDefault(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // bindDefault()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = QGLFramebufferObject::bindDefault();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGLFramebufferObjectFunc_blitFramebuffer(PyObject* self, PyObject* args, PyObject* kwds)
{
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 6) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtOpenGL.QGLFramebufferObject.blitFramebuffer(): too many arguments");
        return 0;
    } else if (numArgs < 4) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtOpenGL.QGLFramebufferObject.blitFramebuffer(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOOOOO:blitFramebuffer", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4]), &(pyargs[5])))
        return 0;


    // Overloaded function decisor
    // 0: blitFramebuffer(QGLFramebufferObject*,QRect,QGLFramebufferObject*,QRect,uint,uint)
    if (numArgs >= 4 && Shiboken::Converter< ::QGLFramebufferObject * >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QRect >::isConvertible(pyargs[1]) && Shiboken::Converter< ::QGLFramebufferObject * >::isConvertible(pyargs[2]) && Shiboken::Converter< ::QRect >::isConvertible(pyargs[3])) {
        if (numArgs == 4) {
            overloadId = 0; // blitFramebuffer(QGLFramebufferObject*,QRect,QGLFramebufferObject*,QRect,uint,uint)
        } else if (SbkNumber_Check(pyargs[4])) {
            if (numArgs == 5) {
                overloadId = 0; // blitFramebuffer(QGLFramebufferObject*,QRect,QGLFramebufferObject*,QRect,uint,uint)
            } else if (SbkNumber_Check(pyargs[5])) {
                overloadId = 0; // blitFramebuffer(QGLFramebufferObject*,QRect,QGLFramebufferObject*,QRect,uint,uint)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGLFramebufferObjectFunc_blitFramebuffer_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "buffers");
                if (value) {
                    if (pyargs[4])
                        errorArgName = "buffers";
                    else if (SbkNumber_Check(value))
                        pyargs[4] = value;
                    else
                        goto Sbk_QGLFramebufferObjectFunc_blitFramebuffer_TypeError;
                }
                value = PyDict_GetItemString(kwds, "filter");
                if (value) {
                    if (pyargs[5])
                        errorArgName = "filter";
                    else if (SbkNumber_Check(value))
                        pyargs[5] = value;
                    else
                        goto Sbk_QGLFramebufferObjectFunc_blitFramebuffer_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtOpenGL.QGLFramebufferObject.blitFramebuffer(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QGLFramebufferObject * cppArg0 = Shiboken::Converter<QGLFramebufferObject * >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            QRect cppArg1 = Shiboken::Converter<QRect >::toCpp(pyargs[1]);
            if (!Shiboken::Object::isValid(pyargs[2]))
                return 0;
            QGLFramebufferObject * cppArg2 = Shiboken::Converter<QGLFramebufferObject * >::toCpp(pyargs[2]);
            if (!Shiboken::Object::isValid(pyargs[3]))
                return 0;
            QRect cppArg3 = Shiboken::Converter<QRect >::toCpp(pyargs[3]);
            unsigned int cppArg4 = pyargs[4] ? Shiboken::Converter<unsigned int >::toCpp(pyargs[4]) : 0x00004000;
            unsigned int cppArg5 = pyargs[5] ? Shiboken::Converter<unsigned int >::toCpp(pyargs[5]) : 0x2600;

            if(!PyErr_Occurred()) {
                // blitFramebuffer(QGLFramebufferObject*,QRect,QGLFramebufferObject*,QRect,uint,uint)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QGLFramebufferObject::blitFramebuffer(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGLFramebufferObjectFunc_blitFramebuffer_TypeError:
        const char* overloads[] = {"PySide.QtOpenGL.QGLFramebufferObject, PySide.QtCore.QRect, PySide.QtOpenGL.QGLFramebufferObject, PySide.QtCore.QRect, unsigned int = 0x00004000, unsigned int = 0x2600", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtOpenGL.QGLFramebufferObject.blitFramebuffer", overloads);
        return 0;
}

static PyObject* Sbk_QGLFramebufferObjectFunc_devType(PyObject* self)
{
    QGLFramebufferObject* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLFramebufferObject* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // devType()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = (Shiboken::Object::isUserType(self) ? const_cast<const QGLFramebufferObject*>(cppSelf)->::QGLFramebufferObject::devType() : const_cast<const QGLFramebufferObject*>(cppSelf)->devType());
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGLFramebufferObjectFunc_drawTexture(PyObject* self, PyObject* args, PyObject* kwds)
{
    QGLFramebufferObject* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLFramebufferObject* >::toCpp(self);

    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtOpenGL.QGLFramebufferObject.drawTexture(): too many arguments");
        return 0;
    } else if (numArgs < 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtOpenGL.QGLFramebufferObject.drawTexture(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOO:drawTexture", &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: drawTexture(QPointF,uint,uint)
    // 1: drawTexture(QRectF,uint,uint)
    if (numArgs >= 2 && Shiboken::Converter< ::QRectF >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 1; // drawTexture(QRectF,uint,uint)
        } else if (SbkNumber_Check(pyargs[2])) {
            overloadId = 1; // drawTexture(QRectF,uint,uint)
        }
    } else if (numArgs >= 2 && Shiboken::Converter< ::QPointF >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 0; // drawTexture(QPointF,uint,uint)
        } else if (SbkNumber_Check(pyargs[2])) {
            overloadId = 0; // drawTexture(QPointF,uint,uint)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGLFramebufferObjectFunc_drawTexture_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // drawTexture(QPointF,uint,uint)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "textureTarget");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "textureTarget";
                        else if (SbkNumber_Check(value))
                            pyargs[2] = value;
                        else
                            goto Sbk_QGLFramebufferObjectFunc_drawTexture_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtOpenGL.QGLFramebufferObject.drawTexture(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QPointF cppArg0 = Shiboken::Converter<QPointF >::toCpp(pyargs[0]);
                unsigned int cppArg1 = Shiboken::Converter<unsigned int >::toCpp(pyargs[1]);
                unsigned int cppArg2 = pyargs[2] ? Shiboken::Converter<unsigned int >::toCpp(pyargs[2]) : 0x0DE1;

                if(!PyErr_Occurred()) {
                    // drawTexture(QPointF,uint,uint)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->drawTexture(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // drawTexture(QRectF,uint,uint)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "textureTarget");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "textureTarget";
                        else if (SbkNumber_Check(value))
                            pyargs[2] = value;
                        else
                            goto Sbk_QGLFramebufferObjectFunc_drawTexture_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtOpenGL.QGLFramebufferObject.drawTexture(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QRectF cppArg0 = Shiboken::Converter<QRectF >::toCpp(pyargs[0]);
                unsigned int cppArg1 = Shiboken::Converter<unsigned int >::toCpp(pyargs[1]);
                unsigned int cppArg2 = pyargs[2] ? Shiboken::Converter<unsigned int >::toCpp(pyargs[2]) : 0x0DE1;

                if(!PyErr_Occurred()) {
                    // drawTexture(QRectF,uint,uint)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->drawTexture(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGLFramebufferObjectFunc_drawTexture_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPointF, unsigned int, unsigned int = 0x0DE1", "PySide.QtCore.QRectF, unsigned int, unsigned int = 0x0DE1", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtOpenGL.QGLFramebufferObject.drawTexture", overloads);
        return 0;
}

static PyObject* Sbk_QGLFramebufferObjectFunc_format(PyObject* self)
{
    QGLFramebufferObject* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLFramebufferObject* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // format()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QGLFramebufferObjectFormat cppResult = const_cast<const QGLFramebufferObject*>(cppSelf)->format();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QGLFramebufferObjectFormat >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGLFramebufferObjectFunc_handle(PyObject* self)
{
    QGLFramebufferObject* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLFramebufferObject* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // handle()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                unsigned int cppResult = const_cast<const QGLFramebufferObject*>(cppSelf)->handle();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< unsigned int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGLFramebufferObjectFunc_hasOpenGLFramebufferBlit(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // hasOpenGLFramebufferBlit()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = QGLFramebufferObject::hasOpenGLFramebufferBlit();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGLFramebufferObjectFunc_hasOpenGLFramebufferObjects(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // hasOpenGLFramebufferObjects()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = QGLFramebufferObject::hasOpenGLFramebufferObjects();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGLFramebufferObjectFunc_isBound(PyObject* self)
{
    QGLFramebufferObject* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLFramebufferObject* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isBound()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QGLFramebufferObject*>(cppSelf)->isBound();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGLFramebufferObjectFunc_isValid(PyObject* self)
{
    QGLFramebufferObject* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLFramebufferObject* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isValid()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QGLFramebufferObject*>(cppSelf)->isValid();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGLFramebufferObjectFunc_metric(PyObject* self, PyObject* arg)
{
    QGLFramebufferObject* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLFramebufferObject* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: metric(QPaintDevice::PaintDeviceMetric)const
    if (Shiboken::Converter< ::QPaintDevice::PaintDeviceMetric >::isConvertible(arg)) {
        overloadId = 0; // metric(QPaintDevice::PaintDeviceMetric)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGLFramebufferObjectFunc_metric_TypeError;

    // Call function/method
    {
        {
            QPaintDevice::PaintDeviceMetric cppArg0 = Shiboken::Converter<QPaintDevice::PaintDeviceMetric >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // metric(QPaintDevice::PaintDeviceMetric)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = (Shiboken::Object::isUserType(self) ? const_cast<const QGLFramebufferObject*>(cppSelf)->::QGLFramebufferObject::metric(cppArg0) : const_cast<const QGLFramebufferObject*>(cppSelf)->metric(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QGLFramebufferObjectFunc_metric_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPaintDevice.PaintDeviceMetric", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtOpenGL.QGLFramebufferObject.metric", overloads);
        return 0;
}

static PyObject* Sbk_QGLFramebufferObjectFunc_paintEngine(PyObject* self)
{
    QGLFramebufferObject* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLFramebufferObject* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // paintEngine()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QPaintEngine * cppResult = (Shiboken::Object::isUserType(self) ? const_cast<const QGLFramebufferObject*>(cppSelf)->::QGLFramebufferObject::paintEngine() : const_cast<const QGLFramebufferObject*>(cppSelf)->paintEngine());
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QPaintEngine * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGLFramebufferObjectFunc_release(PyObject* self)
{
    QGLFramebufferObject* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLFramebufferObject* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // release()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->release();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGLFramebufferObjectFunc_size(PyObject* self)
{
    QGLFramebufferObject* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLFramebufferObject* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // size()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QSize cppResult = const_cast<const QGLFramebufferObject*>(cppSelf)->size();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QSize >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGLFramebufferObjectFunc_texture(PyObject* self)
{
    QGLFramebufferObject* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLFramebufferObject* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // texture()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                unsigned int cppResult = const_cast<const QGLFramebufferObject*>(cppSelf)->texture();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< unsigned int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGLFramebufferObjectFunc_toImage(PyObject* self)
{
    QGLFramebufferObject* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLFramebufferObject* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // toImage()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QImage cppResult = const_cast<const QGLFramebufferObject*>(cppSelf)->toImage();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QImage >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef Sbk_QGLFramebufferObject_methods[] = {
    {"attachment", (PyCFunction)Sbk_QGLFramebufferObjectFunc_attachment, METH_NOARGS},
    {"bind", (PyCFunction)Sbk_QGLFramebufferObjectFunc_bind, METH_NOARGS},
    {"bindDefault", (PyCFunction)Sbk_QGLFramebufferObjectFunc_bindDefault, METH_NOARGS|METH_STATIC},
    {"blitFramebuffer", (PyCFunction)Sbk_QGLFramebufferObjectFunc_blitFramebuffer, METH_VARARGS|METH_KEYWORDS|METH_STATIC},
    {"devType", (PyCFunction)Sbk_QGLFramebufferObjectFunc_devType, METH_NOARGS},
    {"drawTexture", (PyCFunction)Sbk_QGLFramebufferObjectFunc_drawTexture, METH_VARARGS|METH_KEYWORDS},
    {"format", (PyCFunction)Sbk_QGLFramebufferObjectFunc_format, METH_NOARGS},
    {"handle", (PyCFunction)Sbk_QGLFramebufferObjectFunc_handle, METH_NOARGS},
    {"hasOpenGLFramebufferBlit", (PyCFunction)Sbk_QGLFramebufferObjectFunc_hasOpenGLFramebufferBlit, METH_NOARGS|METH_STATIC},
    {"hasOpenGLFramebufferObjects", (PyCFunction)Sbk_QGLFramebufferObjectFunc_hasOpenGLFramebufferObjects, METH_NOARGS|METH_STATIC},
    {"isBound", (PyCFunction)Sbk_QGLFramebufferObjectFunc_isBound, METH_NOARGS},
    {"isValid", (PyCFunction)Sbk_QGLFramebufferObjectFunc_isValid, METH_NOARGS},
    {"metric", (PyCFunction)Sbk_QGLFramebufferObjectFunc_metric, METH_O},
    {"paintEngine", (PyCFunction)Sbk_QGLFramebufferObjectFunc_paintEngine, METH_NOARGS},
    {"release", (PyCFunction)Sbk_QGLFramebufferObjectFunc_release, METH_NOARGS},
    {"size", (PyCFunction)Sbk_QGLFramebufferObjectFunc_size, METH_NOARGS},
    {"texture", (PyCFunction)Sbk_QGLFramebufferObjectFunc_texture, METH_NOARGS},
    {"toImage", (PyCFunction)Sbk_QGLFramebufferObjectFunc_toImage, METH_NOARGS},

    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QGLFramebufferObject_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtOpenGL.QGLFramebufferObject",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QGLFramebufferObject_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QGLFramebufferObject_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern

static SbkObjectType* Sbk_QGLFramebufferObject_typeDiscovery(void* cptr, SbkObjectType* instanceType)
{
    if (instanceType == reinterpret_cast<SbkObjectType*>(Shiboken::SbkType<QPaintDevice >()) && dynamic_cast<QGLFramebufferObject*>(reinterpret_cast<QPaintDevice*>(cptr)))
        return &Sbk_QGLFramebufferObject_Type;
    return 0;
}


void init_QGLFramebufferObject(PyObject* module)
{
    SbkPySide_QtOpenGLTypes[SBK_QGLFRAMEBUFFEROBJECT_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QGLFramebufferObject_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QGLFramebufferObject_Type);
    Sbk_QGLFramebufferObject_Type.super.ht_type.tp_base = SbkPySide_QtGuiTypes[SBK_QPAINTDEVICE_IDX];
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QGLFramebufferObject_Type, &Shiboken::callCppDestructor<QGLFramebufferObject >);
    if (PyType_Ready((PyTypeObject*)&Sbk_QGLFramebufferObject_Type) < 0)
        return;

    // Fill type discovery information
    Shiboken::ObjectType::setTypeDiscoveryFunction(&Sbk_QGLFramebufferObject_Type, &Sbk_QGLFramebufferObject_typeDiscovery);
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkObjectType*>(SbkPySide_QtGuiTypes[SBK_QPAINTDEVICE_IDX]), &Sbk_QGLFramebufferObject_Type);

    Shiboken::ObjectType::setOriginalName(&Sbk_QGLFramebufferObject_Type, "QGLFramebufferObject*");
    PyModule_AddObject(module, "QGLFramebufferObject",
        ((PyObject*)&Sbk_QGLFramebufferObject_Type));

    // Initialize enums
    PyObject* enumItem;

    // init enum: Attachment
    PyTypeObject* SbkPySide_QtOpenGL_QGLFramebufferObject_Attachment = Shiboken::Enum::newType("PySide.QtOpenGL.QGLFramebufferObject.Attachment");
    SbkPySide_QtOpenGLTypes[SBK_QGLFRAMEBUFFEROBJECT_ATTACHMENT_IDX] = SbkPySide_QtOpenGL_QGLFramebufferObject_Attachment;
    if (PyType_Ready(SbkPySide_QtOpenGL_QGLFramebufferObject_Attachment) < 0)
        return;
    PyDict_SetItemString(Sbk_QGLFramebufferObject_Type.super.ht_type.tp_dict,
            "Attachment",((PyObject*)SbkPySide_QtOpenGL_QGLFramebufferObject_Attachment));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtOpenGL_QGLFramebufferObject_Attachment,(long) QGLFramebufferObject::NoAttachment, "NoAttachment");
    PyDict_SetItemString(Sbk_QGLFramebufferObject_Type.super.ht_type.tp_dict,"NoAttachment", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtOpenGL_QGLFramebufferObject_Attachment->tp_dict,"NoAttachment", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtOpenGL_QGLFramebufferObject_Attachment,(long) QGLFramebufferObject::CombinedDepthStencil, "CombinedDepthStencil");
    PyDict_SetItemString(Sbk_QGLFramebufferObject_Type.super.ht_type.tp_dict,"CombinedDepthStencil", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtOpenGL_QGLFramebufferObject_Attachment->tp_dict,"CombinedDepthStencil", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtOpenGL_QGLFramebufferObject_Attachment,(long) QGLFramebufferObject::Depth, "Depth");
    PyDict_SetItemString(Sbk_QGLFramebufferObject_Type.super.ht_type.tp_dict,"Depth", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtOpenGL_QGLFramebufferObject_Attachment->tp_dict,"Depth", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QGLFramebufferObject::Attachment");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::Attachment");
    // end of enum Attachment


    Shiboken::TypeResolver::createObjectTypeResolver<QGLFramebufferObject >("QGLFramebufferObject*");
    Shiboken::TypeResolver::createObjectTypeResolver<QGLFramebufferObject >(typeid(QGLFramebufferObject).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QGLFramebufferObject >(typeid(QGLFramebufferObjectWrapper).name());
    PySide::initQtMetaType< ::QGLFramebufferObject* >();
    qRegisterMetaType< ::QGLFramebufferObject::Attachment >("QGLFramebufferObject::Attachment");
}

