/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtscript_python.h"

#include "qscriptclasspropertyiterator_wrapper.h"

// Extra includes
#include <qscriptclasspropertyiterator.h>
#include <qscriptstring.h>
#include <qscriptvalue.h>


// Native ---------------------------------------------------------

QScriptClassPropertyIteratorWrapper::QScriptClassPropertyIteratorWrapper(const QScriptValue & object) : QScriptClassPropertyIterator(object) {
    // ... middle
}

QFlags<QScriptValue::PropertyFlag> QScriptClassPropertyIteratorWrapper::flags() const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return QFlags<QScriptValue::PropertyFlag>();
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "flags"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QScriptClassPropertyIterator::flags();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QFlags<QScriptValue::PropertyFlag>();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QFlags<QScriptValue::PropertyFlag> >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QScriptClassPropertyIterator.flags", Shiboken::SbkType<QFlags<QScriptValue::PropertyFlag> >()->tp_name, pyResult->ob_type->tp_name);
        return QFlags<QScriptValue::PropertyFlag>();
    }
    QFlags<QScriptValue::PropertyFlag> cppResult(Shiboken::Converter< ::QFlags<QScriptValue::PropertyFlag> >::toCpp(pyResult));
    return cppResult;
}

bool QScriptClassPropertyIteratorWrapper::hasNext() const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return bool(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "hasNext"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QScriptClassPropertyIterator.hasNext()' not implemented.");
        return bool(0);
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QScriptClassPropertyIterator.hasNext", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    return cppResult;
}

bool QScriptClassPropertyIteratorWrapper::hasPrevious() const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return bool(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "hasPrevious"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QScriptClassPropertyIterator.hasPrevious()' not implemented.");
        return bool(0);
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QScriptClassPropertyIterator.hasPrevious", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    return cppResult;
}

uint QScriptClassPropertyIteratorWrapper::id() const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return uint(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "id"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QScriptClassPropertyIterator::id();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return uint(0);
    }
    // Check return type
    bool typeIsValid = PyInt_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QScriptClassPropertyIterator.id", "uint", pyResult->ob_type->tp_name);
        return uint(0);
    }
    uint cppResult(Shiboken::Converter< unsigned int >::toCpp(pyResult));
    return cppResult;
}

QScriptString QScriptClassPropertyIteratorWrapper::name() const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return QScriptString();
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "name"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QScriptClassPropertyIterator.name()' not implemented.");
        return QScriptString();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QScriptString();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QScriptString >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QScriptClassPropertyIterator.name", Shiboken::SbkType<QScriptString >()->tp_name, pyResult->ob_type->tp_name);
        return QScriptString();
    }
    QScriptString cppResult(Shiboken::Converter< ::QScriptString >::toCpp(pyResult));
    return cppResult;
}

void QScriptClassPropertyIteratorWrapper::next()
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "next"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QScriptClassPropertyIterator.next()' not implemented.");
        return ;
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QScriptClassPropertyIteratorWrapper::previous()
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "previous"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QScriptClassPropertyIterator.previous()' not implemented.");
        return ;
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QScriptClassPropertyIteratorWrapper::toBack()
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "toBack"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QScriptClassPropertyIterator.toBack()' not implemented.");
        return ;
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QScriptClassPropertyIteratorWrapper::toFront()
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "toFront"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QScriptClassPropertyIterator.toFront()' not implemented.");
        return ;
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

QScriptClassPropertyIteratorWrapper::~QScriptClassPropertyIteratorWrapper()
{
    SbkObject* wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QScriptClassPropertyIterator_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QScriptClassPropertyIterator >()))
        return -1;

    QScriptClassPropertyIteratorWrapper* cptr = 0;
    int overloadId = -1;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);
    SbkObjectType* type = reinterpret_cast<SbkObjectType*>(self->ob_type);
    SbkObjectType* myType = reinterpret_cast<SbkObjectType*>(SbkPySide_QtScriptTypes[SBK_QSCRIPTCLASSPROPERTYITERATOR_IDX]);
    if (type == myType) {
        PyErr_SetString(PyExc_NotImplementedError,
            "'QScriptClassPropertyIterator' represents a C++ abstract class and cannot be instantiated");
        return -1;
    }



    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QScriptClassPropertyIterator", 1, 1, &(pyargs[0])))
        return -1;

    // Overloaded function decisor
    // 0: QScriptClassPropertyIterator(QScriptValue)
    if (numArgs == 1 && Shiboken::Converter< ::QScriptValue >::isConvertible(pyargs[0])) {
        overloadId = 0; // QScriptClassPropertyIterator(QScriptValue)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QScriptClassPropertyIterator_Init_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(pyargs[0]))
                return -1;
            QScriptValue cppArg0 = Shiboken::Converter<QScriptValue >::toCpp(pyargs[0]);

            if(!PyErr_Occurred()) {
                // QScriptClassPropertyIterator(QScriptValue)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new QScriptClassPropertyIteratorWrapper(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QScriptClassPropertyIterator >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QScriptClassPropertyIterator_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QScriptClassPropertyIterator_Init_TypeError:
        const char* overloads[] = {"PySide.QtScript.QScriptValue", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtScript.QScriptClassPropertyIterator", overloads);
        return -1;
}

static PyObject* Sbk_QScriptClassPropertyIteratorFunc_flags(PyObject* self)
{
    QScriptClassPropertyIterator* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QScriptClassPropertyIterator* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // flags()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QFlags<QScriptValue::PropertyFlag> cppResult = (Shiboken::Object::isUserType(self) ? const_cast<const QScriptClassPropertyIterator*>(cppSelf)->::QScriptClassPropertyIterator::flags() : const_cast<const QScriptClassPropertyIterator*>(cppSelf)->flags());
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QFlags<QScriptValue::PropertyFlag> >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QScriptClassPropertyIteratorFunc_hasNext(PyObject* self)
{
    QScriptClassPropertyIterator* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QScriptClassPropertyIterator* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // hasNext()const
                if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self))) {
                    PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QScriptClassPropertyIterator.hasNext()' not implemented.");
                    return 0;
                }
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QScriptClassPropertyIterator*>(cppSelf)->hasNext();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QScriptClassPropertyIteratorFunc_hasPrevious(PyObject* self)
{
    QScriptClassPropertyIterator* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QScriptClassPropertyIterator* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // hasPrevious()const
                if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self))) {
                    PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QScriptClassPropertyIterator.hasPrevious()' not implemented.");
                    return 0;
                }
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QScriptClassPropertyIterator*>(cppSelf)->hasPrevious();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QScriptClassPropertyIteratorFunc_id(PyObject* self)
{
    QScriptClassPropertyIterator* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QScriptClassPropertyIterator* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // id()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                uint cppResult = (Shiboken::Object::isUserType(self) ? const_cast<const QScriptClassPropertyIterator*>(cppSelf)->::QScriptClassPropertyIterator::id() : const_cast<const QScriptClassPropertyIterator*>(cppSelf)->id());
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< unsigned int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QScriptClassPropertyIteratorFunc_name(PyObject* self)
{
    QScriptClassPropertyIterator* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QScriptClassPropertyIterator* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // name()const
                if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self))) {
                    PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QScriptClassPropertyIterator.name()' not implemented.");
                    return 0;
                }
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QScriptString cppResult = const_cast<const QScriptClassPropertyIterator*>(cppSelf)->name();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QScriptString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QScriptClassPropertyIteratorFunc_next(PyObject* self)
{
    QScriptClassPropertyIterator* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QScriptClassPropertyIterator* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // next()
                if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self))) {
                    PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QScriptClassPropertyIterator.next()' not implemented.");
                    return 0;
                }
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->next();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QScriptClassPropertyIteratorFunc_object(PyObject* self)
{
    QScriptClassPropertyIterator* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QScriptClassPropertyIterator* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // object()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QScriptValue cppResult = const_cast<const QScriptClassPropertyIterator*>(cppSelf)->object();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QScriptValue >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QScriptClassPropertyIteratorFunc_previous(PyObject* self)
{
    QScriptClassPropertyIterator* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QScriptClassPropertyIterator* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // previous()
                if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self))) {
                    PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QScriptClassPropertyIterator.previous()' not implemented.");
                    return 0;
                }
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->previous();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QScriptClassPropertyIteratorFunc_toBack(PyObject* self)
{
    QScriptClassPropertyIterator* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QScriptClassPropertyIterator* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // toBack()
                if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self))) {
                    PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QScriptClassPropertyIterator.toBack()' not implemented.");
                    return 0;
                }
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->toBack();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QScriptClassPropertyIteratorFunc_toFront(PyObject* self)
{
    QScriptClassPropertyIterator* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QScriptClassPropertyIterator* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // toFront()
                if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self))) {
                    PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QScriptClassPropertyIterator.toFront()' not implemented.");
                    return 0;
                }
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->toFront();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyMethodDef Sbk_QScriptClassPropertyIterator_methods[] = {
    {"flags", (PyCFunction)Sbk_QScriptClassPropertyIteratorFunc_flags, METH_NOARGS},
    {"hasNext", (PyCFunction)Sbk_QScriptClassPropertyIteratorFunc_hasNext, METH_NOARGS},
    {"hasPrevious", (PyCFunction)Sbk_QScriptClassPropertyIteratorFunc_hasPrevious, METH_NOARGS},
    {"id", (PyCFunction)Sbk_QScriptClassPropertyIteratorFunc_id, METH_NOARGS},
    {"name", (PyCFunction)Sbk_QScriptClassPropertyIteratorFunc_name, METH_NOARGS},
    {"next", (PyCFunction)Sbk_QScriptClassPropertyIteratorFunc_next, METH_NOARGS},
    {"object", (PyCFunction)Sbk_QScriptClassPropertyIteratorFunc_object, METH_NOARGS},
    {"previous", (PyCFunction)Sbk_QScriptClassPropertyIteratorFunc_previous, METH_NOARGS},
    {"toBack", (PyCFunction)Sbk_QScriptClassPropertyIteratorFunc_toBack, METH_NOARGS},
    {"toFront", (PyCFunction)Sbk_QScriptClassPropertyIteratorFunc_toFront, METH_NOARGS},

    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QScriptClassPropertyIterator_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtScript.QScriptClassPropertyIterator",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QScriptClassPropertyIterator_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QScriptClassPropertyIterator_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QScriptClassPropertyIterator(PyObject* module)
{
    SbkPySide_QtScriptTypes[SBK_QSCRIPTCLASSPROPERTYITERATOR_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QScriptClassPropertyIterator_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QScriptClassPropertyIterator_Type);
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QScriptClassPropertyIterator_Type, &Shiboken::callCppDestructor<QScriptClassPropertyIterator >);
    if (PyType_Ready((PyTypeObject*)&Sbk_QScriptClassPropertyIterator_Type) < 0)
        return;

    // Fill type discovery information

    Shiboken::ObjectType::setOriginalName(&Sbk_QScriptClassPropertyIterator_Type, "QScriptClassPropertyIterator*");
    PyModule_AddObject(module, "QScriptClassPropertyIterator",
        ((PyObject*)&Sbk_QScriptClassPropertyIterator_Type));


    Shiboken::TypeResolver::createObjectTypeResolver<QScriptClassPropertyIterator >("QScriptClassPropertyIterator*");
    Shiboken::TypeResolver::createObjectTypeResolver<QScriptClassPropertyIterator >("QScriptClassPropertyIterator$ConcreteWrapper*");
    Shiboken::TypeResolver::createObjectTypeResolver<QScriptClassPropertyIterator >(typeid(QScriptClassPropertyIterator).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QScriptClassPropertyIterator >(typeid(QScriptClassPropertyIteratorWrapper).name());
    PySide::initQtMetaType< ::QScriptClassPropertyIterator* >();
}

