/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtscript_python.h"

#include "qscriptcontextinfo_wrapper.h"

// Extra includes
#include <QStringList>
#include <qdatastream.h>
#include <qscriptcontext.h>
#include <qscriptcontextinfo.h>



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QScriptContextInfo_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QScriptContextInfo >()))
        return -1;

    QScriptContextInfo* cptr = 0;
    int overloadId = -1;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QScriptContextInfo", 0, 1, &(pyargs[0])))
        return -1;

    // Overloaded function decisor
    // 0: QScriptContextInfo()
    // 1: QScriptContextInfo(const QScriptContext*)
    // 2: QScriptContextInfo(QScriptContextInfo)
    if (numArgs == 0) {
        overloadId = 0; // QScriptContextInfo()
    } else if (numArgs == 1 && Shiboken::Converter< ::QScriptContext * >::isConvertible(pyargs[0])) {
        overloadId = 1; // QScriptContextInfo(const QScriptContext*)
    } else if (numArgs == 1 && Shiboken::Converter< ::QScriptContextInfo >::isConvertible(pyargs[0])) {
        overloadId = 2; // QScriptContextInfo(QScriptContextInfo)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QScriptContextInfo_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QScriptContextInfo()
            {

                if(!PyErr_Occurred()) {
                    // QScriptContextInfo()
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QScriptContextInfo();
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // QScriptContextInfo(const QScriptContext*)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QScriptContext * cppArg0 = Shiboken::Converter<QScriptContext * >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QScriptContextInfo(const QScriptContext*)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QScriptContextInfo(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 2: // QScriptContextInfo(QScriptContextInfo)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QScriptContextInfo cppArg0 = Shiboken::Converter<QScriptContextInfo >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QScriptContextInfo(QScriptContextInfo)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QScriptContextInfo(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QScriptContextInfo >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QScriptContextInfo_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QScriptContextInfo_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtScript.QScriptContext", "PySide.QtScript.QScriptContextInfo", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtScript.QScriptContextInfo", overloads);
        return -1;
}

static PyObject* Sbk_QScriptContextInfoFunc_columnNumber(PyObject* self)
{
    QScriptContextInfo* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QScriptContextInfo* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // columnNumber()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QScriptContextInfo*>(cppSelf)->columnNumber();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QScriptContextInfoFunc_fileName(PyObject* self)
{
    QScriptContextInfo* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QScriptContextInfo* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // fileName()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QScriptContextInfo*>(cppSelf)->fileName();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QScriptContextInfoFunc_functionEndLineNumber(PyObject* self)
{
    QScriptContextInfo* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QScriptContextInfo* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // functionEndLineNumber()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QScriptContextInfo*>(cppSelf)->functionEndLineNumber();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QScriptContextInfoFunc_functionMetaIndex(PyObject* self)
{
    QScriptContextInfo* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QScriptContextInfo* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // functionMetaIndex()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QScriptContextInfo*>(cppSelf)->functionMetaIndex();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QScriptContextInfoFunc_functionName(PyObject* self)
{
    QScriptContextInfo* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QScriptContextInfo* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // functionName()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QScriptContextInfo*>(cppSelf)->functionName();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QScriptContextInfoFunc_functionParameterNames(PyObject* self)
{
    QScriptContextInfo* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QScriptContextInfo* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // functionParameterNames()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QStringList cppResult = const_cast<const QScriptContextInfo*>(cppSelf)->functionParameterNames();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QStringList >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QScriptContextInfoFunc_functionStartLineNumber(PyObject* self)
{
    QScriptContextInfo* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QScriptContextInfo* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // functionStartLineNumber()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QScriptContextInfo*>(cppSelf)->functionStartLineNumber();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QScriptContextInfoFunc_functionType(PyObject* self)
{
    QScriptContextInfo* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QScriptContextInfo* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // functionType()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QScriptContextInfo::FunctionType cppResult = const_cast<const QScriptContextInfo*>(cppSelf)->functionType();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QScriptContextInfo::FunctionType >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QScriptContextInfoFunc_isNull(PyObject* self)
{
    QScriptContextInfo* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QScriptContextInfo* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isNull()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QScriptContextInfo*>(cppSelf)->isNull();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QScriptContextInfoFunc_lineNumber(PyObject* self)
{
    QScriptContextInfo* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QScriptContextInfo* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // lineNumber()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QScriptContextInfo*>(cppSelf)->lineNumber();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QScriptContextInfoFunc_scriptId(PyObject* self)
{
    QScriptContextInfo* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QScriptContextInfo* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // scriptId()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                qint64 cppResult = const_cast<const QScriptContextInfo*>(cppSelf)->scriptId();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< long long >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject *Sbk_QScriptContextInfo___copy__(PyObject *self)
{
        QScriptContextInfo* cppSelf = 0;
        if (!Shiboken::Object::isValid(self))
            return 0;
        cppSelf = Shiboken::Converter<QScriptContextInfo*>::toCpp(self);
        PyObject* pyResult = 0;
        QScriptContextInfo* copy = new QScriptContextInfo(*cppSelf);
        pyResult = Shiboken::Converter<QScriptContextInfo*>::toPython(copy);
        Shiboken::Object::getOwnership(pyResult);

        if (PyErr_Occurred() || !pyResult) {
            Py_XDECREF(pyResult);
            return 0;
        }
        return pyResult;
}

static PyMethodDef Sbk_QScriptContextInfo_methods[] = {
    {"columnNumber", (PyCFunction)Sbk_QScriptContextInfoFunc_columnNumber, METH_NOARGS},
    {"fileName", (PyCFunction)Sbk_QScriptContextInfoFunc_fileName, METH_NOARGS},
    {"functionEndLineNumber", (PyCFunction)Sbk_QScriptContextInfoFunc_functionEndLineNumber, METH_NOARGS},
    {"functionMetaIndex", (PyCFunction)Sbk_QScriptContextInfoFunc_functionMetaIndex, METH_NOARGS},
    {"functionName", (PyCFunction)Sbk_QScriptContextInfoFunc_functionName, METH_NOARGS},
    {"functionParameterNames", (PyCFunction)Sbk_QScriptContextInfoFunc_functionParameterNames, METH_NOARGS},
    {"functionStartLineNumber", (PyCFunction)Sbk_QScriptContextInfoFunc_functionStartLineNumber, METH_NOARGS},
    {"functionType", (PyCFunction)Sbk_QScriptContextInfoFunc_functionType, METH_NOARGS},
    {"isNull", (PyCFunction)Sbk_QScriptContextInfoFunc_isNull, METH_NOARGS},
    {"lineNumber", (PyCFunction)Sbk_QScriptContextInfoFunc_lineNumber, METH_NOARGS},
    {"scriptId", (PyCFunction)Sbk_QScriptContextInfoFunc_scriptId, METH_NOARGS},

    {"__copy__", (PyCFunction)Sbk_QScriptContextInfo___copy__, METH_NOARGS},
    {0} // Sentinel
};

static int Sbk_QScriptContextInfo___nb_bool(PyObject* pyObj)
{
    if (!Shiboken::Object::isValid(pyObj))
        return -1;
    const ::QScriptContextInfo* cppSelf = Shiboken::Converter< ::QScriptContextInfo*>::toCpp(pyObj);
    int result;
    Py_BEGIN_ALLOW_THREADS
    result = !cppSelf->isNull();
    Py_END_ALLOW_THREADS
    return result;
}

static PyObject* Sbk_QScriptContextInfoFunc___lshift__(PyObject* self, PyObject* arg)
{
    QScriptContextInfo* cppSelf = 0;
    bool isReverse = Shiboken::Converter< ::QScriptContextInfo >::checkType(arg) && !Shiboken::Converter< ::QScriptContextInfo >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QScriptContextInfo* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && Shiboken::Object::checkType(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__rlshift__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__rlshift__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator<<(QDataStream&,QScriptContextInfo)
    if (isReverse && Shiboken::Converter< ::QDataStream & >::isConvertible(arg)) {
        overloadId = 0; // operator<<(QDataStream&,QScriptContextInfo)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QScriptContextInfoFunc___lshift___TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QDataStream & cppArg0 = Shiboken::Converter<QDataStream & >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // operator<<(QDataStream&,QScriptContextInfo) [reverse operator]
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QDataStream & cppResult = (cppArg0) << (*cppSelf);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QDataStream & >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QScriptContextInfoFunc___lshift___TypeError:
        const char* overloads[] = {"PySide.QtCore.QDataStream", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtScript.QScriptContextInfo.__lshift__", overloads);
        return 0;
}

static PyObject* Sbk_QScriptContextInfoFunc___rshift__(PyObject* self, PyObject* arg)
{
    QScriptContextInfo* cppSelf = 0;
    bool isReverse = Shiboken::Converter< ::QScriptContextInfo >::checkType(arg) && !Shiboken::Converter< ::QScriptContextInfo >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QScriptContextInfo* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && Shiboken::Object::checkType(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__rrshift__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__rrshift__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator>>(QDataStream&,QScriptContextInfo&)
    if (isReverse && Shiboken::Converter< ::QDataStream & >::isConvertible(arg)) {
        overloadId = 0; // operator>>(QDataStream&,QScriptContextInfo&)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QScriptContextInfoFunc___rshift___TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QDataStream & cppArg0 = Shiboken::Converter<QDataStream & >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // operator>>(QDataStream&,QScriptContextInfo&) [reverse operator]
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QDataStream & cppResult = (cppArg0) >> (*cppSelf);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QDataStream & >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QScriptContextInfoFunc___rshift___TypeError:
        const char* overloads[] = {"PySide.QtCore.QDataStream", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtScript.QScriptContextInfo.__rshift__", overloads);
        return 0;
}

// type has number operators
static PyNumberMethods Sbk_QScriptContextInfo_as_number = {
    /*nb_add*/                  (binaryfunc)0,
    /*nb_subtract*/             (binaryfunc)0,
    /*nb_multiply*/             (binaryfunc)0,
    /*nb_divide*/               (binaryfunc)0,
    /*nb_remainder*/            (binaryfunc)0,
    /*nb_divmod*/               0,
    /*nb_power*/                0,
    /*nb_negative*/             (unaryfunc)0,
    /*nb_positive*/             (unaryfunc)0,
    /*nb_absolute*/             0,
    /*nb_nonzero*/              Sbk_QScriptContextInfo___nb_bool,
    /*nb_invert*/               (unaryfunc)0,
    /*nb_lshift*/               (binaryfunc)Sbk_QScriptContextInfoFunc___lshift__,
    /*nb_rshift*/               (binaryfunc)Sbk_QScriptContextInfoFunc___rshift__,
    /*nb_and*/                  (binaryfunc)0,
    /*nb_xor*/                  (binaryfunc)0,
    /*nb_or*/                   (binaryfunc)0,
    /*nb_coerce*/               0,
    /*nb_int*/                  0,
    /*nb_long*/                 0,
    /*nb_float*/                0,
    /*nb_oct*/                  0,
    /*nb_hex*/                  0,
    /*nb_inplace_add*/          (binaryfunc)0,
    /*nb_inplace_subtract*/     (binaryfunc)0,
    /*nb_inplace_multiply*/     (binaryfunc)0,
    /*nb_inplace_divide*/       (binaryfunc)0,
    /*nb_inplace_remainder*/    (binaryfunc)0,
    /*nb_inplace_power*/        0,
    /*nb_inplace_lshift*/       (binaryfunc)0,
    /*nb_inplace_rshift*/       (binaryfunc)0,
    /*nb_inplace_and*/          (binaryfunc)0,
    /*nb_inplace_xor*/          (binaryfunc)0,
    /*nb_inplace_or*/           (binaryfunc)0,
    /*nb_floor_divide*/         0,
    /*nb_true_divide*/          (binaryfunc)0,
    /*nb_inplace_floor_divide*/ 0,
    /*nb_inplace_true_divide*/  0,
    /*nb_index*/                0
};

// Rich comparison
static PyObject* Sbk_QScriptContextInfo_richcompare(PyObject* self, PyObject* arg, int op)
{
    PyObject* pyResult = 0;
    QScriptContextInfo& cppSelf = *Shiboken::Converter< QScriptContextInfo* >::toCpp(self);

    switch (op) {
        case Py_NE:
            if (Shiboken::Converter< ::QScriptContextInfo >::isConvertible(arg)) {
                // operator!=(const QScriptContextInfo & other) const
                QScriptContextInfo cppArg0 = Shiboken::Converter< ::QScriptContextInfo >::toCpp(arg);
                pyResult = Shiboken::Converter< bool >::toPython(cppSelf != cppArg0);
            } else goto Sbk_QScriptContextInfo_RichComparison_TypeError;

            break;
        case Py_EQ:
            if (Shiboken::Converter< ::QScriptContextInfo >::isConvertible(arg)) {
                // operator==(const QScriptContextInfo & other) const
                QScriptContextInfo cppArg0 = Shiboken::Converter< ::QScriptContextInfo >::toCpp(arg);
                pyResult = Shiboken::Converter< bool >::toPython(cppSelf == cppArg0);
            } else goto Sbk_QScriptContextInfo_RichComparison_TypeError;

            break;
        default:
            goto Sbk_QScriptContextInfo_RichComparison_TypeError;
    }

    if (pyResult && !PyErr_Occurred())
        return pyResult;
    Sbk_QScriptContextInfo_RichComparison_TypeError:
    PyErr_SetString(PyExc_NotImplementedError, "operator not implemented.");
    return 0;

}

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QScriptContextInfo_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtScript.QScriptContextInfo",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        &Sbk_QScriptContextInfo_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      Sbk_QScriptContextInfo_richcompare,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QScriptContextInfo_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QScriptContextInfo_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QScriptContextInfo(PyObject* module)
{
    SbkPySide_QtScriptTypes[SBK_QSCRIPTCONTEXTINFO_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QScriptContextInfo_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QScriptContextInfo_Type);
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QScriptContextInfo_Type, &Shiboken::callCppDestructor<QScriptContextInfo >);
    if (PyType_Ready((PyTypeObject*)&Sbk_QScriptContextInfo_Type) < 0)
        return;

    Shiboken::ObjectType::setOriginalName(&Sbk_QScriptContextInfo_Type, "QScriptContextInfo");
    PyModule_AddObject(module, "QScriptContextInfo",
        ((PyObject*)&Sbk_QScriptContextInfo_Type));

    // Initialize enums
    PyObject* enumItem;

    // init enum: FunctionType
    PyTypeObject* SbkPySide_QtScript_QScriptContextInfo_FunctionType = Shiboken::Enum::newType("PySide.QtScript.QScriptContextInfo.FunctionType");
    SbkPySide_QtScriptTypes[SBK_QSCRIPTCONTEXTINFO_FUNCTIONTYPE_IDX] = SbkPySide_QtScript_QScriptContextInfo_FunctionType;
    if (PyType_Ready(SbkPySide_QtScript_QScriptContextInfo_FunctionType) < 0)
        return;
    PyDict_SetItemString(Sbk_QScriptContextInfo_Type.super.ht_type.tp_dict,
            "FunctionType",((PyObject*)SbkPySide_QtScript_QScriptContextInfo_FunctionType));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtScript_QScriptContextInfo_FunctionType,(long) QScriptContextInfo::ScriptFunction, "ScriptFunction");
    PyDict_SetItemString(Sbk_QScriptContextInfo_Type.super.ht_type.tp_dict,"ScriptFunction", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtScript_QScriptContextInfo_FunctionType->tp_dict,"ScriptFunction", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtScript_QScriptContextInfo_FunctionType,(long) QScriptContextInfo::QtFunction, "QtFunction");
    PyDict_SetItemString(Sbk_QScriptContextInfo_Type.super.ht_type.tp_dict,"QtFunction", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtScript_QScriptContextInfo_FunctionType->tp_dict,"QtFunction", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtScript_QScriptContextInfo_FunctionType,(long) QScriptContextInfo::QtPropertyFunction, "QtPropertyFunction");
    PyDict_SetItemString(Sbk_QScriptContextInfo_Type.super.ht_type.tp_dict,"QtPropertyFunction", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtScript_QScriptContextInfo_FunctionType->tp_dict,"QtPropertyFunction", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtScript_QScriptContextInfo_FunctionType,(long) QScriptContextInfo::NativeFunction, "NativeFunction");
    PyDict_SetItemString(Sbk_QScriptContextInfo_Type.super.ht_type.tp_dict,"NativeFunction", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtScript_QScriptContextInfo_FunctionType->tp_dict,"NativeFunction", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QScriptContextInfo::FunctionType");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::FunctionType");
    // end of enum FunctionType


    Shiboken::TypeResolver::createValueTypeResolver<QScriptContextInfo >("QScriptContextInfo");
    Shiboken::TypeResolver::createObjectTypeResolver<QScriptContextInfo >("QScriptContextInfo*");
    Shiboken::TypeResolver::createValueTypeResolver<QScriptContextInfo >(typeid(QScriptContextInfo).name());
    PySide::initQtMetaType< ::QScriptContextInfo >();
    qRegisterMetaType< ::QScriptContextInfo::FunctionType >("QScriptContextInfo::FunctionType");
}

