/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include "pyside_qtscripttools_python.h"

#include "qscriptenginedebugger_wrapper.h"

// Extra includes
#include <QList>
#include <QScriptEngine>
#include <qaction.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qmainwindow.h>
#include <qmenu.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qscriptengine.h>
#include <qscriptenginedebugger.h>
#include <qthread.h>
#include <qtoolbar.h>
#include <qwidget.h>


// Native ---------------------------------------------------------

QScriptEngineDebuggerWrapper::QScriptEngineDebuggerWrapper(QObject * parent) : QScriptEngineDebugger(parent) {
    // ... middle
}

void QScriptEngineDebuggerWrapper::childEvent(QChildEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "childEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::childEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QChildEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QScriptEngineDebuggerWrapper::connectNotify(const char * signal)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "connectNotify"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QScriptEngineDebuggerWrapper::customEvent(QEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "customEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::customEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QScriptEngineDebuggerWrapper::disconnectNotify(const char * signal)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "disconnectNotify"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

bool QScriptEngineDebuggerWrapper::event(QEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return bool(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "event"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::event(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QScriptEngineDebugger.event", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
    return cppResult;
}

bool QScriptEngineDebuggerWrapper::eventFilter(QObject * arg__1, QEvent * arg__2)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return bool(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "eventFilter"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::eventFilter(arg__1, arg__2);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter< ::QObject * >::toPython(arg__1),
        Shiboken::Converter< ::QEvent * >::toPython(arg__2)
    ));
    bool invalidadeArg2 = PyTuple_GET_ITEM(pyargs, 1)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QScriptEngineDebugger.eventFilter", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    if (invalidadeArg2)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 1));
    return cppResult;
}

void QScriptEngineDebuggerWrapper::timerEvent(QTimerEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "timerEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::timerEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QTimerEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

const QMetaObject* QScriptEngineDebuggerWrapper::metaObject() const
{
    SbkObject* pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    return reinterpret_cast<QMetaObject*>(Shiboken::Object::getTypeUserData(pySelf));
}

int QScriptEngineDebuggerWrapper::qt_metacall(QMetaObject::Call call, int id, void** args)
{
    int result = QScriptEngineDebugger::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

QScriptEngineDebuggerWrapper::~QScriptEngineDebuggerWrapper()
{
    SbkObject* wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QScriptEngineDebugger_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QScriptEngineDebugger >()))
        return -1;

    QScriptEngineDebuggerWrapper* cptr = 0;
    int overloadId = -1;
    const char* argNames[] = {"parent"};
    const QMetaObject* metaObject;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths


    if (!PyArg_ParseTuple(args, "|O:QScriptEngineDebugger", &(pyargs[0])))
        return -1;

    // Overloaded function decisor
    // 0: QScriptEngineDebugger(QObject*)
    if (numArgs == 0) {
        overloadId = 0; // QScriptEngineDebugger(QObject*)
    } else if (Shiboken::Converter< ::QObject * >::isConvertible(pyargs[0])) {
        overloadId = 0; // QScriptEngineDebugger(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QScriptEngineDebugger_Init_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "parent");
                if (value) {
                    if (pyargs[0])
                        errorArgName = "parent";
                    else if (Shiboken::Converter< ::QObject * >::isConvertible(value))
                        pyargs[0] = value;
                    else
                        goto Sbk_QScriptEngineDebugger_Init_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtScriptTools.QScriptEngineDebugger(): got multiple values for keyword argument '%s'", errorArgName);
                    return -1;
                }
            }
            if (!Shiboken::Object::isValid(pyargs[0]))
                return -1;
            QObject * cppArg0 = pyargs[0] ? Shiboken::Converter<QObject * >::toCpp(pyargs[0]) : 0;

            if(!PyErr_Occurred()) {
                // QScriptEngineDebugger(QObject*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new QScriptEngineDebuggerWrapper(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                Shiboken::Object::setParent(pyargs[0], self);
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QScriptEngineDebugger >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QScriptEngineDebugger_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    metaObject = cptr->metaObject(); // <- init python qt properties
    if (kwds && !PySide::fillQtProperties(self, metaObject, kwds, argNames, 1))
        return -1;


    return 1;

    Sbk_QScriptEngineDebugger_Init_TypeError:
        const char* overloads[] = {"PySide.QtCore.QObject = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtScriptTools.QScriptEngineDebugger", overloads);
        return -1;
}

static PyObject* Sbk_QScriptEngineDebuggerFunc_action(PyObject* self, PyObject* arg)
{
    QScriptEngineDebugger* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QScriptEngineDebugger* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: action(QScriptEngineDebugger::DebuggerAction)const
    if (Shiboken::Converter< ::QScriptEngineDebugger::DebuggerAction >::isConvertible(arg)) {
        overloadId = 0; // action(QScriptEngineDebugger::DebuggerAction)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QScriptEngineDebuggerFunc_action_TypeError;

    // Call function/method
    {
        {
            QScriptEngineDebugger::DebuggerAction cppArg0 = Shiboken::Converter<QScriptEngineDebugger::DebuggerAction >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // action(QScriptEngineDebugger::DebuggerAction)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QAction * cppResult = const_cast<const QScriptEngineDebugger*>(cppSelf)->action(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QAction * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QScriptEngineDebuggerFunc_action_TypeError:
        const char* overloads[] = {"PySide.QtScriptTools.QScriptEngineDebugger.DebuggerAction", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtScriptTools.QScriptEngineDebugger.action", overloads);
        return 0;
}

static PyObject* Sbk_QScriptEngineDebuggerFunc_attachTo(PyObject* self, PyObject* arg)
{
    QScriptEngineDebugger* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QScriptEngineDebugger* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: attachTo(QScriptEngine*)
    if (Shiboken::Converter< ::QScriptEngine * >::isConvertible(arg)) {
        overloadId = 0; // attachTo(QScriptEngine*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QScriptEngineDebuggerFunc_attachTo_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QScriptEngine * cppArg0 = Shiboken::Converter<QScriptEngine * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // attachTo(QScriptEngine*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->attachTo(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QScriptEngineDebuggerFunc_attachTo_TypeError:
        const char* overloads[] = {"PySide.QtScript.QScriptEngine", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtScriptTools.QScriptEngineDebugger.attachTo", overloads);
        return 0;
}

static PyObject* Sbk_QScriptEngineDebuggerFunc_autoShowStandardWindow(PyObject* self)
{
    QScriptEngineDebugger* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QScriptEngineDebugger* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // autoShowStandardWindow()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QScriptEngineDebugger*>(cppSelf)->autoShowStandardWindow();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QScriptEngineDebuggerFunc_createStandardMenu(PyObject* self, PyObject* args, PyObject* kwds)
{
    QScriptEngineDebugger* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QScriptEngineDebugger* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtScriptTools.QScriptEngineDebugger.createStandardMenu(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:createStandardMenu", &(pyargs[0])))
        return 0;


    // Overloaded function decisor
    // 0: createStandardMenu(QWidget*)
    if (numArgs == 0) {
        overloadId = 0; // createStandardMenu(QWidget*)
    } else if (Shiboken::Converter< ::QWidget * >::isConvertible(pyargs[0])) {
        overloadId = 0; // createStandardMenu(QWidget*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QScriptEngineDebuggerFunc_createStandardMenu_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "parent");
                if (value) {
                    if (pyargs[0])
                        errorArgName = "parent";
                    else if (Shiboken::Converter< ::QWidget * >::isConvertible(value))
                        pyargs[0] = value;
                    else
                        goto Sbk_QScriptEngineDebuggerFunc_createStandardMenu_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtScriptTools.QScriptEngineDebugger.createStandardMenu(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QWidget * cppArg0 = pyargs[0] ? Shiboken::Converter<QWidget * >::toCpp(pyargs[0]) : 0;

            if(!PyErr_Occurred()) {
                // createStandardMenu(QWidget*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QMenu * cppResult = cppSelf->createStandardMenu(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QMenu * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QScriptEngineDebuggerFunc_createStandardMenu_TypeError:
        const char* overloads[] = {"PySide.QtGui.QWidget = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtScriptTools.QScriptEngineDebugger.createStandardMenu", overloads);
        return 0;
}

static PyObject* Sbk_QScriptEngineDebuggerFunc_createStandardToolBar(PyObject* self, PyObject* args, PyObject* kwds)
{
    QScriptEngineDebugger* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QScriptEngineDebugger* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtScriptTools.QScriptEngineDebugger.createStandardToolBar(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:createStandardToolBar", &(pyargs[0])))
        return 0;


    // Overloaded function decisor
    // 0: createStandardToolBar(QWidget*)
    if (numArgs == 0) {
        overloadId = 0; // createStandardToolBar(QWidget*)
    } else if (Shiboken::Converter< ::QWidget * >::isConvertible(pyargs[0])) {
        overloadId = 0; // createStandardToolBar(QWidget*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QScriptEngineDebuggerFunc_createStandardToolBar_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "parent");
                if (value) {
                    if (pyargs[0])
                        errorArgName = "parent";
                    else if (Shiboken::Converter< ::QWidget * >::isConvertible(value))
                        pyargs[0] = value;
                    else
                        goto Sbk_QScriptEngineDebuggerFunc_createStandardToolBar_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtScriptTools.QScriptEngineDebugger.createStandardToolBar(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QWidget * cppArg0 = pyargs[0] ? Shiboken::Converter<QWidget * >::toCpp(pyargs[0]) : 0;

            if(!PyErr_Occurred()) {
                // createStandardToolBar(QWidget*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QToolBar * cppResult = cppSelf->createStandardToolBar(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QToolBar * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QScriptEngineDebuggerFunc_createStandardToolBar_TypeError:
        const char* overloads[] = {"PySide.QtGui.QWidget = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtScriptTools.QScriptEngineDebugger.createStandardToolBar", overloads);
        return 0;
}

static PyObject* Sbk_QScriptEngineDebuggerFunc_setAutoShowStandardWindow(PyObject* self, PyObject* arg)
{
    QScriptEngineDebugger* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QScriptEngineDebugger* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setAutoShowStandardWindow(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setAutoShowStandardWindow(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QScriptEngineDebuggerFunc_setAutoShowStandardWindow_TypeError;

    // Call function/method
    {
        {
            bool cppArg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setAutoShowStandardWindow(bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setAutoShowStandardWindow(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QScriptEngineDebuggerFunc_setAutoShowStandardWindow_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtScriptTools.QScriptEngineDebugger.setAutoShowStandardWindow", overloads);
        return 0;
}

static PyObject* Sbk_QScriptEngineDebuggerFunc_standardWindow(PyObject* self)
{
    QScriptEngineDebugger* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QScriptEngineDebugger* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // standardWindow()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QMainWindow * cppResult = const_cast<const QScriptEngineDebugger*>(cppSelf)->standardWindow();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QMainWindow * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QScriptEngineDebuggerFunc_state(PyObject* self)
{
    QScriptEngineDebugger* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QScriptEngineDebugger* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // state()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QScriptEngineDebugger::DebuggerState cppResult = const_cast<const QScriptEngineDebugger*>(cppSelf)->state();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QScriptEngineDebugger::DebuggerState >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QScriptEngineDebuggerFunc_widget(PyObject* self, PyObject* arg)
{
    QScriptEngineDebugger* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QScriptEngineDebugger* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: widget(QScriptEngineDebugger::DebuggerWidget)const
    if (Shiboken::Converter< ::QScriptEngineDebugger::DebuggerWidget >::isConvertible(arg)) {
        overloadId = 0; // widget(QScriptEngineDebugger::DebuggerWidget)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QScriptEngineDebuggerFunc_widget_TypeError;

    // Call function/method
    {
        {
            QScriptEngineDebugger::DebuggerWidget cppArg0 = Shiboken::Converter<QScriptEngineDebugger::DebuggerWidget >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // widget(QScriptEngineDebugger::DebuggerWidget)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QWidget * cppResult = const_cast<const QScriptEngineDebugger*>(cppSelf)->widget(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QWidget * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QScriptEngineDebuggerFunc_widget_TypeError:
        const char* overloads[] = {"PySide.QtScriptTools.QScriptEngineDebugger.DebuggerWidget", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtScriptTools.QScriptEngineDebugger.widget", overloads);
        return 0;
}

static PyMethodDef Sbk_QScriptEngineDebugger_methods[] = {
    {"action", (PyCFunction)Sbk_QScriptEngineDebuggerFunc_action, METH_O},
    {"attachTo", (PyCFunction)Sbk_QScriptEngineDebuggerFunc_attachTo, METH_O},
    {"autoShowStandardWindow", (PyCFunction)Sbk_QScriptEngineDebuggerFunc_autoShowStandardWindow, METH_NOARGS},
    {"createStandardMenu", (PyCFunction)Sbk_QScriptEngineDebuggerFunc_createStandardMenu, METH_VARARGS|METH_KEYWORDS},
    {"createStandardToolBar", (PyCFunction)Sbk_QScriptEngineDebuggerFunc_createStandardToolBar, METH_VARARGS|METH_KEYWORDS},
    {"setAutoShowStandardWindow", (PyCFunction)Sbk_QScriptEngineDebuggerFunc_setAutoShowStandardWindow, METH_O},
    {"standardWindow", (PyCFunction)Sbk_QScriptEngineDebuggerFunc_standardWindow, METH_NOARGS},
    {"state", (PyCFunction)Sbk_QScriptEngineDebuggerFunc_state, METH_NOARGS},
    {"widget", (PyCFunction)Sbk_QScriptEngineDebuggerFunc_widget, METH_O},

    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QScriptEngineDebugger_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtScriptTools.QScriptEngineDebugger",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QScriptEngineDebugger_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QScriptEngineDebugger_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern

static SbkObjectType* Sbk_QScriptEngineDebugger_typeDiscovery(void* cptr, SbkObjectType* instanceType)
{
    if (instanceType == reinterpret_cast<SbkObjectType*>(Shiboken::SbkType<QObject >()) && dynamic_cast<QScriptEngineDebugger*>(reinterpret_cast<QObject*>(cptr)))
        return &Sbk_QScriptEngineDebugger_Type;
    return 0;
}


void init_QScriptEngineDebugger(PyObject* module)
{
    SbkPySide_QtScriptToolsTypes[SBK_QSCRIPTENGINEDEBUGGER_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QScriptEngineDebugger_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QScriptEngineDebugger_Type);
    Shiboken::ObjectType::setSubTypeInitHook(&Sbk_QScriptEngineDebugger_Type, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(&Sbk_QScriptEngineDebugger_Type, &QScriptEngineDebugger::staticMetaObject);    Sbk_QScriptEngineDebugger_Type.super.ht_type.tp_base = SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX];
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QScriptEngineDebugger_Type, &Shiboken::callCppDestructor<QScriptEngineDebugger >);
    if (PyType_Ready((PyTypeObject*)&Sbk_QScriptEngineDebugger_Type) < 0)
        return;

    // Fill type discovery information
    Shiboken::ObjectType::setTypeDiscoveryFunction(&Sbk_QScriptEngineDebugger_Type, &Sbk_QScriptEngineDebugger_typeDiscovery);
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkObjectType*>(SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX]), &Sbk_QScriptEngineDebugger_Type);

    Shiboken::ObjectType::setOriginalName(&Sbk_QScriptEngineDebugger_Type, "QScriptEngineDebugger*");
    PyModule_AddObject(module, "QScriptEngineDebugger",
        ((PyObject*)&Sbk_QScriptEngineDebugger_Type));

    // Initialize enums
    PyObject* enumItem;

    // init enum: DebuggerWidget
    PyTypeObject* SbkPySide_QtScriptTools_QScriptEngineDebugger_DebuggerWidget = Shiboken::Enum::newType("PySide.QtScriptTools.QScriptEngineDebugger.DebuggerWidget");
    SbkPySide_QtScriptToolsTypes[SBK_QSCRIPTENGINEDEBUGGER_DEBUGGERWIDGET_IDX] = SbkPySide_QtScriptTools_QScriptEngineDebugger_DebuggerWidget;
    if (PyType_Ready(SbkPySide_QtScriptTools_QScriptEngineDebugger_DebuggerWidget) < 0)
        return;
    PyDict_SetItemString(Sbk_QScriptEngineDebugger_Type.super.ht_type.tp_dict,
            "DebuggerWidget",((PyObject*)SbkPySide_QtScriptTools_QScriptEngineDebugger_DebuggerWidget));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtScriptTools_QScriptEngineDebugger_DebuggerWidget,(long) QScriptEngineDebugger::ConsoleWidget, "ConsoleWidget");
    PyDict_SetItemString(Sbk_QScriptEngineDebugger_Type.super.ht_type.tp_dict,"ConsoleWidget", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtScriptTools_QScriptEngineDebugger_DebuggerWidget->tp_dict,"ConsoleWidget", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtScriptTools_QScriptEngineDebugger_DebuggerWidget,(long) QScriptEngineDebugger::StackWidget, "StackWidget");
    PyDict_SetItemString(Sbk_QScriptEngineDebugger_Type.super.ht_type.tp_dict,"StackWidget", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtScriptTools_QScriptEngineDebugger_DebuggerWidget->tp_dict,"StackWidget", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtScriptTools_QScriptEngineDebugger_DebuggerWidget,(long) QScriptEngineDebugger::ScriptsWidget, "ScriptsWidget");
    PyDict_SetItemString(Sbk_QScriptEngineDebugger_Type.super.ht_type.tp_dict,"ScriptsWidget", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtScriptTools_QScriptEngineDebugger_DebuggerWidget->tp_dict,"ScriptsWidget", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtScriptTools_QScriptEngineDebugger_DebuggerWidget,(long) QScriptEngineDebugger::LocalsWidget, "LocalsWidget");
    PyDict_SetItemString(Sbk_QScriptEngineDebugger_Type.super.ht_type.tp_dict,"LocalsWidget", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtScriptTools_QScriptEngineDebugger_DebuggerWidget->tp_dict,"LocalsWidget", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtScriptTools_QScriptEngineDebugger_DebuggerWidget,(long) QScriptEngineDebugger::CodeWidget, "CodeWidget");
    PyDict_SetItemString(Sbk_QScriptEngineDebugger_Type.super.ht_type.tp_dict,"CodeWidget", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtScriptTools_QScriptEngineDebugger_DebuggerWidget->tp_dict,"CodeWidget", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtScriptTools_QScriptEngineDebugger_DebuggerWidget,(long) QScriptEngineDebugger::CodeFinderWidget, "CodeFinderWidget");
    PyDict_SetItemString(Sbk_QScriptEngineDebugger_Type.super.ht_type.tp_dict,"CodeFinderWidget", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtScriptTools_QScriptEngineDebugger_DebuggerWidget->tp_dict,"CodeFinderWidget", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtScriptTools_QScriptEngineDebugger_DebuggerWidget,(long) QScriptEngineDebugger::BreakpointsWidget, "BreakpointsWidget");
    PyDict_SetItemString(Sbk_QScriptEngineDebugger_Type.super.ht_type.tp_dict,"BreakpointsWidget", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtScriptTools_QScriptEngineDebugger_DebuggerWidget->tp_dict,"BreakpointsWidget", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtScriptTools_QScriptEngineDebugger_DebuggerWidget,(long) QScriptEngineDebugger::DebugOutputWidget, "DebugOutputWidget");
    PyDict_SetItemString(Sbk_QScriptEngineDebugger_Type.super.ht_type.tp_dict,"DebugOutputWidget", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtScriptTools_QScriptEngineDebugger_DebuggerWidget->tp_dict,"DebugOutputWidget", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtScriptTools_QScriptEngineDebugger_DebuggerWidget,(long) QScriptEngineDebugger::ErrorLogWidget, "ErrorLogWidget");
    PyDict_SetItemString(Sbk_QScriptEngineDebugger_Type.super.ht_type.tp_dict,"ErrorLogWidget", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtScriptTools_QScriptEngineDebugger_DebuggerWidget->tp_dict,"ErrorLogWidget", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QScriptEngineDebugger::DebuggerWidget");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::DebuggerWidget");
    // end of enum DebuggerWidget

    // init enum: DebuggerAction
    PyTypeObject* SbkPySide_QtScriptTools_QScriptEngineDebugger_DebuggerAction = Shiboken::Enum::newType("PySide.QtScriptTools.QScriptEngineDebugger.DebuggerAction");
    SbkPySide_QtScriptToolsTypes[SBK_QSCRIPTENGINEDEBUGGER_DEBUGGERACTION_IDX] = SbkPySide_QtScriptTools_QScriptEngineDebugger_DebuggerAction;
    if (PyType_Ready(SbkPySide_QtScriptTools_QScriptEngineDebugger_DebuggerAction) < 0)
        return;
    PyDict_SetItemString(Sbk_QScriptEngineDebugger_Type.super.ht_type.tp_dict,
            "DebuggerAction",((PyObject*)SbkPySide_QtScriptTools_QScriptEngineDebugger_DebuggerAction));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtScriptTools_QScriptEngineDebugger_DebuggerAction,(long) QScriptEngineDebugger::InterruptAction, "InterruptAction");
    PyDict_SetItemString(Sbk_QScriptEngineDebugger_Type.super.ht_type.tp_dict,"InterruptAction", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtScriptTools_QScriptEngineDebugger_DebuggerAction->tp_dict,"InterruptAction", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtScriptTools_QScriptEngineDebugger_DebuggerAction,(long) QScriptEngineDebugger::ContinueAction, "ContinueAction");
    PyDict_SetItemString(Sbk_QScriptEngineDebugger_Type.super.ht_type.tp_dict,"ContinueAction", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtScriptTools_QScriptEngineDebugger_DebuggerAction->tp_dict,"ContinueAction", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtScriptTools_QScriptEngineDebugger_DebuggerAction,(long) QScriptEngineDebugger::StepIntoAction, "StepIntoAction");
    PyDict_SetItemString(Sbk_QScriptEngineDebugger_Type.super.ht_type.tp_dict,"StepIntoAction", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtScriptTools_QScriptEngineDebugger_DebuggerAction->tp_dict,"StepIntoAction", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtScriptTools_QScriptEngineDebugger_DebuggerAction,(long) QScriptEngineDebugger::StepOverAction, "StepOverAction");
    PyDict_SetItemString(Sbk_QScriptEngineDebugger_Type.super.ht_type.tp_dict,"StepOverAction", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtScriptTools_QScriptEngineDebugger_DebuggerAction->tp_dict,"StepOverAction", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtScriptTools_QScriptEngineDebugger_DebuggerAction,(long) QScriptEngineDebugger::StepOutAction, "StepOutAction");
    PyDict_SetItemString(Sbk_QScriptEngineDebugger_Type.super.ht_type.tp_dict,"StepOutAction", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtScriptTools_QScriptEngineDebugger_DebuggerAction->tp_dict,"StepOutAction", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtScriptTools_QScriptEngineDebugger_DebuggerAction,(long) QScriptEngineDebugger::RunToCursorAction, "RunToCursorAction");
    PyDict_SetItemString(Sbk_QScriptEngineDebugger_Type.super.ht_type.tp_dict,"RunToCursorAction", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtScriptTools_QScriptEngineDebugger_DebuggerAction->tp_dict,"RunToCursorAction", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtScriptTools_QScriptEngineDebugger_DebuggerAction,(long) QScriptEngineDebugger::RunToNewScriptAction, "RunToNewScriptAction");
    PyDict_SetItemString(Sbk_QScriptEngineDebugger_Type.super.ht_type.tp_dict,"RunToNewScriptAction", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtScriptTools_QScriptEngineDebugger_DebuggerAction->tp_dict,"RunToNewScriptAction", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtScriptTools_QScriptEngineDebugger_DebuggerAction,(long) QScriptEngineDebugger::ToggleBreakpointAction, "ToggleBreakpointAction");
    PyDict_SetItemString(Sbk_QScriptEngineDebugger_Type.super.ht_type.tp_dict,"ToggleBreakpointAction", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtScriptTools_QScriptEngineDebugger_DebuggerAction->tp_dict,"ToggleBreakpointAction", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtScriptTools_QScriptEngineDebugger_DebuggerAction,(long) QScriptEngineDebugger::ClearDebugOutputAction, "ClearDebugOutputAction");
    PyDict_SetItemString(Sbk_QScriptEngineDebugger_Type.super.ht_type.tp_dict,"ClearDebugOutputAction", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtScriptTools_QScriptEngineDebugger_DebuggerAction->tp_dict,"ClearDebugOutputAction", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtScriptTools_QScriptEngineDebugger_DebuggerAction,(long) QScriptEngineDebugger::ClearErrorLogAction, "ClearErrorLogAction");
    PyDict_SetItemString(Sbk_QScriptEngineDebugger_Type.super.ht_type.tp_dict,"ClearErrorLogAction", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtScriptTools_QScriptEngineDebugger_DebuggerAction->tp_dict,"ClearErrorLogAction", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtScriptTools_QScriptEngineDebugger_DebuggerAction,(long) QScriptEngineDebugger::ClearConsoleAction, "ClearConsoleAction");
    PyDict_SetItemString(Sbk_QScriptEngineDebugger_Type.super.ht_type.tp_dict,"ClearConsoleAction", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtScriptTools_QScriptEngineDebugger_DebuggerAction->tp_dict,"ClearConsoleAction", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtScriptTools_QScriptEngineDebugger_DebuggerAction,(long) QScriptEngineDebugger::FindInScriptAction, "FindInScriptAction");
    PyDict_SetItemString(Sbk_QScriptEngineDebugger_Type.super.ht_type.tp_dict,"FindInScriptAction", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtScriptTools_QScriptEngineDebugger_DebuggerAction->tp_dict,"FindInScriptAction", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtScriptTools_QScriptEngineDebugger_DebuggerAction,(long) QScriptEngineDebugger::FindNextInScriptAction, "FindNextInScriptAction");
    PyDict_SetItemString(Sbk_QScriptEngineDebugger_Type.super.ht_type.tp_dict,"FindNextInScriptAction", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtScriptTools_QScriptEngineDebugger_DebuggerAction->tp_dict,"FindNextInScriptAction", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtScriptTools_QScriptEngineDebugger_DebuggerAction,(long) QScriptEngineDebugger::FindPreviousInScriptAction, "FindPreviousInScriptAction");
    PyDict_SetItemString(Sbk_QScriptEngineDebugger_Type.super.ht_type.tp_dict,"FindPreviousInScriptAction", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtScriptTools_QScriptEngineDebugger_DebuggerAction->tp_dict,"FindPreviousInScriptAction", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtScriptTools_QScriptEngineDebugger_DebuggerAction,(long) QScriptEngineDebugger::GoToLineAction, "GoToLineAction");
    PyDict_SetItemString(Sbk_QScriptEngineDebugger_Type.super.ht_type.tp_dict,"GoToLineAction", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtScriptTools_QScriptEngineDebugger_DebuggerAction->tp_dict,"GoToLineAction", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QScriptEngineDebugger::DebuggerAction");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::DebuggerAction");
    // end of enum DebuggerAction

    // init enum: DebuggerState
    PyTypeObject* SbkPySide_QtScriptTools_QScriptEngineDebugger_DebuggerState = Shiboken::Enum::newType("PySide.QtScriptTools.QScriptEngineDebugger.DebuggerState");
    SbkPySide_QtScriptToolsTypes[SBK_QSCRIPTENGINEDEBUGGER_DEBUGGERSTATE_IDX] = SbkPySide_QtScriptTools_QScriptEngineDebugger_DebuggerState;
    if (PyType_Ready(SbkPySide_QtScriptTools_QScriptEngineDebugger_DebuggerState) < 0)
        return;
    PyDict_SetItemString(Sbk_QScriptEngineDebugger_Type.super.ht_type.tp_dict,
            "DebuggerState",((PyObject*)SbkPySide_QtScriptTools_QScriptEngineDebugger_DebuggerState));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtScriptTools_QScriptEngineDebugger_DebuggerState,(long) QScriptEngineDebugger::RunningState, "RunningState");
    PyDict_SetItemString(Sbk_QScriptEngineDebugger_Type.super.ht_type.tp_dict,"RunningState", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtScriptTools_QScriptEngineDebugger_DebuggerState->tp_dict,"RunningState", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtScriptTools_QScriptEngineDebugger_DebuggerState,(long) QScriptEngineDebugger::SuspendedState, "SuspendedState");
    PyDict_SetItemString(Sbk_QScriptEngineDebugger_Type.super.ht_type.tp_dict,"SuspendedState", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtScriptTools_QScriptEngineDebugger_DebuggerState->tp_dict,"SuspendedState", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QScriptEngineDebugger::DebuggerState");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::DebuggerState");
    // end of enum DebuggerState

    // Initialize signals
    PySideSignal* signal_item;

    signal_item = PySide::Signal::newObject("evaluationSuspended", "void", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QScriptEngineDebugger_Type, "evaluationSuspended", signal_item);
    Py_DECREF((PyObject*) signal_item);
    signal_item = PySide::Signal::newObject("evaluationResumed", "void", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QScriptEngineDebugger_Type, "evaluationResumed", signal_item);
    Py_DECREF((PyObject*) signal_item);


    Shiboken::TypeResolver::createObjectTypeResolver<QScriptEngineDebugger >("QScriptEngineDebugger*");
    Shiboken::TypeResolver::createObjectTypeResolver<QScriptEngineDebugger >(typeid(QScriptEngineDebugger).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QScriptEngineDebugger >(typeid(QScriptEngineDebuggerWrapper).name());
    PySide::initQtMetaType< ::QScriptEngineDebugger* >();
    qRegisterMetaType< ::QScriptEngineDebugger::DebuggerWidget >("QScriptEngineDebugger::DebuggerWidget");
    qRegisterMetaType< ::QScriptEngineDebugger::DebuggerAction >("QScriptEngineDebugger::DebuggerAction");
    qRegisterMetaType< ::QScriptEngineDebugger::DebuggerState >("QScriptEngineDebugger::DebuggerState");
}

