/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtsql_python.h"

#include "qsqlerror_wrapper.h"

// Extra includes
#include <qsqlerror.h>



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QSqlError_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QSqlError >()))
        return -1;

    QSqlError* cptr = 0;
    int overloadId = -1;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);

    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 4) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtSql.QSqlError(): too many arguments");
        return -1;
    }

    if (!PyArg_ParseTuple(args, "|OOOO:QSqlError", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return -1;

    // Overloaded function decisor
    // 0: QSqlError(QSqlError)
    // 1: QSqlError(QString,QString,QSqlError::ErrorType,int)
    if (numArgs == 0) {
        overloadId = 1; // QSqlError(QString,QString,QSqlError::ErrorType,int)
    } else if (Shiboken::Converter< QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 1; // QSqlError(QString,QString,QSqlError::ErrorType,int)
        } else if (Shiboken::Converter< QString >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 1; // QSqlError(QString,QString,QSqlError::ErrorType,int)
            } else if (Shiboken::Converter< ::QSqlError::ErrorType >::isConvertible(pyargs[2])) {
                if (numArgs == 3) {
                    overloadId = 1; // QSqlError(QString,QString,QSqlError::ErrorType,int)
                } else if (SbkNumber_Check(pyargs[3])) {
                    overloadId = 1; // QSqlError(QString,QString,QSqlError::ErrorType,int)
                }
            }
        }
    } else if (numArgs == 1 && Shiboken::Converter< ::QSqlError >::isConvertible(pyargs[0])) {
        overloadId = 0; // QSqlError(QSqlError)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QSqlError_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QSqlError(QSqlError)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QSqlError cppArg0 = Shiboken::Converter<QSqlError >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QSqlError(QSqlError)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QSqlError(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // QSqlError(QString,QString,QSqlError::ErrorType,int)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "driverText");
                    if (value) {
                        if (pyargs[0])
                            errorArgName = "driverText";
                        else if (Shiboken::Converter< QString >::isConvertible(value))
                            pyargs[0] = value;
                        else
                            goto Sbk_QSqlError_Init_TypeError;
                    }
                    value = PyDict_GetItemString(kwds, "databaseText");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "databaseText";
                        else if (Shiboken::Converter< QString >::isConvertible(value))
                            pyargs[1] = value;
                        else
                            goto Sbk_QSqlError_Init_TypeError;
                    }
                    value = PyDict_GetItemString(kwds, "type");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "type";
                        else if (Shiboken::Converter< ::QSqlError::ErrorType >::isConvertible(value))
                            pyargs[2] = value;
                        else
                            goto Sbk_QSqlError_Init_TypeError;
                    }
                    value = PyDict_GetItemString(kwds, "number");
                    if (value) {
                        if (pyargs[3])
                            errorArgName = "number";
                        else if (SbkNumber_Check(value))
                            pyargs[3] = value;
                        else
                            goto Sbk_QSqlError_Init_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtSql.QSqlError(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                QString cppArg0 = pyargs[0] ? Shiboken::Converter<QString >::toCpp(pyargs[0]) : QString();
                QString cppArg1 = pyargs[1] ? Shiboken::Converter<QString >::toCpp(pyargs[1]) : QString();
                QSqlError::ErrorType cppArg2 = pyargs[2] ? Shiboken::Converter<QSqlError::ErrorType >::toCpp(pyargs[2]) : QSqlError::NoError;
                int cppArg3 = pyargs[3] ? Shiboken::Converter<int >::toCpp(pyargs[3]) : -1;

                if(!PyErr_Occurred()) {
                    // QSqlError(QString,QString,QSqlError::ErrorType,int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QSqlError(cppArg0, cppArg1, cppArg2, cppArg3);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QSqlError >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QSqlError_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QSqlError_Init_TypeError:
        const char* overloads[] = {"PySide.QtSql.QSqlError", "QString = QString(), QString = QString(), PySide.QtSql.QSqlError.ErrorType = NoError, int = -1", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtSql.QSqlError", overloads);
        return -1;
}

static PyObject* Sbk_QSqlErrorFunc_databaseText(PyObject* self)
{
    QSqlError* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QSqlError* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // databaseText()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QSqlError*>(cppSelf)->databaseText();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QSqlErrorFunc_driverText(PyObject* self)
{
    QSqlError* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QSqlError* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // driverText()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QSqlError*>(cppSelf)->driverText();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QSqlErrorFunc_isValid(PyObject* self)
{
    QSqlError* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QSqlError* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isValid()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QSqlError*>(cppSelf)->isValid();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QSqlErrorFunc_number(PyObject* self)
{
    QSqlError* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QSqlError* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // number()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QSqlError*>(cppSelf)->number();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QSqlErrorFunc_setDatabaseText(PyObject* self, PyObject* arg)
{
    QSqlError* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QSqlError* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setDatabaseText(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // setDatabaseText(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QSqlErrorFunc_setDatabaseText_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setDatabaseText(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setDatabaseText(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QSqlErrorFunc_setDatabaseText_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtSql.QSqlError.setDatabaseText", overloads);
        return 0;
}

static PyObject* Sbk_QSqlErrorFunc_setDriverText(PyObject* self, PyObject* arg)
{
    QSqlError* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QSqlError* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setDriverText(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // setDriverText(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QSqlErrorFunc_setDriverText_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setDriverText(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setDriverText(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QSqlErrorFunc_setDriverText_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtSql.QSqlError.setDriverText", overloads);
        return 0;
}

static PyObject* Sbk_QSqlErrorFunc_setNumber(PyObject* self, PyObject* arg)
{
    QSqlError* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QSqlError* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setNumber(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setNumber(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QSqlErrorFunc_setNumber_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setNumber(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setNumber(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QSqlErrorFunc_setNumber_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtSql.QSqlError.setNumber", overloads);
        return 0;
}

static PyObject* Sbk_QSqlErrorFunc_setType(PyObject* self, PyObject* arg)
{
    QSqlError* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QSqlError* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setType(QSqlError::ErrorType)
    if (Shiboken::Converter< ::QSqlError::ErrorType >::isConvertible(arg)) {
        overloadId = 0; // setType(QSqlError::ErrorType)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QSqlErrorFunc_setType_TypeError;

    // Call function/method
    {
        {
            QSqlError::ErrorType cppArg0 = Shiboken::Converter<QSqlError::ErrorType >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setType(QSqlError::ErrorType)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setType(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QSqlErrorFunc_setType_TypeError:
        const char* overloads[] = {"PySide.QtSql.QSqlError.ErrorType", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtSql.QSqlError.setType", overloads);
        return 0;
}

static PyObject* Sbk_QSqlErrorFunc_text(PyObject* self)
{
    QSqlError* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QSqlError* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // text()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QSqlError*>(cppSelf)->text();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QSqlErrorFunc_type(PyObject* self)
{
    QSqlError* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QSqlError* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // type()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QSqlError::ErrorType cppResult = const_cast<const QSqlError*>(cppSelf)->type();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QSqlError::ErrorType >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject *Sbk_QSqlError___copy__(PyObject *self)
{
        QSqlError* cppSelf = 0;
        if (!Shiboken::Object::isValid(self))
            return 0;
        cppSelf = Shiboken::Converter<QSqlError*>::toCpp(self);
        PyObject* pyResult = 0;
        QSqlError* copy = new QSqlError(*cppSelf);
        pyResult = Shiboken::Converter<QSqlError*>::toPython(copy);
        Shiboken::Object::getOwnership(pyResult);

        if (PyErr_Occurred() || !pyResult) {
            Py_XDECREF(pyResult);
            return 0;
        }
        return pyResult;
}

static PyMethodDef Sbk_QSqlError_methods[] = {
    {"databaseText", (PyCFunction)Sbk_QSqlErrorFunc_databaseText, METH_NOARGS},
    {"driverText", (PyCFunction)Sbk_QSqlErrorFunc_driverText, METH_NOARGS},
    {"isValid", (PyCFunction)Sbk_QSqlErrorFunc_isValid, METH_NOARGS},
    {"number", (PyCFunction)Sbk_QSqlErrorFunc_number, METH_NOARGS},
    {"setDatabaseText", (PyCFunction)Sbk_QSqlErrorFunc_setDatabaseText, METH_O},
    {"setDriverText", (PyCFunction)Sbk_QSqlErrorFunc_setDriverText, METH_O},
    {"setNumber", (PyCFunction)Sbk_QSqlErrorFunc_setNumber, METH_O},
    {"setType", (PyCFunction)Sbk_QSqlErrorFunc_setType, METH_O},
    {"text", (PyCFunction)Sbk_QSqlErrorFunc_text, METH_NOARGS},
    {"type", (PyCFunction)Sbk_QSqlErrorFunc_type, METH_NOARGS},

    {"__copy__", (PyCFunction)Sbk_QSqlError___copy__, METH_NOARGS},
    {0} // Sentinel
};

} // extern "C"

extern "C"
{
static PyObject* Sbk_QSqlError__repr__(PyObject* pyObj)
{
    QBuffer buffer;
    buffer.open(QBuffer::ReadWrite);
    QDebug dbg(&buffer);
    dbg << Shiboken::Converter< ::QSqlError >::toCpp(pyObj);
    buffer.close();
    return PyString_FromFormat("<PySide.QtSql.%s at %p>", buffer.data().constData(), pyObj);
}
} // extern C

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QSqlError_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtSql.QSqlError",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Sbk_QSqlError__repr__,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QSqlError_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QSqlError_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QSqlError(PyObject* module)
{
    SbkPySide_QtSqlTypes[SBK_QSQLERROR_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QSqlError_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QSqlError_Type);
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QSqlError_Type, &Shiboken::callCppDestructor<QSqlError >);
    if (PyType_Ready((PyTypeObject*)&Sbk_QSqlError_Type) < 0)
        return;

    Shiboken::ObjectType::setOriginalName(&Sbk_QSqlError_Type, "QSqlError");
    PyModule_AddObject(module, "QSqlError",
        ((PyObject*)&Sbk_QSqlError_Type));

    // Initialize enums
    PyObject* enumItem;

    // init enum: ErrorType
    PyTypeObject* SbkPySide_QtSql_QSqlError_ErrorType = Shiboken::Enum::newType("PySide.QtSql.QSqlError.ErrorType");
    SbkPySide_QtSqlTypes[SBK_QSQLERROR_ERRORTYPE_IDX] = SbkPySide_QtSql_QSqlError_ErrorType;
    if (PyType_Ready(SbkPySide_QtSql_QSqlError_ErrorType) < 0)
        return;
    PyDict_SetItemString(Sbk_QSqlError_Type.super.ht_type.tp_dict,
            "ErrorType",((PyObject*)SbkPySide_QtSql_QSqlError_ErrorType));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtSql_QSqlError_ErrorType,(long) QSqlError::NoError, "NoError");
    PyDict_SetItemString(Sbk_QSqlError_Type.super.ht_type.tp_dict,"NoError", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtSql_QSqlError_ErrorType->tp_dict,"NoError", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtSql_QSqlError_ErrorType,(long) QSqlError::ConnectionError, "ConnectionError");
    PyDict_SetItemString(Sbk_QSqlError_Type.super.ht_type.tp_dict,"ConnectionError", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtSql_QSqlError_ErrorType->tp_dict,"ConnectionError", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtSql_QSqlError_ErrorType,(long) QSqlError::StatementError, "StatementError");
    PyDict_SetItemString(Sbk_QSqlError_Type.super.ht_type.tp_dict,"StatementError", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtSql_QSqlError_ErrorType->tp_dict,"StatementError", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtSql_QSqlError_ErrorType,(long) QSqlError::TransactionError, "TransactionError");
    PyDict_SetItemString(Sbk_QSqlError_Type.super.ht_type.tp_dict,"TransactionError", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtSql_QSqlError_ErrorType->tp_dict,"TransactionError", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtSql_QSqlError_ErrorType,(long) QSqlError::UnknownError, "UnknownError");
    PyDict_SetItemString(Sbk_QSqlError_Type.super.ht_type.tp_dict,"UnknownError", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtSql_QSqlError_ErrorType->tp_dict,"UnknownError", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QSqlError::ErrorType");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::ErrorType");
    // end of enum ErrorType


    Shiboken::TypeResolver::createValueTypeResolver<QSqlError >("QSqlError");
    Shiboken::TypeResolver::createObjectTypeResolver<QSqlError >("QSqlError*");
    Shiboken::TypeResolver::createValueTypeResolver<QSqlError >(typeid(QSqlError).name());
    PySide::initQtMetaType< ::QSqlError >();
    qRegisterMetaType< ::QSqlError::ErrorType >("QSqlError::ErrorType");
}

