/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include "pyside_qtuitools_python.h"

#include "quiloader_wrapper.h"

// Extra includes
#include <QList>
#include <QStringList>
#include "glue/plugins.h"
#include "glue/uitools_loadui.h"
#include <qaction.h>
#include <qactiongroup.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qdir.h>
#include <qiodevice.h>
#include <qlayout.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qthread.h>
#include <quiloader.h>
#include <qwidget.h>



// Native ---------------------------------------------------------

QUiLoaderWrapper::QUiLoaderWrapper(QObject * parent) : QUiLoader(parent) {
    // ... middle
}

void QUiLoaderWrapper::childEvent(QChildEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "childEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::childEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QChildEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QUiLoaderWrapper::connectNotify(const char * signal)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "connectNotify"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

QAction * QUiLoaderWrapper::createAction(QObject * parent, const QString & name)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return 0;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "createAction"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QUiLoader::createAction(parent, name);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter< ::QObject * >::toPython(parent),
        Shiboken::Converter< QString >::toPython(name)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return 0;
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QAction * >::isConvertible(pyResult);
    typeIsValid = typeIsValid || (pyResult == Py_None);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QUiLoader.createAction", Shiboken::SbkType<QAction >()->tp_name, pyResult->ob_type->tp_name);
        return 0;
    }
    QAction * cppResult(Shiboken::Converter< ::QAction * >::toCpp(pyResult));
    return cppResult;
}

QActionGroup * QUiLoaderWrapper::createActionGroup(QObject * parent, const QString & name)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return 0;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "createActionGroup"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QUiLoader::createActionGroup(parent, name);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter< ::QObject * >::toPython(parent),
        Shiboken::Converter< QString >::toPython(name)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return 0;
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QActionGroup * >::isConvertible(pyResult);
    typeIsValid = typeIsValid || (pyResult == Py_None);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QUiLoader.createActionGroup", Shiboken::SbkType<QActionGroup >()->tp_name, pyResult->ob_type->tp_name);
        return 0;
    }
    QActionGroup * cppResult(Shiboken::Converter< ::QActionGroup * >::toCpp(pyResult));
    return cppResult;
}

QLayout * QUiLoaderWrapper::createLayout(const QString & className, QObject * parent, const QString & name)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return 0;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "createLayout"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QUiLoader::createLayout(className, parent, name);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NNN)",
        Shiboken::Converter< QString >::toPython(className),
        Shiboken::Converter< ::QObject * >::toPython(parent),
        Shiboken::Converter< QString >::toPython(name)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return 0;
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QLayout * >::isConvertible(pyResult);
    typeIsValid = typeIsValid || (pyResult == Py_None);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QUiLoader.createLayout", Shiboken::SbkType<QLayout >()->tp_name, pyResult->ob_type->tp_name);
        return 0;
    }
    QLayout * cppResult(Shiboken::Converter< ::QLayout * >::toCpp(pyResult));
    return cppResult;
}

QWidget * QUiLoaderWrapper::createWidget(const QString & className, QWidget * parent, const QString & name)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return 0;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "createWidget"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QUiLoader::createWidget(className, parent, name);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NNN)",
        Shiboken::Converter< QString >::toPython(className),
        Shiboken::Converter< ::QWidget * >::toPython(parent),
        Shiboken::Converter< QString >::toPython(name)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return 0;
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QWidget * >::isConvertible(pyResult);
    typeIsValid = typeIsValid || (pyResult == Py_None);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QUiLoader.createWidget", Shiboken::SbkType<QWidget >()->tp_name, pyResult->ob_type->tp_name);
        return 0;
    }
    QWidget * cppResult(Shiboken::Converter< ::QWidget * >::toCpp(pyResult));
    return cppResult;
}

void QUiLoaderWrapper::customEvent(QEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "customEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::customEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QUiLoaderWrapper::disconnectNotify(const char * signal)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "disconnectNotify"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

bool QUiLoaderWrapper::event(QEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return bool(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "event"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::event(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QUiLoader.event", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
    return cppResult;
}

bool QUiLoaderWrapper::eventFilter(QObject * arg__1, QEvent * arg__2)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return bool(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "eventFilter"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::eventFilter(arg__1, arg__2);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter< ::QObject * >::toPython(arg__1),
        Shiboken::Converter< ::QEvent * >::toPython(arg__2)
    ));
    bool invalidadeArg2 = PyTuple_GET_ITEM(pyargs, 1)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QUiLoader.eventFilter", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    if (invalidadeArg2)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 1));
    return cppResult;
}

void QUiLoaderWrapper::timerEvent(QTimerEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "timerEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::timerEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QTimerEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

const QMetaObject* QUiLoaderWrapper::metaObject() const
{
    SbkObject* pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    return reinterpret_cast<QMetaObject*>(Shiboken::Object::getTypeUserData(pySelf));
}

int QUiLoaderWrapper::qt_metacall(QMetaObject::Call call, int id, void** args)
{
    int result = QUiLoader::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

QUiLoaderWrapper::~QUiLoaderWrapper()
{
    SbkObject* wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QUiLoader_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QUiLoader >()))
        return -1;

    QUiLoaderWrapper* cptr = 0;
    int overloadId = -1;
    const char* argNames[] = {"parent"};
    const QMetaObject* metaObject;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths


    if (!PyArg_ParseTuple(args, "|O:QUiLoader", &(pyargs[0])))
        return -1;

    // Overloaded function decisor
    // 0: QUiLoader(QObject*)
    if (numArgs == 0) {
        overloadId = 0; // QUiLoader(QObject*)
    } else if (Shiboken::Converter< ::QObject * >::isConvertible(pyargs[0])) {
        overloadId = 0; // QUiLoader(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QUiLoader_Init_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "parent");
                if (value) {
                    if (pyargs[0])
                        errorArgName = "parent";
                    else if (Shiboken::Converter< ::QObject * >::isConvertible(value))
                        pyargs[0] = value;
                    else
                        goto Sbk_QUiLoader_Init_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtUiTools.QUiLoader(): got multiple values for keyword argument '%s'", errorArgName);
                    return -1;
                }
            }
            if (!Shiboken::Object::isValid(pyargs[0]))
                return -1;
            QObject * cppArg0 = pyargs[0] ? Shiboken::Converter<QObject * >::toCpp(pyargs[0]) : 0;

            if(!PyErr_Occurred()) {
                // QUiLoader(QObject*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new QUiLoaderWrapper(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                Shiboken::Object::setParent(pyargs[0], self);
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QUiLoader >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QUiLoader_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    metaObject = cptr->metaObject(); // <- init python qt properties
    if (kwds && !PySide::fillQtProperties(self, metaObject, kwds, argNames, 1))
        return -1;


    return 1;

    Sbk_QUiLoader_Init_TypeError:
        const char* overloads[] = {"PySide.QtCore.QObject = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtUiTools.QUiLoader", overloads);
        return -1;
}

static PyObject* Sbk_QUiLoaderFunc_addPluginPath(PyObject* self, PyObject* arg)
{
    QUiLoader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QUiLoader* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: addPluginPath(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // addPluginPath(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QUiLoaderFunc_addPluginPath_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // addPluginPath(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->addPluginPath(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QUiLoaderFunc_addPluginPath_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtUiTools.QUiLoader.addPluginPath", overloads);
        return 0;
}

static PyObject* Sbk_QUiLoaderFunc_availableLayouts(PyObject* self)
{
    QUiLoader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QUiLoader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // availableLayouts()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QStringList cppResult = const_cast<const QUiLoader*>(cppSelf)->availableLayouts();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QStringList >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QUiLoaderFunc_availableWidgets(PyObject* self)
{
    QUiLoader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QUiLoader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // availableWidgets()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QStringList cppResult = const_cast<const QUiLoader*>(cppSelf)->availableWidgets();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QStringList >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QUiLoaderFunc_clearPluginPaths(PyObject* self)
{
    QUiLoader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QUiLoader* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // clearPluginPaths()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->clearPluginPaths();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QUiLoaderFunc_createAction(PyObject* self, PyObject* args, PyObject* kwds)
{
    QUiLoader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QUiLoader* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtUiTools.QUiLoader.createAction(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:createAction", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: createAction(QObject*,QString)
    if (numArgs == 0) {
        overloadId = 0; // createAction(QObject*,QString)
    } else if (Shiboken::Converter< ::QObject * >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // createAction(QObject*,QString)
        } else if (Shiboken::Converter< QString >::isConvertible(pyargs[1])) {
            overloadId = 0; // createAction(QObject*,QString)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QUiLoaderFunc_createAction_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "parent");
                if (value) {
                    if (pyargs[0])
                        errorArgName = "parent";
                    else if (Shiboken::Converter< ::QObject * >::isConvertible(value))
                        pyargs[0] = value;
                    else
                        goto Sbk_QUiLoaderFunc_createAction_TypeError;
                }
                value = PyDict_GetItemString(kwds, "name");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "name";
                    else if (Shiboken::Converter< QString >::isConvertible(value))
                        pyargs[1] = value;
                    else
                        goto Sbk_QUiLoaderFunc_createAction_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtUiTools.QUiLoader.createAction(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QObject * cppArg0 = pyargs[0] ? Shiboken::Converter<QObject * >::toCpp(pyargs[0]) : 0;
            QString cppArg1 = pyargs[1] ? Shiboken::Converter<QString >::toCpp(pyargs[1]) : QString();

            if(!PyErr_Occurred()) {
                // createAction(QObject*,QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QAction * cppResult = (Shiboken::Object::isUserType(self) ? cppSelf->::QUiLoader::createAction(cppArg0, cppArg1) : cppSelf->createAction(cppArg0, cppArg1));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QAction * >::toPython(cppResult);
                Shiboken::Object::setParent(pyargs[0], pyResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QUiLoaderFunc_createAction_TypeError:
        const char* overloads[] = {"PySide.QtCore.QObject = None, QString = QString()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtUiTools.QUiLoader.createAction", overloads);
        return 0;
}

static PyObject* Sbk_QUiLoaderFunc_createActionGroup(PyObject* self, PyObject* args, PyObject* kwds)
{
    QUiLoader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QUiLoader* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtUiTools.QUiLoader.createActionGroup(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:createActionGroup", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: createActionGroup(QObject*,QString)
    if (numArgs == 0) {
        overloadId = 0; // createActionGroup(QObject*,QString)
    } else if (Shiboken::Converter< ::QObject * >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // createActionGroup(QObject*,QString)
        } else if (Shiboken::Converter< QString >::isConvertible(pyargs[1])) {
            overloadId = 0; // createActionGroup(QObject*,QString)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QUiLoaderFunc_createActionGroup_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "parent");
                if (value) {
                    if (pyargs[0])
                        errorArgName = "parent";
                    else if (Shiboken::Converter< ::QObject * >::isConvertible(value))
                        pyargs[0] = value;
                    else
                        goto Sbk_QUiLoaderFunc_createActionGroup_TypeError;
                }
                value = PyDict_GetItemString(kwds, "name");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "name";
                    else if (Shiboken::Converter< QString >::isConvertible(value))
                        pyargs[1] = value;
                    else
                        goto Sbk_QUiLoaderFunc_createActionGroup_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtUiTools.QUiLoader.createActionGroup(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QObject * cppArg0 = pyargs[0] ? Shiboken::Converter<QObject * >::toCpp(pyargs[0]) : 0;
            QString cppArg1 = pyargs[1] ? Shiboken::Converter<QString >::toCpp(pyargs[1]) : QString();

            if(!PyErr_Occurred()) {
                // createActionGroup(QObject*,QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QActionGroup * cppResult = (Shiboken::Object::isUserType(self) ? cppSelf->::QUiLoader::createActionGroup(cppArg0, cppArg1) : cppSelf->createActionGroup(cppArg0, cppArg1));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QActionGroup * >::toPython(cppResult);
                Shiboken::Object::setParent(pyargs[0], pyResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QUiLoaderFunc_createActionGroup_TypeError:
        const char* overloads[] = {"PySide.QtCore.QObject = None, QString = QString()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtUiTools.QUiLoader.createActionGroup", overloads);
        return 0;
}

static PyObject* Sbk_QUiLoaderFunc_createLayout(PyObject* self, PyObject* args, PyObject* kwds)
{
    QUiLoader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QUiLoader* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtUiTools.QUiLoader.createLayout(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtUiTools.QUiLoader.createLayout(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOO:createLayout", &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: createLayout(QString,QObject*,QString)
    if (Shiboken::Converter< QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // createLayout(QString,QObject*,QString)
        } else if (Shiboken::Converter< ::QObject * >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 0; // createLayout(QString,QObject*,QString)
            } else if (Shiboken::Converter< QString >::isConvertible(pyargs[2])) {
                overloadId = 0; // createLayout(QString,QObject*,QString)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QUiLoaderFunc_createLayout_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "parent");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "parent";
                    else if (Shiboken::Converter< ::QObject * >::isConvertible(value))
                        pyargs[1] = value;
                    else
                        goto Sbk_QUiLoaderFunc_createLayout_TypeError;
                }
                value = PyDict_GetItemString(kwds, "name");
                if (value) {
                    if (pyargs[2])
                        errorArgName = "name";
                    else if (Shiboken::Converter< QString >::isConvertible(value))
                        pyargs[2] = value;
                    else
                        goto Sbk_QUiLoaderFunc_createLayout_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtUiTools.QUiLoader.createLayout(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            QObject * cppArg1 = pyargs[1] ? Shiboken::Converter<QObject * >::toCpp(pyargs[1]) : 0;
            QString cppArg2 = pyargs[2] ? Shiboken::Converter<QString >::toCpp(pyargs[2]) : QString();

            if(!PyErr_Occurred()) {
                // createLayout(QString,QObject*,QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QLayout * cppResult = (Shiboken::Object::isUserType(self) ? cppSelf->::QUiLoader::createLayout(cppArg0, cppArg1, cppArg2) : cppSelf->createLayout(cppArg0, cppArg1, cppArg2));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QLayout * >::toPython(cppResult);
                Shiboken::Object::setParent(pyargs[1], pyResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QUiLoaderFunc_createLayout_TypeError:
        const char* overloads[] = {"QString, PySide.QtCore.QObject = None, QString = QString()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtUiTools.QUiLoader.createLayout", overloads);
        return 0;
}

static PyObject* Sbk_QUiLoaderFunc_createWidget(PyObject* self, PyObject* args, PyObject* kwds)
{
    QUiLoader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QUiLoader* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtUiTools.QUiLoader.createWidget(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtUiTools.QUiLoader.createWidget(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOO:createWidget", &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: createWidget(QString,QWidget*,QString)
    if (Shiboken::Converter< QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // createWidget(QString,QWidget*,QString)
        } else if (Shiboken::Converter< ::QWidget * >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 0; // createWidget(QString,QWidget*,QString)
            } else if (Shiboken::Converter< QString >::isConvertible(pyargs[2])) {
                overloadId = 0; // createWidget(QString,QWidget*,QString)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QUiLoaderFunc_createWidget_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "parent");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "parent";
                    else if (Shiboken::Converter< ::QWidget * >::isConvertible(value))
                        pyargs[1] = value;
                    else
                        goto Sbk_QUiLoaderFunc_createWidget_TypeError;
                }
                value = PyDict_GetItemString(kwds, "name");
                if (value) {
                    if (pyargs[2])
                        errorArgName = "name";
                    else if (Shiboken::Converter< QString >::isConvertible(value))
                        pyargs[2] = value;
                    else
                        goto Sbk_QUiLoaderFunc_createWidget_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtUiTools.QUiLoader.createWidget(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            QWidget * cppArg1 = pyargs[1] ? Shiboken::Converter<QWidget * >::toCpp(pyargs[1]) : 0;
            QString cppArg2 = pyargs[2] ? Shiboken::Converter<QString >::toCpp(pyargs[2]) : QString();

            if(!PyErr_Occurred()) {
                // createWidget(QString,QWidget*,QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QWidget * cppResult = (Shiboken::Object::isUserType(self) ? cppSelf->::QUiLoader::createWidget(cppArg0, cppArg1, cppArg2) : cppSelf->createWidget(cppArg0, cppArg1, cppArg2));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QWidget * >::toPython(cppResult);
                Shiboken::Object::setParent(pyargs[1], pyResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QUiLoaderFunc_createWidget_TypeError:
        const char* overloads[] = {"QString, PySide.QtGui.QWidget = None, QString = QString()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtUiTools.QUiLoader.createWidget", overloads);
        return 0;
}

static PyObject* Sbk_QUiLoaderFunc_isLanguageChangeEnabled(PyObject* self)
{
    QUiLoader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QUiLoader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isLanguageChangeEnabled()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QUiLoader*>(cppSelf)->isLanguageChangeEnabled();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QUiLoaderFunc_isScriptingEnabled(PyObject* self)
{
    QUiLoader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QUiLoader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isScriptingEnabled()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QUiLoader*>(cppSelf)->isScriptingEnabled();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QUiLoaderFunc_isTranslationEnabled(PyObject* self)
{
    QUiLoader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QUiLoader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isTranslationEnabled()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QUiLoader*>(cppSelf)->isTranslationEnabled();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QUiLoaderFunc_load(PyObject* self, PyObject* args, PyObject* kwds)
{
    QUiLoader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QUiLoader* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtUiTools.QUiLoader.load(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtUiTools.QUiLoader.load(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:load", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: load(QIODevice*,QWidget*)
    // 1: load(QString,QWidget*)
    if (Shiboken::Converter< ::QIODevice * >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // load(QIODevice*,QWidget*)
        } else if (Shiboken::Converter< ::QWidget * >::isConvertible(pyargs[1])) {
            overloadId = 0; // load(QIODevice*,QWidget*)
        }
    } else if (Shiboken::Converter< QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 1; // load(QString,QWidget*)
        } else if (Shiboken::Converter< ::QWidget * >::isConvertible(pyargs[1])) {
            overloadId = 1; // load(QString,QWidget*)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QUiLoaderFunc_load_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // load(QIODevice*,QWidget*)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "parentWidget");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "parentWidget";
                        else if (Shiboken::Converter< ::QWidget * >::isConvertible(value))
                            pyargs[1] = value;
                        else
                            goto Sbk_QUiLoaderFunc_load_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtUiTools.QUiLoader.load(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QIODevice * cppArg0 = Shiboken::Converter<QIODevice * >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QWidget * cppArg1 = pyargs[1] ? Shiboken::Converter<QWidget * >::toCpp(pyargs[1]) : 0;

                if(!PyErr_Occurred()) {
                    // load(QIODevice*,QWidget*)
                    // Begin code injection

                    //Avoid calling the original function: cppSelf->load
                    pyResult = quiloader_load_ui_from_device(cppSelf, cppArg0, cppArg1);

                    // End of code injection

                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QWidget * cppResult = cppSelf->load(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS

                    Shiboken::Object::setParent(pyargs[1], pyResult);
                    Shiboken::Object::setParent(self, pyResult);
                }
                break;
            }
            case 1: // load(QString,QWidget*)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "parentWidget");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "parentWidget";
                        else if (Shiboken::Converter< ::QWidget * >::isConvertible(value))
                            pyargs[1] = value;
                        else
                            goto Sbk_QUiLoaderFunc_load_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtUiTools.QUiLoader.load(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QWidget * cppArg1 = pyargs[1] ? Shiboken::Converter<QWidget * >::toCpp(pyargs[1]) : 0;

                if(!PyErr_Occurred()) {
                    // load(QString,QWidget*)
                    // Begin code injection

                    //Avoid calling the original function: cppSelf->load
                    pyResult = quiloader_load_ui(cppSelf, cppArg0, cppArg1);

                    // End of code injection


                    Shiboken::Object::setParent(pyargs[1], pyResult);
                }
                break;
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QUiLoaderFunc_load_TypeError:
        const char* overloads[] = {"PySide.QtCore.QIODevice, PySide.QtGui.QWidget = None", "QString, PySide.QtGui.QWidget = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtUiTools.QUiLoader.load", overloads);
        return 0;
}

static PyObject* Sbk_QUiLoaderFunc_pluginPaths(PyObject* self)
{
    QUiLoader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QUiLoader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // pluginPaths()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QStringList cppResult = const_cast<const QUiLoader*>(cppSelf)->pluginPaths();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QStringList >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QUiLoaderFunc_registerCustomWidget(PyObject* self, PyObject* arg)
{
    QUiLoader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QUiLoader* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: registerCustomWidget(PyObject*)
    if (PyObject_Check(arg)) {
        overloadId = 0; // registerCustomWidget(PyObject*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QUiLoaderFunc_registerCustomWidget_TypeError;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // registerCustomWidget(PyObject*)
                // Begin code injection

                registerCustomWidget(arg);
                cppSelf->addPluginPath(""); // force reload widgets

                // End of code injection


            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QUiLoaderFunc_registerCustomWidget_TypeError:
        const char* overloads[] = {"PyObject", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtUiTools.QUiLoader.registerCustomWidget", overloads);
        return 0;
}

static PyObject* Sbk_QUiLoaderFunc_setLanguageChangeEnabled(PyObject* self, PyObject* arg)
{
    QUiLoader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QUiLoader* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setLanguageChangeEnabled(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setLanguageChangeEnabled(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QUiLoaderFunc_setLanguageChangeEnabled_TypeError;

    // Call function/method
    {
        {
            bool cppArg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setLanguageChangeEnabled(bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setLanguageChangeEnabled(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QUiLoaderFunc_setLanguageChangeEnabled_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtUiTools.QUiLoader.setLanguageChangeEnabled", overloads);
        return 0;
}

static PyObject* Sbk_QUiLoaderFunc_setScriptingEnabled(PyObject* self, PyObject* arg)
{
    QUiLoader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QUiLoader* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setScriptingEnabled(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setScriptingEnabled(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QUiLoaderFunc_setScriptingEnabled_TypeError;

    // Call function/method
    {
        {
            bool cppArg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setScriptingEnabled(bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setScriptingEnabled(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QUiLoaderFunc_setScriptingEnabled_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtUiTools.QUiLoader.setScriptingEnabled", overloads);
        return 0;
}

static PyObject* Sbk_QUiLoaderFunc_setTranslationEnabled(PyObject* self, PyObject* arg)
{
    QUiLoader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QUiLoader* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setTranslationEnabled(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setTranslationEnabled(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QUiLoaderFunc_setTranslationEnabled_TypeError;

    // Call function/method
    {
        {
            bool cppArg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setTranslationEnabled(bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setTranslationEnabled(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QUiLoaderFunc_setTranslationEnabled_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtUiTools.QUiLoader.setTranslationEnabled", overloads);
        return 0;
}

static PyObject* Sbk_QUiLoaderFunc_setWorkingDirectory(PyObject* self, PyObject* arg)
{
    QUiLoader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QUiLoader* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setWorkingDirectory(QDir)
    if (Shiboken::Converter< ::QDir >::isConvertible(arg)) {
        overloadId = 0; // setWorkingDirectory(QDir)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QUiLoaderFunc_setWorkingDirectory_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QDir cppArg0 = Shiboken::Converter<QDir >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setWorkingDirectory(QDir)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setWorkingDirectory(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QUiLoaderFunc_setWorkingDirectory_TypeError:
        const char* overloads[] = {"PySide.QtCore.QDir", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtUiTools.QUiLoader.setWorkingDirectory", overloads);
        return 0;
}

static PyObject* Sbk_QUiLoaderFunc_workingDirectory(PyObject* self)
{
    QUiLoader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QUiLoader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // workingDirectory()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QDir cppResult = const_cast<const QUiLoader*>(cppSelf)->workingDirectory();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QDir >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef Sbk_QUiLoader_methods[] = {
    {"addPluginPath", (PyCFunction)Sbk_QUiLoaderFunc_addPluginPath, METH_O},
    {"availableLayouts", (PyCFunction)Sbk_QUiLoaderFunc_availableLayouts, METH_NOARGS},
    {"availableWidgets", (PyCFunction)Sbk_QUiLoaderFunc_availableWidgets, METH_NOARGS},
    {"clearPluginPaths", (PyCFunction)Sbk_QUiLoaderFunc_clearPluginPaths, METH_NOARGS},
    {"createAction", (PyCFunction)Sbk_QUiLoaderFunc_createAction, METH_VARARGS|METH_KEYWORDS},
    {"createActionGroup", (PyCFunction)Sbk_QUiLoaderFunc_createActionGroup, METH_VARARGS|METH_KEYWORDS},
    {"createLayout", (PyCFunction)Sbk_QUiLoaderFunc_createLayout, METH_VARARGS|METH_KEYWORDS},
    {"createWidget", (PyCFunction)Sbk_QUiLoaderFunc_createWidget, METH_VARARGS|METH_KEYWORDS},
    {"isLanguageChangeEnabled", (PyCFunction)Sbk_QUiLoaderFunc_isLanguageChangeEnabled, METH_NOARGS},
    {"isScriptingEnabled", (PyCFunction)Sbk_QUiLoaderFunc_isScriptingEnabled, METH_NOARGS},
    {"isTranslationEnabled", (PyCFunction)Sbk_QUiLoaderFunc_isTranslationEnabled, METH_NOARGS},
    {"load", (PyCFunction)Sbk_QUiLoaderFunc_load, METH_VARARGS|METH_KEYWORDS},
    {"pluginPaths", (PyCFunction)Sbk_QUiLoaderFunc_pluginPaths, METH_NOARGS},
    {"registerCustomWidget", (PyCFunction)Sbk_QUiLoaderFunc_registerCustomWidget, METH_O},
    {"setLanguageChangeEnabled", (PyCFunction)Sbk_QUiLoaderFunc_setLanguageChangeEnabled, METH_O},
    {"setScriptingEnabled", (PyCFunction)Sbk_QUiLoaderFunc_setScriptingEnabled, METH_O},
    {"setTranslationEnabled", (PyCFunction)Sbk_QUiLoaderFunc_setTranslationEnabled, METH_O},
    {"setWorkingDirectory", (PyCFunction)Sbk_QUiLoaderFunc_setWorkingDirectory, METH_O},
    {"workingDirectory", (PyCFunction)Sbk_QUiLoaderFunc_workingDirectory, METH_NOARGS},

    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QUiLoader_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtUiTools.QUiLoader",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QUiLoader_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QUiLoader_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern

static SbkObjectType* Sbk_QUiLoader_typeDiscovery(void* cptr, SbkObjectType* instanceType)
{
    if (instanceType == reinterpret_cast<SbkObjectType*>(Shiboken::SbkType<QObject >()) && dynamic_cast<QUiLoader*>(reinterpret_cast<QObject*>(cptr)))
        return &Sbk_QUiLoader_Type;
    return 0;
}


void init_QUiLoader(PyObject* module)
{
    SbkPySide_QtUiToolsTypes[SBK_QUILOADER_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QUiLoader_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QUiLoader_Type);
    Shiboken::ObjectType::setSubTypeInitHook(&Sbk_QUiLoader_Type, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(&Sbk_QUiLoader_Type, &QUiLoader::staticMetaObject);    // Begin code injection

    Q_IMPORT_PLUGIN(uiplugin);

    // End of code injection

    Sbk_QUiLoader_Type.super.ht_type.tp_base = SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX];
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QUiLoader_Type, &Shiboken::callCppDestructor<QUiLoader >);
    if (PyType_Ready((PyTypeObject*)&Sbk_QUiLoader_Type) < 0)
        return;

    // Fill type discovery information
    Shiboken::ObjectType::setTypeDiscoveryFunction(&Sbk_QUiLoader_Type, &Sbk_QUiLoader_typeDiscovery);
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkObjectType*>(SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX]), &Sbk_QUiLoader_Type);

    Shiboken::ObjectType::setOriginalName(&Sbk_QUiLoader_Type, "QUiLoader*");
    PyModule_AddObject(module, "QUiLoader",
        ((PyObject*)&Sbk_QUiLoader_Type));



    Shiboken::TypeResolver::createObjectTypeResolver<QUiLoader >("QUiLoader*");
    Shiboken::TypeResolver::createObjectTypeResolver<QUiLoader >(typeid(QUiLoader).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QUiLoader >(typeid(QUiLoaderWrapper).name());
    PySide::initQtMetaType< ::QUiLoader* >();
}


