/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtwebkit_python.h"

#include "qwebpluginfactory_mimetype_wrapper.h"

// Extra includes
#include <qwebpluginfactory.h>



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QWebPluginFactory_MimeType_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QWebPluginFactory::MimeType >()))
        return -1;

    QWebPluginFactory::MimeType* cptr = 0;
    int overloadId = -1;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "MimeType", 0, 1, &(pyargs[0])))
        return -1;

    // Overloaded function decisor
    // 0: MimeType()
    // 1: MimeType(QWebPluginFactory::MimeType)
    if (numArgs == 0) {
        overloadId = 0; // MimeType()
    } else if (numArgs == 1 && Shiboken::Converter< ::QWebPluginFactory::MimeType >::isConvertible(pyargs[0])) {
        overloadId = 1; // MimeType(QWebPluginFactory::MimeType)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWebPluginFactory_MimeType_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // MimeType()
            {

                if(!PyErr_Occurred()) {
                    // MimeType()
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QWebPluginFactory::MimeType();
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // MimeType(QWebPluginFactory::MimeType)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QWebPluginFactory::MimeType cppArg0 = Shiboken::Converter<QWebPluginFactory::MimeType >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // MimeType(QWebPluginFactory::MimeType)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QWebPluginFactory::MimeType(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QWebPluginFactory::MimeType >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QWebPluginFactory_MimeType_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QWebPluginFactory_MimeType_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtWebKit.QWebPluginFactory::MimeType", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtWebKit.MimeType", overloads);
        return -1;
}

static PyObject *Sbk_QWebPluginFactory_MimeType___copy__(PyObject *self)
{
        QWebPluginFactory::MimeType* cppSelf = 0;
        if (!Shiboken::Object::isValid(self))
            return 0;
        cppSelf = Shiboken::Converter<QWebPluginFactory::MimeType*>::toCpp(self);
        PyObject* pyResult = 0;
        QWebPluginFactory::MimeType* copy = new QWebPluginFactory::MimeType(*cppSelf);
        pyResult = Shiboken::Converter<QWebPluginFactory::MimeType*>::toPython(copy);
        Shiboken::Object::getOwnership(pyResult);

        if (PyErr_Occurred() || !pyResult) {
            Py_XDECREF(pyResult);
            return 0;
        }
        return pyResult;
}

static PyMethodDef Sbk_QWebPluginFactory_MimeType_methods[] = {

    {"__copy__", (PyCFunction)Sbk_QWebPluginFactory_MimeType___copy__, METH_NOARGS},
    {0} // Sentinel
};

// Rich comparison
static PyObject* Sbk_QWebPluginFactory_MimeType_richcompare(PyObject* self, PyObject* arg, int op)
{
    PyObject* pyResult = 0;
    QWebPluginFactory::MimeType& cppSelf = *Shiboken::Converter< QWebPluginFactory::MimeType* >::toCpp(self);

    switch (op) {
        case Py_NE:
            if (Shiboken::Converter< ::QWebPluginFactory::MimeType >::isConvertible(arg)) {
                // operator!=(const QWebPluginFactory::MimeType & other) const
                QWebPluginFactory::MimeType cppArg0 = Shiboken::Converter< ::QWebPluginFactory::MimeType >::toCpp(arg);
                pyResult = Shiboken::Converter< bool >::toPython(cppSelf != cppArg0);
            } else goto Sbk_QWebPluginFactory_MimeType_RichComparison_TypeError;

            break;
        case Py_EQ:
            if (Shiboken::Converter< ::QWebPluginFactory::MimeType >::isConvertible(arg)) {
                // operator==(const QWebPluginFactory::MimeType & other) const
                QWebPluginFactory::MimeType cppArg0 = Shiboken::Converter< ::QWebPluginFactory::MimeType >::toCpp(arg);
                pyResult = Shiboken::Converter< bool >::toPython(cppSelf == cppArg0);
            } else goto Sbk_QWebPluginFactory_MimeType_RichComparison_TypeError;

            break;
        default:
            goto Sbk_QWebPluginFactory_MimeType_RichComparison_TypeError;
    }

    if (pyResult && !PyErr_Occurred())
        return pyResult;
    Sbk_QWebPluginFactory_MimeType_RichComparison_TypeError:
    PyErr_SetString(PyExc_NotImplementedError, "operator not implemented.");
    return 0;

}

static PyObject* Sbk_QWebPluginFactory_MimeType_get_description(PyObject* self, void*)
{
    PyObject* val = Shiboken::Converter< QString >::toPython( Shiboken::Converter< QWebPluginFactory::MimeType* >::toCpp(self)->description);
    return val;
}

static int Sbk_QWebPluginFactory_MimeType_set_description(PyObject* self, PyObject* value, void*)
{
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'description' may not be deleted");
        return -1;
    }
    if (!Shiboken::Converter< QString >::isConvertible(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'description', 'QString' or convertible type expected");
        return -1;
    }

    Shiboken::Converter< QWebPluginFactory::MimeType* >::toCpp(self)->description = Shiboken::Converter< QString >::toCpp(value);

    return 0;
}

static PyObject* Sbk_QWebPluginFactory_MimeType_get_name(PyObject* self, void*)
{
    PyObject* val = Shiboken::Converter< QString >::toPython( Shiboken::Converter< QWebPluginFactory::MimeType* >::toCpp(self)->name);
    return val;
}

static int Sbk_QWebPluginFactory_MimeType_set_name(PyObject* self, PyObject* value, void*)
{
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'name' may not be deleted");
        return -1;
    }
    if (!Shiboken::Converter< QString >::isConvertible(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'name', 'QString' or convertible type expected");
        return -1;
    }

    Shiboken::Converter< QWebPluginFactory::MimeType* >::toCpp(self)->name = Shiboken::Converter< QString >::toCpp(value);

    return 0;
}

static PyObject* Sbk_QWebPluginFactory_MimeType_get_fileExtensions(PyObject* self, void*)
{
    PyObject* val = Shiboken::createWrapper(&Shiboken::Converter< QWebPluginFactory::MimeType* >::toCpp(self)->fileExtensions);
    Shiboken::Object::releaseOwnership(val);
    return val;
}

static int Sbk_QWebPluginFactory_MimeType_set_fileExtensions(PyObject* self, PyObject* value, void*)
{
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'fileExtensions' may not be deleted");
        return -1;
    }
    if (!Shiboken::Converter< ::QStringList >::isConvertible(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'fileExtensions', 'QList' or convertible type expected");
        return -1;
    }

    Shiboken::Converter< QWebPluginFactory::MimeType* >::toCpp(self)->fileExtensions = Shiboken::Converter< ::QStringList >::toCpp(value);

    return 0;
}

// Getters and Setters for MimeType
static PyGetSetDef Sbk_QWebPluginFactory_MimeType_getsetlist[] = {
    {const_cast<char*>("description"), Sbk_QWebPluginFactory_MimeType_get_description, Sbk_QWebPluginFactory_MimeType_set_description},
    {const_cast<char*>("name"), Sbk_QWebPluginFactory_MimeType_get_name, Sbk_QWebPluginFactory_MimeType_set_name},
    {const_cast<char*>("fileExtensions"), Sbk_QWebPluginFactory_MimeType_get_fileExtensions, Sbk_QWebPluginFactory_MimeType_set_fileExtensions},
    {0}  // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QWebPluginFactory_MimeType_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtWebKit.QWebPluginFactory.MimeType",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      Sbk_QWebPluginFactory_MimeType_richcompare,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QWebPluginFactory_MimeType_methods,
    /*tp_members*/          0,
    /*tp_getset*/           Sbk_QWebPluginFactory_MimeType_getsetlist,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QWebPluginFactory_MimeType_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QWebPluginFactory_MimeType(PyObject* module)
{
    SbkPySide_QtWebKitTypes[SBK_QWEBPLUGINFACTORY_MIMETYPE_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QWebPluginFactory_MimeType_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QWebPluginFactory_MimeType_Type);
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QWebPluginFactory_MimeType_Type, &Shiboken::callCppDestructor<QWebPluginFactory::MimeType >);
    if (PyType_Ready((PyTypeObject*)&Sbk_QWebPluginFactory_MimeType_Type) < 0)
        return;

    Shiboken::ObjectType::setOriginalName(&Sbk_QWebPluginFactory_MimeType_Type, "QWebPluginFactory::MimeType");
    PyDict_SetItemString(module,"MimeType", (PyObject*)&Sbk_QWebPluginFactory_MimeType_Type);

    Shiboken::TypeResolver::createValueTypeResolver<QWebPluginFactory::MimeType >("QWebPluginFactory::MimeType");
    Shiboken::TypeResolver::createObjectTypeResolver<QWebPluginFactory::MimeType >("QWebPluginFactory::MimeType*");
    Shiboken::TypeResolver::createValueTypeResolver<QWebPluginFactory::MimeType >(typeid(QWebPluginFactory::MimeType).name());
    PySide::initQtMetaType< ::QWebPluginFactory::MimeType >();
}

