/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtxml_python.h"

#include "qdomelement_wrapper.h"

// Extra includes
#include <qdom.h>
#include <qtextstream.h>



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QDomElement_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QDomElement >()))
        return -1;

    QDomElement* cptr = 0;
    int overloadId = -1;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QDomElement", 0, 1, &(pyargs[0])))
        return -1;

    // Overloaded function decisor
    // 0: QDomElement()
    // 1: QDomElement(QDomElement)
    if (numArgs == 0) {
        overloadId = 0; // QDomElement()
    } else if (numArgs == 1 && Shiboken::Converter< ::QDomElement >::isConvertible(pyargs[0])) {
        overloadId = 1; // QDomElement(QDomElement)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDomElement_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QDomElement()
            {

                if(!PyErr_Occurred()) {
                    // QDomElement()
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QDomElement();
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // QDomElement(QDomElement)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QDomElement cppArg0 = Shiboken::Converter<QDomElement >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QDomElement(QDomElement)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QDomElement(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QDomElement >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QDomElement_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QDomElement_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtXml.QDomElement", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtXml.QDomElement", overloads);
        return -1;
}

static PyObject* Sbk_QDomElementFunc_attribute(PyObject* self, PyObject* args, PyObject* kwds)
{
    QDomElement* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDomElement* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtXml.QDomElement.attribute(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtXml.QDomElement.attribute(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:attribute", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: attribute(QString,QString)const
    if (Shiboken::Converter< QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // attribute(QString,QString)const
        } else if (Shiboken::Converter< QString >::isConvertible(pyargs[1])) {
            overloadId = 0; // attribute(QString,QString)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDomElementFunc_attribute_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "defValue");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "defValue";
                    else if (Shiboken::Converter< QString >::isConvertible(value))
                        pyargs[1] = value;
                    else
                        goto Sbk_QDomElementFunc_attribute_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtXml.QDomElement.attribute(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            QString cppArg1 = pyargs[1] ? Shiboken::Converter<QString >::toCpp(pyargs[1]) : QString();

            if(!PyErr_Occurred()) {
                // attribute(QString,QString)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QDomElement*>(cppSelf)->attribute(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QDomElementFunc_attribute_TypeError:
        const char* overloads[] = {"QString, QString = QString()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtXml.QDomElement.attribute", overloads);
        return 0;
}

static PyObject* Sbk_QDomElementFunc_attributeNS(PyObject* self, PyObject* args, PyObject* kwds)
{
    QDomElement* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDomElement* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtXml.QDomElement.attributeNS(): too many arguments");
        return 0;
    } else if (numArgs < 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtXml.QDomElement.attributeNS(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOO:attributeNS", &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: attributeNS(QString,QString,QString)const
    if (numArgs >= 2 && Shiboken::Converter< QString >::isConvertible(pyargs[0]) && Shiboken::Converter< QString >::isConvertible(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 0; // attributeNS(QString,QString,QString)const
        } else if (Shiboken::Converter< QString >::isConvertible(pyargs[2])) {
            overloadId = 0; // attributeNS(QString,QString,QString)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDomElementFunc_attributeNS_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "defValue");
                if (value) {
                    if (pyargs[2])
                        errorArgName = "defValue";
                    else if (Shiboken::Converter< QString >::isConvertible(value))
                        pyargs[2] = value;
                    else
                        goto Sbk_QDomElementFunc_attributeNS_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtXml.QDomElement.attributeNS(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            QString cppArg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);
            QString cppArg2 = pyargs[2] ? Shiboken::Converter<QString >::toCpp(pyargs[2]) : QString();

            if(!PyErr_Occurred()) {
                // attributeNS(QString,QString,QString)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QDomElement*>(cppSelf)->attributeNS(cppArg0, cppArg1, cppArg2);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QDomElementFunc_attributeNS_TypeError:
        const char* overloads[] = {"QString, QString, QString = QString()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtXml.QDomElement.attributeNS", overloads);
        return 0;
}

static PyObject* Sbk_QDomElementFunc_attributeNode(PyObject* self, PyObject* arg)
{
    QDomElement* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDomElement* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: attributeNode(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // attributeNode(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDomElementFunc_attributeNode_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // attributeNode(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QDomAttr cppResult = cppSelf->attributeNode(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QDomAttr >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QDomElementFunc_attributeNode_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtXml.QDomElement.attributeNode", overloads);
        return 0;
}

static PyObject* Sbk_QDomElementFunc_attributeNodeNS(PyObject* self, PyObject* args)
{
    QDomElement* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDomElement* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "attributeNodeNS", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: attributeNodeNS(QString,QString)
    if (numArgs == 2 && Shiboken::Converter< QString >::isConvertible(pyargs[0]) && Shiboken::Converter< QString >::isConvertible(pyargs[1])) {
        overloadId = 0; // attributeNodeNS(QString,QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDomElementFunc_attributeNodeNS_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            QString cppArg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // attributeNodeNS(QString,QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QDomAttr cppResult = cppSelf->attributeNodeNS(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QDomAttr >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QDomElementFunc_attributeNodeNS_TypeError:
        const char* overloads[] = {"QString, QString", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtXml.QDomElement.attributeNodeNS", overloads);
        return 0;
}

static PyObject* Sbk_QDomElementFunc_attributes(PyObject* self)
{
    QDomElement* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDomElement* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // attributes()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QDomNamedNodeMap cppResult = const_cast<const QDomElement*>(cppSelf)->attributes();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QDomNamedNodeMap >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDomElementFunc_elementsByTagName(PyObject* self, PyObject* arg)
{
    QDomElement* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDomElement* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: elementsByTagName(QString)const
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // elementsByTagName(QString)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDomElementFunc_elementsByTagName_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // elementsByTagName(QString)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QDomNodeList cppResult = const_cast<const QDomElement*>(cppSelf)->elementsByTagName(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QDomNodeList >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QDomElementFunc_elementsByTagName_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtXml.QDomElement.elementsByTagName", overloads);
        return 0;
}

static PyObject* Sbk_QDomElementFunc_elementsByTagNameNS(PyObject* self, PyObject* args)
{
    QDomElement* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDomElement* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "elementsByTagNameNS", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: elementsByTagNameNS(QString,QString)const
    if (numArgs == 2 && Shiboken::Converter< QString >::isConvertible(pyargs[0]) && Shiboken::Converter< QString >::isConvertible(pyargs[1])) {
        overloadId = 0; // elementsByTagNameNS(QString,QString)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDomElementFunc_elementsByTagNameNS_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            QString cppArg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // elementsByTagNameNS(QString,QString)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QDomNodeList cppResult = const_cast<const QDomElement*>(cppSelf)->elementsByTagNameNS(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QDomNodeList >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QDomElementFunc_elementsByTagNameNS_TypeError:
        const char* overloads[] = {"QString, QString", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtXml.QDomElement.elementsByTagNameNS", overloads);
        return 0;
}

static PyObject* Sbk_QDomElementFunc_hasAttribute(PyObject* self, PyObject* arg)
{
    QDomElement* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDomElement* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: hasAttribute(QString)const
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // hasAttribute(QString)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDomElementFunc_hasAttribute_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // hasAttribute(QString)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QDomElement*>(cppSelf)->hasAttribute(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QDomElementFunc_hasAttribute_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtXml.QDomElement.hasAttribute", overloads);
        return 0;
}

static PyObject* Sbk_QDomElementFunc_hasAttributeNS(PyObject* self, PyObject* args)
{
    QDomElement* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDomElement* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "hasAttributeNS", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: hasAttributeNS(QString,QString)const
    if (numArgs == 2 && Shiboken::Converter< QString >::isConvertible(pyargs[0]) && Shiboken::Converter< QString >::isConvertible(pyargs[1])) {
        overloadId = 0; // hasAttributeNS(QString,QString)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDomElementFunc_hasAttributeNS_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            QString cppArg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // hasAttributeNS(QString,QString)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QDomElement*>(cppSelf)->hasAttributeNS(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QDomElementFunc_hasAttributeNS_TypeError:
        const char* overloads[] = {"QString, QString", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtXml.QDomElement.hasAttributeNS", overloads);
        return 0;
}

static PyObject* Sbk_QDomElementFunc_nodeType(PyObject* self)
{
    QDomElement* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDomElement* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // nodeType()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QDomNode::NodeType cppResult = const_cast<const QDomElement*>(cppSelf)->nodeType();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QDomNode::NodeType >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDomElementFunc_removeAttribute(PyObject* self, PyObject* arg)
{
    QDomElement* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDomElement* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: removeAttribute(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // removeAttribute(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDomElementFunc_removeAttribute_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // removeAttribute(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->removeAttribute(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QDomElementFunc_removeAttribute_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtXml.QDomElement.removeAttribute", overloads);
        return 0;
}

static PyObject* Sbk_QDomElementFunc_removeAttributeNS(PyObject* self, PyObject* args)
{
    QDomElement* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDomElement* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "removeAttributeNS", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: removeAttributeNS(QString,QString)
    if (numArgs == 2 && Shiboken::Converter< QString >::isConvertible(pyargs[0]) && Shiboken::Converter< QString >::isConvertible(pyargs[1])) {
        overloadId = 0; // removeAttributeNS(QString,QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDomElementFunc_removeAttributeNS_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            QString cppArg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // removeAttributeNS(QString,QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->removeAttributeNS(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QDomElementFunc_removeAttributeNS_TypeError:
        const char* overloads[] = {"QString, QString", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtXml.QDomElement.removeAttributeNS", overloads);
        return 0;
}

static PyObject* Sbk_QDomElementFunc_removeAttributeNode(PyObject* self, PyObject* arg)
{
    QDomElement* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDomElement* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: removeAttributeNode(QDomAttr)
    if (Shiboken::Converter< ::QDomAttr >::isConvertible(arg)) {
        overloadId = 0; // removeAttributeNode(QDomAttr)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDomElementFunc_removeAttributeNode_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QDomAttr cppArg0 = Shiboken::Converter<QDomAttr >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // removeAttributeNode(QDomAttr)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QDomAttr cppResult = cppSelf->removeAttributeNode(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QDomAttr >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QDomElementFunc_removeAttributeNode_TypeError:
        const char* overloads[] = {"PySide.QtXml.QDomAttr", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtXml.QDomElement.removeAttributeNode", overloads);
        return 0;
}

static PyObject* Sbk_QDomElementFunc_setAttribute(PyObject* self, PyObject* args)
{
    QDomElement* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDomElement* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setAttribute", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setAttribute(QString,QString)
    // 1: setAttribute(QString,double)
    // 2: setAttribute(QString,float)
    // 3: setAttribute(QString,int)
    // 4: setAttribute(QString,qlonglong)
    // 5: setAttribute(QString,qulonglong)
    // 6: setAttribute(QString,uint)
    if (Shiboken::Converter< QString >::isConvertible(pyargs[0])) {
        if (numArgs == 2 && SbkNumber_Check(pyargs[1])) {
            overloadId = 6; // setAttribute(QString,uint)
        } else if (numArgs == 2 && PyLong_Check(pyargs[1])) {
            overloadId = 5; // setAttribute(QString,qulonglong)
        } else if (numArgs == 2 && PyLong_Check(pyargs[1])) {
            overloadId = 4; // setAttribute(QString,qlonglong)
        } else if (numArgs == 2 && PyFloat_Check(pyargs[1])) {
            overloadId = 2; // setAttribute(QString,float)
        } else if (numArgs == 2 && PyFloat_Check(pyargs[1])) {
            overloadId = 1; // setAttribute(QString,double)
        } else if (numArgs == 2 && SbkNumber_Check(pyargs[1])) {
            overloadId = 3; // setAttribute(QString,int)
        } else if (numArgs == 2 && Shiboken::Converter< QString >::isConvertible(pyargs[1])) {
            overloadId = 0; // setAttribute(QString,QString)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDomElementFunc_setAttribute_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // setAttribute(QString,QString)
            {
                QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                QString cppArg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // setAttribute(QString,QString)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setAttribute(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // setAttribute(QString,double)
            {
                QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                double cppArg1 = Shiboken::Converter<double >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // setAttribute(QString,double)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setAttribute(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 2: // setAttribute(QString,float)
            {
                QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                float cppArg1 = Shiboken::Converter<float >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // setAttribute(QString,float)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setAttribute(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 3: // setAttribute(QString,int)
            {
                QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // setAttribute(QString,int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setAttribute(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 4: // setAttribute(QString,qlonglong)
            {
                QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                qlonglong cppArg1 = Shiboken::Converter<qlonglong >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // setAttribute(QString,qlonglong)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setAttribute(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 5: // setAttribute(QString,qulonglong)
            {
                QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                qulonglong cppArg1 = Shiboken::Converter<qulonglong >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // setAttribute(QString,qulonglong)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setAttribute(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 6: // setAttribute(QString,uint)
            {
                QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                uint cppArg1 = Shiboken::Converter<uint >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // setAttribute(QString,uint)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setAttribute(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QDomElementFunc_setAttribute_TypeError:
        const char* overloads[] = {"QString, QString", "QString, float", "QString, float", "QString, int", "QString, long long", "QString, unsigned long long", "QString, unsigned int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtXml.QDomElement.setAttribute", overloads);
        return 0;
}

static PyObject* Sbk_QDomElementFunc_setAttributeNS(PyObject* self, PyObject* args)
{
    QDomElement* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDomElement* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setAttributeNS", 3, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: setAttributeNS(QString,QString,QString)
    // 1: setAttributeNS(QString,QString,double)
    // 2: setAttributeNS(QString,QString,int)
    // 3: setAttributeNS(QString,QString,qlonglong)
    // 4: setAttributeNS(QString,QString,qulonglong)
    // 5: setAttributeNS(QString,QString,uint)
    if (numArgs >= 2 && Shiboken::Converter< QString >::isConvertible(pyargs[0]) && Shiboken::Converter< QString >::isConvertible(pyargs[1])) {
        if (numArgs == 3 && SbkNumber_Check(pyargs[2])) {
            overloadId = 5; // setAttributeNS(QString,QString,uint)
        } else if (numArgs == 3 && PyLong_Check(pyargs[2])) {
            overloadId = 4; // setAttributeNS(QString,QString,qulonglong)
        } else if (numArgs == 3 && PyLong_Check(pyargs[2])) {
            overloadId = 3; // setAttributeNS(QString,QString,qlonglong)
        } else if (numArgs == 3 && PyFloat_Check(pyargs[2])) {
            overloadId = 1; // setAttributeNS(QString,QString,double)
        } else if (numArgs == 3 && SbkNumber_Check(pyargs[2])) {
            overloadId = 2; // setAttributeNS(QString,QString,int)
        } else if (numArgs == 3 && Shiboken::Converter< QString >::isConvertible(pyargs[2])) {
            overloadId = 0; // setAttributeNS(QString,QString,QString)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDomElementFunc_setAttributeNS_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // setAttributeNS(QString,QString,QString)
            {
                QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                QString cppArg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);
                QString cppArg2 = Shiboken::Converter<QString >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                    // setAttributeNS(QString,QString,QString)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setAttributeNS(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // setAttributeNS(QString,QString,double)
            {
                QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                QString cppArg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);
                double cppArg2 = Shiboken::Converter<double >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                    // setAttributeNS(QString,QString,double)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setAttributeNS(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 2: // setAttributeNS(QString,QString,int)
            {
                QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                QString cppArg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);
                int cppArg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                    // setAttributeNS(QString,QString,int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setAttributeNS(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 3: // setAttributeNS(QString,QString,qlonglong)
            {
                QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                QString cppArg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);
                qlonglong cppArg2 = Shiboken::Converter<qlonglong >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                    // setAttributeNS(QString,QString,qlonglong)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setAttributeNS(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 4: // setAttributeNS(QString,QString,qulonglong)
            {
                QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                QString cppArg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);
                qulonglong cppArg2 = Shiboken::Converter<qulonglong >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                    // setAttributeNS(QString,QString,qulonglong)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setAttributeNS(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 5: // setAttributeNS(QString,QString,uint)
            {
                QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                QString cppArg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);
                uint cppArg2 = Shiboken::Converter<uint >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                    // setAttributeNS(QString,QString,uint)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setAttributeNS(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QDomElementFunc_setAttributeNS_TypeError:
        const char* overloads[] = {"QString, QString, QString", "QString, QString, float", "QString, QString, int", "QString, QString, long long", "QString, QString, unsigned long long", "QString, QString, unsigned int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtXml.QDomElement.setAttributeNS", overloads);
        return 0;
}

static PyObject* Sbk_QDomElementFunc_setAttributeNode(PyObject* self, PyObject* arg)
{
    QDomElement* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDomElement* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setAttributeNode(QDomAttr)
    if (Shiboken::Converter< ::QDomAttr >::isConvertible(arg)) {
        overloadId = 0; // setAttributeNode(QDomAttr)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDomElementFunc_setAttributeNode_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QDomAttr cppArg0 = Shiboken::Converter<QDomAttr >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setAttributeNode(QDomAttr)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QDomAttr cppResult = cppSelf->setAttributeNode(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QDomAttr >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QDomElementFunc_setAttributeNode_TypeError:
        const char* overloads[] = {"PySide.QtXml.QDomAttr", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtXml.QDomElement.setAttributeNode", overloads);
        return 0;
}

static PyObject* Sbk_QDomElementFunc_setAttributeNodeNS(PyObject* self, PyObject* arg)
{
    QDomElement* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDomElement* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setAttributeNodeNS(QDomAttr)
    if (Shiboken::Converter< ::QDomAttr >::isConvertible(arg)) {
        overloadId = 0; // setAttributeNodeNS(QDomAttr)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDomElementFunc_setAttributeNodeNS_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QDomAttr cppArg0 = Shiboken::Converter<QDomAttr >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setAttributeNodeNS(QDomAttr)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QDomAttr cppResult = cppSelf->setAttributeNodeNS(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QDomAttr >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QDomElementFunc_setAttributeNodeNS_TypeError:
        const char* overloads[] = {"PySide.QtXml.QDomAttr", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtXml.QDomElement.setAttributeNodeNS", overloads);
        return 0;
}

static PyObject* Sbk_QDomElementFunc_setTagName(PyObject* self, PyObject* arg)
{
    QDomElement* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDomElement* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setTagName(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // setTagName(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDomElementFunc_setTagName_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setTagName(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setTagName(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QDomElementFunc_setTagName_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtXml.QDomElement.setTagName", overloads);
        return 0;
}

static PyObject* Sbk_QDomElementFunc_tagName(PyObject* self)
{
    QDomElement* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDomElement* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // tagName()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QDomElement*>(cppSelf)->tagName();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDomElementFunc_text(PyObject* self)
{
    QDomElement* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDomElement* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // text()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QDomElement*>(cppSelf)->text();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject *Sbk_QDomElement___copy__(PyObject *self)
{
        QDomElement* cppSelf = 0;
        if (!Shiboken::Object::isValid(self))
            return 0;
        cppSelf = Shiboken::Converter<QDomElement*>::toCpp(self);
        PyObject* pyResult = 0;
        QDomElement* copy = new QDomElement(*cppSelf);
        pyResult = Shiboken::Converter<QDomElement*>::toPython(copy);
        Shiboken::Object::getOwnership(pyResult);

        if (PyErr_Occurred() || !pyResult) {
            Py_XDECREF(pyResult);
            return 0;
        }
        return pyResult;
}

static PyMethodDef Sbk_QDomElement_methods[] = {
    {"attribute", (PyCFunction)Sbk_QDomElementFunc_attribute, METH_VARARGS|METH_KEYWORDS},
    {"attributeNS", (PyCFunction)Sbk_QDomElementFunc_attributeNS, METH_VARARGS|METH_KEYWORDS},
    {"attributeNode", (PyCFunction)Sbk_QDomElementFunc_attributeNode, METH_O},
    {"attributeNodeNS", (PyCFunction)Sbk_QDomElementFunc_attributeNodeNS, METH_VARARGS},
    {"attributes", (PyCFunction)Sbk_QDomElementFunc_attributes, METH_NOARGS},
    {"elementsByTagName", (PyCFunction)Sbk_QDomElementFunc_elementsByTagName, METH_O},
    {"elementsByTagNameNS", (PyCFunction)Sbk_QDomElementFunc_elementsByTagNameNS, METH_VARARGS},
    {"hasAttribute", (PyCFunction)Sbk_QDomElementFunc_hasAttribute, METH_O},
    {"hasAttributeNS", (PyCFunction)Sbk_QDomElementFunc_hasAttributeNS, METH_VARARGS},
    {"nodeType", (PyCFunction)Sbk_QDomElementFunc_nodeType, METH_NOARGS},
    {"removeAttribute", (PyCFunction)Sbk_QDomElementFunc_removeAttribute, METH_O},
    {"removeAttributeNS", (PyCFunction)Sbk_QDomElementFunc_removeAttributeNS, METH_VARARGS},
    {"removeAttributeNode", (PyCFunction)Sbk_QDomElementFunc_removeAttributeNode, METH_O},
    {"setAttribute", (PyCFunction)Sbk_QDomElementFunc_setAttribute, METH_VARARGS},
    {"setAttributeNS", (PyCFunction)Sbk_QDomElementFunc_setAttributeNS, METH_VARARGS},
    {"setAttributeNode", (PyCFunction)Sbk_QDomElementFunc_setAttributeNode, METH_O},
    {"setAttributeNodeNS", (PyCFunction)Sbk_QDomElementFunc_setAttributeNodeNS, METH_O},
    {"setTagName", (PyCFunction)Sbk_QDomElementFunc_setTagName, METH_O},
    {"tagName", (PyCFunction)Sbk_QDomElementFunc_tagName, METH_NOARGS},
    {"text", (PyCFunction)Sbk_QDomElementFunc_text, METH_NOARGS},

    {"__copy__", (PyCFunction)Sbk_QDomElement___copy__, METH_NOARGS},
    {0} // Sentinel
};

static int Sbk_QDomElement___nb_bool(PyObject* pyObj)
{
    if (!Shiboken::Object::isValid(pyObj))
        return -1;
    const ::QDomElement* cppSelf = Shiboken::Converter< ::QDomElement*>::toCpp(pyObj);
    int result;
    Py_BEGIN_ALLOW_THREADS
    result = !cppSelf->isNull();
    Py_END_ALLOW_THREADS
    return result;
}

// type has number operators
static PyNumberMethods Sbk_QDomElement_as_number = {
    /*nb_add*/                  (binaryfunc)0,
    /*nb_subtract*/             (binaryfunc)0,
    /*nb_multiply*/             (binaryfunc)0,
    /*nb_divide*/               (binaryfunc)0,
    /*nb_remainder*/            (binaryfunc)0,
    /*nb_divmod*/               0,
    /*nb_power*/                0,
    /*nb_negative*/             (unaryfunc)0,
    /*nb_positive*/             (unaryfunc)0,
    /*nb_absolute*/             0,
    /*nb_nonzero*/              Sbk_QDomElement___nb_bool,
    /*nb_invert*/               (unaryfunc)0,
    /*nb_lshift*/               (binaryfunc)0,
    /*nb_rshift*/               (binaryfunc)0,
    /*nb_and*/                  (binaryfunc)0,
    /*nb_xor*/                  (binaryfunc)0,
    /*nb_or*/                   (binaryfunc)0,
    /*nb_coerce*/               0,
    /*nb_int*/                  0,
    /*nb_long*/                 0,
    /*nb_float*/                0,
    /*nb_oct*/                  0,
    /*nb_hex*/                  0,
    /*nb_inplace_add*/          (binaryfunc)0,
    /*nb_inplace_subtract*/     (binaryfunc)0,
    /*nb_inplace_multiply*/     (binaryfunc)0,
    /*nb_inplace_divide*/       (binaryfunc)0,
    /*nb_inplace_remainder*/    (binaryfunc)0,
    /*nb_inplace_power*/        0,
    /*nb_inplace_lshift*/       (binaryfunc)0,
    /*nb_inplace_rshift*/       (binaryfunc)0,
    /*nb_inplace_and*/          (binaryfunc)0,
    /*nb_inplace_xor*/          (binaryfunc)0,
    /*nb_inplace_or*/           (binaryfunc)0,
    /*nb_floor_divide*/         0,
    /*nb_true_divide*/          (binaryfunc)0,
    /*nb_inplace_floor_divide*/ 0,
    /*nb_inplace_true_divide*/  0,
    /*nb_index*/                0
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QDomElement_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtXml.QDomElement",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        &Sbk_QDomElement_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QDomElement_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QDomElement_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QDomElement(PyObject* module)
{
    SbkPySide_QtXmlTypes[SBK_QDOMELEMENT_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QDomElement_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QDomElement_Type);
    Sbk_QDomElement_Type.super.ht_type.tp_base = SbkPySide_QtXmlTypes[SBK_QDOMNODE_IDX];
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QDomElement_Type, &Shiboken::callCppDestructor<QDomElement >);
    if (PyType_Ready((PyTypeObject*)&Sbk_QDomElement_Type) < 0)
        return;

    Shiboken::ObjectType::setOriginalName(&Sbk_QDomElement_Type, "QDomElement");
    PyModule_AddObject(module, "QDomElement",
        ((PyObject*)&Sbk_QDomElement_Type));


    Shiboken::TypeResolver::createValueTypeResolver<QDomElement >("QDomElement");
    Shiboken::TypeResolver::createObjectTypeResolver<QDomElement >("QDomElement*");
    Shiboken::TypeResolver::createValueTypeResolver<QDomElement >(typeid(QDomElement).name());
    PySide::initQtMetaType< ::QDomElement >();
}

