/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


#include <Python.h>
#include <shiboken.h>
#include <algorithm>
#include "pyside_qtxml_python.h"



// Extra includes

// Global functions ------------------------------------------------------------

static PyMethodDef QtXml_methods[] = {
    {0} // Sentinel
};

// Classes initialization functions ------------------------------------------------------------
void init_QXmlDeclHandler(PyObject* module);
void init_QXmlLexicalHandler(PyObject* module);
void init_QXmlEntityResolver(PyObject* module);
void init_QXmlDTDHandler(PyObject* module);
void init_QXmlErrorHandler(PyObject* module);
void init_QXmlContentHandler(PyObject* module);
void init_QXmlDefaultHandler(PyObject* module);
void init_QXmlLocator(PyObject* module);
void init_QXmlReader(PyObject* module);
void init_QXmlSimpleReader(PyObject* module);
void init_QXmlParseException(PyObject* module);
void init_QXmlInputSource(PyObject* module);
void init_QXmlAttributes(PyObject* module);
void init_QXmlNamespaceSupport(PyObject* module);
void init_QDomNamedNodeMap(PyObject* module);
void init_QDomNodeList(PyObject* module);
void init_QDomNode(PyObject* module);
void init_QDomDocument(PyObject* module);
void init_QDomDocumentType(PyObject* module);
void init_QDomProcessingInstruction(PyObject* module);
void init_QDomEntityReference(PyObject* module);
void init_QDomEntity(PyObject* module);
void init_QDomNotation(PyObject* module);
void init_QDomElement(PyObject* module);
void init_QDomAttr(PyObject* module);
void init_QDomCharacterData(PyObject* module);
void init_QDomComment(PyObject* module);
void init_QDomText(PyObject* module);
void init_QDomCDATASection(PyObject* module);
void init_QDomDocumentFragment(PyObject* module);
void init_QDomImplementation(PyObject* module);

PyTypeObject** SbkPySide_QtXmlTypes;

PyTypeObject** SbkPySide_QtCoreTypes;

// Module initialization ------------------------------------------------------------

#if defined _WIN32 || defined __CYGWIN__
    #define SBK_EXPORT_MODULE __declspec(dllexport)
#elif __GNUC__ >= 4
    #define SBK_EXPORT_MODULE __attribute__ ((visibility("default")))
#else
    #define SBK_EXPORT_MODULE
#endif

extern "C" SBK_EXPORT_MODULE void initQtXml()
{
    if (!Shiboken::importModule("PySide.QtCore", &SbkPySide_QtCoreTypes)) {
        PyErr_SetString(PyExc_ImportError,"could not import PySide.QtCore");
        return;
    }

    Shiboken::init();
    PyObject* module = Py_InitModule("QtXml", QtXml_methods);

    // Create a CObject containing the API pointer array's address
    static PyTypeObject* cppApi[SBK_QtXml_IDX_COUNT];
    SbkPySide_QtXmlTypes = cppApi;
    PyObject* cppApiObject = PyCObject_FromVoidPtr(reinterpret_cast<void*>(cppApi), 0);
    PyModule_AddObject(module, "_Cpp_Api", cppApiObject);

    // Initialize classes in the type system
    init_QXmlDeclHandler(module);
    init_QXmlLexicalHandler(module);
    init_QXmlEntityResolver(module);
    init_QXmlDTDHandler(module);
    init_QXmlErrorHandler(module);
    init_QXmlContentHandler(module);
    init_QXmlDefaultHandler(module);
    init_QXmlLocator(module);
    init_QXmlReader(module);
    init_QXmlSimpleReader(module);
    init_QXmlParseException(module);
    init_QXmlInputSource(module);
    init_QXmlAttributes(module);
    init_QXmlNamespaceSupport(module);
    init_QDomNamedNodeMap(module);
    init_QDomNodeList(module);
    init_QDomNode(module);
    init_QDomDocument(module);
    init_QDomDocumentType(module);
    init_QDomProcessingInstruction(module);
    init_QDomEntityReference(module);
    init_QDomEntity(module);
    init_QDomNotation(module);
    init_QDomElement(module);
    init_QDomAttr(module);
    init_QDomCharacterData(module);
    init_QDomComment(module);
    init_QDomText(module);
    init_QDomCDATASection(module);
    init_QDomDocumentFragment(module);
    init_QDomImplementation(module);

    // Register primitive types on TypeResolver

    if (PyErr_Occurred()) {
        PyErr_Print();
        Py_FatalError("can't initialize module QtXml");
    }
}

