/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtxml_python.h"

#include "qxmlparseexception_wrapper.h"

// Extra includes
#include <qxml.h>



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QXmlParseException_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QXmlParseException >()))
        return -1;

    QXmlParseException* cptr = 0;
    int overloadId = -1;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);

    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 5) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtXml.QXmlParseException(): too many arguments");
        return -1;
    }

    if (!PyArg_ParseTuple(args, "|OOOOO:QXmlParseException", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4])))
        return -1;

    // Overloaded function decisor
    // 0: QXmlParseException(QString,int,int,QString,QString)
    // 1: QXmlParseException(QXmlParseException)
    if (numArgs == 0) {
        overloadId = 0; // QXmlParseException(QString,int,int,QString,QString)
    } else if (numArgs == 1 && Shiboken::Converter< ::QXmlParseException >::isConvertible(pyargs[0])) {
        overloadId = 1; // QXmlParseException(QXmlParseException)
    } else if (Shiboken::Converter< QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // QXmlParseException(QString,int,int,QString,QString)
        } else if (SbkNumber_Check(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 0; // QXmlParseException(QString,int,int,QString,QString)
            } else if (SbkNumber_Check(pyargs[2])) {
                if (numArgs == 3) {
                    overloadId = 0; // QXmlParseException(QString,int,int,QString,QString)
                } else if (Shiboken::Converter< QString >::isConvertible(pyargs[3])) {
                    if (numArgs == 4) {
                        overloadId = 0; // QXmlParseException(QString,int,int,QString,QString)
                    } else if (Shiboken::Converter< QString >::isConvertible(pyargs[4])) {
                        overloadId = 0; // QXmlParseException(QString,int,int,QString,QString)
                    }
                }
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QXmlParseException_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QXmlParseException(QString,int,int,QString,QString)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "name");
                    if (value) {
                        if (pyargs[0])
                            errorArgName = "name";
                        else if (Shiboken::Converter< QString >::isConvertible(value))
                            pyargs[0] = value;
                        else
                            goto Sbk_QXmlParseException_Init_TypeError;
                    }
                    value = PyDict_GetItemString(kwds, "c");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "c";
                        else if (SbkNumber_Check(value))
                            pyargs[1] = value;
                        else
                            goto Sbk_QXmlParseException_Init_TypeError;
                    }
                    value = PyDict_GetItemString(kwds, "l");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "l";
                        else if (SbkNumber_Check(value))
                            pyargs[2] = value;
                        else
                            goto Sbk_QXmlParseException_Init_TypeError;
                    }
                    value = PyDict_GetItemString(kwds, "p");
                    if (value) {
                        if (pyargs[3])
                            errorArgName = "p";
                        else if (Shiboken::Converter< QString >::isConvertible(value))
                            pyargs[3] = value;
                        else
                            goto Sbk_QXmlParseException_Init_TypeError;
                    }
                    value = PyDict_GetItemString(kwds, "s");
                    if (value) {
                        if (pyargs[4])
                            errorArgName = "s";
                        else if (Shiboken::Converter< QString >::isConvertible(value))
                            pyargs[4] = value;
                        else
                            goto Sbk_QXmlParseException_Init_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtXml.QXmlParseException(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                QString cppArg0 = pyargs[0] ? Shiboken::Converter<QString >::toCpp(pyargs[0]) : QString();
                int cppArg1 = pyargs[1] ? Shiboken::Converter<int >::toCpp(pyargs[1]) : -1;
                int cppArg2 = pyargs[2] ? Shiboken::Converter<int >::toCpp(pyargs[2]) : -1;
                QString cppArg3 = pyargs[3] ? Shiboken::Converter<QString >::toCpp(pyargs[3]) : QString();
                QString cppArg4 = pyargs[4] ? Shiboken::Converter<QString >::toCpp(pyargs[4]) : QString();

                if(!PyErr_Occurred()) {
                    // QXmlParseException(QString,int,int,QString,QString)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QXmlParseException(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // QXmlParseException(QXmlParseException)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                const QXmlParseException & cppArg0 = Shiboken::Converter<const QXmlParseException & >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QXmlParseException(QXmlParseException)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QXmlParseException(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QXmlParseException >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QXmlParseException_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QXmlParseException_Init_TypeError:
        const char* overloads[] = {"QString = QString(), int = -1, int = -1, QString = QString(), QString = QString()", "PySide.QtXml.QXmlParseException", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtXml.QXmlParseException", overloads);
        return -1;
}

static PyObject* Sbk_QXmlParseExceptionFunc_columnNumber(PyObject* self)
{
    QXmlParseException* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlParseException* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // columnNumber()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QXmlParseException*>(cppSelf)->columnNumber();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QXmlParseExceptionFunc_lineNumber(PyObject* self)
{
    QXmlParseException* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlParseException* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // lineNumber()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QXmlParseException*>(cppSelf)->lineNumber();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QXmlParseExceptionFunc_message(PyObject* self)
{
    QXmlParseException* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlParseException* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // message()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QXmlParseException*>(cppSelf)->message();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QXmlParseExceptionFunc_publicId(PyObject* self)
{
    QXmlParseException* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlParseException* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // publicId()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QXmlParseException*>(cppSelf)->publicId();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QXmlParseExceptionFunc_systemId(PyObject* self)
{
    QXmlParseException* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlParseException* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // systemId()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QXmlParseException*>(cppSelf)->systemId();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef Sbk_QXmlParseException_methods[] = {
    {"columnNumber", (PyCFunction)Sbk_QXmlParseExceptionFunc_columnNumber, METH_NOARGS},
    {"lineNumber", (PyCFunction)Sbk_QXmlParseExceptionFunc_lineNumber, METH_NOARGS},
    {"message", (PyCFunction)Sbk_QXmlParseExceptionFunc_message, METH_NOARGS},
    {"publicId", (PyCFunction)Sbk_QXmlParseExceptionFunc_publicId, METH_NOARGS},
    {"systemId", (PyCFunction)Sbk_QXmlParseExceptionFunc_systemId, METH_NOARGS},

    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QXmlParseException_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtXml.QXmlParseException",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QXmlParseException_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QXmlParseException_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QXmlParseException(PyObject* module)
{
    SbkPySide_QtXmlTypes[SBK_QXMLPARSEEXCEPTION_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QXmlParseException_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QXmlParseException_Type);
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QXmlParseException_Type, &Shiboken::callCppDestructor<QXmlParseException >);
    if (PyType_Ready((PyTypeObject*)&Sbk_QXmlParseException_Type) < 0)
        return;

    Shiboken::ObjectType::setOriginalName(&Sbk_QXmlParseException_Type, "QXmlParseException*");
    PyModule_AddObject(module, "QXmlParseException",
        ((PyObject*)&Sbk_QXmlParseException_Type));


    Shiboken::TypeResolver::createObjectTypeResolver<QXmlParseException >("QXmlParseException*");
    Shiboken::TypeResolver::createObjectTypeResolver<QXmlParseException >(typeid(QXmlParseException).name());
    PySide::initQtMetaType< ::QXmlParseException* >();
}

