/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtxmlpatterns_python.h"

#include "qabstractxmlnodemodel_wrapper.h"

// Extra includes
#include <QVector>
#include <qabstractxmlnodemodel.h>
#include <qabstractxmlreceiver.h>
#include <qsourcelocation.h>
#include <qurl.h>
#include <qxmlname.h>


// Native ---------------------------------------------------------

QAbstractXmlNodeModelWrapper::QAbstractXmlNodeModelWrapper() : QAbstractXmlNodeModel() {
    // ... middle
}

QVector<QXmlNodeModelIndex > QAbstractXmlNodeModelWrapper::attributes(const QXmlNodeModelIndex & element) const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return QVector<QXmlNodeModelIndex >();
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "attributes"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QAbstractXmlNodeModel.attributes()' not implemented.");
        return QVector<QXmlNodeModelIndex >();
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QXmlNodeModelIndex >::toPython(element)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QVector<QXmlNodeModelIndex >();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QVector<QXmlNodeModelIndex > >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QAbstractXmlNodeModel.attributes", "vector", pyResult->ob_type->tp_name);
        return QVector<QXmlNodeModelIndex >();
    }
    QVector<QXmlNodeModelIndex > cppResult(Shiboken::Converter< ::QVector<QXmlNodeModelIndex > >::toCpp(pyResult));
    return cppResult;
}

QUrl QAbstractXmlNodeModelWrapper::baseUri(const QXmlNodeModelIndex & ni) const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return QUrl();
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "baseUri"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QAbstractXmlNodeModel.baseUri()' not implemented.");
        return QUrl();
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QXmlNodeModelIndex >::toPython(ni)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QUrl();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QUrl >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QAbstractXmlNodeModel.baseUri", Shiboken::SbkType<QUrl >()->tp_name, pyResult->ob_type->tp_name);
        return QUrl();
    }
    QUrl cppResult(Shiboken::Converter< ::QUrl >::toCpp(pyResult));
    return cppResult;
}

QXmlNodeModelIndex::DocumentOrder QAbstractXmlNodeModelWrapper::compareOrder(const QXmlNodeModelIndex & ni1, const QXmlNodeModelIndex & ni2) const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return QXmlNodeModelIndex::DocumentOrder();
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "compareOrder"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QAbstractXmlNodeModel.compareOrder()' not implemented.");
        return QXmlNodeModelIndex::DocumentOrder();
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter< ::QXmlNodeModelIndex >::toPython(ni1),
        Shiboken::Converter< ::QXmlNodeModelIndex >::toPython(ni2)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QXmlNodeModelIndex::DocumentOrder();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QXmlNodeModelIndex::DocumentOrder >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QAbstractXmlNodeModel.compareOrder", Shiboken::SbkType<QXmlNodeModelIndex::DocumentOrder >()->tp_name, pyResult->ob_type->tp_name);
        return QXmlNodeModelIndex::DocumentOrder();
    }
    QXmlNodeModelIndex::DocumentOrder cppResult(Shiboken::Converter< ::QXmlNodeModelIndex::DocumentOrder >::toCpp(pyResult));
    return cppResult;
}

QUrl QAbstractXmlNodeModelWrapper::documentUri(const QXmlNodeModelIndex & ni) const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return QUrl();
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "documentUri"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QAbstractXmlNodeModel.documentUri()' not implemented.");
        return QUrl();
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QXmlNodeModelIndex >::toPython(ni)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QUrl();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QUrl >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QAbstractXmlNodeModel.documentUri", Shiboken::SbkType<QUrl >()->tp_name, pyResult->ob_type->tp_name);
        return QUrl();
    }
    QUrl cppResult(Shiboken::Converter< ::QUrl >::toCpp(pyResult));
    return cppResult;
}

QXmlNodeModelIndex QAbstractXmlNodeModelWrapper::elementById(const QXmlName & NCName) const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return QXmlNodeModelIndex();
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "elementById"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QAbstractXmlNodeModel.elementById()' not implemented.");
        return QXmlNodeModelIndex();
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QXmlName >::toPython(NCName)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QXmlNodeModelIndex();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QXmlNodeModelIndex >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QAbstractXmlNodeModel.elementById", Shiboken::SbkType<QXmlNodeModelIndex >()->tp_name, pyResult->ob_type->tp_name);
        return QXmlNodeModelIndex();
    }
    QXmlNodeModelIndex cppResult(Shiboken::Converter< ::QXmlNodeModelIndex >::toCpp(pyResult));
    return cppResult;
}

bool QAbstractXmlNodeModelWrapper::isDeepEqual(const QXmlNodeModelIndex & ni1, const QXmlNodeModelIndex & ni2) const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return bool(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "isDeepEqual"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractXmlNodeModel::isDeepEqual(ni1, ni2);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter< ::QXmlNodeModelIndex >::toPython(ni1),
        Shiboken::Converter< ::QXmlNodeModelIndex >::toPython(ni2)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QAbstractXmlNodeModel.isDeepEqual", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    return cppResult;
}

QXmlNodeModelIndex::NodeKind QAbstractXmlNodeModelWrapper::kind(const QXmlNodeModelIndex & ni) const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return QXmlNodeModelIndex::NodeKind();
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "kind"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QAbstractXmlNodeModel.kind()' not implemented.");
        return QXmlNodeModelIndex::NodeKind();
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QXmlNodeModelIndex >::toPython(ni)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QXmlNodeModelIndex::NodeKind();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QXmlNodeModelIndex::NodeKind >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QAbstractXmlNodeModel.kind", Shiboken::SbkType<QXmlNodeModelIndex::NodeKind >()->tp_name, pyResult->ob_type->tp_name);
        return QXmlNodeModelIndex::NodeKind();
    }
    QXmlNodeModelIndex::NodeKind cppResult(Shiboken::Converter< ::QXmlNodeModelIndex::NodeKind >::toCpp(pyResult));
    return cppResult;
}

QXmlName QAbstractXmlNodeModelWrapper::name(const QXmlNodeModelIndex & ni) const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return QXmlName();
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "name"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QAbstractXmlNodeModel.name()' not implemented.");
        return QXmlName();
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QXmlNodeModelIndex >::toPython(ni)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QXmlName();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QXmlName >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QAbstractXmlNodeModel.name", Shiboken::SbkType<QXmlName >()->tp_name, pyResult->ob_type->tp_name);
        return QXmlName();
    }
    QXmlName cppResult(Shiboken::Converter< ::QXmlName >::toCpp(pyResult));
    return cppResult;
}

QVector<QXmlName > QAbstractXmlNodeModelWrapper::namespaceBindings(const QXmlNodeModelIndex & n) const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return QVector<QXmlName >();
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "namespaceBindings"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QAbstractXmlNodeModel.namespaceBindings()' not implemented.");
        return QVector<QXmlName >();
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QXmlNodeModelIndex >::toPython(n)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QVector<QXmlName >();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QVector<QXmlName > >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QAbstractXmlNodeModel.namespaceBindings", "vector", pyResult->ob_type->tp_name);
        return QVector<QXmlName >();
    }
    QVector<QXmlName > cppResult(Shiboken::Converter< ::QVector<QXmlName > >::toCpp(pyResult));
    return cppResult;
}

short QAbstractXmlNodeModelWrapper::namespaceForPrefix(const QXmlNodeModelIndex & ni, const short prefix) const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return short(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "namespaceForPrefix"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractXmlNodeModel::namespaceForPrefix(ni, prefix);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(Nh)",
        Shiboken::Converter< ::QXmlNodeModelIndex >::toPython(ni),
        prefix
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return short(0);
    }
    // Check return type
    bool typeIsValid = PyInt_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QAbstractXmlNodeModel.namespaceForPrefix", "short", pyResult->ob_type->tp_name);
        return short(0);
    }
    short cppResult(Shiboken::Converter< short >::toCpp(pyResult));
    return cppResult;
}

QXmlNodeModelIndex QAbstractXmlNodeModelWrapper::nextFromSimpleAxis(QAbstractXmlNodeModel::SimpleAxis axis, const QXmlNodeModelIndex & origin) const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return QXmlNodeModelIndex();
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "nextFromSimpleAxis"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QAbstractXmlNodeModel.nextFromSimpleAxis()' not implemented.");
        return QXmlNodeModelIndex();
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter< ::QAbstractXmlNodeModel::SimpleAxis >::toPython(axis),
        Shiboken::Converter< ::QXmlNodeModelIndex >::toPython(origin)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QXmlNodeModelIndex();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QXmlNodeModelIndex >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QAbstractXmlNodeModel.nextFromSimpleAxis", Shiboken::SbkType<QXmlNodeModelIndex >()->tp_name, pyResult->ob_type->tp_name);
        return QXmlNodeModelIndex();
    }
    QXmlNodeModelIndex cppResult(Shiboken::Converter< ::QXmlNodeModelIndex >::toCpp(pyResult));
    return cppResult;
}

QVector<QXmlNodeModelIndex > QAbstractXmlNodeModelWrapper::nodesByIdref(const QXmlName & NCName) const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return QVector<QXmlNodeModelIndex >();
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "nodesByIdref"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QAbstractXmlNodeModel.nodesByIdref()' not implemented.");
        return QVector<QXmlNodeModelIndex >();
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QXmlName >::toPython(NCName)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QVector<QXmlNodeModelIndex >();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QVector<QXmlNodeModelIndex > >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QAbstractXmlNodeModel.nodesByIdref", "vector", pyResult->ob_type->tp_name);
        return QVector<QXmlNodeModelIndex >();
    }
    QVector<QXmlNodeModelIndex > cppResult(Shiboken::Converter< ::QVector<QXmlNodeModelIndex > >::toCpp(pyResult));
    return cppResult;
}

QXmlNodeModelIndex QAbstractXmlNodeModelWrapper::root(const QXmlNodeModelIndex & n) const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return QXmlNodeModelIndex();
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "root"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QAbstractXmlNodeModel.root()' not implemented.");
        return QXmlNodeModelIndex();
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QXmlNodeModelIndex >::toPython(n)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QXmlNodeModelIndex();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QXmlNodeModelIndex >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QAbstractXmlNodeModel.root", Shiboken::SbkType<QXmlNodeModelIndex >()->tp_name, pyResult->ob_type->tp_name);
        return QXmlNodeModelIndex();
    }
    QXmlNodeModelIndex cppResult(Shiboken::Converter< ::QXmlNodeModelIndex >::toCpp(pyResult));
    return cppResult;
}

void QAbstractXmlNodeModelWrapper::sendNamespaces(const QXmlNodeModelIndex & n, QAbstractXmlReceiver * receiver) const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "sendNamespaces"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractXmlNodeModel::sendNamespaces(n, receiver);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter< ::QXmlNodeModelIndex >::toPython(n),
        Shiboken::Converter< ::QAbstractXmlReceiver * >::toPython(receiver)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

QString QAbstractXmlNodeModelWrapper::stringValue(const QXmlNodeModelIndex & n) const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return QString();
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "stringValue"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QAbstractXmlNodeModel.stringValue()' not implemented.");
        return QString();
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QXmlNodeModelIndex >::toPython(n)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QString();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< QString >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QAbstractXmlNodeModel.stringValue", "QString", pyResult->ob_type->tp_name);
        return QString();
    }
    QString cppResult(Shiboken::Converter< QString >::toCpp(pyResult));
    return cppResult;
}

QVariant QAbstractXmlNodeModelWrapper::typedValue(const QXmlNodeModelIndex & n) const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return QVariant(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "typedValue"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QAbstractXmlNodeModel.typedValue()' not implemented.");
        return QVariant(0);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QXmlNodeModelIndex >::toPython(n)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QVariant(0);
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< QVariant >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QAbstractXmlNodeModel.typedValue", "QVariant", pyResult->ob_type->tp_name);
        return QVariant(0);
    }
    QVariant cppResult(Shiboken::Converter< QVariant >::toCpp(pyResult));
    return cppResult;
}

QAbstractXmlNodeModelWrapper::~QAbstractXmlNodeModelWrapper()
{
    SbkObject* wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QAbstractXmlNodeModel_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QAbstractXmlNodeModel >()))
        return -1;

    QAbstractXmlNodeModelWrapper* cptr = 0;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);
    SbkObjectType* type = reinterpret_cast<SbkObjectType*>(self->ob_type);
    SbkObjectType* myType = reinterpret_cast<SbkObjectType*>(SbkPySide_QtXmlPatternsTypes[SBK_QABSTRACTXMLNODEMODEL_IDX]);
    if (type == myType) {
        PyErr_SetString(PyExc_NotImplementedError,
            "'QAbstractXmlNodeModel' represents a C++ abstract class and cannot be instantiated");
        return -1;
    }


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // QAbstractXmlNodeModel()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new QAbstractXmlNodeModelWrapper();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QAbstractXmlNodeModel >(), cptr)) {
        delete cptr;
        return -1;
    }
    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject* Sbk_QAbstractXmlNodeModelFunc_attributes(PyObject* self, PyObject* arg)
{
    QAbstractXmlNodeModel* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QAbstractXmlNodeModel* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: attributes(QXmlNodeModelIndex)const
    if (Shiboken::Converter< ::QXmlNodeModelIndex >::isConvertible(arg)) {
        overloadId = 0; // attributes(QXmlNodeModelIndex)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QAbstractXmlNodeModelFunc_attributes_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QXmlNodeModelIndex cppArg0 = Shiboken::Converter<QXmlNodeModelIndex >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // attributes(QXmlNodeModelIndex)const
                if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self))) {
                    PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QAbstractXmlNodeModel.attributes()' not implemented.");
                    return 0;
                }
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QVector<QXmlNodeModelIndex > cppResult = const_cast<const QAbstractXmlNodeModel*>(cppSelf)->attributes(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QVector<QXmlNodeModelIndex > >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QAbstractXmlNodeModelFunc_attributes_TypeError:
        const char* overloads[] = {"PySide.QtXmlPatterns.QXmlNodeModelIndex", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtXmlPatterns.QAbstractXmlNodeModel.attributes", overloads);
        return 0;
}

static PyObject* Sbk_QAbstractXmlNodeModelFunc_baseUri(PyObject* self, PyObject* arg)
{
    QAbstractXmlNodeModel* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QAbstractXmlNodeModel* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: baseUri(QXmlNodeModelIndex)const
    if (Shiboken::Converter< ::QXmlNodeModelIndex >::isConvertible(arg)) {
        overloadId = 0; // baseUri(QXmlNodeModelIndex)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QAbstractXmlNodeModelFunc_baseUri_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QXmlNodeModelIndex cppArg0 = Shiboken::Converter<QXmlNodeModelIndex >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // baseUri(QXmlNodeModelIndex)const
                if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self))) {
                    PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QAbstractXmlNodeModel.baseUri()' not implemented.");
                    return 0;
                }
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QUrl cppResult = const_cast<const QAbstractXmlNodeModel*>(cppSelf)->baseUri(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QUrl >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QAbstractXmlNodeModelFunc_baseUri_TypeError:
        const char* overloads[] = {"PySide.QtXmlPatterns.QXmlNodeModelIndex", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtXmlPatterns.QAbstractXmlNodeModel.baseUri", overloads);
        return 0;
}

static PyObject* Sbk_QAbstractXmlNodeModelFunc_compareOrder(PyObject* self, PyObject* args)
{
    QAbstractXmlNodeModel* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QAbstractXmlNodeModel* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "compareOrder", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: compareOrder(QXmlNodeModelIndex,QXmlNodeModelIndex)const
    if (numArgs == 2 && Shiboken::Converter< ::QXmlNodeModelIndex >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QXmlNodeModelIndex >::isConvertible(pyargs[1])) {
        overloadId = 0; // compareOrder(QXmlNodeModelIndex,QXmlNodeModelIndex)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QAbstractXmlNodeModelFunc_compareOrder_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QXmlNodeModelIndex cppArg0 = Shiboken::Converter<QXmlNodeModelIndex >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            QXmlNodeModelIndex cppArg1 = Shiboken::Converter<QXmlNodeModelIndex >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // compareOrder(QXmlNodeModelIndex,QXmlNodeModelIndex)const
                if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self))) {
                    PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QAbstractXmlNodeModel.compareOrder()' not implemented.");
                    return 0;
                }
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QXmlNodeModelIndex::DocumentOrder cppResult = const_cast<const QAbstractXmlNodeModel*>(cppSelf)->compareOrder(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QXmlNodeModelIndex::DocumentOrder >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QAbstractXmlNodeModelFunc_compareOrder_TypeError:
        const char* overloads[] = {"PySide.QtXmlPatterns.QXmlNodeModelIndex, PySide.QtXmlPatterns.QXmlNodeModelIndex", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtXmlPatterns.QAbstractXmlNodeModel.compareOrder", overloads);
        return 0;
}

static PyObject* Sbk_QAbstractXmlNodeModelFunc_createIndex(PyObject* self, PyObject* args, PyObject* kwds)
{
    QAbstractXmlNodeModel* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QAbstractXmlNodeModel* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtXmlPatterns.QAbstractXmlNodeModel.createIndex(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtXmlPatterns.QAbstractXmlNodeModel.createIndex(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:createIndex", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: createIndex(qint64)const
    // 1: createIndex(qint64,qint64)const
    // 2: createIndex(void*,qint64)const
    if (Shiboken::Converter< void * >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 2; // createIndex(void*,qint64)const
        } else if (SbkNumber_Check(pyargs[1])) {
            overloadId = 2; // createIndex(void*,qint64)const
        }
    } else if (SbkNumber_Check(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // createIndex(qint64)const
        } else if (numArgs == 2 && SbkNumber_Check(pyargs[1])) {
            overloadId = 1; // createIndex(qint64,qint64)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QAbstractXmlNodeModelFunc_createIndex_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // createIndex(qint64)const
            {
                qint64 cppArg0 = Shiboken::Converter<qint64 >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // createIndex(qint64)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QXmlNodeModelIndex cppResult = const_cast<const QAbstractXmlNodeModel*>(cppSelf)->createIndex(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QXmlNodeModelIndex >::toPython(cppResult);
                }
                break;
            }
            case 1: // createIndex(qint64,qint64)const
            {
                qint64 cppArg0 = Shiboken::Converter<qint64 >::toCpp(pyargs[0]);
                qint64 cppArg1 = Shiboken::Converter<qint64 >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // createIndex(qint64,qint64)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QXmlNodeModelIndex cppResult = const_cast<const QAbstractXmlNodeModel*>(cppSelf)->createIndex(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QXmlNodeModelIndex >::toPython(cppResult);
                }
                break;
            }
            case 2: // createIndex(void*,qint64)const
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "additionalData");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "additionalData";
                        else if (SbkNumber_Check(value))
                            pyargs[1] = value;
                        else
                            goto Sbk_QAbstractXmlNodeModelFunc_createIndex_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtXmlPatterns.QAbstractXmlNodeModel.createIndex(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                void * cppArg0 = Shiboken::Converter<void * >::toCpp(pyargs[0]);
                qint64 cppArg1 = pyargs[1] ? Shiboken::Converter<qint64 >::toCpp(pyargs[1]) : 0;

                if(!PyErr_Occurred()) {
                    // createIndex(void*,qint64)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QXmlNodeModelIndex cppResult = const_cast<const QAbstractXmlNodeModel*>(cppSelf)->createIndex(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QXmlNodeModelIndex >::toPython(cppResult);
                }
                break;
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QAbstractXmlNodeModelFunc_createIndex_TypeError:
        const char* overloads[] = {"long long", "long long, long long", "void, long long = 0", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtXmlPatterns.QAbstractXmlNodeModel.createIndex", overloads);
        return 0;
}

static PyObject* Sbk_QAbstractXmlNodeModelFunc_documentUri(PyObject* self, PyObject* arg)
{
    QAbstractXmlNodeModel* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QAbstractXmlNodeModel* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: documentUri(QXmlNodeModelIndex)const
    if (Shiboken::Converter< ::QXmlNodeModelIndex >::isConvertible(arg)) {
        overloadId = 0; // documentUri(QXmlNodeModelIndex)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QAbstractXmlNodeModelFunc_documentUri_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QXmlNodeModelIndex cppArg0 = Shiboken::Converter<QXmlNodeModelIndex >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // documentUri(QXmlNodeModelIndex)const
                if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self))) {
                    PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QAbstractXmlNodeModel.documentUri()' not implemented.");
                    return 0;
                }
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QUrl cppResult = const_cast<const QAbstractXmlNodeModel*>(cppSelf)->documentUri(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QUrl >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QAbstractXmlNodeModelFunc_documentUri_TypeError:
        const char* overloads[] = {"PySide.QtXmlPatterns.QXmlNodeModelIndex", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtXmlPatterns.QAbstractXmlNodeModel.documentUri", overloads);
        return 0;
}

static PyObject* Sbk_QAbstractXmlNodeModelFunc_elementById(PyObject* self, PyObject* arg)
{
    QAbstractXmlNodeModel* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QAbstractXmlNodeModel* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: elementById(QXmlName)const
    if (Shiboken::Converter< ::QXmlName >::isConvertible(arg)) {
        overloadId = 0; // elementById(QXmlName)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QAbstractXmlNodeModelFunc_elementById_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QXmlName cppArg0 = Shiboken::Converter<QXmlName >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // elementById(QXmlName)const
                if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self))) {
                    PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QAbstractXmlNodeModel.elementById()' not implemented.");
                    return 0;
                }
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QXmlNodeModelIndex cppResult = const_cast<const QAbstractXmlNodeModel*>(cppSelf)->elementById(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QXmlNodeModelIndex >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QAbstractXmlNodeModelFunc_elementById_TypeError:
        const char* overloads[] = {"PySide.QtXmlPatterns.QXmlName", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtXmlPatterns.QAbstractXmlNodeModel.elementById", overloads);
        return 0;
}

static PyObject* Sbk_QAbstractXmlNodeModelFunc_isDeepEqual(PyObject* self, PyObject* args)
{
    QAbstractXmlNodeModel* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QAbstractXmlNodeModel* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "isDeepEqual", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: isDeepEqual(QXmlNodeModelIndex,QXmlNodeModelIndex)const
    if (numArgs == 2 && Shiboken::Converter< ::QXmlNodeModelIndex >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QXmlNodeModelIndex >::isConvertible(pyargs[1])) {
        overloadId = 0; // isDeepEqual(QXmlNodeModelIndex,QXmlNodeModelIndex)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QAbstractXmlNodeModelFunc_isDeepEqual_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QXmlNodeModelIndex cppArg0 = Shiboken::Converter<QXmlNodeModelIndex >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            QXmlNodeModelIndex cppArg1 = Shiboken::Converter<QXmlNodeModelIndex >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // isDeepEqual(QXmlNodeModelIndex,QXmlNodeModelIndex)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = (Shiboken::Object::isUserType(self) ? const_cast<const QAbstractXmlNodeModel*>(cppSelf)->::QAbstractXmlNodeModel::isDeepEqual(cppArg0, cppArg1) : const_cast<const QAbstractXmlNodeModel*>(cppSelf)->isDeepEqual(cppArg0, cppArg1));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QAbstractXmlNodeModelFunc_isDeepEqual_TypeError:
        const char* overloads[] = {"PySide.QtXmlPatterns.QXmlNodeModelIndex, PySide.QtXmlPatterns.QXmlNodeModelIndex", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtXmlPatterns.QAbstractXmlNodeModel.isDeepEqual", overloads);
        return 0;
}

static PyObject* Sbk_QAbstractXmlNodeModelFunc_kind(PyObject* self, PyObject* arg)
{
    QAbstractXmlNodeModel* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QAbstractXmlNodeModel* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: kind(QXmlNodeModelIndex)const
    if (Shiboken::Converter< ::QXmlNodeModelIndex >::isConvertible(arg)) {
        overloadId = 0; // kind(QXmlNodeModelIndex)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QAbstractXmlNodeModelFunc_kind_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QXmlNodeModelIndex cppArg0 = Shiboken::Converter<QXmlNodeModelIndex >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // kind(QXmlNodeModelIndex)const
                if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self))) {
                    PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QAbstractXmlNodeModel.kind()' not implemented.");
                    return 0;
                }
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QXmlNodeModelIndex::NodeKind cppResult = const_cast<const QAbstractXmlNodeModel*>(cppSelf)->kind(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QXmlNodeModelIndex::NodeKind >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QAbstractXmlNodeModelFunc_kind_TypeError:
        const char* overloads[] = {"PySide.QtXmlPatterns.QXmlNodeModelIndex", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtXmlPatterns.QAbstractXmlNodeModel.kind", overloads);
        return 0;
}

static PyObject* Sbk_QAbstractXmlNodeModelFunc_name(PyObject* self, PyObject* arg)
{
    QAbstractXmlNodeModel* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QAbstractXmlNodeModel* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: name(QXmlNodeModelIndex)const
    if (Shiboken::Converter< ::QXmlNodeModelIndex >::isConvertible(arg)) {
        overloadId = 0; // name(QXmlNodeModelIndex)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QAbstractXmlNodeModelFunc_name_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QXmlNodeModelIndex cppArg0 = Shiboken::Converter<QXmlNodeModelIndex >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // name(QXmlNodeModelIndex)const
                if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self))) {
                    PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QAbstractXmlNodeModel.name()' not implemented.");
                    return 0;
                }
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QXmlName cppResult = const_cast<const QAbstractXmlNodeModel*>(cppSelf)->name(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QXmlName >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QAbstractXmlNodeModelFunc_name_TypeError:
        const char* overloads[] = {"PySide.QtXmlPatterns.QXmlNodeModelIndex", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtXmlPatterns.QAbstractXmlNodeModel.name", overloads);
        return 0;
}

static PyObject* Sbk_QAbstractXmlNodeModelFunc_namespaceBindings(PyObject* self, PyObject* arg)
{
    QAbstractXmlNodeModel* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QAbstractXmlNodeModel* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: namespaceBindings(QXmlNodeModelIndex)const
    if (Shiboken::Converter< ::QXmlNodeModelIndex >::isConvertible(arg)) {
        overloadId = 0; // namespaceBindings(QXmlNodeModelIndex)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QAbstractXmlNodeModelFunc_namespaceBindings_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QXmlNodeModelIndex cppArg0 = Shiboken::Converter<QXmlNodeModelIndex >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // namespaceBindings(QXmlNodeModelIndex)const
                if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self))) {
                    PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QAbstractXmlNodeModel.namespaceBindings()' not implemented.");
                    return 0;
                }
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QVector<QXmlName > cppResult = const_cast<const QAbstractXmlNodeModel*>(cppSelf)->namespaceBindings(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QVector<QXmlName > >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QAbstractXmlNodeModelFunc_namespaceBindings_TypeError:
        const char* overloads[] = {"PySide.QtXmlPatterns.QXmlNodeModelIndex", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtXmlPatterns.QAbstractXmlNodeModel.namespaceBindings", overloads);
        return 0;
}

static PyObject* Sbk_QAbstractXmlNodeModelFunc_namespaceForPrefix(PyObject* self, PyObject* args)
{
    QAbstractXmlNodeModel* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QAbstractXmlNodeModel* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "namespaceForPrefix", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: namespaceForPrefix(QXmlNodeModelIndex,short)const
    if (numArgs == 2 && Shiboken::Converter< ::QXmlNodeModelIndex >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 0; // namespaceForPrefix(QXmlNodeModelIndex,short)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QAbstractXmlNodeModelFunc_namespaceForPrefix_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QXmlNodeModelIndex cppArg0 = Shiboken::Converter<QXmlNodeModelIndex >::toCpp(pyargs[0]);
            short cppArg1 = Shiboken::Converter<short >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // namespaceForPrefix(QXmlNodeModelIndex,short)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                short cppResult = (Shiboken::Object::isUserType(self) ? const_cast<const QAbstractXmlNodeModel*>(cppSelf)->::QAbstractXmlNodeModel::namespaceForPrefix(cppArg0, cppArg1) : const_cast<const QAbstractXmlNodeModel*>(cppSelf)->namespaceForPrefix(cppArg0, cppArg1));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< short >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QAbstractXmlNodeModelFunc_namespaceForPrefix_TypeError:
        const char* overloads[] = {"PySide.QtXmlPatterns.QXmlNodeModelIndex, short", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtXmlPatterns.QAbstractXmlNodeModel.namespaceForPrefix", overloads);
        return 0;
}

static PyObject* Sbk_QAbstractXmlNodeModelFunc_nextFromSimpleAxis(PyObject* self, PyObject* args)
{
    QAbstractXmlNodeModel* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QAbstractXmlNodeModel* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "nextFromSimpleAxis", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: nextFromSimpleAxis(QAbstractXmlNodeModel::SimpleAxis,QXmlNodeModelIndex)const
    if (numArgs == 2 && Shiboken::Converter< ::QAbstractXmlNodeModel::SimpleAxis >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QXmlNodeModelIndex >::isConvertible(pyargs[1])) {
        overloadId = 0; // nextFromSimpleAxis(QAbstractXmlNodeModel::SimpleAxis,QXmlNodeModelIndex)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QAbstractXmlNodeModelFunc_nextFromSimpleAxis_TypeError;

    // Call function/method
    {
        {
            QAbstractXmlNodeModel::SimpleAxis cppArg0 = Shiboken::Converter<QAbstractXmlNodeModel::SimpleAxis >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            QXmlNodeModelIndex cppArg1 = Shiboken::Converter<QXmlNodeModelIndex >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // nextFromSimpleAxis(QAbstractXmlNodeModel::SimpleAxis,QXmlNodeModelIndex)const
                if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self))) {
                    PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QAbstractXmlNodeModel.nextFromSimpleAxis()' not implemented.");
                    return 0;
                }
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QXmlNodeModelIndex cppResult = const_cast<const QAbstractXmlNodeModel*>(cppSelf)->nextFromSimpleAxis(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QXmlNodeModelIndex >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QAbstractXmlNodeModelFunc_nextFromSimpleAxis_TypeError:
        const char* overloads[] = {"PySide.QtXmlPatterns.QAbstractXmlNodeModel.SimpleAxis, PySide.QtXmlPatterns.QXmlNodeModelIndex", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtXmlPatterns.QAbstractXmlNodeModel.nextFromSimpleAxis", overloads);
        return 0;
}

static PyObject* Sbk_QAbstractXmlNodeModelFunc_nodesByIdref(PyObject* self, PyObject* arg)
{
    QAbstractXmlNodeModel* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QAbstractXmlNodeModel* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: nodesByIdref(QXmlName)const
    if (Shiboken::Converter< ::QXmlName >::isConvertible(arg)) {
        overloadId = 0; // nodesByIdref(QXmlName)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QAbstractXmlNodeModelFunc_nodesByIdref_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QXmlName cppArg0 = Shiboken::Converter<QXmlName >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // nodesByIdref(QXmlName)const
                if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self))) {
                    PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QAbstractXmlNodeModel.nodesByIdref()' not implemented.");
                    return 0;
                }
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QVector<QXmlNodeModelIndex > cppResult = const_cast<const QAbstractXmlNodeModel*>(cppSelf)->nodesByIdref(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QVector<QXmlNodeModelIndex > >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QAbstractXmlNodeModelFunc_nodesByIdref_TypeError:
        const char* overloads[] = {"PySide.QtXmlPatterns.QXmlName", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtXmlPatterns.QAbstractXmlNodeModel.nodesByIdref", overloads);
        return 0;
}

static PyObject* Sbk_QAbstractXmlNodeModelFunc_root(PyObject* self, PyObject* arg)
{
    QAbstractXmlNodeModel* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QAbstractXmlNodeModel* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: root(QXmlNodeModelIndex)const
    if (Shiboken::Converter< ::QXmlNodeModelIndex >::isConvertible(arg)) {
        overloadId = 0; // root(QXmlNodeModelIndex)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QAbstractXmlNodeModelFunc_root_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QXmlNodeModelIndex cppArg0 = Shiboken::Converter<QXmlNodeModelIndex >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // root(QXmlNodeModelIndex)const
                if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self))) {
                    PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QAbstractXmlNodeModel.root()' not implemented.");
                    return 0;
                }
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QXmlNodeModelIndex cppResult = const_cast<const QAbstractXmlNodeModel*>(cppSelf)->root(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QXmlNodeModelIndex >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QAbstractXmlNodeModelFunc_root_TypeError:
        const char* overloads[] = {"PySide.QtXmlPatterns.QXmlNodeModelIndex", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtXmlPatterns.QAbstractXmlNodeModel.root", overloads);
        return 0;
}

static PyObject* Sbk_QAbstractXmlNodeModelFunc_sendNamespaces(PyObject* self, PyObject* args)
{
    QAbstractXmlNodeModel* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QAbstractXmlNodeModel* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "sendNamespaces", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: sendNamespaces(QXmlNodeModelIndex,QAbstractXmlReceiver*)const
    if (numArgs == 2 && Shiboken::Converter< ::QXmlNodeModelIndex >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QAbstractXmlReceiver * >::isConvertible(pyargs[1])) {
        overloadId = 0; // sendNamespaces(QXmlNodeModelIndex,QAbstractXmlReceiver*)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QAbstractXmlNodeModelFunc_sendNamespaces_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QXmlNodeModelIndex cppArg0 = Shiboken::Converter<QXmlNodeModelIndex >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            QAbstractXmlReceiver * cppArg1 = Shiboken::Converter<QAbstractXmlReceiver * >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // sendNamespaces(QXmlNodeModelIndex,QAbstractXmlReceiver*)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? const_cast<const QAbstractXmlNodeModel*>(cppSelf)->::QAbstractXmlNodeModel::sendNamespaces(cppArg0, cppArg1) : const_cast<const QAbstractXmlNodeModel*>(cppSelf)->sendNamespaces(cppArg0, cppArg1));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QAbstractXmlNodeModelFunc_sendNamespaces_TypeError:
        const char* overloads[] = {"PySide.QtXmlPatterns.QXmlNodeModelIndex, PySide.QtXmlPatterns.QAbstractXmlReceiver", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtXmlPatterns.QAbstractXmlNodeModel.sendNamespaces", overloads);
        return 0;
}

static PyObject* Sbk_QAbstractXmlNodeModelFunc_sourceLocation(PyObject* self, PyObject* arg)
{
    QAbstractXmlNodeModel* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QAbstractXmlNodeModel* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: sourceLocation(QXmlNodeModelIndex)const
    if (Shiboken::Converter< ::QXmlNodeModelIndex >::isConvertible(arg)) {
        overloadId = 0; // sourceLocation(QXmlNodeModelIndex)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QAbstractXmlNodeModelFunc_sourceLocation_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QXmlNodeModelIndex cppArg0 = Shiboken::Converter<QXmlNodeModelIndex >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // sourceLocation(QXmlNodeModelIndex)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QSourceLocation cppResult = const_cast<const QAbstractXmlNodeModel*>(cppSelf)->sourceLocation(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QSourceLocation >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QAbstractXmlNodeModelFunc_sourceLocation_TypeError:
        const char* overloads[] = {"PySide.QtXmlPatterns.QXmlNodeModelIndex", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtXmlPatterns.QAbstractXmlNodeModel.sourceLocation", overloads);
        return 0;
}

static PyObject* Sbk_QAbstractXmlNodeModelFunc_stringValue(PyObject* self, PyObject* arg)
{
    QAbstractXmlNodeModel* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QAbstractXmlNodeModel* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: stringValue(QXmlNodeModelIndex)const
    if (Shiboken::Converter< ::QXmlNodeModelIndex >::isConvertible(arg)) {
        overloadId = 0; // stringValue(QXmlNodeModelIndex)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QAbstractXmlNodeModelFunc_stringValue_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QXmlNodeModelIndex cppArg0 = Shiboken::Converter<QXmlNodeModelIndex >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // stringValue(QXmlNodeModelIndex)const
                if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self))) {
                    PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QAbstractXmlNodeModel.stringValue()' not implemented.");
                    return 0;
                }
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QAbstractXmlNodeModel*>(cppSelf)->stringValue(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QAbstractXmlNodeModelFunc_stringValue_TypeError:
        const char* overloads[] = {"PySide.QtXmlPatterns.QXmlNodeModelIndex", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtXmlPatterns.QAbstractXmlNodeModel.stringValue", overloads);
        return 0;
}

static PyObject* Sbk_QAbstractXmlNodeModelFunc_typedValue(PyObject* self, PyObject* arg)
{
    QAbstractXmlNodeModel* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QAbstractXmlNodeModel* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: typedValue(QXmlNodeModelIndex)const
    if (Shiboken::Converter< ::QXmlNodeModelIndex >::isConvertible(arg)) {
        overloadId = 0; // typedValue(QXmlNodeModelIndex)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QAbstractXmlNodeModelFunc_typedValue_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QXmlNodeModelIndex cppArg0 = Shiboken::Converter<QXmlNodeModelIndex >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // typedValue(QXmlNodeModelIndex)const
                if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self))) {
                    PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QAbstractXmlNodeModel.typedValue()' not implemented.");
                    return 0;
                }
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QVariant cppResult = const_cast<const QAbstractXmlNodeModel*>(cppSelf)->typedValue(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QVariant >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QAbstractXmlNodeModelFunc_typedValue_TypeError:
        const char* overloads[] = {"PySide.QtXmlPatterns.QXmlNodeModelIndex", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtXmlPatterns.QAbstractXmlNodeModel.typedValue", overloads);
        return 0;
}

static PyMethodDef Sbk_QAbstractXmlNodeModel_methods[] = {
    {"attributes", (PyCFunction)Sbk_QAbstractXmlNodeModelFunc_attributes, METH_O},
    {"baseUri", (PyCFunction)Sbk_QAbstractXmlNodeModelFunc_baseUri, METH_O},
    {"compareOrder", (PyCFunction)Sbk_QAbstractXmlNodeModelFunc_compareOrder, METH_VARARGS},
    {"createIndex", (PyCFunction)Sbk_QAbstractXmlNodeModelFunc_createIndex, METH_VARARGS|METH_KEYWORDS},
    {"documentUri", (PyCFunction)Sbk_QAbstractXmlNodeModelFunc_documentUri, METH_O},
    {"elementById", (PyCFunction)Sbk_QAbstractXmlNodeModelFunc_elementById, METH_O},
    {"isDeepEqual", (PyCFunction)Sbk_QAbstractXmlNodeModelFunc_isDeepEqual, METH_VARARGS},
    {"kind", (PyCFunction)Sbk_QAbstractXmlNodeModelFunc_kind, METH_O},
    {"name", (PyCFunction)Sbk_QAbstractXmlNodeModelFunc_name, METH_O},
    {"namespaceBindings", (PyCFunction)Sbk_QAbstractXmlNodeModelFunc_namespaceBindings, METH_O},
    {"namespaceForPrefix", (PyCFunction)Sbk_QAbstractXmlNodeModelFunc_namespaceForPrefix, METH_VARARGS},
    {"nextFromSimpleAxis", (PyCFunction)Sbk_QAbstractXmlNodeModelFunc_nextFromSimpleAxis, METH_VARARGS},
    {"nodesByIdref", (PyCFunction)Sbk_QAbstractXmlNodeModelFunc_nodesByIdref, METH_O},
    {"root", (PyCFunction)Sbk_QAbstractXmlNodeModelFunc_root, METH_O},
    {"sendNamespaces", (PyCFunction)Sbk_QAbstractXmlNodeModelFunc_sendNamespaces, METH_VARARGS},
    {"sourceLocation", (PyCFunction)Sbk_QAbstractXmlNodeModelFunc_sourceLocation, METH_O},
    {"stringValue", (PyCFunction)Sbk_QAbstractXmlNodeModelFunc_stringValue, METH_O},
    {"typedValue", (PyCFunction)Sbk_QAbstractXmlNodeModelFunc_typedValue, METH_O},

    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QAbstractXmlNodeModel_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtXmlPatterns.QAbstractXmlNodeModel",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QAbstractXmlNodeModel_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QAbstractXmlNodeModel_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QAbstractXmlNodeModel(PyObject* module)
{
    SbkPySide_QtXmlPatternsTypes[SBK_QABSTRACTXMLNODEMODEL_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QAbstractXmlNodeModel_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QAbstractXmlNodeModel_Type);
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QAbstractXmlNodeModel_Type, &Shiboken::callCppDestructor<QAbstractXmlNodeModel >);
    if (PyType_Ready((PyTypeObject*)&Sbk_QAbstractXmlNodeModel_Type) < 0)
        return;

    // Fill type discovery information

    Shiboken::ObjectType::setOriginalName(&Sbk_QAbstractXmlNodeModel_Type, "QAbstractXmlNodeModel*");
    PyModule_AddObject(module, "QAbstractXmlNodeModel",
        ((PyObject*)&Sbk_QAbstractXmlNodeModel_Type));

    // Initialize enums
    PyObject* enumItem;

    // init enum: SimpleAxis
    PyTypeObject* SbkPySide_QtXmlPatterns_QAbstractXmlNodeModel_SimpleAxis = Shiboken::Enum::newType("PySide.QtXmlPatterns.QAbstractXmlNodeModel.SimpleAxis");
    SbkPySide_QtXmlPatternsTypes[SBK_QABSTRACTXMLNODEMODEL_SIMPLEAXIS_IDX] = SbkPySide_QtXmlPatterns_QAbstractXmlNodeModel_SimpleAxis;
    if (PyType_Ready(SbkPySide_QtXmlPatterns_QAbstractXmlNodeModel_SimpleAxis) < 0)
        return;
    PyDict_SetItemString(Sbk_QAbstractXmlNodeModel_Type.super.ht_type.tp_dict,
            "SimpleAxis",((PyObject*)SbkPySide_QtXmlPatterns_QAbstractXmlNodeModel_SimpleAxis));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtXmlPatterns_QAbstractXmlNodeModel_SimpleAxis,(long) QAbstractXmlNodeModel::Parent, "Parent");
    PyDict_SetItemString(Sbk_QAbstractXmlNodeModel_Type.super.ht_type.tp_dict,"Parent", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtXmlPatterns_QAbstractXmlNodeModel_SimpleAxis->tp_dict,"Parent", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtXmlPatterns_QAbstractXmlNodeModel_SimpleAxis,(long) QAbstractXmlNodeModel::FirstChild, "FirstChild");
    PyDict_SetItemString(Sbk_QAbstractXmlNodeModel_Type.super.ht_type.tp_dict,"FirstChild", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtXmlPatterns_QAbstractXmlNodeModel_SimpleAxis->tp_dict,"FirstChild", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtXmlPatterns_QAbstractXmlNodeModel_SimpleAxis,(long) QAbstractXmlNodeModel::PreviousSibling, "PreviousSibling");
    PyDict_SetItemString(Sbk_QAbstractXmlNodeModel_Type.super.ht_type.tp_dict,"PreviousSibling", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtXmlPatterns_QAbstractXmlNodeModel_SimpleAxis->tp_dict,"PreviousSibling", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtXmlPatterns_QAbstractXmlNodeModel_SimpleAxis,(long) QAbstractXmlNodeModel::NextSibling, "NextSibling");
    PyDict_SetItemString(Sbk_QAbstractXmlNodeModel_Type.super.ht_type.tp_dict,"NextSibling", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtXmlPatterns_QAbstractXmlNodeModel_SimpleAxis->tp_dict,"NextSibling", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QAbstractXmlNodeModel::SimpleAxis");
    Shiboken::TypeResolver::createValueTypeResolver<int>("QAbstractXmlNodeModel$ConcreteWrapper::SimpleAxis");
    // end of enum SimpleAxis

    // init enum: NodeCopySetting
    PyTypeObject* SbkPySide_QtXmlPatterns_QAbstractXmlNodeModel_NodeCopySetting = Shiboken::Enum::newType("PySide.QtXmlPatterns.QAbstractXmlNodeModel.NodeCopySetting");
    SbkPySide_QtXmlPatternsTypes[SBK_QABSTRACTXMLNODEMODEL_NODECOPYSETTING_IDX] = SbkPySide_QtXmlPatterns_QAbstractXmlNodeModel_NodeCopySetting;
    if (PyType_Ready(SbkPySide_QtXmlPatterns_QAbstractXmlNodeModel_NodeCopySetting) < 0)
        return;
    PyDict_SetItemString(Sbk_QAbstractXmlNodeModel_Type.super.ht_type.tp_dict,
            "NodeCopySetting",((PyObject*)SbkPySide_QtXmlPatterns_QAbstractXmlNodeModel_NodeCopySetting));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtXmlPatterns_QAbstractXmlNodeModel_NodeCopySetting,(long) QAbstractXmlNodeModel::InheritNamespaces, "InheritNamespaces");
    PyDict_SetItemString(Sbk_QAbstractXmlNodeModel_Type.super.ht_type.tp_dict,"InheritNamespaces", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtXmlPatterns_QAbstractXmlNodeModel_NodeCopySetting->tp_dict,"InheritNamespaces", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtXmlPatterns_QAbstractXmlNodeModel_NodeCopySetting,(long) QAbstractXmlNodeModel::PreserveNamespaces, "PreserveNamespaces");
    PyDict_SetItemString(Sbk_QAbstractXmlNodeModel_Type.super.ht_type.tp_dict,"PreserveNamespaces", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtXmlPatterns_QAbstractXmlNodeModel_NodeCopySetting->tp_dict,"PreserveNamespaces", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QAbstractXmlNodeModel::NodeCopySetting");
    Shiboken::TypeResolver::createValueTypeResolver<int>("QAbstractXmlNodeModel$ConcreteWrapper::NodeCopySetting");
    // end of enum NodeCopySetting


    Shiboken::TypeResolver::createObjectTypeResolver<QAbstractXmlNodeModel >("QAbstractXmlNodeModel*");
    Shiboken::TypeResolver::createObjectTypeResolver<QAbstractXmlNodeModel >("QAbstractXmlNodeModel$ConcreteWrapper*");
    Shiboken::TypeResolver::createObjectTypeResolver<QAbstractXmlNodeModel >(typeid(QAbstractXmlNodeModel).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QAbstractXmlNodeModel >(typeid(QAbstractXmlNodeModelWrapper).name());
    PySide::initQtMetaType< ::QAbstractXmlNodeModel* >();
    qRegisterMetaType< ::QAbstractXmlNodeModel::SimpleAxis >("QAbstractXmlNodeModel::SimpleAxis");
    qRegisterMetaType< ::QAbstractXmlNodeModel::NodeCopySetting >("QAbstractXmlNodeModel::NodeCopySetting");
}

