/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtxmlpatterns_python.h"

#include "qsourcelocation_wrapper.h"

// Extra includes
#include <qsourcelocation.h>
#include <qurl.h>



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QSourceLocation_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QSourceLocation >()))
        return -1;

    QSourceLocation* cptr = 0;
    int overloadId = -1;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);

    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtXmlPatterns.QSourceLocation(): too many arguments");
        return -1;
    }

    if (!PyArg_ParseTuple(args, "|OOO:QSourceLocation", &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return -1;

    // Overloaded function decisor
    // 0: QSourceLocation()
    // 1: QSourceLocation(QSourceLocation)
    // 2: QSourceLocation(QUrl,int,int)
    if (numArgs == 0) {
        overloadId = 0; // QSourceLocation()
    } else if (Shiboken::Converter< ::QUrl >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 2; // QSourceLocation(QUrl,int,int)
        } else if (SbkNumber_Check(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 2; // QSourceLocation(QUrl,int,int)
            } else if (SbkNumber_Check(pyargs[2])) {
                overloadId = 2; // QSourceLocation(QUrl,int,int)
            }
        }
    } else if (numArgs == 1 && Shiboken::Converter< ::QSourceLocation >::isConvertible(pyargs[0])) {
        overloadId = 1; // QSourceLocation(QSourceLocation)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QSourceLocation_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QSourceLocation()
            {

                if(!PyErr_Occurred()) {
                    // QSourceLocation()
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QSourceLocation();
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // QSourceLocation(QSourceLocation)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QSourceLocation cppArg0 = Shiboken::Converter<QSourceLocation >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QSourceLocation(QSourceLocation)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QSourceLocation(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 2: // QSourceLocation(QUrl,int,int)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "line");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "line";
                        else if (SbkNumber_Check(value))
                            pyargs[1] = value;
                        else
                            goto Sbk_QSourceLocation_Init_TypeError;
                    }
                    value = PyDict_GetItemString(kwds, "column");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "column";
                        else if (SbkNumber_Check(value))
                            pyargs[2] = value;
                        else
                            goto Sbk_QSourceLocation_Init_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtXmlPatterns.QSourceLocation(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QUrl cppArg0 = Shiboken::Converter<QUrl >::toCpp(pyargs[0]);
                int cppArg1 = pyargs[1] ? Shiboken::Converter<int >::toCpp(pyargs[1]) : -1;
                int cppArg2 = pyargs[2] ? Shiboken::Converter<int >::toCpp(pyargs[2]) : -1;

                if(!PyErr_Occurred()) {
                    // QSourceLocation(QUrl,int,int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QSourceLocation(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QSourceLocation >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QSourceLocation_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QSourceLocation_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtXmlPatterns.QSourceLocation", "PySide.QtCore.QUrl, int = -1, int = -1", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtXmlPatterns.QSourceLocation", overloads);
        return -1;
}

static PyObject* Sbk_QSourceLocationFunc_column(PyObject* self)
{
    QSourceLocation* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QSourceLocation* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // column()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                qint64 cppResult = const_cast<const QSourceLocation*>(cppSelf)->column();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< long long >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QSourceLocationFunc_isNull(PyObject* self)
{
    QSourceLocation* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QSourceLocation* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isNull()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QSourceLocation*>(cppSelf)->isNull();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QSourceLocationFunc_line(PyObject* self)
{
    QSourceLocation* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QSourceLocation* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // line()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                qint64 cppResult = const_cast<const QSourceLocation*>(cppSelf)->line();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< long long >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QSourceLocationFunc_setColumn(PyObject* self, PyObject* arg)
{
    QSourceLocation* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QSourceLocation* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setColumn(qint64)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setColumn(qint64)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QSourceLocationFunc_setColumn_TypeError;

    // Call function/method
    {
        {
            qint64 cppArg0 = Shiboken::Converter<qint64 >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setColumn(qint64)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setColumn(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QSourceLocationFunc_setColumn_TypeError:
        const char* overloads[] = {"long long", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtXmlPatterns.QSourceLocation.setColumn", overloads);
        return 0;
}

static PyObject* Sbk_QSourceLocationFunc_setLine(PyObject* self, PyObject* arg)
{
    QSourceLocation* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QSourceLocation* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setLine(qint64)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setLine(qint64)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QSourceLocationFunc_setLine_TypeError;

    // Call function/method
    {
        {
            qint64 cppArg0 = Shiboken::Converter<qint64 >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setLine(qint64)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setLine(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QSourceLocationFunc_setLine_TypeError:
        const char* overloads[] = {"long long", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtXmlPatterns.QSourceLocation.setLine", overloads);
        return 0;
}

static PyObject* Sbk_QSourceLocationFunc_setUri(PyObject* self, PyObject* arg)
{
    QSourceLocation* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QSourceLocation* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setUri(QUrl)
    if (Shiboken::Converter< ::QUrl >::isConvertible(arg)) {
        overloadId = 0; // setUri(QUrl)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QSourceLocationFunc_setUri_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QUrl cppArg0 = Shiboken::Converter<QUrl >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setUri(QUrl)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setUri(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QSourceLocationFunc_setUri_TypeError:
        const char* overloads[] = {"PySide.QtCore.QUrl", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtXmlPatterns.QSourceLocation.setUri", overloads);
        return 0;
}

static PyObject* Sbk_QSourceLocationFunc_uri(PyObject* self)
{
    QSourceLocation* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QSourceLocation* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // uri()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QUrl cppResult = const_cast<const QSourceLocation*>(cppSelf)->uri();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QUrl >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject *Sbk_QSourceLocation___copy__(PyObject *self)
{
        QSourceLocation* cppSelf = 0;
        if (!Shiboken::Object::isValid(self))
            return 0;
        cppSelf = Shiboken::Converter<QSourceLocation*>::toCpp(self);
        PyObject* pyResult = 0;
        QSourceLocation* copy = new QSourceLocation(*cppSelf);
        pyResult = Shiboken::Converter<QSourceLocation*>::toPython(copy);
        Shiboken::Object::getOwnership(pyResult);

        if (PyErr_Occurred() || !pyResult) {
            Py_XDECREF(pyResult);
            return 0;
        }
        return pyResult;
}

static PyMethodDef Sbk_QSourceLocation_methods[] = {
    {"column", (PyCFunction)Sbk_QSourceLocationFunc_column, METH_NOARGS},
    {"isNull", (PyCFunction)Sbk_QSourceLocationFunc_isNull, METH_NOARGS},
    {"line", (PyCFunction)Sbk_QSourceLocationFunc_line, METH_NOARGS},
    {"setColumn", (PyCFunction)Sbk_QSourceLocationFunc_setColumn, METH_O},
    {"setLine", (PyCFunction)Sbk_QSourceLocationFunc_setLine, METH_O},
    {"setUri", (PyCFunction)Sbk_QSourceLocationFunc_setUri, METH_O},
    {"uri", (PyCFunction)Sbk_QSourceLocationFunc_uri, METH_NOARGS},

    {"__copy__", (PyCFunction)Sbk_QSourceLocation___copy__, METH_NOARGS},
    {0} // Sentinel
};

static int Sbk_QSourceLocation___nb_bool(PyObject* pyObj)
{
    if (!Shiboken::Object::isValid(pyObj))
        return -1;
    const ::QSourceLocation* cppSelf = Shiboken::Converter< ::QSourceLocation*>::toCpp(pyObj);
    int result;
    Py_BEGIN_ALLOW_THREADS
    result = !cppSelf->isNull();
    Py_END_ALLOW_THREADS
    return result;
}

// type has number operators
static PyNumberMethods Sbk_QSourceLocation_as_number = {
    /*nb_add*/                  (binaryfunc)0,
    /*nb_subtract*/             (binaryfunc)0,
    /*nb_multiply*/             (binaryfunc)0,
    /*nb_divide*/               (binaryfunc)0,
    /*nb_remainder*/            (binaryfunc)0,
    /*nb_divmod*/               0,
    /*nb_power*/                0,
    /*nb_negative*/             (unaryfunc)0,
    /*nb_positive*/             (unaryfunc)0,
    /*nb_absolute*/             0,
    /*nb_nonzero*/              Sbk_QSourceLocation___nb_bool,
    /*nb_invert*/               (unaryfunc)0,
    /*nb_lshift*/               (binaryfunc)0,
    /*nb_rshift*/               (binaryfunc)0,
    /*nb_and*/                  (binaryfunc)0,
    /*nb_xor*/                  (binaryfunc)0,
    /*nb_or*/                   (binaryfunc)0,
    /*nb_coerce*/               0,
    /*nb_int*/                  0,
    /*nb_long*/                 0,
    /*nb_float*/                0,
    /*nb_oct*/                  0,
    /*nb_hex*/                  0,
    /*nb_inplace_add*/          (binaryfunc)0,
    /*nb_inplace_subtract*/     (binaryfunc)0,
    /*nb_inplace_multiply*/     (binaryfunc)0,
    /*nb_inplace_divide*/       (binaryfunc)0,
    /*nb_inplace_remainder*/    (binaryfunc)0,
    /*nb_inplace_power*/        0,
    /*nb_inplace_lshift*/       (binaryfunc)0,
    /*nb_inplace_rshift*/       (binaryfunc)0,
    /*nb_inplace_and*/          (binaryfunc)0,
    /*nb_inplace_xor*/          (binaryfunc)0,
    /*nb_inplace_or*/           (binaryfunc)0,
    /*nb_floor_divide*/         0,
    /*nb_true_divide*/          (binaryfunc)0,
    /*nb_inplace_floor_divide*/ 0,
    /*nb_inplace_true_divide*/  0,
    /*nb_index*/                0
};

// Rich comparison
static PyObject* Sbk_QSourceLocation_richcompare(PyObject* self, PyObject* arg, int op)
{
    PyObject* pyResult = 0;
    QSourceLocation& cppSelf = *Shiboken::Converter< QSourceLocation* >::toCpp(self);

    switch (op) {
        case Py_NE:
            if (Shiboken::Converter< ::QSourceLocation >::isConvertible(arg)) {
                // operator!=(const QSourceLocation & other) const
                QSourceLocation cppArg0 = Shiboken::Converter< ::QSourceLocation >::toCpp(arg);
                pyResult = Shiboken::Converter< bool >::toPython(cppSelf != cppArg0);
            } else goto Sbk_QSourceLocation_RichComparison_TypeError;

            break;
        case Py_EQ:
            if (Shiboken::Converter< ::QSourceLocation >::isConvertible(arg)) {
                // operator==(const QSourceLocation & other) const
                QSourceLocation cppArg0 = Shiboken::Converter< ::QSourceLocation >::toCpp(arg);
                pyResult = Shiboken::Converter< bool >::toPython(cppSelf == cppArg0);
            } else goto Sbk_QSourceLocation_RichComparison_TypeError;

            break;
        default:
            goto Sbk_QSourceLocation_RichComparison_TypeError;
    }

    if (pyResult && !PyErr_Occurred())
        return pyResult;
    Sbk_QSourceLocation_RichComparison_TypeError:
    PyErr_SetString(PyExc_NotImplementedError, "operator not implemented.");
    return 0;

}

} // extern "C"

extern "C"
{
static PyObject* Sbk_QSourceLocation__repr__(PyObject* pyObj)
{
    QBuffer buffer;
    buffer.open(QBuffer::ReadWrite);
    QDebug dbg(&buffer);
    dbg << Shiboken::Converter< ::QSourceLocation >::toCpp(pyObj);
    buffer.close();
    return PyString_FromFormat("<PySide.QtXmlPatterns.%s at %p>", buffer.data().constData(), pyObj);
}
} // extern C

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QSourceLocation_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtXmlPatterns.QSourceLocation",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Sbk_QSourceLocation__repr__,
    /*tp_as_number*/        &Sbk_QSourceLocation_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      Sbk_QSourceLocation_richcompare,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QSourceLocation_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QSourceLocation_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QSourceLocation(PyObject* module)
{
    SbkPySide_QtXmlPatternsTypes[SBK_QSOURCELOCATION_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QSourceLocation_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QSourceLocation_Type);
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QSourceLocation_Type, &Shiboken::callCppDestructor<QSourceLocation >);
    if (PyType_Ready((PyTypeObject*)&Sbk_QSourceLocation_Type) < 0)
        return;

    Shiboken::ObjectType::setOriginalName(&Sbk_QSourceLocation_Type, "QSourceLocation");
    PyModule_AddObject(module, "QSourceLocation",
        ((PyObject*)&Sbk_QSourceLocation_Type));


    Shiboken::TypeResolver::createValueTypeResolver<QSourceLocation >("QSourceLocation");
    Shiboken::TypeResolver::createObjectTypeResolver<QSourceLocation >("QSourceLocation*");
    Shiboken::TypeResolver::createValueTypeResolver<QSourceLocation >(typeid(QSourceLocation).name());
    PySide::initQtMetaType< ::QSourceLocation >();
}

