/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtxmlpatterns_python.h"

#include "qxmlquery_wrapper.h"

// Extra includes
#include <QStringList>
#include <qabstractmessagehandler.h>
#include <qabstracturiresolver.h>
#include <qabstractxmlnodemodel.h>
#include <qabstractxmlreceiver.h>
#include <qiodevice.h>
#include <qurl.h>
#include <qxmlname.h>
#include <qxmlnamepool.h>
#include <qxmlquery.h>
#include <qxmlresultitems.h>



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QXmlQuery_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QXmlQuery >()))
        return -1;

    QXmlQuery* cptr = 0;
    int overloadId = -1;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);

    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtXmlPatterns.QXmlQuery(): too many arguments");
        return -1;
    }

    if (!PyArg_ParseTuple(args, "|OO:QXmlQuery", &(pyargs[0]), &(pyargs[1])))
        return -1;

    // Overloaded function decisor
    // 0: QXmlQuery()
    // 1: QXmlQuery(QXmlQuery::QueryLanguage,QXmlNamePool)
    // 2: QXmlQuery(QXmlNamePool)
    // 3: QXmlQuery(QXmlQuery)
    if (numArgs == 0) {
        overloadId = 0; // QXmlQuery()
    } else if (numArgs == 1 && Shiboken::Converter< ::QXmlNamePool >::isConvertible(pyargs[0])) {
        overloadId = 2; // QXmlQuery(QXmlNamePool)
    } else if (Shiboken::Converter< ::QXmlQuery::QueryLanguage >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 1; // QXmlQuery(QXmlQuery::QueryLanguage,QXmlNamePool)
        } else if (Shiboken::Converter< ::QXmlNamePool >::isConvertible(pyargs[1])) {
            overloadId = 1; // QXmlQuery(QXmlQuery::QueryLanguage,QXmlNamePool)
        }
    } else if (numArgs == 1 && Shiboken::Converter< ::QXmlQuery >::isConvertible(pyargs[0])) {
        overloadId = 3; // QXmlQuery(QXmlQuery)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QXmlQuery_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QXmlQuery()
            {

                if(!PyErr_Occurred()) {
                    // QXmlQuery()
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QXmlQuery();
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // QXmlQuery(QXmlQuery::QueryLanguage,QXmlNamePool)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "np");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "np";
                        else if (Shiboken::Converter< ::QXmlNamePool >::isConvertible(value))
                            pyargs[1] = value;
                        else
                            goto Sbk_QXmlQuery_Init_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtXmlPatterns.QXmlQuery(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                QXmlQuery::QueryLanguage cppArg0 = Shiboken::Converter<QXmlQuery::QueryLanguage >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return -1;
                QXmlNamePool cppArg1_tmp = QXmlNamePool();
                QXmlNamePool cppArg1 = pyargs[1] ? Shiboken::Converter<QXmlNamePool >::toCpp(pyargs[1]) : cppArg1_tmp;

                if(!PyErr_Occurred()) {
                    // QXmlQuery(QXmlQuery::QueryLanguage,QXmlNamePool)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QXmlQuery(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 2: // QXmlQuery(QXmlNamePool)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QXmlNamePool cppArg0 = Shiboken::Converter<QXmlNamePool >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QXmlQuery(QXmlNamePool)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QXmlQuery(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 3: // QXmlQuery(QXmlQuery)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QXmlQuery cppArg0 = Shiboken::Converter<QXmlQuery >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QXmlQuery(QXmlQuery)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QXmlQuery(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QXmlQuery >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QXmlQuery_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QXmlQuery_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtXmlPatterns.QXmlQuery.QueryLanguage, PySide.QtXmlPatterns.QXmlNamePool = QXmlNamePool()", "PySide.QtXmlPatterns.QXmlNamePool", "PySide.QtXmlPatterns.QXmlQuery", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtXmlPatterns.QXmlQuery", overloads);
        return -1;
}

static PyObject* Sbk_QXmlQueryFunc_bindVariable(PyObject* self, PyObject* args)
{
    QXmlQuery* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlQuery* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "bindVariable", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: bindVariable(QString,QIODevice*)
    // 1: bindVariable(QString,QXmlItem)
    // 2: bindVariable(QString,QXmlQuery)
    // 3: bindVariable(QXmlName,QIODevice*)
    // 4: bindVariable(QXmlName,QXmlItem)
    // 5: bindVariable(QXmlName,QXmlQuery)
    if (Shiboken::Converter< ::QXmlName >::isConvertible(pyargs[0])) {
        if (numArgs == 2 && Shiboken::Converter< ::QXmlQuery >::isConvertible(pyargs[1])) {
            overloadId = 5; // bindVariable(QXmlName,QXmlQuery)
        } else if (numArgs == 2 && Shiboken::Converter< ::QXmlItem >::isConvertible(pyargs[1])) {
            overloadId = 4; // bindVariable(QXmlName,QXmlItem)
        } else if (numArgs == 2 && Shiboken::Converter< ::QIODevice * >::isConvertible(pyargs[1])) {
            overloadId = 3; // bindVariable(QXmlName,QIODevice*)
        }
    } else if (Shiboken::Converter< QString >::isConvertible(pyargs[0])) {
        if (numArgs == 2 && Shiboken::Converter< ::QXmlQuery >::isConvertible(pyargs[1])) {
            overloadId = 2; // bindVariable(QString,QXmlQuery)
        } else if (numArgs == 2 && Shiboken::Converter< ::QXmlItem >::isConvertible(pyargs[1])) {
            overloadId = 1; // bindVariable(QString,QXmlItem)
        } else if (numArgs == 2 && Shiboken::Converter< ::QIODevice * >::isConvertible(pyargs[1])) {
            overloadId = 0; // bindVariable(QString,QIODevice*)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QXmlQueryFunc_bindVariable_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // bindVariable(QString,QIODevice*)
            {
                QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QIODevice * cppArg1 = Shiboken::Converter<QIODevice * >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // bindVariable(QString,QIODevice*)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->bindVariable(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // bindVariable(QString,QXmlItem)
            {
                QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QXmlItem cppArg1 = Shiboken::Converter<QXmlItem >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // bindVariable(QString,QXmlItem)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->bindVariable(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 2: // bindVariable(QString,QXmlQuery)
            {
                QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QXmlQuery cppArg1 = Shiboken::Converter<QXmlQuery >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // bindVariable(QString,QXmlQuery)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->bindVariable(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 3: // bindVariable(QXmlName,QIODevice*)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QXmlName cppArg0 = Shiboken::Converter<QXmlName >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QIODevice * cppArg1 = Shiboken::Converter<QIODevice * >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // bindVariable(QXmlName,QIODevice*)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->bindVariable(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 4: // bindVariable(QXmlName,QXmlItem)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QXmlName cppArg0 = Shiboken::Converter<QXmlName >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QXmlItem cppArg1 = Shiboken::Converter<QXmlItem >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // bindVariable(QXmlName,QXmlItem)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->bindVariable(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 5: // bindVariable(QXmlName,QXmlQuery)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QXmlName cppArg0 = Shiboken::Converter<QXmlName >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QXmlQuery cppArg1 = Shiboken::Converter<QXmlQuery >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // bindVariable(QXmlName,QXmlQuery)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->bindVariable(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QXmlQueryFunc_bindVariable_TypeError:
        const char* overloads[] = {"QString, PySide.QtCore.QIODevice", "QString, PySide.QtXmlPatterns.QXmlItem", "QString, PySide.QtXmlPatterns.QXmlQuery", "PySide.QtXmlPatterns.QXmlName, PySide.QtCore.QIODevice", "PySide.QtXmlPatterns.QXmlName, PySide.QtXmlPatterns.QXmlItem", "PySide.QtXmlPatterns.QXmlName, PySide.QtXmlPatterns.QXmlQuery", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtXmlPatterns.QXmlQuery.bindVariable", overloads);
        return 0;
}

static PyObject* Sbk_QXmlQueryFunc_evaluateTo(PyObject* self, PyObject* arg)
{
    QXmlQuery* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlQuery* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: evaluateTo(QAbstractXmlReceiver*)const
    // 1: evaluateTo(QIODevice*)const
    // 2: evaluateTo(QString*)const
    // 3: evaluateTo(QStringList*)const
    // 4: evaluateTo(QXmlResultItems*)const
    if (Shiboken::Converter< ::QXmlResultItems * >::isConvertible(arg)) {
        overloadId = 4; // evaluateTo(QXmlResultItems*)const
    } else if (Shiboken::Converter< ::QStringList * >::isConvertible(arg)) {
        overloadId = 3; // evaluateTo(QStringList*)const
    } else if (Shiboken::Converter< ::QIODevice * >::isConvertible(arg)) {
        overloadId = 1; // evaluateTo(QIODevice*)const
    } else if (Shiboken::Converter< ::QAbstractXmlReceiver * >::isConvertible(arg)) {
        overloadId = 0; // evaluateTo(QAbstractXmlReceiver*)const
    } else if (Shiboken::Converter< ::QString * >::isConvertible(arg)) {
        overloadId = 2; // evaluateTo(QString*)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QXmlQueryFunc_evaluateTo_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // evaluateTo(QAbstractXmlReceiver*)const
            {
                if (!Shiboken::Object::isValid(arg))
                    return 0;
                QAbstractXmlReceiver * cppArg0 = Shiboken::Converter<QAbstractXmlReceiver * >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // evaluateTo(QAbstractXmlReceiver*)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    bool cppResult = const_cast<const QXmlQuery*>(cppSelf)->evaluateTo(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< bool >::toPython(cppResult);
                }
                break;
            }
            case 1: // evaluateTo(QIODevice*)const
            {
                if (!Shiboken::Object::isValid(arg))
                    return 0;
                QIODevice * cppArg0 = Shiboken::Converter<QIODevice * >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // evaluateTo(QIODevice*)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    bool cppResult = const_cast<const QXmlQuery*>(cppSelf)->evaluateTo(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< bool >::toPython(cppResult);
                }
                break;
            }
            case 2: // evaluateTo(QString*)const
            {
                QString * cppArg0 = Shiboken::Converter<QString * >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // evaluateTo(QString*)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    bool cppResult = const_cast<const QXmlQuery*>(cppSelf)->evaluateTo(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< bool >::toPython(cppResult);
                }
                break;
            }
            case 3: // evaluateTo(QStringList*)const
            {
                QStringList * cppArg0 = Shiboken::Converter<QStringList * >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // evaluateTo(QStringList*)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    bool cppResult = const_cast<const QXmlQuery*>(cppSelf)->evaluateTo(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< bool >::toPython(cppResult);
                }
                break;
            }
            case 4: // evaluateTo(QXmlResultItems*)const
            {
                if (!Shiboken::Object::isValid(arg))
                    return 0;
                QXmlResultItems * cppArg0 = Shiboken::Converter<QXmlResultItems * >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // evaluateTo(QXmlResultItems*)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    const_cast<const QXmlQuery*>(cppSelf)->evaluateTo(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Py_None;
                    Py_INCREF(Py_None);
                }
                break;
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QXmlQueryFunc_evaluateTo_TypeError:
        const char* overloads[] = {"PySide.QtXmlPatterns.QAbstractXmlReceiver", "PySide.QtCore.QIODevice", "QString", "list", "PySide.QtXmlPatterns.QXmlResultItems", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtXmlPatterns.QXmlQuery.evaluateTo", overloads);
        return 0;
}

static PyObject* Sbk_QXmlQueryFunc_initialTemplateName(PyObject* self)
{
    QXmlQuery* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlQuery* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // initialTemplateName()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QXmlName cppResult = const_cast<const QXmlQuery*>(cppSelf)->initialTemplateName();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QXmlName >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QXmlQueryFunc_isValid(PyObject* self)
{
    QXmlQuery* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlQuery* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isValid()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QXmlQuery*>(cppSelf)->isValid();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QXmlQueryFunc_messageHandler(PyObject* self)
{
    QXmlQuery* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlQuery* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // messageHandler()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QAbstractMessageHandler * cppResult = const_cast<const QXmlQuery*>(cppSelf)->messageHandler();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QAbstractMessageHandler * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QXmlQueryFunc_namePool(PyObject* self)
{
    QXmlQuery* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlQuery* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // namePool()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QXmlNamePool cppResult = const_cast<const QXmlQuery*>(cppSelf)->namePool();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QXmlNamePool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QXmlQueryFunc_queryLanguage(PyObject* self)
{
    QXmlQuery* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlQuery* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // queryLanguage()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QXmlQuery::QueryLanguage cppResult = const_cast<const QXmlQuery*>(cppSelf)->queryLanguage();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QXmlQuery::QueryLanguage >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QXmlQueryFunc_setFocus(PyObject* self, PyObject* arg)
{
    QXmlQuery* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlQuery* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setFocus(QIODevice*)
    // 1: setFocus(QString)
    // 2: setFocus(QUrl)
    // 3: setFocus(QXmlItem)
    if (Shiboken::Converter< ::QXmlItem >::isConvertible(arg)) {
        overloadId = 3; // setFocus(QXmlItem)
    } else if (Shiboken::Converter< ::QIODevice * >::isConvertible(arg)) {
        overloadId = 0; // setFocus(QIODevice*)
    } else if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 1; // setFocus(QString)
    } else if (Shiboken::Converter< ::QUrl >::isConvertible(arg)) {
        overloadId = 2; // setFocus(QUrl)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QXmlQueryFunc_setFocus_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // setFocus(QIODevice*)
            {
                if (!Shiboken::Object::isValid(arg))
                    return 0;
                QIODevice * cppArg0 = Shiboken::Converter<QIODevice * >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // setFocus(QIODevice*)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    bool cppResult = cppSelf->setFocus(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< bool >::toPython(cppResult);
                }
                break;
            }
            case 1: // setFocus(QString)
            {
                QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // setFocus(QString)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    bool cppResult = cppSelf->setFocus(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< bool >::toPython(cppResult);
                }
                break;
            }
            case 2: // setFocus(QUrl)
            {
                if (!Shiboken::Object::isValid(arg))
                    return 0;
                QUrl cppArg0 = Shiboken::Converter<QUrl >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // setFocus(QUrl)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    bool cppResult = cppSelf->setFocus(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< bool >::toPython(cppResult);
                }
                break;
            }
            case 3: // setFocus(QXmlItem)
            {
                if (!Shiboken::Object::isValid(arg))
                    return 0;
                QXmlItem cppArg0 = Shiboken::Converter<QXmlItem >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // setFocus(QXmlItem)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setFocus(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Py_None;
                    Py_INCREF(Py_None);
                }
                break;
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QXmlQueryFunc_setFocus_TypeError:
        const char* overloads[] = {"PySide.QtCore.QIODevice", "QString", "PySide.QtCore.QUrl", "PySide.QtXmlPatterns.QXmlItem", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtXmlPatterns.QXmlQuery.setFocus", overloads);
        return 0;
}

static PyObject* Sbk_QXmlQueryFunc_setInitialTemplateName(PyObject* self, PyObject* arg)
{
    QXmlQuery* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlQuery* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setInitialTemplateName(QString)
    // 1: setInitialTemplateName(QXmlName)
    if (Shiboken::Converter< ::QXmlName >::isConvertible(arg)) {
        overloadId = 1; // setInitialTemplateName(QXmlName)
    } else if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // setInitialTemplateName(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QXmlQueryFunc_setInitialTemplateName_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // setInitialTemplateName(QString)
            {
                QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // setInitialTemplateName(QString)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setInitialTemplateName(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // setInitialTemplateName(QXmlName)
            {
                if (!Shiboken::Object::isValid(arg))
                    return 0;
                QXmlName cppArg0 = Shiboken::Converter<QXmlName >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // setInitialTemplateName(QXmlName)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setInitialTemplateName(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QXmlQueryFunc_setInitialTemplateName_TypeError:
        const char* overloads[] = {"QString", "PySide.QtXmlPatterns.QXmlName", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtXmlPatterns.QXmlQuery.setInitialTemplateName", overloads);
        return 0;
}

static PyObject* Sbk_QXmlQueryFunc_setMessageHandler(PyObject* self, PyObject* arg)
{
    QXmlQuery* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlQuery* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setMessageHandler(QAbstractMessageHandler*)
    if (Shiboken::Converter< ::QAbstractMessageHandler * >::isConvertible(arg)) {
        overloadId = 0; // setMessageHandler(QAbstractMessageHandler*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QXmlQueryFunc_setMessageHandler_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QAbstractMessageHandler * cppArg0 = Shiboken::Converter<QAbstractMessageHandler * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setMessageHandler(QAbstractMessageHandler*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setMessageHandler(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QXmlQueryFunc_setMessageHandler_TypeError:
        const char* overloads[] = {"PySide.QtXmlPatterns.QAbstractMessageHandler", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtXmlPatterns.QXmlQuery.setMessageHandler", overloads);
        return 0;
}

static PyObject* Sbk_QXmlQueryFunc_setQuery(PyObject* self, PyObject* args, PyObject* kwds)
{
    QXmlQuery* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlQuery* >::toCpp(self);

    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtXmlPatterns.QXmlQuery.setQuery(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtXmlPatterns.QXmlQuery.setQuery(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:setQuery", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setQuery(QIODevice*,QUrl)
    // 1: setQuery(QString,QUrl)
    // 2: setQuery(QUrl,QUrl)
    if (Shiboken::Converter< ::QIODevice * >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // setQuery(QIODevice*,QUrl)
        } else if (Shiboken::Converter< ::QUrl >::isConvertible(pyargs[1])) {
            overloadId = 0; // setQuery(QIODevice*,QUrl)
        }
    } else if (Shiboken::Converter< QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 1; // setQuery(QString,QUrl)
        } else if (Shiboken::Converter< ::QUrl >::isConvertible(pyargs[1])) {
            overloadId = 1; // setQuery(QString,QUrl)
        }
    } else if (Shiboken::Converter< ::QUrl >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 2; // setQuery(QUrl,QUrl)
        } else if (Shiboken::Converter< ::QUrl >::isConvertible(pyargs[1])) {
            overloadId = 2; // setQuery(QUrl,QUrl)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QXmlQueryFunc_setQuery_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // setQuery(QIODevice*,QUrl)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "documentURI");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "documentURI";
                        else if (Shiboken::Converter< ::QUrl >::isConvertible(value))
                            pyargs[1] = value;
                        else
                            goto Sbk_QXmlQueryFunc_setQuery_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtXmlPatterns.QXmlQuery.setQuery(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QIODevice * cppArg0 = Shiboken::Converter<QIODevice * >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QUrl cppArg1_tmp = QUrl();
                QUrl cppArg1 = pyargs[1] ? Shiboken::Converter<QUrl >::toCpp(pyargs[1]) : cppArg1_tmp;

                if(!PyErr_Occurred()) {
                    // setQuery(QIODevice*,QUrl)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setQuery(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // setQuery(QString,QUrl)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "documentURI");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "documentURI";
                        else if (Shiboken::Converter< ::QUrl >::isConvertible(value))
                            pyargs[1] = value;
                        else
                            goto Sbk_QXmlQueryFunc_setQuery_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtXmlPatterns.QXmlQuery.setQuery(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QUrl cppArg1_tmp = QUrl();
                QUrl cppArg1 = pyargs[1] ? Shiboken::Converter<QUrl >::toCpp(pyargs[1]) : cppArg1_tmp;

                if(!PyErr_Occurred()) {
                    // setQuery(QString,QUrl)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setQuery(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 2: // setQuery(QUrl,QUrl)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "baseURI");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "baseURI";
                        else if (Shiboken::Converter< ::QUrl >::isConvertible(value))
                            pyargs[1] = value;
                        else
                            goto Sbk_QXmlQueryFunc_setQuery_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtXmlPatterns.QXmlQuery.setQuery(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QUrl cppArg0 = Shiboken::Converter<QUrl >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QUrl cppArg1_tmp = QUrl();
                QUrl cppArg1 = pyargs[1] ? Shiboken::Converter<QUrl >::toCpp(pyargs[1]) : cppArg1_tmp;

                if(!PyErr_Occurred()) {
                    // setQuery(QUrl,QUrl)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setQuery(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QXmlQueryFunc_setQuery_TypeError:
        const char* overloads[] = {"PySide.QtCore.QIODevice, PySide.QtCore.QUrl = QUrl()", "QString, PySide.QtCore.QUrl = QUrl()", "PySide.QtCore.QUrl, PySide.QtCore.QUrl = QUrl()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtXmlPatterns.QXmlQuery.setQuery", overloads);
        return 0;
}

static PyObject* Sbk_QXmlQueryFunc_setUriResolver(PyObject* self, PyObject* arg)
{
    QXmlQuery* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlQuery* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setUriResolver(const QAbstractUriResolver*)
    if (Shiboken::Converter< ::QAbstractUriResolver * >::isConvertible(arg)) {
        overloadId = 0; // setUriResolver(const QAbstractUriResolver*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QXmlQueryFunc_setUriResolver_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QAbstractUriResolver * cppArg0 = Shiboken::Converter<QAbstractUriResolver * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setUriResolver(const QAbstractUriResolver*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setUriResolver(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QXmlQueryFunc_setUriResolver_TypeError:
        const char* overloads[] = {"PySide.QtXmlPatterns.QAbstractUriResolver", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtXmlPatterns.QXmlQuery.setUriResolver", overloads);
        return 0;
}

static PyObject* Sbk_QXmlQueryFunc_uriResolver(PyObject* self)
{
    QXmlQuery* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlQuery* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // uriResolver()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                const QAbstractUriResolver * cppResult = const_cast<const QXmlQuery*>(cppSelf)->uriResolver();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QAbstractUriResolver * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject *Sbk_QXmlQuery___copy__(PyObject *self)
{
        QXmlQuery* cppSelf = 0;
        if (!Shiboken::Object::isValid(self))
            return 0;
        cppSelf = Shiboken::Converter<QXmlQuery*>::toCpp(self);
        PyObject* pyResult = 0;
        QXmlQuery* copy = new QXmlQuery(*cppSelf);
        pyResult = Shiboken::Converter<QXmlQuery*>::toPython(copy);
        Shiboken::Object::getOwnership(pyResult);

        if (PyErr_Occurred() || !pyResult) {
            Py_XDECREF(pyResult);
            return 0;
        }
        return pyResult;
}

static PyMethodDef Sbk_QXmlQuery_methods[] = {
    {"bindVariable", (PyCFunction)Sbk_QXmlQueryFunc_bindVariable, METH_VARARGS},
    {"evaluateTo", (PyCFunction)Sbk_QXmlQueryFunc_evaluateTo, METH_O},
    {"initialTemplateName", (PyCFunction)Sbk_QXmlQueryFunc_initialTemplateName, METH_NOARGS},
    {"isValid", (PyCFunction)Sbk_QXmlQueryFunc_isValid, METH_NOARGS},
    {"messageHandler", (PyCFunction)Sbk_QXmlQueryFunc_messageHandler, METH_NOARGS},
    {"namePool", (PyCFunction)Sbk_QXmlQueryFunc_namePool, METH_NOARGS},
    {"queryLanguage", (PyCFunction)Sbk_QXmlQueryFunc_queryLanguage, METH_NOARGS},
    {"setFocus", (PyCFunction)Sbk_QXmlQueryFunc_setFocus, METH_O},
    {"setInitialTemplateName", (PyCFunction)Sbk_QXmlQueryFunc_setInitialTemplateName, METH_O},
    {"setMessageHandler", (PyCFunction)Sbk_QXmlQueryFunc_setMessageHandler, METH_O},
    {"setQuery", (PyCFunction)Sbk_QXmlQueryFunc_setQuery, METH_VARARGS|METH_KEYWORDS},
    {"setUriResolver", (PyCFunction)Sbk_QXmlQueryFunc_setUriResolver, METH_O},
    {"uriResolver", (PyCFunction)Sbk_QXmlQueryFunc_uriResolver, METH_NOARGS},

    {"__copy__", (PyCFunction)Sbk_QXmlQuery___copy__, METH_NOARGS},
    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QXmlQuery_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtXmlPatterns.QXmlQuery",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QXmlQuery_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QXmlQuery_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QXmlQuery(PyObject* module)
{
    SbkPySide_QtXmlPatternsTypes[SBK_QXMLQUERY_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QXmlQuery_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QXmlQuery_Type);
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QXmlQuery_Type, &Shiboken::callCppDestructor<QXmlQuery >);
    if (PyType_Ready((PyTypeObject*)&Sbk_QXmlQuery_Type) < 0)
        return;

    Shiboken::ObjectType::setOriginalName(&Sbk_QXmlQuery_Type, "QXmlQuery");
    PyModule_AddObject(module, "QXmlQuery",
        ((PyObject*)&Sbk_QXmlQuery_Type));

    // Initialize enums
    PyObject* enumItem;

    // init enum: QueryLanguage
    PyTypeObject* SbkPySide_QtXmlPatterns_QXmlQuery_QueryLanguage = Shiboken::Enum::newType("PySide.QtXmlPatterns.QXmlQuery.QueryLanguage");
    SbkPySide_QtXmlPatternsTypes[SBK_QXMLQUERY_QUERYLANGUAGE_IDX] = SbkPySide_QtXmlPatterns_QXmlQuery_QueryLanguage;
    if (PyType_Ready(SbkPySide_QtXmlPatterns_QXmlQuery_QueryLanguage) < 0)
        return;
    PyDict_SetItemString(Sbk_QXmlQuery_Type.super.ht_type.tp_dict,
            "QueryLanguage",((PyObject*)SbkPySide_QtXmlPatterns_QXmlQuery_QueryLanguage));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtXmlPatterns_QXmlQuery_QueryLanguage,(long) QXmlQuery::XQuery10, "XQuery10");
    PyDict_SetItemString(Sbk_QXmlQuery_Type.super.ht_type.tp_dict,"XQuery10", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtXmlPatterns_QXmlQuery_QueryLanguage->tp_dict,"XQuery10", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtXmlPatterns_QXmlQuery_QueryLanguage,(long) QXmlQuery::XSLT20, "XSLT20");
    PyDict_SetItemString(Sbk_QXmlQuery_Type.super.ht_type.tp_dict,"XSLT20", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtXmlPatterns_QXmlQuery_QueryLanguage->tp_dict,"XSLT20", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtXmlPatterns_QXmlQuery_QueryLanguage,(long) QXmlQuery::XmlSchema11IdentityConstraintSelector, "XmlSchema11IdentityConstraintSelector");
    PyDict_SetItemString(Sbk_QXmlQuery_Type.super.ht_type.tp_dict,"XmlSchema11IdentityConstraintSelector", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtXmlPatterns_QXmlQuery_QueryLanguage->tp_dict,"XmlSchema11IdentityConstraintSelector", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtXmlPatterns_QXmlQuery_QueryLanguage,(long) QXmlQuery::XmlSchema11IdentityConstraintField, "XmlSchema11IdentityConstraintField");
    PyDict_SetItemString(Sbk_QXmlQuery_Type.super.ht_type.tp_dict,"XmlSchema11IdentityConstraintField", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtXmlPatterns_QXmlQuery_QueryLanguage->tp_dict,"XmlSchema11IdentityConstraintField", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtXmlPatterns_QXmlQuery_QueryLanguage,(long) QXmlQuery::XPath20, "XPath20");
    PyDict_SetItemString(Sbk_QXmlQuery_Type.super.ht_type.tp_dict,"XPath20", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtXmlPatterns_QXmlQuery_QueryLanguage->tp_dict,"XPath20", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QXmlQuery::QueryLanguage");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::QueryLanguage");
    // end of enum QueryLanguage


    Shiboken::TypeResolver::createValueTypeResolver<QXmlQuery >("QXmlQuery");
    Shiboken::TypeResolver::createObjectTypeResolver<QXmlQuery >("QXmlQuery*");
    Shiboken::TypeResolver::createValueTypeResolver<QXmlQuery >(typeid(QXmlQuery).name());
    PySide::initQtMetaType< ::QXmlQuery >();
    qRegisterMetaType< ::QXmlQuery::QueryLanguage >("QXmlQuery::QueryLanguage");
}

