/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtxmlpatterns_python.h"

#include "qxmlschema_wrapper.h"

// Extra includes
#include <qabstractmessagehandler.h>
#include <qabstracturiresolver.h>
#include <qbytearray.h>
#include <qiodevice.h>
#include <qurl.h>
#include <qxmlnamepool.h>
#include <qxmlschema.h>



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QXmlSchema_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QXmlSchema >()))
        return -1;

    QXmlSchema* cptr = 0;
    int overloadId = -1;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QXmlSchema", 0, 1, &(pyargs[0])))
        return -1;

    // Overloaded function decisor
    // 0: QXmlSchema()
    // 1: QXmlSchema(QXmlSchema)
    if (numArgs == 0) {
        overloadId = 0; // QXmlSchema()
    } else if (numArgs == 1 && Shiboken::Converter< ::QXmlSchema >::isConvertible(pyargs[0])) {
        overloadId = 1; // QXmlSchema(QXmlSchema)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QXmlSchema_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QXmlSchema()
            {

                if(!PyErr_Occurred()) {
                    // QXmlSchema()
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QXmlSchema();
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // QXmlSchema(QXmlSchema)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                const QXmlSchema & cppArg0 = Shiboken::Converter<const QXmlSchema & >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QXmlSchema(QXmlSchema)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QXmlSchema(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QXmlSchema >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QXmlSchema_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QXmlSchema_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtXmlPatterns.QXmlSchema", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtXmlPatterns.QXmlSchema", overloads);
        return -1;
}

static PyObject* Sbk_QXmlSchemaFunc_documentUri(PyObject* self)
{
    QXmlSchema* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlSchema* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // documentUri()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QUrl cppResult = const_cast<const QXmlSchema*>(cppSelf)->documentUri();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QUrl >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QXmlSchemaFunc_isValid(PyObject* self)
{
    QXmlSchema* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlSchema* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isValid()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QXmlSchema*>(cppSelf)->isValid();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QXmlSchemaFunc_load(PyObject* self, PyObject* args, PyObject* kwds)
{
    QXmlSchema* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlSchema* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtXmlPatterns.QXmlSchema.load(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtXmlPatterns.QXmlSchema.load(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:load", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: load(QIODevice*,QUrl)
    // 1: load(QByteArray,QUrl)
    // 2: load(QUrl)
    if (numArgs == 1 && Shiboken::Converter< ::QUrl >::isConvertible(pyargs[0])) {
        overloadId = 2; // load(QUrl)
    } else if (Shiboken::Converter< ::QByteArray >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 1; // load(QByteArray,QUrl)
        } else if (Shiboken::Converter< ::QUrl >::isConvertible(pyargs[1])) {
            overloadId = 1; // load(QByteArray,QUrl)
        }
    } else if (Shiboken::Converter< ::QIODevice * >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // load(QIODevice*,QUrl)
        } else if (Shiboken::Converter< ::QUrl >::isConvertible(pyargs[1])) {
            overloadId = 0; // load(QIODevice*,QUrl)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QXmlSchemaFunc_load_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // load(QIODevice*,QUrl)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "documentUri");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "documentUri";
                        else if (Shiboken::Converter< ::QUrl >::isConvertible(value))
                            pyargs[1] = value;
                        else
                            goto Sbk_QXmlSchemaFunc_load_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtXmlPatterns.QXmlSchema.load(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QIODevice * cppArg0 = Shiboken::Converter<QIODevice * >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QUrl cppArg1_tmp = QUrl();
                QUrl cppArg1 = pyargs[1] ? Shiboken::Converter<QUrl >::toCpp(pyargs[1]) : cppArg1_tmp;

                if(!PyErr_Occurred()) {
                    // load(QIODevice*,QUrl)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    bool cppResult = cppSelf->load(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< bool >::toPython(cppResult);
                }
                break;
            }
            case 1: // load(QByteArray,QUrl)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "documentUri");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "documentUri";
                        else if (Shiboken::Converter< ::QUrl >::isConvertible(value))
                            pyargs[1] = value;
                        else
                            goto Sbk_QXmlSchemaFunc_load_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtXmlPatterns.QXmlSchema.load(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QByteArray cppArg0 = Shiboken::Converter<QByteArray >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QUrl cppArg1_tmp = QUrl();
                QUrl cppArg1 = pyargs[1] ? Shiboken::Converter<QUrl >::toCpp(pyargs[1]) : cppArg1_tmp;

                if(!PyErr_Occurred()) {
                    // load(QByteArray,QUrl)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    bool cppResult = cppSelf->load(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< bool >::toPython(cppResult);
                }
                break;
            }
            case 2: // load(QUrl)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QUrl cppArg0 = Shiboken::Converter<QUrl >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // load(QUrl)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    bool cppResult = cppSelf->load(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< bool >::toPython(cppResult);
                }
                break;
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QXmlSchemaFunc_load_TypeError:
        const char* overloads[] = {"PySide.QtCore.QIODevice, PySide.QtCore.QUrl = QUrl()", "PySide.QtCore.QByteArray, PySide.QtCore.QUrl = QUrl()", "PySide.QtCore.QUrl", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtXmlPatterns.QXmlSchema.load", overloads);
        return 0;
}

static PyObject* Sbk_QXmlSchemaFunc_messageHandler(PyObject* self)
{
    QXmlSchema* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlSchema* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // messageHandler()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QAbstractMessageHandler * cppResult = const_cast<const QXmlSchema*>(cppSelf)->messageHandler();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QAbstractMessageHandler * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QXmlSchemaFunc_namePool(PyObject* self)
{
    QXmlSchema* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlSchema* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // namePool()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QXmlNamePool cppResult = const_cast<const QXmlSchema*>(cppSelf)->namePool();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QXmlNamePool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QXmlSchemaFunc_setMessageHandler(PyObject* self, PyObject* arg)
{
    QXmlSchema* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlSchema* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setMessageHandler(QAbstractMessageHandler*)
    if (Shiboken::Converter< ::QAbstractMessageHandler * >::isConvertible(arg)) {
        overloadId = 0; // setMessageHandler(QAbstractMessageHandler*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QXmlSchemaFunc_setMessageHandler_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QAbstractMessageHandler * cppArg0 = Shiboken::Converter<QAbstractMessageHandler * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setMessageHandler(QAbstractMessageHandler*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setMessageHandler(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QXmlSchemaFunc_setMessageHandler_TypeError:
        const char* overloads[] = {"PySide.QtXmlPatterns.QAbstractMessageHandler", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtXmlPatterns.QXmlSchema.setMessageHandler", overloads);
        return 0;
}

static PyObject* Sbk_QXmlSchemaFunc_setUriResolver(PyObject* self, PyObject* arg)
{
    QXmlSchema* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlSchema* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setUriResolver(const QAbstractUriResolver*)
    if (Shiboken::Converter< ::QAbstractUriResolver * >::isConvertible(arg)) {
        overloadId = 0; // setUriResolver(const QAbstractUriResolver*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QXmlSchemaFunc_setUriResolver_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QAbstractUriResolver * cppArg0 = Shiboken::Converter<QAbstractUriResolver * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setUriResolver(const QAbstractUriResolver*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setUriResolver(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QXmlSchemaFunc_setUriResolver_TypeError:
        const char* overloads[] = {"PySide.QtXmlPatterns.QAbstractUriResolver", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtXmlPatterns.QXmlSchema.setUriResolver", overloads);
        return 0;
}

static PyObject* Sbk_QXmlSchemaFunc_uriResolver(PyObject* self)
{
    QXmlSchema* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlSchema* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // uriResolver()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                const QAbstractUriResolver * cppResult = const_cast<const QXmlSchema*>(cppSelf)->uriResolver();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QAbstractUriResolver * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef Sbk_QXmlSchema_methods[] = {
    {"documentUri", (PyCFunction)Sbk_QXmlSchemaFunc_documentUri, METH_NOARGS},
    {"isValid", (PyCFunction)Sbk_QXmlSchemaFunc_isValid, METH_NOARGS},
    {"load", (PyCFunction)Sbk_QXmlSchemaFunc_load, METH_VARARGS|METH_KEYWORDS},
    {"messageHandler", (PyCFunction)Sbk_QXmlSchemaFunc_messageHandler, METH_NOARGS},
    {"namePool", (PyCFunction)Sbk_QXmlSchemaFunc_namePool, METH_NOARGS},
    {"setMessageHandler", (PyCFunction)Sbk_QXmlSchemaFunc_setMessageHandler, METH_O},
    {"setUriResolver", (PyCFunction)Sbk_QXmlSchemaFunc_setUriResolver, METH_O},
    {"uriResolver", (PyCFunction)Sbk_QXmlSchemaFunc_uriResolver, METH_NOARGS},

    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QXmlSchema_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtXmlPatterns.QXmlSchema",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QXmlSchema_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QXmlSchema_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QXmlSchema(PyObject* module)
{
    SbkPySide_QtXmlPatternsTypes[SBK_QXMLSCHEMA_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QXmlSchema_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QXmlSchema_Type);
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QXmlSchema_Type, &Shiboken::callCppDestructor<QXmlSchema >);
    if (PyType_Ready((PyTypeObject*)&Sbk_QXmlSchema_Type) < 0)
        return;

    Shiboken::ObjectType::setOriginalName(&Sbk_QXmlSchema_Type, "QXmlSchema*");
    PyModule_AddObject(module, "QXmlSchema",
        ((PyObject*)&Sbk_QXmlSchema_Type));


    Shiboken::TypeResolver::createObjectTypeResolver<QXmlSchema >("QXmlSchema*");
    Shiboken::TypeResolver::createObjectTypeResolver<QXmlSchema >(typeid(QXmlSchema).name());
    PySide::initQtMetaType< ::QXmlSchema* >();
}

