/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


#include <Python.h>
#include <shiboken.h>
#include <algorithm>
#include "pyside_phonon_python.h"



// Extra includes

// Global functions ------------------------------------------------------------

static PyMethodDef phonon_methods[] = {
    {0} // Sentinel
};

// Classes initialization functions ------------------------------------------------------------
void init_Phonon(PyObject* module);
void init_Phonon_BackendCapabilities(PyObject* module);
void init_Phonon_AudioChannelDescription(PyObject* module);
void init_Phonon_AudioOutputDevice(PyObject* module);
void init_Phonon_AudioCaptureDevice(PyObject* module);
void init_Phonon_SubtitleDescription(PyObject* module);
void init_Phonon_VideoCaptureDevice(PyObject* module);
void init_Phonon_EffectDescription(PyObject* module);
void init_Phonon_VolumeFaderInterface(PyObject* module);
void init_Phonon_VideoWidgetInterface(PyObject* module);
void init_Phonon_StreamInterface(PyObject* module);
void init_Phonon_PlatformPlugin(PyObject* module);
void init_Phonon_MediaSource(PyObject* module);
void init_Phonon_MediaObjectInterface(PyObject* module);
void init_Phonon_EffectParameter(PyObject* module);
void init_Phonon_EffectInterface(PyObject* module);
void init_Phonon_BackendInterface(PyObject* module);
void init_Phonon_AddonInterface(PyObject* module);
void init_Phonon_MediaNode(PyObject* module);
void init_Phonon_AbstractVideoOutput(PyObject* module);
void init_Phonon_Path(PyObject* module);
void init_Phonon_EffectDescriptionModel(PyObject* module);
void init_Phonon_AudioOutputDeviceModel(PyObject* module);
void init_Phonon_SeekSlider(PyObject* module);
void init_Phonon_EffectWidget(PyObject* module);
void init_Phonon_VolumeSlider(PyObject* module);
void init_Phonon_VideoWidget(PyObject* module);
void init_Phonon_VideoPlayer(PyObject* module);
void init_Phonon_BackendCapabilities_NotifierWrapper(PyObject* module);
void init_Phonon_MediaObject(PyObject* module);
void init_Phonon_MediaController(PyObject* module);
void init_Phonon_Effect(PyObject* module);
void init_Phonon_VolumeFaderEffect(PyObject* module);
void init_Phonon_AbstractMediaStream(PyObject* module);
void init_Phonon_AbstractAudioOutput(PyObject* module);
void init_Phonon_AudioOutput(PyObject* module);

PyTypeObject** SbkPySide_phononTypes;

PyTypeObject** SbkPySide_QtGuiTypes;

PyTypeObject** SbkPySide_QtCoreTypes;

// Module initialization ------------------------------------------------------------

#if defined _WIN32 || defined __CYGWIN__
    #define SBK_EXPORT_MODULE __declspec(dllexport)
#elif __GNUC__ >= 4
    #define SBK_EXPORT_MODULE __attribute__ ((visibility("default")))
#else
    #define SBK_EXPORT_MODULE
#endif

extern "C" SBK_EXPORT_MODULE void initphonon()
{
    if (!Shiboken::importModule("PySide.QtGui", &SbkPySide_QtGuiTypes)) {
        PyErr_SetString(PyExc_ImportError,"could not import PySide.QtGui");
        return;
    }

    if (!Shiboken::importModule("PySide.QtCore", &SbkPySide_QtCoreTypes)) {
        PyErr_SetString(PyExc_ImportError,"could not import PySide.QtCore");
        return;
    }

    Shiboken::init();
    PyObject* module = Py_InitModule("phonon", phonon_methods);

    // Create a CObject containing the API pointer array's address
    static PyTypeObject* cppApi[SBK_phonon_IDX_COUNT];
    SbkPySide_phononTypes = cppApi;
    PyObject* cppApiObject = PyCObject_FromVoidPtr(reinterpret_cast<void*>(cppApi), 0);
    PyModule_AddObject(module, "_Cpp_Api", cppApiObject);

    // Initialize classes in the type system
    init_Phonon(module);
    init_Phonon_BackendCapabilities(SbkPySide_phononTypes[SBK_PHONON_IDX]->tp_dict);
    init_Phonon_AudioChannelDescription(SbkPySide_phononTypes[SBK_PHONON_IDX]->tp_dict);
    init_Phonon_AudioOutputDevice(SbkPySide_phononTypes[SBK_PHONON_IDX]->tp_dict);
    init_Phonon_AudioCaptureDevice(SbkPySide_phononTypes[SBK_PHONON_IDX]->tp_dict);
    init_Phonon_SubtitleDescription(SbkPySide_phononTypes[SBK_PHONON_IDX]->tp_dict);
    init_Phonon_VideoCaptureDevice(SbkPySide_phononTypes[SBK_PHONON_IDX]->tp_dict);
    init_Phonon_EffectDescription(SbkPySide_phononTypes[SBK_PHONON_IDX]->tp_dict);
    init_Phonon_VolumeFaderInterface(SbkPySide_phononTypes[SBK_PHONON_IDX]->tp_dict);
    init_Phonon_VideoWidgetInterface(SbkPySide_phononTypes[SBK_PHONON_IDX]->tp_dict);
    init_Phonon_StreamInterface(SbkPySide_phononTypes[SBK_PHONON_IDX]->tp_dict);
    init_Phonon_PlatformPlugin(SbkPySide_phononTypes[SBK_PHONON_IDX]->tp_dict);
    init_Phonon_MediaSource(SbkPySide_phononTypes[SBK_PHONON_IDX]->tp_dict);
    init_Phonon_MediaObjectInterface(SbkPySide_phononTypes[SBK_PHONON_IDX]->tp_dict);
    init_Phonon_EffectParameter(SbkPySide_phononTypes[SBK_PHONON_IDX]->tp_dict);
    init_Phonon_EffectInterface(SbkPySide_phononTypes[SBK_PHONON_IDX]->tp_dict);
    init_Phonon_BackendInterface(SbkPySide_phononTypes[SBK_PHONON_IDX]->tp_dict);
    init_Phonon_AddonInterface(SbkPySide_phononTypes[SBK_PHONON_IDX]->tp_dict);
    init_Phonon_MediaNode(SbkPySide_phononTypes[SBK_PHONON_IDX]->tp_dict);
    init_Phonon_AbstractVideoOutput(SbkPySide_phononTypes[SBK_PHONON_IDX]->tp_dict);
    init_Phonon_Path(SbkPySide_phononTypes[SBK_PHONON_IDX]->tp_dict);
    init_Phonon_EffectDescriptionModel(SbkPySide_phononTypes[SBK_PHONON_IDX]->tp_dict);
    init_Phonon_AudioOutputDeviceModel(SbkPySide_phononTypes[SBK_PHONON_IDX]->tp_dict);
    init_Phonon_SeekSlider(SbkPySide_phononTypes[SBK_PHONON_IDX]->tp_dict);
    init_Phonon_EffectWidget(SbkPySide_phononTypes[SBK_PHONON_IDX]->tp_dict);
    init_Phonon_VolumeSlider(SbkPySide_phononTypes[SBK_PHONON_IDX]->tp_dict);
    init_Phonon_VideoWidget(SbkPySide_phononTypes[SBK_PHONON_IDX]->tp_dict);
    init_Phonon_VideoPlayer(SbkPySide_phononTypes[SBK_PHONON_IDX]->tp_dict);
    init_Phonon_BackendCapabilities_NotifierWrapper(SbkPySide_phononTypes[SBK_PHONON_BACKENDCAPABILITIES_IDX]->tp_dict);
    init_Phonon_MediaObject(SbkPySide_phononTypes[SBK_PHONON_IDX]->tp_dict);
    init_Phonon_MediaController(SbkPySide_phononTypes[SBK_PHONON_IDX]->tp_dict);
    init_Phonon_Effect(SbkPySide_phononTypes[SBK_PHONON_IDX]->tp_dict);
    init_Phonon_VolumeFaderEffect(SbkPySide_phononTypes[SBK_PHONON_IDX]->tp_dict);
    init_Phonon_AbstractMediaStream(SbkPySide_phononTypes[SBK_PHONON_IDX]->tp_dict);
    init_Phonon_AbstractAudioOutput(SbkPySide_phononTypes[SBK_PHONON_IDX]->tp_dict);
    init_Phonon_AudioOutput(SbkPySide_phononTypes[SBK_PHONON_IDX]->tp_dict);

    // Register primitive types on TypeResolver

    if (PyErr_Occurred()) {
        PyErr_Print();
        Py_FatalError("can't initialize module phonon");
    }
}

