/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtcore_python.h"

#include "qlocale_wrapper.h"

// Extra includes
#include <QDate>
#include <QList>
#include <qdatetime.h>
#include <qlocale.h>



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QLocale_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QLocale >()))
        return -1;

    QLocale* cptr = 0;
    int overloadId = -1;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);

    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QLocale(): too many arguments");
        return -1;
    }

    if (!PyArg_ParseTuple(args, "|OO:QLocale", &(pyargs[0]), &(pyargs[1])))
        return -1;

    // Overloaded function decisor
    // 0: QLocale()
    // 1: QLocale(QLocale::Language,QLocale::Country)
    // 2: QLocale(QLocale)
    // 3: QLocale(QString)
    if (numArgs == 0) {
        overloadId = 0; // QLocale()
    } else if (numArgs == 1 && Shiboken::Converter< QString >::isConvertible(pyargs[0])) {
        overloadId = 3; // QLocale(QString)
    } else if (Shiboken::Converter< ::QLocale::Language >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 1; // QLocale(QLocale::Language,QLocale::Country)
        } else if (Shiboken::Converter< ::QLocale::Country >::isConvertible(pyargs[1])) {
            overloadId = 1; // QLocale(QLocale::Language,QLocale::Country)
        }
    } else if (numArgs == 1 && Shiboken::Converter< ::QLocale >::isConvertible(pyargs[0])) {
        overloadId = 2; // QLocale(QLocale)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QLocale_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QLocale()
            {

                if(!PyErr_Occurred()) {
                    // QLocale()
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QLocale();
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // QLocale(QLocale::Language,QLocale::Country)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "country");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "country";
                        else if (Shiboken::Converter< ::QLocale::Country >::isConvertible(value))
                            pyargs[1] = value;
                        else
                            goto Sbk_QLocale_Init_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtCore.QLocale(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                QLocale::Language cppArg0 = Shiboken::Converter<QLocale::Language >::toCpp(pyargs[0]);
                QLocale::Country cppArg1 = pyargs[1] ? Shiboken::Converter<QLocale::Country >::toCpp(pyargs[1]) : QLocale::AnyCountry;

                if(!PyErr_Occurred()) {
                    // QLocale(QLocale::Language,QLocale::Country)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QLocale(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 2: // QLocale(QLocale)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QLocale cppArg0 = Shiboken::Converter<QLocale >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QLocale(QLocale)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QLocale(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 3: // QLocale(QString)
            {
                QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QLocale(QString)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QLocale(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QLocale >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QLocale_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QLocale_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtCore.QLocale.Language, PySide.QtCore.QLocale.Country = AnyCountry", "PySide.QtCore.QLocale", "QString", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QLocale", overloads);
        return -1;
}

static PyObject* Sbk_QLocaleFunc_amText(PyObject* self)
{
    QLocale* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QLocale* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // amText()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QLocale*>(cppSelf)->amText();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QLocaleFunc_c(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // c()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QLocale cppResult = QLocale::c();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QLocale >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QLocaleFunc_countriesForLanguage(PyObject* self, PyObject* arg)
{
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: countriesForLanguage(QLocale::Language)
    if (Shiboken::Converter< ::QLocale::Language >::isConvertible(arg)) {
        overloadId = 0; // countriesForLanguage(QLocale::Language)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QLocaleFunc_countriesForLanguage_TypeError;

    // Call function/method
    {
        {
            QLocale::Language cppArg0 = Shiboken::Converter<QLocale::Language >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // countriesForLanguage(QLocale::Language)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QList<QLocale::Country > cppResult = QLocale::countriesForLanguage(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QList<QLocale::Country > >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QLocaleFunc_countriesForLanguage_TypeError:
        const char* overloads[] = {"PySide.QtCore.QLocale.Language", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QLocale.countriesForLanguage", overloads);
        return 0;
}

static PyObject* Sbk_QLocaleFunc_country(PyObject* self)
{
    QLocale* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QLocale* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // country()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QLocale::Country cppResult = const_cast<const QLocale*>(cppSelf)->country();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QLocale::Country >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QLocaleFunc_countryToString(PyObject* self, PyObject* arg)
{
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: countryToString(QLocale::Country)
    if (Shiboken::Converter< ::QLocale::Country >::isConvertible(arg)) {
        overloadId = 0; // countryToString(QLocale::Country)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QLocaleFunc_countryToString_TypeError;

    // Call function/method
    {
        {
            QLocale::Country cppArg0 = Shiboken::Converter<QLocale::Country >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // countryToString(QLocale::Country)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = QLocale::countryToString(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QLocaleFunc_countryToString_TypeError:
        const char* overloads[] = {"PySide.QtCore.QLocale.Country", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QLocale.countryToString", overloads);
        return 0;
}

static PyObject* Sbk_QLocaleFunc_dateFormat(PyObject* self, PyObject* args, PyObject* kwds)
{
    QLocale* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QLocale* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QLocale.dateFormat(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:dateFormat", &(pyargs[0])))
        return 0;


    // Overloaded function decisor
    // 0: dateFormat(QLocale::FormatType)const
    if (numArgs == 0) {
        overloadId = 0; // dateFormat(QLocale::FormatType)const
    } else if (Shiboken::Converter< ::QLocale::FormatType >::isConvertible(pyargs[0])) {
        overloadId = 0; // dateFormat(QLocale::FormatType)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QLocaleFunc_dateFormat_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "format");
                if (value) {
                    if (pyargs[0])
                        errorArgName = "format";
                    else if (Shiboken::Converter< ::QLocale::FormatType >::isConvertible(value))
                        pyargs[0] = value;
                    else
                        goto Sbk_QLocaleFunc_dateFormat_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.QLocale.dateFormat(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QLocale::FormatType cppArg0 = pyargs[0] ? Shiboken::Converter<QLocale::FormatType >::toCpp(pyargs[0]) : QLocale::LongFormat;

            if(!PyErr_Occurred()) {
                // dateFormat(QLocale::FormatType)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QLocale*>(cppSelf)->dateFormat(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QLocaleFunc_dateFormat_TypeError:
        const char* overloads[] = {"PySide.QtCore.QLocale.FormatType = LongFormat", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QLocale.dateFormat", overloads);
        return 0;
}

static PyObject* Sbk_QLocaleFunc_dateTimeFormat(PyObject* self, PyObject* args, PyObject* kwds)
{
    QLocale* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QLocale* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QLocale.dateTimeFormat(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:dateTimeFormat", &(pyargs[0])))
        return 0;


    // Overloaded function decisor
    // 0: dateTimeFormat(QLocale::FormatType)const
    if (numArgs == 0) {
        overloadId = 0; // dateTimeFormat(QLocale::FormatType)const
    } else if (Shiboken::Converter< ::QLocale::FormatType >::isConvertible(pyargs[0])) {
        overloadId = 0; // dateTimeFormat(QLocale::FormatType)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QLocaleFunc_dateTimeFormat_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "format");
                if (value) {
                    if (pyargs[0])
                        errorArgName = "format";
                    else if (Shiboken::Converter< ::QLocale::FormatType >::isConvertible(value))
                        pyargs[0] = value;
                    else
                        goto Sbk_QLocaleFunc_dateTimeFormat_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.QLocale.dateTimeFormat(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QLocale::FormatType cppArg0 = pyargs[0] ? Shiboken::Converter<QLocale::FormatType >::toCpp(pyargs[0]) : QLocale::LongFormat;

            if(!PyErr_Occurred()) {
                // dateTimeFormat(QLocale::FormatType)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QLocale*>(cppSelf)->dateTimeFormat(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QLocaleFunc_dateTimeFormat_TypeError:
        const char* overloads[] = {"PySide.QtCore.QLocale.FormatType = LongFormat", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QLocale.dateTimeFormat", overloads);
        return 0;
}

static PyObject* Sbk_QLocaleFunc_dayName(PyObject* self, PyObject* args, PyObject* kwds)
{
    QLocale* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QLocale* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QLocale.dayName(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QLocale.dayName(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:dayName", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: dayName(int,QLocale::FormatType)const
    if (SbkNumber_Check(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // dayName(int,QLocale::FormatType)const
        } else if (Shiboken::Converter< ::QLocale::FormatType >::isConvertible(pyargs[1])) {
            overloadId = 0; // dayName(int,QLocale::FormatType)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QLocaleFunc_dayName_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "format");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "format";
                    else if (Shiboken::Converter< ::QLocale::FormatType >::isConvertible(value))
                        pyargs[1] = value;
                    else
                        goto Sbk_QLocaleFunc_dayName_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.QLocale.dayName(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            QLocale::FormatType cppArg1 = pyargs[1] ? Shiboken::Converter<QLocale::FormatType >::toCpp(pyargs[1]) : QLocale::LongFormat;

            if(!PyErr_Occurred()) {
                // dayName(int,QLocale::FormatType)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QLocale*>(cppSelf)->dayName(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QLocaleFunc_dayName_TypeError:
        const char* overloads[] = {"int, PySide.QtCore.QLocale.FormatType = LongFormat", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QLocale.dayName", overloads);
        return 0;
}

static PyObject* Sbk_QLocaleFunc_decimalPoint(PyObject* self)
{
    QLocale* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QLocale* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // decimalPoint()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QChar cppResult = const_cast<const QLocale*>(cppSelf)->decimalPoint();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QChar >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QLocaleFunc_exponential(PyObject* self)
{
    QLocale* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QLocale* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // exponential()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QChar cppResult = const_cast<const QLocale*>(cppSelf)->exponential();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QChar >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QLocaleFunc_groupSeparator(PyObject* self)
{
    QLocale* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QLocale* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // groupSeparator()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QChar cppResult = const_cast<const QLocale*>(cppSelf)->groupSeparator();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QChar >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QLocaleFunc_language(PyObject* self)
{
    QLocale* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QLocale* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // language()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QLocale::Language cppResult = const_cast<const QLocale*>(cppSelf)->language();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QLocale::Language >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QLocaleFunc_languageToString(PyObject* self, PyObject* arg)
{
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: languageToString(QLocale::Language)
    if (Shiboken::Converter< ::QLocale::Language >::isConvertible(arg)) {
        overloadId = 0; // languageToString(QLocale::Language)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QLocaleFunc_languageToString_TypeError;

    // Call function/method
    {
        {
            QLocale::Language cppArg0 = Shiboken::Converter<QLocale::Language >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // languageToString(QLocale::Language)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = QLocale::languageToString(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QLocaleFunc_languageToString_TypeError:
        const char* overloads[] = {"PySide.QtCore.QLocale.Language", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QLocale.languageToString", overloads);
        return 0;
}

static PyObject* Sbk_QLocaleFunc_measurementSystem(PyObject* self)
{
    QLocale* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QLocale* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // measurementSystem()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QLocale::MeasurementSystem cppResult = const_cast<const QLocale*>(cppSelf)->measurementSystem();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QLocale::MeasurementSystem >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QLocaleFunc_monthName(PyObject* self, PyObject* args, PyObject* kwds)
{
    QLocale* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QLocale* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QLocale.monthName(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QLocale.monthName(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:monthName", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: monthName(int,QLocale::FormatType)const
    if (SbkNumber_Check(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // monthName(int,QLocale::FormatType)const
        } else if (Shiboken::Converter< ::QLocale::FormatType >::isConvertible(pyargs[1])) {
            overloadId = 0; // monthName(int,QLocale::FormatType)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QLocaleFunc_monthName_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "format");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "format";
                    else if (Shiboken::Converter< ::QLocale::FormatType >::isConvertible(value))
                        pyargs[1] = value;
                    else
                        goto Sbk_QLocaleFunc_monthName_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.QLocale.monthName(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            QLocale::FormatType cppArg1 = pyargs[1] ? Shiboken::Converter<QLocale::FormatType >::toCpp(pyargs[1]) : QLocale::LongFormat;

            if(!PyErr_Occurred()) {
                // monthName(int,QLocale::FormatType)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QLocale*>(cppSelf)->monthName(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QLocaleFunc_monthName_TypeError:
        const char* overloads[] = {"int, PySide.QtCore.QLocale.FormatType = LongFormat", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QLocale.monthName", overloads);
        return 0;
}

static PyObject* Sbk_QLocaleFunc_name(PyObject* self)
{
    QLocale* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QLocale* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // name()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QLocale*>(cppSelf)->name();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QLocaleFunc_negativeSign(PyObject* self)
{
    QLocale* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QLocale* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // negativeSign()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QChar cppResult = const_cast<const QLocale*>(cppSelf)->negativeSign();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QChar >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QLocaleFunc_numberOptions(PyObject* self)
{
    QLocale* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QLocale* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // numberOptions()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QFlags<QLocale::NumberOption> cppResult = const_cast<const QLocale*>(cppSelf)->numberOptions();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QFlags<QLocale::NumberOption> >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QLocaleFunc_percent(PyObject* self)
{
    QLocale* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QLocale* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // percent()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QChar cppResult = const_cast<const QLocale*>(cppSelf)->percent();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QChar >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QLocaleFunc_pmText(PyObject* self)
{
    QLocale* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QLocale* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // pmText()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QLocale*>(cppSelf)->pmText();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QLocaleFunc_positiveSign(PyObject* self)
{
    QLocale* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QLocale* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // positiveSign()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QChar cppResult = const_cast<const QLocale*>(cppSelf)->positiveSign();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QChar >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QLocaleFunc_setDefault(PyObject* self, PyObject* arg)
{
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setDefault(QLocale)
    if (Shiboken::Converter< ::QLocale >::isConvertible(arg)) {
        overloadId = 0; // setDefault(QLocale)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QLocaleFunc_setDefault_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QLocale cppArg0 = Shiboken::Converter<QLocale >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setDefault(QLocale)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QLocale::setDefault(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QLocaleFunc_setDefault_TypeError:
        const char* overloads[] = {"PySide.QtCore.QLocale", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QLocale.setDefault", overloads);
        return 0;
}

static PyObject* Sbk_QLocaleFunc_setNumberOptions(PyObject* self, PyObject* arg)
{
    QLocale* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QLocale* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setNumberOptions(QFlags<QLocale::NumberOption>)
    if (Shiboken::Converter< ::QFlags<QLocale::NumberOption> >::isConvertible(arg)) {
        overloadId = 0; // setNumberOptions(QFlags<QLocale::NumberOption>)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QLocaleFunc_setNumberOptions_TypeError;

    // Call function/method
    {
        {
            QFlags<QLocale::NumberOption> cppArg0 = Shiboken::Converter<QFlags<QLocale::NumberOption> >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setNumberOptions(QFlags<QLocale::NumberOption>)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setNumberOptions(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QLocaleFunc_setNumberOptions_TypeError:
        const char* overloads[] = {"PySide.QtCore.QLocale.NumberOptions", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QLocale.setNumberOptions", overloads);
        return 0;
}

static PyObject* Sbk_QLocaleFunc_standaloneDayName(PyObject* self, PyObject* args, PyObject* kwds)
{
    QLocale* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QLocale* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QLocale.standaloneDayName(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QLocale.standaloneDayName(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:standaloneDayName", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: standaloneDayName(int,QLocale::FormatType)const
    if (SbkNumber_Check(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // standaloneDayName(int,QLocale::FormatType)const
        } else if (Shiboken::Converter< ::QLocale::FormatType >::isConvertible(pyargs[1])) {
            overloadId = 0; // standaloneDayName(int,QLocale::FormatType)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QLocaleFunc_standaloneDayName_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "format");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "format";
                    else if (Shiboken::Converter< ::QLocale::FormatType >::isConvertible(value))
                        pyargs[1] = value;
                    else
                        goto Sbk_QLocaleFunc_standaloneDayName_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.QLocale.standaloneDayName(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            QLocale::FormatType cppArg1 = pyargs[1] ? Shiboken::Converter<QLocale::FormatType >::toCpp(pyargs[1]) : QLocale::LongFormat;

            if(!PyErr_Occurred()) {
                // standaloneDayName(int,QLocale::FormatType)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QLocale*>(cppSelf)->standaloneDayName(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QLocaleFunc_standaloneDayName_TypeError:
        const char* overloads[] = {"int, PySide.QtCore.QLocale.FormatType = LongFormat", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QLocale.standaloneDayName", overloads);
        return 0;
}

static PyObject* Sbk_QLocaleFunc_standaloneMonthName(PyObject* self, PyObject* args, PyObject* kwds)
{
    QLocale* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QLocale* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QLocale.standaloneMonthName(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QLocale.standaloneMonthName(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:standaloneMonthName", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: standaloneMonthName(int,QLocale::FormatType)const
    if (SbkNumber_Check(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // standaloneMonthName(int,QLocale::FormatType)const
        } else if (Shiboken::Converter< ::QLocale::FormatType >::isConvertible(pyargs[1])) {
            overloadId = 0; // standaloneMonthName(int,QLocale::FormatType)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QLocaleFunc_standaloneMonthName_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "format");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "format";
                    else if (Shiboken::Converter< ::QLocale::FormatType >::isConvertible(value))
                        pyargs[1] = value;
                    else
                        goto Sbk_QLocaleFunc_standaloneMonthName_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.QLocale.standaloneMonthName(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            QLocale::FormatType cppArg1 = pyargs[1] ? Shiboken::Converter<QLocale::FormatType >::toCpp(pyargs[1]) : QLocale::LongFormat;

            if(!PyErr_Occurred()) {
                // standaloneMonthName(int,QLocale::FormatType)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QLocale*>(cppSelf)->standaloneMonthName(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QLocaleFunc_standaloneMonthName_TypeError:
        const char* overloads[] = {"int, PySide.QtCore.QLocale.FormatType = LongFormat", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QLocale.standaloneMonthName", overloads);
        return 0;
}

static PyObject* Sbk_QLocaleFunc_system(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // system()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QLocale cppResult = QLocale::system();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QLocale >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QLocaleFunc_textDirection(PyObject* self)
{
    QLocale* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QLocale* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // textDirection()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                Qt::LayoutDirection cppResult = const_cast<const QLocale*>(cppSelf)->textDirection();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::Qt::LayoutDirection >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QLocaleFunc_timeFormat(PyObject* self, PyObject* args, PyObject* kwds)
{
    QLocale* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QLocale* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QLocale.timeFormat(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:timeFormat", &(pyargs[0])))
        return 0;


    // Overloaded function decisor
    // 0: timeFormat(QLocale::FormatType)const
    if (numArgs == 0) {
        overloadId = 0; // timeFormat(QLocale::FormatType)const
    } else if (Shiboken::Converter< ::QLocale::FormatType >::isConvertible(pyargs[0])) {
        overloadId = 0; // timeFormat(QLocale::FormatType)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QLocaleFunc_timeFormat_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "format");
                if (value) {
                    if (pyargs[0])
                        errorArgName = "format";
                    else if (Shiboken::Converter< ::QLocale::FormatType >::isConvertible(value))
                        pyargs[0] = value;
                    else
                        goto Sbk_QLocaleFunc_timeFormat_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.QLocale.timeFormat(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QLocale::FormatType cppArg0 = pyargs[0] ? Shiboken::Converter<QLocale::FormatType >::toCpp(pyargs[0]) : QLocale::LongFormat;

            if(!PyErr_Occurred()) {
                // timeFormat(QLocale::FormatType)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QLocale*>(cppSelf)->timeFormat(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QLocaleFunc_timeFormat_TypeError:
        const char* overloads[] = {"PySide.QtCore.QLocale.FormatType = LongFormat", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QLocale.timeFormat", overloads);
        return 0;
}

static PyObject* Sbk_QLocaleFunc_toDate(PyObject* self, PyObject* args, PyObject* kwds)
{
    QLocale* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QLocale* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QLocale.toDate(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QLocale.toDate(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:toDate", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: toDate(QString,QLocale::FormatType)const
    // 1: toDate(QString,QString)const
    if (Shiboken::Converter< QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // toDate(QString,QLocale::FormatType)const
        } else if (numArgs == 2 && Shiboken::Converter< QString >::isConvertible(pyargs[1])) {
            overloadId = 1; // toDate(QString,QString)const
        } else if (Shiboken::Converter< ::QLocale::FormatType >::isConvertible(pyargs[1])) {
            overloadId = 0; // toDate(QString,QLocale::FormatType)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QLocaleFunc_toDate_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // toDate(QString,QLocale::FormatType)const
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "format");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "format";
                        else if (Shiboken::Converter< ::QLocale::FormatType >::isConvertible(value))
                            pyargs[1] = value;
                        else
                            goto Sbk_QLocaleFunc_toDate_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtCore.QLocale.toDate(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                QLocale::FormatType cppArg1 = pyargs[1] ? Shiboken::Converter<QLocale::FormatType >::toCpp(pyargs[1]) : QLocale::LongFormat;

                if(!PyErr_Occurred()) {
                    // toDate(QString,QLocale::FormatType)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QDate cppResult = const_cast<const QLocale*>(cppSelf)->toDate(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QDate >::toPython(cppResult);
                }
                break;
            }
            case 1: // toDate(QString,QString)const
            {
                QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                QString cppArg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // toDate(QString,QString)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QDate cppResult = const_cast<const QLocale*>(cppSelf)->toDate(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QDate >::toPython(cppResult);
                }
                break;
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QLocaleFunc_toDate_TypeError:
        const char* overloads[] = {"QString, PySide.QtCore.QLocale.FormatType = LongFormat", "QString, QString", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QLocale.toDate", overloads);
        return 0;
}

static PyObject* Sbk_QLocaleFunc_toDateTime(PyObject* self, PyObject* args, PyObject* kwds)
{
    QLocale* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QLocale* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QLocale.toDateTime(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QLocale.toDateTime(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:toDateTime", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: toDateTime(QString,QLocale::FormatType)const
    // 1: toDateTime(QString,QString)const
    if (Shiboken::Converter< QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // toDateTime(QString,QLocale::FormatType)const
        } else if (numArgs == 2 && Shiboken::Converter< QString >::isConvertible(pyargs[1])) {
            overloadId = 1; // toDateTime(QString,QString)const
        } else if (Shiboken::Converter< ::QLocale::FormatType >::isConvertible(pyargs[1])) {
            overloadId = 0; // toDateTime(QString,QLocale::FormatType)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QLocaleFunc_toDateTime_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // toDateTime(QString,QLocale::FormatType)const
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "format");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "format";
                        else if (Shiboken::Converter< ::QLocale::FormatType >::isConvertible(value))
                            pyargs[1] = value;
                        else
                            goto Sbk_QLocaleFunc_toDateTime_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtCore.QLocale.toDateTime(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                QLocale::FormatType cppArg1 = pyargs[1] ? Shiboken::Converter<QLocale::FormatType >::toCpp(pyargs[1]) : QLocale::LongFormat;

                if(!PyErr_Occurred()) {
                    // toDateTime(QString,QLocale::FormatType)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QDateTime cppResult = const_cast<const QLocale*>(cppSelf)->toDateTime(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QDateTime >::toPython(cppResult);
                }
                break;
            }
            case 1: // toDateTime(QString,QString)const
            {
                QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                QString cppArg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // toDateTime(QString,QString)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QDateTime cppResult = const_cast<const QLocale*>(cppSelf)->toDateTime(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QDateTime >::toPython(cppResult);
                }
                break;
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QLocaleFunc_toDateTime_TypeError:
        const char* overloads[] = {"QString, PySide.QtCore.QLocale.FormatType = LongFormat", "QString, QString", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QLocale.toDateTime", overloads);
        return 0;
}

static PyObject* Sbk_QLocaleFunc_toDouble(PyObject* self, PyObject* arg)
{
    QLocale* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QLocale* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: toDouble(QString,bool*)const
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // toDouble(QString,bool*)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QLocaleFunc_toDouble_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // toDouble(QString,bool*)const
                // Begin code injection

                // TEMPLATE - fix_args,bool* - START
                bool ok_;
                double retval_ = cppSelf->toDouble(cppArg0, &ok_);
                pyResult = Shiboken::makeTuple(retval_, ok_);
                // TEMPLATE - fix_args,bool* - END

                // End of code injection


            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QLocaleFunc_toDouble_TypeError:
        const char* overloads[] = {"QString, bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QLocale.toDouble", overloads);
        return 0;
}

static PyObject* Sbk_QLocaleFunc_toFloat(PyObject* self, PyObject* arg)
{
    QLocale* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QLocale* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: toFloat(QString,bool*)const
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // toFloat(QString,bool*)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QLocaleFunc_toFloat_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // toFloat(QString,bool*)const
                // Begin code injection

                // TEMPLATE - fix_args,bool* - START
                bool ok_;
                float retval_ = cppSelf->toFloat(cppArg0, &ok_);
                pyResult = Shiboken::makeTuple(retval_, ok_);
                // TEMPLATE - fix_args,bool* - END

                // End of code injection


            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QLocaleFunc_toFloat_TypeError:
        const char* overloads[] = {"QString, bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QLocale.toFloat", overloads);
        return 0;
}

static PyObject* Sbk_QLocaleFunc_toInt(PyObject* self, PyObject* args, PyObject* kwds)
{
    QLocale* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QLocale* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QLocale.toInt(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QLocale.toInt(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:toInt", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: toInt(QString,bool*,int)const
    if (Shiboken::Converter< QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // toInt(QString,bool*,int)const
        } else if (SbkNumber_Check(pyargs[1])) {
            overloadId = 0; // toInt(QString,bool*,int)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QLocaleFunc_toInt_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "base");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "base";
                    else if (SbkNumber_Check(value))
                        pyargs[1] = value;
                    else
                        goto Sbk_QLocaleFunc_toInt_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.QLocale.toInt(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            int cppArg1 = pyargs[1] ? Shiboken::Converter<int >::toCpp(pyargs[1]) : 0;

            if(!PyErr_Occurred()) {
                // toInt(QString,bool*,int)const
                // Begin code injection

                // TEMPLATE - fix_arg,bool*,arg - START
                bool ok_;
                int retval_ = cppSelf->toInt(cppArg0, &ok_, cppArg1);
                pyResult = Shiboken::makeTuple(retval_, ok_);
                // TEMPLATE - fix_arg,bool*,arg - END

                // End of code injection


            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QLocaleFunc_toInt_TypeError:
        const char* overloads[] = {"QString, bool = 0, int = 0", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QLocale.toInt", overloads);
        return 0;
}

static PyObject* Sbk_QLocaleFunc_toLongLong(PyObject* self, PyObject* args, PyObject* kwds)
{
    QLocale* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QLocale* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QLocale.toLongLong(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QLocale.toLongLong(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:toLongLong", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: toLongLong(QString,bool*,int)const
    if (Shiboken::Converter< QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // toLongLong(QString,bool*,int)const
        } else if (SbkNumber_Check(pyargs[1])) {
            overloadId = 0; // toLongLong(QString,bool*,int)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QLocaleFunc_toLongLong_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "base");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "base";
                    else if (SbkNumber_Check(value))
                        pyargs[1] = value;
                    else
                        goto Sbk_QLocaleFunc_toLongLong_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.QLocale.toLongLong(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            int cppArg1 = pyargs[1] ? Shiboken::Converter<int >::toCpp(pyargs[1]) : 0;

            if(!PyErr_Occurred()) {
                // toLongLong(QString,bool*,int)const
                // Begin code injection

                // TEMPLATE - fix_arg,bool*,arg - START
                bool ok_;
                qlonglong retval_ = cppSelf->toLongLong(cppArg0, &ok_, cppArg1);
                pyResult = Shiboken::makeTuple(retval_, ok_);
                // TEMPLATE - fix_arg,bool*,arg - END

                // End of code injection


            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QLocaleFunc_toLongLong_TypeError:
        const char* overloads[] = {"QString, bool = 0, int = 0", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QLocale.toLongLong", overloads);
        return 0;
}

static PyObject* Sbk_QLocaleFunc_toShort(PyObject* self, PyObject* args, PyObject* kwds)
{
    QLocale* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QLocale* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QLocale.toShort(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QLocale.toShort(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:toShort", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: toShort(QString,bool*,int)const
    if (Shiboken::Converter< QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // toShort(QString,bool*,int)const
        } else if (SbkNumber_Check(pyargs[1])) {
            overloadId = 0; // toShort(QString,bool*,int)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QLocaleFunc_toShort_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "base");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "base";
                    else if (SbkNumber_Check(value))
                        pyargs[1] = value;
                    else
                        goto Sbk_QLocaleFunc_toShort_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.QLocale.toShort(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            int cppArg1 = pyargs[1] ? Shiboken::Converter<int >::toCpp(pyargs[1]) : 0;

            if(!PyErr_Occurred()) {
                // toShort(QString,bool*,int)const
                // Begin code injection

                // TEMPLATE - fix_arg,bool*,arg - START
                bool ok_;
                short retval_ = cppSelf->toShort(cppArg0, &ok_, cppArg1);
                pyResult = Shiboken::makeTuple(retval_, ok_);
                // TEMPLATE - fix_arg,bool*,arg - END

                // End of code injection


            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QLocaleFunc_toShort_TypeError:
        const char* overloads[] = {"QString, bool = 0, int = 0", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QLocale.toShort", overloads);
        return 0;
}

static PyObject* Sbk_QLocaleFunc_toString(PyObject* self, PyObject* args, PyObject* kwds)
{
    QLocale* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QLocale* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QLocale.toString(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QLocale.toString(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOO:toString", &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: toString(QDate,QLocale::FormatType)const
    // 1: toString(QDate,QString)const
    // 2: toString(QDateTime,QLocale::FormatType)const
    // 3: toString(QDateTime,QString)const
    // 4: toString(QTime,QLocale::FormatType)const
    // 5: toString(QTime,QString)const
    // 6: toString(double,char,int)const
    // 7: toString(float,char,int)const
    // 8: toString(int)const
    // 9: toString(qlonglong)const
    // 10: toString(short)const
    if (numArgs == 1 && PyLong_Check(pyargs[0])) {
        overloadId = 9; // toString(qlonglong)const
    } else if (PyFloat_Check(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 7; // toString(float,char,int)const
        } else if (Shiboken::Converter< char >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 7; // toString(float,char,int)const
            } else if (SbkNumber_Check(pyargs[2])) {
                overloadId = 7; // toString(float,char,int)const
            }
        }
    } else if (PyFloat_Check(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 6; // toString(double,char,int)const
        } else if (Shiboken::Converter< char >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 6; // toString(double,char,int)const
            } else if (SbkNumber_Check(pyargs[2])) {
                overloadId = 6; // toString(double,char,int)const
            }
        }
    } else if (numArgs == 1 && SbkNumber_Check(pyargs[0])) {
        overloadId = 10; // toString(short)const
    } else if (numArgs == 1 && SbkNumber_Check(pyargs[0])) {
        overloadId = 8; // toString(int)const
    } else if (Shiboken::Converter< ::QTime >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 4; // toString(QTime,QLocale::FormatType)const
        } else if (numArgs == 2 && Shiboken::Converter< QString >::isConvertible(pyargs[1])) {
            overloadId = 5; // toString(QTime,QString)const
        } else if (Shiboken::Converter< ::QLocale::FormatType >::isConvertible(pyargs[1])) {
            overloadId = 4; // toString(QTime,QLocale::FormatType)const
        }
    } else if (Shiboken::Converter< ::QDateTime >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 2; // toString(QDateTime,QLocale::FormatType)const
        } else if (numArgs == 2 && Shiboken::Converter< QString >::isConvertible(pyargs[1])) {
            overloadId = 3; // toString(QDateTime,QString)const
        } else if (Shiboken::Converter< ::QLocale::FormatType >::isConvertible(pyargs[1])) {
            overloadId = 2; // toString(QDateTime,QLocale::FormatType)const
        }
    } else if (Shiboken::Converter< ::QDate >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // toString(QDate,QLocale::FormatType)const
        } else if (numArgs == 2 && Shiboken::Converter< QString >::isConvertible(pyargs[1])) {
            overloadId = 1; // toString(QDate,QString)const
        } else if (Shiboken::Converter< ::QLocale::FormatType >::isConvertible(pyargs[1])) {
            overloadId = 0; // toString(QDate,QLocale::FormatType)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QLocaleFunc_toString_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // toString(QDate,QLocale::FormatType)const
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "format");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "format";
                        else if (Shiboken::Converter< ::QLocale::FormatType >::isConvertible(value))
                            pyargs[1] = value;
                        else
                            goto Sbk_QLocaleFunc_toString_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtCore.QLocale.toString(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QDate cppArg0 = Shiboken::Converter<QDate >::toCpp(pyargs[0]);
                QLocale::FormatType cppArg1 = pyargs[1] ? Shiboken::Converter<QLocale::FormatType >::toCpp(pyargs[1]) : QLocale::LongFormat;

                if(!PyErr_Occurred()) {
                    // toString(QDate,QLocale::FormatType)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QString cppResult = const_cast<const QLocale*>(cppSelf)->toString(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< QString >::toPython(cppResult);
                }
                break;
            }
            case 1: // toString(QDate,QString)const
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QDate cppArg0 = Shiboken::Converter<QDate >::toCpp(pyargs[0]);
                QString cppArg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // toString(QDate,QString)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QString cppResult = const_cast<const QLocale*>(cppSelf)->toString(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< QString >::toPython(cppResult);
                }
                break;
            }
            case 2: // toString(QDateTime,QLocale::FormatType)const
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "format");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "format";
                        else if (Shiboken::Converter< ::QLocale::FormatType >::isConvertible(value))
                            pyargs[1] = value;
                        else
                            goto Sbk_QLocaleFunc_toString_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtCore.QLocale.toString(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QDateTime cppArg0 = Shiboken::Converter<QDateTime >::toCpp(pyargs[0]);
                QLocale::FormatType cppArg1 = pyargs[1] ? Shiboken::Converter<QLocale::FormatType >::toCpp(pyargs[1]) : QLocale::LongFormat;

                if(!PyErr_Occurred()) {
                    // toString(QDateTime,QLocale::FormatType)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QString cppResult = const_cast<const QLocale*>(cppSelf)->toString(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< QString >::toPython(cppResult);
                }
                break;
            }
            case 3: // toString(QDateTime,QString)const
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QDateTime cppArg0 = Shiboken::Converter<QDateTime >::toCpp(pyargs[0]);
                QString cppArg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // toString(QDateTime,QString)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QString cppResult = const_cast<const QLocale*>(cppSelf)->toString(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< QString >::toPython(cppResult);
                }
                break;
            }
            case 4: // toString(QTime,QLocale::FormatType)const
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "format");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "format";
                        else if (Shiboken::Converter< ::QLocale::FormatType >::isConvertible(value))
                            pyargs[1] = value;
                        else
                            goto Sbk_QLocaleFunc_toString_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtCore.QLocale.toString(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QTime cppArg0 = Shiboken::Converter<QTime >::toCpp(pyargs[0]);
                QLocale::FormatType cppArg1 = pyargs[1] ? Shiboken::Converter<QLocale::FormatType >::toCpp(pyargs[1]) : QLocale::LongFormat;

                if(!PyErr_Occurred()) {
                    // toString(QTime,QLocale::FormatType)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QString cppResult = const_cast<const QLocale*>(cppSelf)->toString(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< QString >::toPython(cppResult);
                }
                break;
            }
            case 5: // toString(QTime,QString)const
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QTime cppArg0 = Shiboken::Converter<QTime >::toCpp(pyargs[0]);
                QString cppArg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // toString(QTime,QString)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QString cppResult = const_cast<const QLocale*>(cppSelf)->toString(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< QString >::toPython(cppResult);
                }
                break;
            }
            case 6: // toString(double,char,int)const
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "f");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "f";
                        else if (Shiboken::Converter< char >::isConvertible(value))
                            pyargs[1] = value;
                        else
                            goto Sbk_QLocaleFunc_toString_TypeError;
                    }
                    value = PyDict_GetItemString(kwds, "prec");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "prec";
                        else if (SbkNumber_Check(value))
                            pyargs[2] = value;
                        else
                            goto Sbk_QLocaleFunc_toString_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtCore.QLocale.toString(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                double cppArg0 = Shiboken::Converter<double >::toCpp(pyargs[0]);
                char cppArg1 = pyargs[1] ? Shiboken::Converter<char >::toCpp(pyargs[1]) : 'g';
                int cppArg2 = pyargs[2] ? Shiboken::Converter<int >::toCpp(pyargs[2]) : 6;

                if(!PyErr_Occurred()) {
                    // toString(double,char,int)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QString cppResult = const_cast<const QLocale*>(cppSelf)->toString(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< QString >::toPython(cppResult);
                }
                break;
            }
            case 7: // toString(float,char,int)const
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "f");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "f";
                        else if (Shiboken::Converter< char >::isConvertible(value))
                            pyargs[1] = value;
                        else
                            goto Sbk_QLocaleFunc_toString_TypeError;
                    }
                    value = PyDict_GetItemString(kwds, "prec");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "prec";
                        else if (SbkNumber_Check(value))
                            pyargs[2] = value;
                        else
                            goto Sbk_QLocaleFunc_toString_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtCore.QLocale.toString(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                float cppArg0 = Shiboken::Converter<float >::toCpp(pyargs[0]);
                char cppArg1 = pyargs[1] ? Shiboken::Converter<char >::toCpp(pyargs[1]) : 'g';
                int cppArg2 = pyargs[2] ? Shiboken::Converter<int >::toCpp(pyargs[2]) : 6;

                if(!PyErr_Occurred()) {
                    // toString(float,char,int)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QString cppResult = const_cast<const QLocale*>(cppSelf)->toString(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< QString >::toPython(cppResult);
                }
                break;
            }
            case 8: // toString(int)const
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // toString(int)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QString cppResult = const_cast<const QLocale*>(cppSelf)->toString(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< QString >::toPython(cppResult);
                }
                break;
            }
            case 9: // toString(qlonglong)const
            {
                qlonglong cppArg0 = Shiboken::Converter<qlonglong >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // toString(qlonglong)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QString cppResult = const_cast<const QLocale*>(cppSelf)->toString(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< QString >::toPython(cppResult);
                }
                break;
            }
            case 10: // toString(short)const
            {
                short cppArg0 = Shiboken::Converter<short >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // toString(short)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QString cppResult = const_cast<const QLocale*>(cppSelf)->toString(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< QString >::toPython(cppResult);
                }
                break;
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QLocaleFunc_toString_TypeError:
        const char* overloads[] = {"PySide.QtCore.QDate, PySide.QtCore.QLocale.FormatType = LongFormat", "PySide.QtCore.QDate, QString", "PySide.QtCore.QDateTime, PySide.QtCore.QLocale.FormatType = LongFormat", "PySide.QtCore.QDateTime, QString", "PySide.QtCore.QTime, PySide.QtCore.QLocale.FormatType = LongFormat", "PySide.QtCore.QTime, QString", "float, char = 'g', int = 6", "float, char = 'g', int = 6", "int", "long long", "short", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QLocale.toString", overloads);
        return 0;
}

static PyObject* Sbk_QLocaleFunc_toTime(PyObject* self, PyObject* args, PyObject* kwds)
{
    QLocale* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QLocale* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QLocale.toTime(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QLocale.toTime(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:toTime", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: toTime(QString,QLocale::FormatType)const
    // 1: toTime(QString,QString)const
    if (Shiboken::Converter< QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // toTime(QString,QLocale::FormatType)const
        } else if (numArgs == 2 && Shiboken::Converter< QString >::isConvertible(pyargs[1])) {
            overloadId = 1; // toTime(QString,QString)const
        } else if (Shiboken::Converter< ::QLocale::FormatType >::isConvertible(pyargs[1])) {
            overloadId = 0; // toTime(QString,QLocale::FormatType)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QLocaleFunc_toTime_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // toTime(QString,QLocale::FormatType)const
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "format");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "format";
                        else if (Shiboken::Converter< ::QLocale::FormatType >::isConvertible(value))
                            pyargs[1] = value;
                        else
                            goto Sbk_QLocaleFunc_toTime_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtCore.QLocale.toTime(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                QLocale::FormatType cppArg1 = pyargs[1] ? Shiboken::Converter<QLocale::FormatType >::toCpp(pyargs[1]) : QLocale::LongFormat;

                if(!PyErr_Occurred()) {
                    // toTime(QString,QLocale::FormatType)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QTime cppResult = const_cast<const QLocale*>(cppSelf)->toTime(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QTime >::toPython(cppResult);
                }
                break;
            }
            case 1: // toTime(QString,QString)const
            {
                QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                QString cppArg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // toTime(QString,QString)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QTime cppResult = const_cast<const QLocale*>(cppSelf)->toTime(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QTime >::toPython(cppResult);
                }
                break;
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QLocaleFunc_toTime_TypeError:
        const char* overloads[] = {"QString, PySide.QtCore.QLocale.FormatType = LongFormat", "QString, QString", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QLocale.toTime", overloads);
        return 0;
}

static PyObject* Sbk_QLocaleFunc_toUInt(PyObject* self, PyObject* args, PyObject* kwds)
{
    QLocale* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QLocale* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QLocale.toUInt(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QLocale.toUInt(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:toUInt", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: toUInt(QString,bool*,int)const
    if (Shiboken::Converter< QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // toUInt(QString,bool*,int)const
        } else if (SbkNumber_Check(pyargs[1])) {
            overloadId = 0; // toUInt(QString,bool*,int)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QLocaleFunc_toUInt_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "base");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "base";
                    else if (SbkNumber_Check(value))
                        pyargs[1] = value;
                    else
                        goto Sbk_QLocaleFunc_toUInt_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.QLocale.toUInt(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            int cppArg1 = pyargs[1] ? Shiboken::Converter<int >::toCpp(pyargs[1]) : 0;

            if(!PyErr_Occurred()) {
                // toUInt(QString,bool*,int)const
                // Begin code injection

                // TEMPLATE - fix_arg,bool*,arg - START
                bool ok_;
                uint retval_ = cppSelf->toUInt(cppArg0, &ok_, cppArg1);
                pyResult = Shiboken::makeTuple(retval_, ok_);
                // TEMPLATE - fix_arg,bool*,arg - END

                // End of code injection


            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QLocaleFunc_toUInt_TypeError:
        const char* overloads[] = {"QString, bool, int = 0", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QLocale.toUInt", overloads);
        return 0;
}

static PyObject* Sbk_QLocaleFunc_toULongLong(PyObject* self, PyObject* args, PyObject* kwds)
{
    QLocale* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QLocale* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QLocale.toULongLong(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QLocale.toULongLong(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:toULongLong", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: toULongLong(QString,bool*,int)const
    if (Shiboken::Converter< QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // toULongLong(QString,bool*,int)const
        } else if (SbkNumber_Check(pyargs[1])) {
            overloadId = 0; // toULongLong(QString,bool*,int)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QLocaleFunc_toULongLong_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "base");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "base";
                    else if (SbkNumber_Check(value))
                        pyargs[1] = value;
                    else
                        goto Sbk_QLocaleFunc_toULongLong_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.QLocale.toULongLong(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            int cppArg1 = pyargs[1] ? Shiboken::Converter<int >::toCpp(pyargs[1]) : 0;

            if(!PyErr_Occurred()) {
                // toULongLong(QString,bool*,int)const
                // Begin code injection

                // TEMPLATE - fix_arg,bool*,arg - START
                bool ok_;
                qlonglong retval_ = cppSelf->toULongLong(cppArg0, &ok_, cppArg1);
                pyResult = Shiboken::makeTuple(retval_, ok_);
                // TEMPLATE - fix_arg,bool*,arg - END

                // End of code injection


            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QLocaleFunc_toULongLong_TypeError:
        const char* overloads[] = {"QString, bool, int = 0", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QLocale.toULongLong", overloads);
        return 0;
}

static PyObject* Sbk_QLocaleFunc_toUShort(PyObject* self, PyObject* args, PyObject* kwds)
{
    QLocale* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QLocale* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QLocale.toUShort(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QLocale.toUShort(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:toUShort", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: toUShort(QString,bool*,int)const
    if (Shiboken::Converter< QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // toUShort(QString,bool*,int)const
        } else if (SbkNumber_Check(pyargs[1])) {
            overloadId = 0; // toUShort(QString,bool*,int)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QLocaleFunc_toUShort_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "base");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "base";
                    else if (SbkNumber_Check(value))
                        pyargs[1] = value;
                    else
                        goto Sbk_QLocaleFunc_toUShort_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.QLocale.toUShort(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            int cppArg1 = pyargs[1] ? Shiboken::Converter<int >::toCpp(pyargs[1]) : 0;

            if(!PyErr_Occurred()) {
                // toUShort(QString,bool*,int)const
                // Begin code injection

                // TEMPLATE - fix_arg,bool*,arg - START
                bool ok_;
                ushort retval_ = cppSelf->toUShort(cppArg0, &ok_, cppArg1);
                pyResult = Shiboken::makeTuple(retval_, ok_);
                // TEMPLATE - fix_arg,bool*,arg - END

                // End of code injection


            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QLocaleFunc_toUShort_TypeError:
        const char* overloads[] = {"QString, bool = 0, int = 0", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QLocale.toUShort", overloads);
        return 0;
}

static PyObject* Sbk_QLocaleFunc_zeroDigit(PyObject* self)
{
    QLocale* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QLocale* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // zeroDigit()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QChar cppResult = const_cast<const QLocale*>(cppSelf)->zeroDigit();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QChar >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject *Sbk_QLocale___copy__(PyObject *self)
{
        QLocale* cppSelf = 0;
        if (!Shiboken::Object::isValid(self))
            return 0;
        cppSelf = Shiboken::Converter<QLocale*>::toCpp(self);
        PyObject* pyResult = 0;
        QLocale* copy = new QLocale(*cppSelf);
        pyResult = Shiboken::Converter<QLocale*>::toPython(copy);
        Shiboken::Object::getOwnership(pyResult);

        if (PyErr_Occurred() || !pyResult) {
            Py_XDECREF(pyResult);
            return 0;
        }
        return pyResult;
}

static PyMethodDef Sbk_QLocale_methods[] = {
    {"amText", (PyCFunction)Sbk_QLocaleFunc_amText, METH_NOARGS},
    {"c", (PyCFunction)Sbk_QLocaleFunc_c, METH_NOARGS|METH_STATIC},
    {"countriesForLanguage", (PyCFunction)Sbk_QLocaleFunc_countriesForLanguage, METH_O|METH_STATIC},
    {"country", (PyCFunction)Sbk_QLocaleFunc_country, METH_NOARGS},
    {"countryToString", (PyCFunction)Sbk_QLocaleFunc_countryToString, METH_O|METH_STATIC},
    {"dateFormat", (PyCFunction)Sbk_QLocaleFunc_dateFormat, METH_VARARGS|METH_KEYWORDS},
    {"dateTimeFormat", (PyCFunction)Sbk_QLocaleFunc_dateTimeFormat, METH_VARARGS|METH_KEYWORDS},
    {"dayName", (PyCFunction)Sbk_QLocaleFunc_dayName, METH_VARARGS|METH_KEYWORDS},
    {"decimalPoint", (PyCFunction)Sbk_QLocaleFunc_decimalPoint, METH_NOARGS},
    {"exponential", (PyCFunction)Sbk_QLocaleFunc_exponential, METH_NOARGS},
    {"groupSeparator", (PyCFunction)Sbk_QLocaleFunc_groupSeparator, METH_NOARGS},
    {"language", (PyCFunction)Sbk_QLocaleFunc_language, METH_NOARGS},
    {"languageToString", (PyCFunction)Sbk_QLocaleFunc_languageToString, METH_O|METH_STATIC},
    {"measurementSystem", (PyCFunction)Sbk_QLocaleFunc_measurementSystem, METH_NOARGS},
    {"monthName", (PyCFunction)Sbk_QLocaleFunc_monthName, METH_VARARGS|METH_KEYWORDS},
    {"name", (PyCFunction)Sbk_QLocaleFunc_name, METH_NOARGS},
    {"negativeSign", (PyCFunction)Sbk_QLocaleFunc_negativeSign, METH_NOARGS},
    {"numberOptions", (PyCFunction)Sbk_QLocaleFunc_numberOptions, METH_NOARGS},
    {"percent", (PyCFunction)Sbk_QLocaleFunc_percent, METH_NOARGS},
    {"pmText", (PyCFunction)Sbk_QLocaleFunc_pmText, METH_NOARGS},
    {"positiveSign", (PyCFunction)Sbk_QLocaleFunc_positiveSign, METH_NOARGS},
    {"setDefault", (PyCFunction)Sbk_QLocaleFunc_setDefault, METH_O|METH_STATIC},
    {"setNumberOptions", (PyCFunction)Sbk_QLocaleFunc_setNumberOptions, METH_O},
    {"standaloneDayName", (PyCFunction)Sbk_QLocaleFunc_standaloneDayName, METH_VARARGS|METH_KEYWORDS},
    {"standaloneMonthName", (PyCFunction)Sbk_QLocaleFunc_standaloneMonthName, METH_VARARGS|METH_KEYWORDS},
    {"system", (PyCFunction)Sbk_QLocaleFunc_system, METH_NOARGS|METH_STATIC},
    {"textDirection", (PyCFunction)Sbk_QLocaleFunc_textDirection, METH_NOARGS},
    {"timeFormat", (PyCFunction)Sbk_QLocaleFunc_timeFormat, METH_VARARGS|METH_KEYWORDS},
    {"toDate", (PyCFunction)Sbk_QLocaleFunc_toDate, METH_VARARGS|METH_KEYWORDS},
    {"toDateTime", (PyCFunction)Sbk_QLocaleFunc_toDateTime, METH_VARARGS|METH_KEYWORDS},
    {"toDouble", (PyCFunction)Sbk_QLocaleFunc_toDouble, METH_O},
    {"toFloat", (PyCFunction)Sbk_QLocaleFunc_toFloat, METH_O},
    {"toInt", (PyCFunction)Sbk_QLocaleFunc_toInt, METH_VARARGS|METH_KEYWORDS},
    {"toLongLong", (PyCFunction)Sbk_QLocaleFunc_toLongLong, METH_VARARGS|METH_KEYWORDS},
    {"toShort", (PyCFunction)Sbk_QLocaleFunc_toShort, METH_VARARGS|METH_KEYWORDS},
    {"toString", (PyCFunction)Sbk_QLocaleFunc_toString, METH_VARARGS|METH_KEYWORDS},
    {"toTime", (PyCFunction)Sbk_QLocaleFunc_toTime, METH_VARARGS|METH_KEYWORDS},
    {"toUInt", (PyCFunction)Sbk_QLocaleFunc_toUInt, METH_VARARGS|METH_KEYWORDS},
    {"toULongLong", (PyCFunction)Sbk_QLocaleFunc_toULongLong, METH_VARARGS|METH_KEYWORDS},
    {"toUShort", (PyCFunction)Sbk_QLocaleFunc_toUShort, METH_VARARGS|METH_KEYWORDS},
    {"zeroDigit", (PyCFunction)Sbk_QLocaleFunc_zeroDigit, METH_NOARGS},

    {"__copy__", (PyCFunction)Sbk_QLocale___copy__, METH_NOARGS},
    {0} // Sentinel
};

// Rich comparison
static PyObject* Sbk_QLocale_richcompare(PyObject* self, PyObject* arg, int op)
{
    PyObject* pyResult = 0;
    QLocale& cppSelf = *Shiboken::Converter< QLocale* >::toCpp(self);

    switch (op) {
        case Py_NE:
            if (Shiboken::Converter< ::QLocale >::isConvertible(arg)) {
                // operator!=(const QLocale & other) const
                QLocale cppArg0 = Shiboken::Converter< ::QLocale >::toCpp(arg);
                pyResult = Shiboken::Converter< bool >::toPython(cppSelf != cppArg0);
            } else goto Sbk_QLocale_RichComparison_TypeError;

            break;
        case Py_EQ:
            if (Shiboken::Converter< ::QLocale >::isConvertible(arg)) {
                // operator==(const QLocale & other) const
                QLocale cppArg0 = Shiboken::Converter< ::QLocale >::toCpp(arg);
                pyResult = Shiboken::Converter< bool >::toPython(cppSelf == cppArg0);
            } else goto Sbk_QLocale_RichComparison_TypeError;

            break;
        default:
            goto Sbk_QLocale_RichComparison_TypeError;
    }

    if (pyResult && !PyErr_Occurred())
        return pyResult;
    Sbk_QLocale_RichComparison_TypeError:
    PyErr_SetString(PyExc_NotImplementedError, "operator not implemented.");
    return 0;

}

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QLocale_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtCore.QLocale",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      Sbk_QLocale_richcompare,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QLocale_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QLocale_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern

PyObject* SbkPySide_QtCore_QLocale_NumberOption___and__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QLocale::NumberOptions >::toPython(
        Shiboken::Converter<QLocale::NumberOptions>::toCpp(self)
        & Shiboken::Converter< QLocale::NumberOptions >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtCore_QLocale_NumberOption___or__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QLocale::NumberOptions >::toPython(
        Shiboken::Converter<QLocale::NumberOptions>::toCpp(self)
        | Shiboken::Converter< QLocale::NumberOptions >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtCore_QLocale_NumberOption___xor__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QLocale::NumberOptions >::toPython(
        Shiboken::Converter<QLocale::NumberOptions>::toCpp(self)
        ^ Shiboken::Converter< QLocale::NumberOptions >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtCore_QLocale_NumberOption___invert__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QLocale::NumberOptions >::toPython(
        ~Shiboken::Converter<QLocale::NumberOptions >::toCpp(self)
    );
}


static PyNumberMethods SbkPySide_QtCore_QLocale_NumberOption_as_number = {
    /*nb_add*/                  0,
    /*nb_subtract*/             0,
    /*nb_multiply*/             0,
    /*nb_divide*/               0,
    /*nb_remainder*/            0,
    /*nb_divmod*/               0,
    /*nb_power*/                0,
    /*nb_negative*/             0,
    /*nb_positive*/             0,
    /*nb_absolute*/             0,
    /*nb_nonzero*/              0,
    /*nb_invert*/               (unaryfunc)SbkPySide_QtCore_QLocale_NumberOption___invert__,
    /*nb_lshift*/               0,
    /*nb_rshift*/               0,
    /*nb_and*/                  (binaryfunc)SbkPySide_QtCore_QLocale_NumberOption___and__,
    /*nb_xor*/                  (binaryfunc)SbkPySide_QtCore_QLocale_NumberOption___xor__,
    /*nb_or*/                   (binaryfunc)SbkPySide_QtCore_QLocale_NumberOption___or__,
    /*nb_coerce*/               0,
    /*nb_int*/                  0,
    /*nb_long*/                 0,
    /*nb_float*/                0,
    /*nb_oct*/                  0,
    /*nb_hex*/                  0,
    /*nb_inplace_add*/          0,
    /*nb_inplace_subtract*/     0,
    /*nb_inplace_multiply*/     0,
    /*nb_inplace_divide*/       0,
    /*nb_inplace_remainder*/    0,
    /*nb_inplace_power*/        0,
    /*nb_inplace_lshift*/       0,
    /*nb_inplace_rshift*/       0,
    /*nb_inplace_and*/          0,
    /*nb_inplace_xor*/          0,
    /*nb_inplace_or*/           0,
    /*nb_floor_divide*/         0,
    /*nb_true_divide*/          0,
    /*nb_inplace_floor_divide*/ 0,
    /*nb_inplace_true_divide*/  0,
    /*nb_index*/                0
};


// forward declaration of new function
static PyTypeObject SbkPySide_QtCore_QLocale_NumberOptions_Type = {
    PyObject_HEAD_INIT(&PyType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "NumberOptions",
    /*tp_basicsize*/        0,
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        &SbkPySide_QtCore_QLocale_NumberOption_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT | Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              PyInt_Type.tp_new,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};



void init_QLocale(PyObject* module)
{
    SbkPySide_QtCoreTypes[SBK_QLOCALE_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QLocale_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QLocale_Type);
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QLocale_Type, &Shiboken::callCppDestructor<QLocale >);
    if (PyType_Ready((PyTypeObject*)&Sbk_QLocale_Type) < 0)
        return;

    Shiboken::ObjectType::setOriginalName(&Sbk_QLocale_Type, "QLocale");
    PyModule_AddObject(module, "QLocale",
        ((PyObject*)&Sbk_QLocale_Type));

    // Initialize enums
    PyObject* enumItem;

    // init enum: MeasurementSystem
    PyTypeObject* SbkPySide_QtCore_QLocale_MeasurementSystem = Shiboken::Enum::newType("PySide.QtCore.QLocale.MeasurementSystem");
    SbkPySide_QtCoreTypes[SBK_QLOCALE_MEASUREMENTSYSTEM_IDX] = SbkPySide_QtCore_QLocale_MeasurementSystem;
    if (PyType_Ready(SbkPySide_QtCore_QLocale_MeasurementSystem) < 0)
        return;
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,
            "MeasurementSystem",((PyObject*)SbkPySide_QtCore_QLocale_MeasurementSystem));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_MeasurementSystem,(long) QLocale::MetricSystem, "MetricSystem");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"MetricSystem", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_MeasurementSystem->tp_dict,"MetricSystem", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_MeasurementSystem,(long) QLocale::ImperialSystem, "ImperialSystem");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"ImperialSystem", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_MeasurementSystem->tp_dict,"ImperialSystem", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QLocale::MeasurementSystem");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::MeasurementSystem");
    // end of enum MeasurementSystem

    // init enum: NumberOption
    PyTypeObject* SbkPySide_QtCore_QLocale_NumberOption = Shiboken::Enum::newType("PySide.QtCore.QLocale.NumberOption");
    SbkPySide_QtCore_QLocale_NumberOption->tp_as_number = &SbkPySide_QtCore_QLocale_NumberOption_as_number;
    SbkPySide_QtCoreTypes[SBK_QLOCALE_NUMBEROPTION_IDX] = SbkPySide_QtCore_QLocale_NumberOption;
    if (PyType_Ready(SbkPySide_QtCore_QLocale_NumberOption) < 0)
        return;
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,
            "NumberOption",((PyObject*)SbkPySide_QtCore_QLocale_NumberOption));

    // init flags class: QFlags<QLocale::NumberOption>
    SbkPySide_QtCoreTypes[SBK_QFLAGS_QLOCALE_NUMBEROPTION__IDX] = &SbkPySide_QtCore_QLocale_NumberOptions_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtCore_QLocale_NumberOptions_Type) < 0)
        return;
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,
            "NumberOptions",((PyObject*)&SbkPySide_QtCore_QLocale_NumberOptions_Type));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_NumberOption,(long) QLocale::OmitGroupSeparator, "OmitGroupSeparator");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"OmitGroupSeparator", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_NumberOption->tp_dict,"OmitGroupSeparator", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_NumberOption,(long) QLocale::RejectGroupSeparator, "RejectGroupSeparator");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"RejectGroupSeparator", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_NumberOption->tp_dict,"RejectGroupSeparator", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QLocale::NumberOption");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::NumberOption");
    // end of enum NumberOption

    // init enum: FormatType
    PyTypeObject* SbkPySide_QtCore_QLocale_FormatType = Shiboken::Enum::newType("PySide.QtCore.QLocale.FormatType");
    SbkPySide_QtCoreTypes[SBK_QLOCALE_FORMATTYPE_IDX] = SbkPySide_QtCore_QLocale_FormatType;
    if (PyType_Ready(SbkPySide_QtCore_QLocale_FormatType) < 0)
        return;
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,
            "FormatType",((PyObject*)SbkPySide_QtCore_QLocale_FormatType));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_FormatType,(long) QLocale::LongFormat, "LongFormat");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"LongFormat", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_FormatType->tp_dict,"LongFormat", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_FormatType,(long) QLocale::ShortFormat, "ShortFormat");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"ShortFormat", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_FormatType->tp_dict,"ShortFormat", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_FormatType,(long) QLocale::NarrowFormat, "NarrowFormat");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"NarrowFormat", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_FormatType->tp_dict,"NarrowFormat", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QLocale::FormatType");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::FormatType");
    // end of enum FormatType

    // init enum: Country
    PyTypeObject* SbkPySide_QtCore_QLocale_Country = Shiboken::Enum::newType("PySide.QtCore.QLocale.Country");
    SbkPySide_QtCoreTypes[SBK_QLOCALE_COUNTRY_IDX] = SbkPySide_QtCore_QLocale_Country;
    if (PyType_Ready(SbkPySide_QtCore_QLocale_Country) < 0)
        return;
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,
            "Country",((PyObject*)SbkPySide_QtCore_QLocale_Country));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::AnyCountry, "AnyCountry");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"AnyCountry", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"AnyCountry", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Afghanistan, "Afghanistan");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Afghanistan", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Afghanistan", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Albania, "Albania");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Albania", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Albania", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Algeria, "Algeria");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Algeria", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Algeria", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::AmericanSamoa, "AmericanSamoa");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"AmericanSamoa", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"AmericanSamoa", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Andorra, "Andorra");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Andorra", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Andorra", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Angola, "Angola");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Angola", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Angola", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Anguilla, "Anguilla");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Anguilla", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Anguilla", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Antarctica, "Antarctica");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Antarctica", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Antarctica", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::AntiguaAndBarbuda, "AntiguaAndBarbuda");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"AntiguaAndBarbuda", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"AntiguaAndBarbuda", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Argentina, "Argentina");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Argentina", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Argentina", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Armenia, "Armenia");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Armenia", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Armenia", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Aruba, "Aruba");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Aruba", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Aruba", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Australia, "Australia");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Australia", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Australia", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Austria, "Austria");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Austria", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Austria", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Azerbaijan, "Azerbaijan");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Azerbaijan", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Azerbaijan", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Bahamas, "Bahamas");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Bahamas", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Bahamas", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Bahrain, "Bahrain");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Bahrain", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Bahrain", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Bangladesh, "Bangladesh");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Bangladesh", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Bangladesh", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Barbados, "Barbados");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Barbados", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Barbados", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Belarus, "Belarus");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Belarus", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Belarus", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Belgium, "Belgium");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Belgium", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Belgium", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Belize, "Belize");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Belize", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Belize", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Benin, "Benin");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Benin", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Benin", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Bermuda, "Bermuda");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Bermuda", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Bermuda", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Bhutan, "Bhutan");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Bhutan", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Bhutan", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Bolivia, "Bolivia");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Bolivia", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Bolivia", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::BosniaAndHerzegowina, "BosniaAndHerzegowina");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"BosniaAndHerzegowina", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"BosniaAndHerzegowina", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Botswana, "Botswana");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Botswana", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Botswana", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::BouvetIsland, "BouvetIsland");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"BouvetIsland", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"BouvetIsland", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Brazil, "Brazil");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Brazil", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Brazil", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::BritishIndianOceanTerritory, "BritishIndianOceanTerritory");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"BritishIndianOceanTerritory", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"BritishIndianOceanTerritory", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::BruneiDarussalam, "BruneiDarussalam");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"BruneiDarussalam", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"BruneiDarussalam", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Bulgaria, "Bulgaria");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Bulgaria", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Bulgaria", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::BurkinaFaso, "BurkinaFaso");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"BurkinaFaso", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"BurkinaFaso", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Burundi, "Burundi");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Burundi", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Burundi", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Cambodia, "Cambodia");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Cambodia", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Cambodia", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Cameroon, "Cameroon");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Cameroon", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Cameroon", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Canada, "Canada");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Canada", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Canada", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::CapeVerde, "CapeVerde");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"CapeVerde", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"CapeVerde", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::CaymanIslands, "CaymanIslands");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"CaymanIslands", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"CaymanIslands", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::CentralAfricanRepublic, "CentralAfricanRepublic");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"CentralAfricanRepublic", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"CentralAfricanRepublic", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Chad, "Chad");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Chad", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Chad", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Chile, "Chile");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Chile", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Chile", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::China, "China");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"China", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"China", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::ChristmasIsland, "ChristmasIsland");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"ChristmasIsland", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"ChristmasIsland", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::CocosIslands, "CocosIslands");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"CocosIslands", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"CocosIslands", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Colombia, "Colombia");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Colombia", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Colombia", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Comoros, "Comoros");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Comoros", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Comoros", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::DemocraticRepublicOfCongo, "DemocraticRepublicOfCongo");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"DemocraticRepublicOfCongo", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"DemocraticRepublicOfCongo", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::PeoplesRepublicOfCongo, "PeoplesRepublicOfCongo");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"PeoplesRepublicOfCongo", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"PeoplesRepublicOfCongo", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::CookIslands, "CookIslands");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"CookIslands", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"CookIslands", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::CostaRica, "CostaRica");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"CostaRica", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"CostaRica", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::IvoryCoast, "IvoryCoast");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"IvoryCoast", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"IvoryCoast", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Croatia, "Croatia");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Croatia", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Croatia", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Cuba, "Cuba");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Cuba", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Cuba", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Cyprus, "Cyprus");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Cyprus", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Cyprus", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::CzechRepublic, "CzechRepublic");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"CzechRepublic", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"CzechRepublic", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Denmark, "Denmark");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Denmark", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Denmark", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Djibouti, "Djibouti");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Djibouti", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Djibouti", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Dominica, "Dominica");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Dominica", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Dominica", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::DominicanRepublic, "DominicanRepublic");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"DominicanRepublic", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"DominicanRepublic", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::EastTimor, "EastTimor");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"EastTimor", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"EastTimor", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Ecuador, "Ecuador");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Ecuador", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Ecuador", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Egypt, "Egypt");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Egypt", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Egypt", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::ElSalvador, "ElSalvador");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"ElSalvador", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"ElSalvador", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::EquatorialGuinea, "EquatorialGuinea");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"EquatorialGuinea", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"EquatorialGuinea", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Eritrea, "Eritrea");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Eritrea", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Eritrea", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Estonia, "Estonia");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Estonia", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Estonia", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Ethiopia, "Ethiopia");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Ethiopia", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Ethiopia", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::FalklandIslands, "FalklandIslands");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"FalklandIslands", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"FalklandIslands", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::FaroeIslands, "FaroeIslands");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"FaroeIslands", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"FaroeIslands", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::FijiCountry, "FijiCountry");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"FijiCountry", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"FijiCountry", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Finland, "Finland");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Finland", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Finland", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::France, "France");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"France", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"France", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::MetropolitanFrance, "MetropolitanFrance");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"MetropolitanFrance", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"MetropolitanFrance", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::FrenchGuiana, "FrenchGuiana");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"FrenchGuiana", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"FrenchGuiana", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::FrenchPolynesia, "FrenchPolynesia");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"FrenchPolynesia", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"FrenchPolynesia", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::FrenchSouthernTerritories, "FrenchSouthernTerritories");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"FrenchSouthernTerritories", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"FrenchSouthernTerritories", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Gabon, "Gabon");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Gabon", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Gabon", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Gambia, "Gambia");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Gambia", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Gambia", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Georgia, "Georgia");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Georgia", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Georgia", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Germany, "Germany");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Germany", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Germany", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Ghana, "Ghana");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Ghana", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Ghana", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Gibraltar, "Gibraltar");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Gibraltar", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Gibraltar", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Greece, "Greece");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Greece", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Greece", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Greenland, "Greenland");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Greenland", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Greenland", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Grenada, "Grenada");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Grenada", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Grenada", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Guadeloupe, "Guadeloupe");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Guadeloupe", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Guadeloupe", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Guam, "Guam");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Guam", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Guam", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Guatemala, "Guatemala");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Guatemala", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Guatemala", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Guinea, "Guinea");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Guinea", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Guinea", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::GuineaBissau, "GuineaBissau");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"GuineaBissau", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"GuineaBissau", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Guyana, "Guyana");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Guyana", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Guyana", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Haiti, "Haiti");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Haiti", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Haiti", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::HeardAndMcDonaldIslands, "HeardAndMcDonaldIslands");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"HeardAndMcDonaldIslands", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"HeardAndMcDonaldIslands", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Honduras, "Honduras");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Honduras", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Honduras", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::HongKong, "HongKong");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"HongKong", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"HongKong", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Hungary, "Hungary");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Hungary", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Hungary", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Iceland, "Iceland");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Iceland", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Iceland", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::India, "India");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"India", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"India", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Indonesia, "Indonesia");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Indonesia", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Indonesia", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Iran, "Iran");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Iran", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Iran", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Iraq, "Iraq");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Iraq", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Iraq", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Ireland, "Ireland");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Ireland", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Ireland", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Israel, "Israel");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Israel", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Israel", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Italy, "Italy");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Italy", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Italy", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Jamaica, "Jamaica");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Jamaica", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Jamaica", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Japan, "Japan");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Japan", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Japan", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Jordan, "Jordan");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Jordan", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Jordan", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Kazakhstan, "Kazakhstan");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Kazakhstan", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Kazakhstan", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Kenya, "Kenya");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Kenya", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Kenya", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Kiribati, "Kiribati");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Kiribati", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Kiribati", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::DemocraticRepublicOfKorea, "DemocraticRepublicOfKorea");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"DemocraticRepublicOfKorea", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"DemocraticRepublicOfKorea", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::RepublicOfKorea, "RepublicOfKorea");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"RepublicOfKorea", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"RepublicOfKorea", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Kuwait, "Kuwait");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Kuwait", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Kuwait", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Kyrgyzstan, "Kyrgyzstan");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Kyrgyzstan", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Kyrgyzstan", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Lao, "Lao");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Lao", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Lao", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Latvia, "Latvia");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Latvia", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Latvia", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Lebanon, "Lebanon");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Lebanon", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Lebanon", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Lesotho, "Lesotho");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Lesotho", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Lesotho", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Liberia, "Liberia");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Liberia", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Liberia", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::LibyanArabJamahiriya, "LibyanArabJamahiriya");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"LibyanArabJamahiriya", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"LibyanArabJamahiriya", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Liechtenstein, "Liechtenstein");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Liechtenstein", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Liechtenstein", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Lithuania, "Lithuania");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Lithuania", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Lithuania", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Luxembourg, "Luxembourg");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Luxembourg", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Luxembourg", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Macau, "Macau");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Macau", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Macau", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Macedonia, "Macedonia");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Macedonia", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Macedonia", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Madagascar, "Madagascar");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Madagascar", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Madagascar", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Malawi, "Malawi");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Malawi", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Malawi", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Malaysia, "Malaysia");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Malaysia", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Malaysia", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Maldives, "Maldives");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Maldives", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Maldives", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Mali, "Mali");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Mali", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Mali", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Malta, "Malta");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Malta", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Malta", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::MarshallIslands, "MarshallIslands");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"MarshallIslands", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"MarshallIslands", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Martinique, "Martinique");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Martinique", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Martinique", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Mauritania, "Mauritania");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Mauritania", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Mauritania", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Mauritius, "Mauritius");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Mauritius", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Mauritius", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Mayotte, "Mayotte");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Mayotte", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Mayotte", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Mexico, "Mexico");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Mexico", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Mexico", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Micronesia, "Micronesia");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Micronesia", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Micronesia", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Moldova, "Moldova");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Moldova", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Moldova", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Monaco, "Monaco");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Monaco", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Monaco", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Mongolia, "Mongolia");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Mongolia", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Mongolia", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Montserrat, "Montserrat");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Montserrat", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Montserrat", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Morocco, "Morocco");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Morocco", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Morocco", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Mozambique, "Mozambique");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Mozambique", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Mozambique", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Myanmar, "Myanmar");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Myanmar", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Myanmar", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Namibia, "Namibia");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Namibia", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Namibia", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::NauruCountry, "NauruCountry");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"NauruCountry", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"NauruCountry", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Nepal, "Nepal");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Nepal", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Nepal", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Netherlands, "Netherlands");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Netherlands", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Netherlands", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::NetherlandsAntilles, "NetherlandsAntilles");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"NetherlandsAntilles", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"NetherlandsAntilles", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::NewCaledonia, "NewCaledonia");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"NewCaledonia", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"NewCaledonia", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::NewZealand, "NewZealand");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"NewZealand", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"NewZealand", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Nicaragua, "Nicaragua");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Nicaragua", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Nicaragua", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Niger, "Niger");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Niger", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Niger", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Nigeria, "Nigeria");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Nigeria", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Nigeria", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Niue, "Niue");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Niue", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Niue", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::NorfolkIsland, "NorfolkIsland");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"NorfolkIsland", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"NorfolkIsland", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::NorthernMarianaIslands, "NorthernMarianaIslands");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"NorthernMarianaIslands", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"NorthernMarianaIslands", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Norway, "Norway");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Norway", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Norway", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Oman, "Oman");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Oman", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Oman", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Pakistan, "Pakistan");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Pakistan", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Pakistan", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Palau, "Palau");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Palau", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Palau", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::PalestinianTerritory, "PalestinianTerritory");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"PalestinianTerritory", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"PalestinianTerritory", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Panama, "Panama");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Panama", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Panama", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::PapuaNewGuinea, "PapuaNewGuinea");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"PapuaNewGuinea", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"PapuaNewGuinea", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Paraguay, "Paraguay");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Paraguay", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Paraguay", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Peru, "Peru");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Peru", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Peru", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Philippines, "Philippines");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Philippines", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Philippines", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Pitcairn, "Pitcairn");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Pitcairn", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Pitcairn", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Poland, "Poland");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Poland", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Poland", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Portugal, "Portugal");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Portugal", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Portugal", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::PuertoRico, "PuertoRico");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"PuertoRico", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"PuertoRico", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Qatar, "Qatar");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Qatar", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Qatar", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Reunion, "Reunion");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Reunion", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Reunion", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Romania, "Romania");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Romania", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Romania", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::RussianFederation, "RussianFederation");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"RussianFederation", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"RussianFederation", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Rwanda, "Rwanda");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Rwanda", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Rwanda", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::SaintKittsAndNevis, "SaintKittsAndNevis");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"SaintKittsAndNevis", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"SaintKittsAndNevis", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::StLucia, "StLucia");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"StLucia", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"StLucia", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::StVincentAndTheGrenadines, "StVincentAndTheGrenadines");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"StVincentAndTheGrenadines", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"StVincentAndTheGrenadines", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Samoa, "Samoa");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Samoa", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Samoa", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::SanMarino, "SanMarino");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"SanMarino", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"SanMarino", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::SaoTomeAndPrincipe, "SaoTomeAndPrincipe");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"SaoTomeAndPrincipe", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"SaoTomeAndPrincipe", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::SaudiArabia, "SaudiArabia");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"SaudiArabia", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"SaudiArabia", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Senegal, "Senegal");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Senegal", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Senegal", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Seychelles, "Seychelles");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Seychelles", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Seychelles", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::SierraLeone, "SierraLeone");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"SierraLeone", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"SierraLeone", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Singapore, "Singapore");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Singapore", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Singapore", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Slovakia, "Slovakia");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Slovakia", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Slovakia", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Slovenia, "Slovenia");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Slovenia", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Slovenia", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::SolomonIslands, "SolomonIslands");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"SolomonIslands", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"SolomonIslands", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Somalia, "Somalia");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Somalia", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Somalia", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::SouthAfrica, "SouthAfrica");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"SouthAfrica", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"SouthAfrica", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::SouthGeorgiaAndTheSouthSandwichIslands, "SouthGeorgiaAndTheSouthSandwichIslands");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"SouthGeorgiaAndTheSouthSandwichIslands", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"SouthGeorgiaAndTheSouthSandwichIslands", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Spain, "Spain");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Spain", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Spain", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::SriLanka, "SriLanka");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"SriLanka", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"SriLanka", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::StHelena, "StHelena");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"StHelena", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"StHelena", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::StPierreAndMiquelon, "StPierreAndMiquelon");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"StPierreAndMiquelon", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"StPierreAndMiquelon", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Sudan, "Sudan");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Sudan", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Sudan", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Suriname, "Suriname");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Suriname", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Suriname", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::SvalbardAndJanMayenIslands, "SvalbardAndJanMayenIslands");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"SvalbardAndJanMayenIslands", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"SvalbardAndJanMayenIslands", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Swaziland, "Swaziland");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Swaziland", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Swaziland", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Sweden, "Sweden");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Sweden", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Sweden", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Switzerland, "Switzerland");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Switzerland", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Switzerland", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::SyrianArabRepublic, "SyrianArabRepublic");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"SyrianArabRepublic", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"SyrianArabRepublic", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Taiwan, "Taiwan");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Taiwan", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Taiwan", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Tajikistan, "Tajikistan");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Tajikistan", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Tajikistan", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Tanzania, "Tanzania");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Tanzania", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Tanzania", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Thailand, "Thailand");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Thailand", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Thailand", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Togo, "Togo");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Togo", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Togo", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Tokelau, "Tokelau");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Tokelau", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Tokelau", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::TongaCountry, "TongaCountry");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"TongaCountry", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"TongaCountry", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::TrinidadAndTobago, "TrinidadAndTobago");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"TrinidadAndTobago", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"TrinidadAndTobago", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Tunisia, "Tunisia");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Tunisia", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Tunisia", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Turkey, "Turkey");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Turkey", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Turkey", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Turkmenistan, "Turkmenistan");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Turkmenistan", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Turkmenistan", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::TurksAndCaicosIslands, "TurksAndCaicosIslands");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"TurksAndCaicosIslands", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"TurksAndCaicosIslands", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Tuvalu, "Tuvalu");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Tuvalu", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Tuvalu", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Uganda, "Uganda");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Uganda", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Uganda", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Ukraine, "Ukraine");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Ukraine", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Ukraine", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::UnitedArabEmirates, "UnitedArabEmirates");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"UnitedArabEmirates", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"UnitedArabEmirates", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::UnitedKingdom, "UnitedKingdom");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"UnitedKingdom", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"UnitedKingdom", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::UnitedStates, "UnitedStates");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"UnitedStates", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"UnitedStates", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::UnitedStatesMinorOutlyingIslands, "UnitedStatesMinorOutlyingIslands");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"UnitedStatesMinorOutlyingIslands", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"UnitedStatesMinorOutlyingIslands", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Uruguay, "Uruguay");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Uruguay", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Uruguay", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Uzbekistan, "Uzbekistan");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Uzbekistan", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Uzbekistan", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Vanuatu, "Vanuatu");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Vanuatu", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Vanuatu", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::VaticanCityState, "VaticanCityState");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"VaticanCityState", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"VaticanCityState", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Venezuela, "Venezuela");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Venezuela", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Venezuela", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::VietNam, "VietNam");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"VietNam", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"VietNam", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::BritishVirginIslands, "BritishVirginIslands");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"BritishVirginIslands", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"BritishVirginIslands", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::USVirginIslands, "USVirginIslands");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"USVirginIslands", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"USVirginIslands", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::WallisAndFutunaIslands, "WallisAndFutunaIslands");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"WallisAndFutunaIslands", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"WallisAndFutunaIslands", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::WesternSahara, "WesternSahara");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"WesternSahara", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"WesternSahara", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Yemen, "Yemen");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Yemen", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Yemen", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Yugoslavia, "Yugoslavia");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Yugoslavia", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Yugoslavia", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Zambia, "Zambia");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Zambia", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Zambia", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Zimbabwe, "Zimbabwe");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Zimbabwe", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Zimbabwe", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::SerbiaAndMontenegro, "SerbiaAndMontenegro");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"SerbiaAndMontenegro", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"SerbiaAndMontenegro", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Montenegro, "Montenegro");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Montenegro", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Montenegro", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::Serbia, "Serbia");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Serbia", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"Serbia", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::SaintBarthelemy, "SaintBarthelemy");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"SaintBarthelemy", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"SaintBarthelemy", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::SaintMartin, "SaintMartin");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"SaintMartin", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"SaintMartin", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::LatinAmericaAndTheCaribbean, "LatinAmericaAndTheCaribbean");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"LatinAmericaAndTheCaribbean", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"LatinAmericaAndTheCaribbean", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Country,(long) QLocale::LastCountry, "LastCountry");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"LastCountry", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Country->tp_dict,"LastCountry", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QLocale::Country");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::Country");
    // end of enum Country

    // init enum: Language
    PyTypeObject* SbkPySide_QtCore_QLocale_Language = Shiboken::Enum::newType("PySide.QtCore.QLocale.Language");
    SbkPySide_QtCoreTypes[SBK_QLOCALE_LANGUAGE_IDX] = SbkPySide_QtCore_QLocale_Language;
    if (PyType_Ready(SbkPySide_QtCore_QLocale_Language) < 0)
        return;
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,
            "Language",((PyObject*)SbkPySide_QtCore_QLocale_Language));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::C, "C");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"C", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"C", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Abkhazian, "Abkhazian");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Abkhazian", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Abkhazian", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Afan, "Afan");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Afan", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Afan", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Afar, "Afar");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Afar", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Afar", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Afrikaans, "Afrikaans");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Afrikaans", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Afrikaans", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Albanian, "Albanian");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Albanian", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Albanian", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Amharic, "Amharic");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Amharic", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Amharic", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Arabic, "Arabic");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Arabic", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Arabic", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Armenian, "Armenian");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Armenian", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Armenian", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Assamese, "Assamese");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Assamese", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Assamese", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Aymara, "Aymara");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Aymara", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Aymara", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Azerbaijani, "Azerbaijani");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Azerbaijani", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Azerbaijani", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Bashkir, "Bashkir");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Bashkir", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Bashkir", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Basque, "Basque");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Basque", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Basque", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Bengali, "Bengali");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Bengali", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Bengali", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Bhutani, "Bhutani");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Bhutani", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Bhutani", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Bihari, "Bihari");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Bihari", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Bihari", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Bislama, "Bislama");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Bislama", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Bislama", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Breton, "Breton");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Breton", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Breton", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Bulgarian, "Bulgarian");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Bulgarian", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Bulgarian", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Burmese, "Burmese");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Burmese", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Burmese", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Byelorussian, "Byelorussian");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Byelorussian", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Byelorussian", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Cambodian, "Cambodian");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Cambodian", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Cambodian", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Catalan, "Catalan");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Catalan", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Catalan", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Chinese, "Chinese");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Chinese", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Chinese", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Corsican, "Corsican");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Corsican", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Corsican", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Croatian, "Croatian");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Croatian", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Croatian", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Czech, "Czech");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Czech", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Czech", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Danish, "Danish");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Danish", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Danish", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Dutch, "Dutch");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Dutch", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Dutch", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::English, "English");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"English", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"English", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Esperanto, "Esperanto");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Esperanto", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Esperanto", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Estonian, "Estonian");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Estonian", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Estonian", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Faroese, "Faroese");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Faroese", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Faroese", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::FijiLanguage, "FijiLanguage");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"FijiLanguage", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"FijiLanguage", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Finnish, "Finnish");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Finnish", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Finnish", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::French, "French");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"French", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"French", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Frisian, "Frisian");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Frisian", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Frisian", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Gaelic, "Gaelic");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Gaelic", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Gaelic", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Galician, "Galician");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Galician", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Galician", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Georgian, "Georgian");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Georgian", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Georgian", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::German, "German");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"German", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"German", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Greek, "Greek");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Greek", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Greek", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Greenlandic, "Greenlandic");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Greenlandic", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Greenlandic", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Guarani, "Guarani");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Guarani", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Guarani", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Gujarati, "Gujarati");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Gujarati", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Gujarati", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Hausa, "Hausa");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Hausa", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Hausa", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Hebrew, "Hebrew");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Hebrew", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Hebrew", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Hindi, "Hindi");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Hindi", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Hindi", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Hungarian, "Hungarian");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Hungarian", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Hungarian", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Icelandic, "Icelandic");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Icelandic", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Icelandic", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Indonesian, "Indonesian");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Indonesian", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Indonesian", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Interlingua, "Interlingua");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Interlingua", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Interlingua", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Interlingue, "Interlingue");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Interlingue", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Interlingue", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Inuktitut, "Inuktitut");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Inuktitut", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Inuktitut", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Inupiak, "Inupiak");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Inupiak", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Inupiak", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Irish, "Irish");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Irish", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Irish", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Italian, "Italian");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Italian", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Italian", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Japanese, "Japanese");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Japanese", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Japanese", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Javanese, "Javanese");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Javanese", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Javanese", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Kannada, "Kannada");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Kannada", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Kannada", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Kashmiri, "Kashmiri");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Kashmiri", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Kashmiri", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Kazakh, "Kazakh");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Kazakh", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Kazakh", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Kinyarwanda, "Kinyarwanda");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Kinyarwanda", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Kinyarwanda", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Kirghiz, "Kirghiz");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Kirghiz", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Kirghiz", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Korean, "Korean");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Korean", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Korean", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Kurdish, "Kurdish");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Kurdish", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Kurdish", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Kurundi, "Kurundi");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Kurundi", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Kurundi", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Laothian, "Laothian");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Laothian", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Laothian", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Latin, "Latin");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Latin", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Latin", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Latvian, "Latvian");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Latvian", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Latvian", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Lingala, "Lingala");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Lingala", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Lingala", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Lithuanian, "Lithuanian");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Lithuanian", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Lithuanian", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Macedonian, "Macedonian");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Macedonian", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Macedonian", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Malagasy, "Malagasy");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Malagasy", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Malagasy", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Malay, "Malay");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Malay", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Malay", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Malayalam, "Malayalam");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Malayalam", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Malayalam", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Maltese, "Maltese");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Maltese", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Maltese", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Maori, "Maori");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Maori", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Maori", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Marathi, "Marathi");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Marathi", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Marathi", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Moldavian, "Moldavian");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Moldavian", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Moldavian", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Mongolian, "Mongolian");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Mongolian", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Mongolian", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::NauruLanguage, "NauruLanguage");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"NauruLanguage", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"NauruLanguage", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Nepali, "Nepali");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Nepali", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Nepali", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Norwegian, "Norwegian");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Norwegian", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Norwegian", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::NorwegianBokmal, "NorwegianBokmal");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"NorwegianBokmal", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"NorwegianBokmal", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Occitan, "Occitan");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Occitan", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Occitan", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Oriya, "Oriya");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Oriya", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Oriya", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Pashto, "Pashto");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Pashto", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Pashto", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Persian, "Persian");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Persian", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Persian", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Polish, "Polish");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Polish", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Polish", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Portuguese, "Portuguese");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Portuguese", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Portuguese", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Punjabi, "Punjabi");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Punjabi", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Punjabi", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Quechua, "Quechua");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Quechua", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Quechua", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::RhaetoRomance, "RhaetoRomance");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"RhaetoRomance", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"RhaetoRomance", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Romanian, "Romanian");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Romanian", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Romanian", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Russian, "Russian");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Russian", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Russian", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Samoan, "Samoan");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Samoan", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Samoan", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Sangho, "Sangho");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Sangho", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Sangho", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Sanskrit, "Sanskrit");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Sanskrit", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Sanskrit", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Serbian, "Serbian");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Serbian", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Serbian", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::SerboCroatian, "SerboCroatian");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"SerboCroatian", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"SerboCroatian", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Sesotho, "Sesotho");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Sesotho", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Sesotho", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Setswana, "Setswana");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Setswana", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Setswana", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Shona, "Shona");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Shona", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Shona", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Sindhi, "Sindhi");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Sindhi", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Sindhi", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Singhalese, "Singhalese");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Singhalese", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Singhalese", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Siswati, "Siswati");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Siswati", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Siswati", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Slovak, "Slovak");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Slovak", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Slovak", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Slovenian, "Slovenian");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Slovenian", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Slovenian", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Somali, "Somali");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Somali", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Somali", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Spanish, "Spanish");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Spanish", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Spanish", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Sundanese, "Sundanese");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Sundanese", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Sundanese", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Swahili, "Swahili");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Swahili", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Swahili", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Swedish, "Swedish");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Swedish", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Swedish", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Tagalog, "Tagalog");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Tagalog", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Tagalog", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Tajik, "Tajik");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Tajik", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Tajik", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Tamil, "Tamil");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Tamil", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Tamil", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Tatar, "Tatar");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Tatar", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Tatar", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Telugu, "Telugu");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Telugu", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Telugu", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Thai, "Thai");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Thai", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Thai", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Tibetan, "Tibetan");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Tibetan", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Tibetan", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Tigrinya, "Tigrinya");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Tigrinya", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Tigrinya", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::TongaLanguage, "TongaLanguage");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"TongaLanguage", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"TongaLanguage", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Tsonga, "Tsonga");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Tsonga", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Tsonga", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Turkish, "Turkish");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Turkish", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Turkish", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Turkmen, "Turkmen");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Turkmen", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Turkmen", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Twi, "Twi");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Twi", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Twi", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Uigur, "Uigur");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Uigur", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Uigur", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Ukrainian, "Ukrainian");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Ukrainian", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Ukrainian", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Urdu, "Urdu");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Urdu", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Urdu", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Uzbek, "Uzbek");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Uzbek", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Uzbek", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Vietnamese, "Vietnamese");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Vietnamese", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Vietnamese", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Volapuk, "Volapuk");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Volapuk", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Volapuk", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Welsh, "Welsh");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Welsh", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Welsh", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Wolof, "Wolof");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Wolof", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Wolof", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Xhosa, "Xhosa");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Xhosa", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Xhosa", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Yiddish, "Yiddish");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Yiddish", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Yiddish", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Yoruba, "Yoruba");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Yoruba", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Yoruba", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Zhuang, "Zhuang");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Zhuang", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Zhuang", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Zulu, "Zulu");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Zulu", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Zulu", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::NorwegianNynorsk, "NorwegianNynorsk");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"NorwegianNynorsk", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"NorwegianNynorsk", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Nynorsk, "Nynorsk");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Nynorsk", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Nynorsk", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Bosnian, "Bosnian");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Bosnian", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Bosnian", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Divehi, "Divehi");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Divehi", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Divehi", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Manx, "Manx");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Manx", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Manx", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Cornish, "Cornish");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Cornish", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Cornish", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Akan, "Akan");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Akan", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Akan", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Konkani, "Konkani");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Konkani", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Konkani", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Ga, "Ga");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Ga", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Ga", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Igbo, "Igbo");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Igbo", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Igbo", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Kamba, "Kamba");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Kamba", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Kamba", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Syriac, "Syriac");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Syriac", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Syriac", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Blin, "Blin");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Blin", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Blin", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Geez, "Geez");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Geez", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Geez", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Koro, "Koro");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Koro", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Koro", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Sidamo, "Sidamo");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Sidamo", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Sidamo", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Atsam, "Atsam");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Atsam", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Atsam", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Tigre, "Tigre");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Tigre", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Tigre", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Jju, "Jju");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Jju", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Jju", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Friulian, "Friulian");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Friulian", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Friulian", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Venda, "Venda");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Venda", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Venda", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Ewe, "Ewe");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Ewe", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Ewe", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Walamo, "Walamo");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Walamo", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Walamo", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Hawaiian, "Hawaiian");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Hawaiian", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Hawaiian", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Tyap, "Tyap");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Tyap", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Tyap", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Chewa, "Chewa");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Chewa", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Chewa", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Filipino, "Filipino");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Filipino", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Filipino", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::SwissGerman, "SwissGerman");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"SwissGerman", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"SwissGerman", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::SichuanYi, "SichuanYi");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"SichuanYi", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"SichuanYi", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Kpelle, "Kpelle");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Kpelle", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Kpelle", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::LowGerman, "LowGerman");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"LowGerman", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"LowGerman", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::SouthNdebele, "SouthNdebele");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"SouthNdebele", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"SouthNdebele", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::NorthernSotho, "NorthernSotho");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"NorthernSotho", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"NorthernSotho", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::NorthernSami, "NorthernSami");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"NorthernSami", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"NorthernSami", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Taroko, "Taroko");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Taroko", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Taroko", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Gusii, "Gusii");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Gusii", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Gusii", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Taita, "Taita");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Taita", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Taita", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Fulah, "Fulah");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Fulah", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Fulah", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Kikuyu, "Kikuyu");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Kikuyu", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Kikuyu", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Samburu, "Samburu");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Samburu", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Samburu", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Sena, "Sena");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Sena", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Sena", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::NorthNdebele, "NorthNdebele");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"NorthNdebele", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"NorthNdebele", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Rombo, "Rombo");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Rombo", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Rombo", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Tachelhit, "Tachelhit");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Tachelhit", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Tachelhit", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Kabyle, "Kabyle");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Kabyle", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Kabyle", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Nyankole, "Nyankole");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Nyankole", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Nyankole", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Bena, "Bena");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Bena", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Bena", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Vunjo, "Vunjo");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Vunjo", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Vunjo", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Bambara, "Bambara");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Bambara", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Bambara", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Embu, "Embu");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Embu", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Embu", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Cherokee, "Cherokee");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Cherokee", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Cherokee", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Morisyen, "Morisyen");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Morisyen", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Morisyen", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Makonde, "Makonde");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Makonde", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Makonde", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Langi, "Langi");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Langi", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Langi", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Ganda, "Ganda");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Ganda", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Ganda", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Bemba, "Bemba");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Bemba", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Bemba", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Kabuverdianu, "Kabuverdianu");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Kabuverdianu", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Kabuverdianu", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Meru, "Meru");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Meru", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Meru", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Kalenjin, "Kalenjin");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Kalenjin", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Kalenjin", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Nama, "Nama");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Nama", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Nama", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Machame, "Machame");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Machame", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Machame", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Colognian, "Colognian");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Colognian", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Colognian", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Masai, "Masai");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Masai", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Masai", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Soga, "Soga");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Soga", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Soga", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Luyia, "Luyia");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Luyia", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Luyia", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Asu, "Asu");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Asu", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Asu", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Teso, "Teso");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Teso", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Teso", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Saho, "Saho");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Saho", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Saho", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::KoyraChiini, "KoyraChiini");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"KoyraChiini", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"KoyraChiini", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Rwa, "Rwa");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Rwa", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Rwa", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Luo, "Luo");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Luo", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Luo", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Chiga, "Chiga");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Chiga", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Chiga", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::CentralMoroccoTamazight, "CentralMoroccoTamazight");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"CentralMoroccoTamazight", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"CentralMoroccoTamazight", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::KoyraboroSenni, "KoyraboroSenni");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"KoyraboroSenni", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"KoyraboroSenni", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::Shambala, "Shambala");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"Shambala", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"Shambala", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QLocale_Language,(long) QLocale::LastLanguage, "LastLanguage");
    PyDict_SetItemString(Sbk_QLocale_Type.super.ht_type.tp_dict,"LastLanguage", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QLocale_Language->tp_dict,"LastLanguage", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QLocale::Language");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::Language");
    // end of enum Language


    Shiboken::TypeResolver::createValueTypeResolver<QLocale >("QLocale");
    Shiboken::TypeResolver::createObjectTypeResolver<QLocale >("QLocale*");
    Shiboken::TypeResolver::createValueTypeResolver<QLocale >(typeid(QLocale).name());
    PySide::initQtMetaType< ::QLocale >();
    qRegisterMetaType< ::QLocale::MeasurementSystem >("QLocale::MeasurementSystem");
    qRegisterMetaType< ::QLocale::NumberOption >("QLocale::NumberOption");
    qRegisterMetaType< ::QLocale::NumberOptions >("QLocale::NumberOptions");
    qRegisterMetaType< ::QLocale::FormatType >("QLocale::FormatType");
    qRegisterMetaType< ::QLocale::Country >("QLocale::Country");
    qRegisterMetaType< ::QLocale::Language >("QLocale::Language");
}

