/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include "pyside_qtgui_python.h"

#include "qstyle_wrapper.h"

// Extra includes
#include <QList>
#include <qapplication.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qicon.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qpainter.h>
#include <qpalette.h>
#include <qpixmap.h>
#include <qpoint.h>
#include <qrect.h>
#include <qsize.h>
#include <qstyle.h>
#include <qstyleoption.h>
#include <qthread.h>
#include <qwidget.h>


// Native ---------------------------------------------------------

QStyleWrapper::QStyleWrapper() : QStyle() {
    // ... middle
}

void QStyleWrapper::childEvent(QChildEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "childEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::childEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QChildEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QStyleWrapper::connectNotify(const char * signal)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "connectNotify"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QStyleWrapper::customEvent(QEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "customEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::customEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QStyleWrapper::disconnectNotify(const char * signal)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "disconnectNotify"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QStyleWrapper::drawComplexControl(QStyle::ComplexControl cc, const QStyleOptionComplex * opt, QPainter * p, const QWidget * widget) const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "drawComplexControl"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QStyle.drawComplexControl()' not implemented.");
        return ;
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NNNN)",
        Shiboken::Converter< ::QStyle::ComplexControl >::toPython(cc),
        Shiboken::Converter< ::QStyleOptionComplex * >::toPython(opt),
        Shiboken::Converter< ::QPainter * >::toPython(p),
        Shiboken::Converter< ::QWidget * >::toPython(widget)
    ));
    bool invalidadeArg3 = PyTuple_GET_ITEM(pyargs, 2)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg3)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 2));
}

void QStyleWrapper::drawControl(QStyle::ControlElement element, const QStyleOption * opt, QPainter * p, const QWidget * w) const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "drawControl"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QStyle.drawControl()' not implemented.");
        return ;
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NNNN)",
        Shiboken::Converter< ::QStyle::ControlElement >::toPython(element),
        Shiboken::Converter< ::QStyleOption * >::toPython(opt),
        Shiboken::Converter< ::QPainter * >::toPython(p),
        Shiboken::Converter< ::QWidget * >::toPython(w)
    ));
    bool invalidadeArg3 = PyTuple_GET_ITEM(pyargs, 2)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg3)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 2));
}

void QStyleWrapper::drawItemPixmap(QPainter * painter, const QRect & rect, int alignment, const QPixmap & pixmap) const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "drawItemPixmap"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QStyle::drawItemPixmap(painter, rect, alignment, pixmap);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NNiN)",
        Shiboken::Converter< ::QPainter * >::toPython(painter),
        Shiboken::Converter< ::QRect >::toPython(rect),
        alignment,
        Shiboken::Converter< ::QPixmap >::toPython(pixmap)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QStyleWrapper::drawItemText(QPainter * painter, const QRect & rect, int flags, const QPalette & pal, bool enabled, const QString & text, QPalette::ColorRole textRole) const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "drawItemText"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QStyle::drawItemText(painter, rect, flags, pal, enabled, text, textRole);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NNiNNNN)",
        Shiboken::Converter< ::QPainter * >::toPython(painter),
        Shiboken::Converter< ::QRect >::toPython(rect),
        flags,
        Shiboken::Converter< ::QPalette >::toPython(pal),
        Shiboken::Converter< bool >::toPython(enabled),
        Shiboken::Converter< QString >::toPython(text),
        Shiboken::Converter< ::QPalette::ColorRole >::toPython(textRole)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QStyleWrapper::drawPrimitive(QStyle::PrimitiveElement pe, const QStyleOption * opt, QPainter * p, const QWidget * w) const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "drawPrimitive"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QStyle.drawPrimitive()' not implemented.");
        return ;
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NNNN)",
        Shiboken::Converter< ::QStyle::PrimitiveElement >::toPython(pe),
        Shiboken::Converter< ::QStyleOption * >::toPython(opt),
        Shiboken::Converter< ::QPainter * >::toPython(p),
        Shiboken::Converter< ::QWidget * >::toPython(w)
    ));
    bool invalidadeArg3 = PyTuple_GET_ITEM(pyargs, 2)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg3)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 2));
}

bool QStyleWrapper::event(QEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return bool(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "event"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::event(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QStyle.event", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
    return cppResult;
}

bool QStyleWrapper::eventFilter(QObject * arg__1, QEvent * arg__2)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return bool(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "eventFilter"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::eventFilter(arg__1, arg__2);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter< ::QObject * >::toPython(arg__1),
        Shiboken::Converter< ::QEvent * >::toPython(arg__2)
    ));
    bool invalidadeArg2 = PyTuple_GET_ITEM(pyargs, 1)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QStyle.eventFilter", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    if (invalidadeArg2)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 1));
    return cppResult;
}

QPixmap QStyleWrapper::generatedIconPixmap(QIcon::Mode iconMode, const QPixmap & pixmap, const QStyleOption * opt) const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return QPixmap();
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "generatedIconPixmap"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QStyle.generatedIconPixmap()' not implemented.");
        return QPixmap();
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NNN)",
        Shiboken::Converter< ::QIcon::Mode >::toPython(iconMode),
        Shiboken::Converter< ::QPixmap >::toPython(pixmap),
        Shiboken::Converter< ::QStyleOption * >::toPython(opt)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QPixmap();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QPixmap >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QStyle.generatedIconPixmap", Shiboken::SbkType<QPixmap >()->tp_name, pyResult->ob_type->tp_name);
        return QPixmap();
    }
    QPixmap cppResult(Shiboken::Converter< ::QPixmap >::toCpp(pyResult));
    return cppResult;
}

QStyle::SubControl QStyleWrapper::hitTestComplexControl(QStyle::ComplexControl cc, const QStyleOptionComplex * opt, const QPoint & pt, const QWidget * widget) const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return QStyle::SubControl();
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "hitTestComplexControl"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QStyle.hitTestComplexControl()' not implemented.");
        return QStyle::SubControl();
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NNNN)",
        Shiboken::Converter< ::QStyle::ComplexControl >::toPython(cc),
        Shiboken::Converter< ::QStyleOptionComplex * >::toPython(opt),
        Shiboken::Converter< ::QPoint >::toPython(pt),
        Shiboken::Converter< ::QWidget * >::toPython(widget)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QStyle::SubControl();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QStyle::SubControl >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QStyle.hitTestComplexControl", Shiboken::SbkType<QStyle::SubControl >()->tp_name, pyResult->ob_type->tp_name);
        return QStyle::SubControl();
    }
    QStyle::SubControl cppResult(Shiboken::Converter< ::QStyle::SubControl >::toCpp(pyResult));
    return cppResult;
}

QRect QStyleWrapper::itemPixmapRect(const QRect & r, int flags, const QPixmap & pixmap) const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return QRect();
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "itemPixmapRect"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QStyle::itemPixmapRect(r, flags, pixmap);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NiN)",
        Shiboken::Converter< ::QRect >::toPython(r),
        flags,
        Shiboken::Converter< ::QPixmap >::toPython(pixmap)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QRect();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QRect >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QStyle.itemPixmapRect", Shiboken::SbkType<QRect >()->tp_name, pyResult->ob_type->tp_name);
        return QRect();
    }
    QRect cppResult(Shiboken::Converter< ::QRect >::toCpp(pyResult));
    return cppResult;
}

int QStyleWrapper::pixelMetric(QStyle::PixelMetric metric, const QStyleOption * option, const QWidget * widget) const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return int(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "pixelMetric"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QStyle.pixelMetric()' not implemented.");
        return int(0);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NNN)",
        Shiboken::Converter< ::QStyle::PixelMetric >::toPython(metric),
        Shiboken::Converter< ::QStyleOption * >::toPython(option),
        Shiboken::Converter< ::QWidget * >::toPython(widget)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return int(0);
    }
    // Check return type
    bool typeIsValid = PyInt_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QStyle.pixelMetric", "int", pyResult->ob_type->tp_name);
        return int(0);
    }
    int cppResult(Shiboken::Converter< int >::toCpp(pyResult));
    return cppResult;
}

void QStyleWrapper::polish(QApplication * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "polish"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QStyle::polish(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QApplication * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QStyleWrapper::polish(QPalette & arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "polish"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QStyle::polish(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QPalette & >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QStyleWrapper::polish(QWidget * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "polish"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QStyle::polish(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QWidget * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

QSize QStyleWrapper::sizeFromContents(QStyle::ContentsType ct, const QStyleOption * opt, const QSize & contentsSize, const QWidget * w) const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return QSize();
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "sizeFromContents"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QStyle.sizeFromContents()' not implemented.");
        return QSize();
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NNNN)",
        Shiboken::Converter< ::QStyle::ContentsType >::toPython(ct),
        Shiboken::Converter< ::QStyleOption * >::toPython(opt),
        Shiboken::Converter< ::QSize >::toPython(contentsSize),
        Shiboken::Converter< ::QWidget * >::toPython(w)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QSize();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QSize >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QStyle.sizeFromContents", Shiboken::SbkType<QSize >()->tp_name, pyResult->ob_type->tp_name);
        return QSize();
    }
    QSize cppResult(Shiboken::Converter< ::QSize >::toCpp(pyResult));
    return cppResult;
}

QPalette QStyleWrapper::standardPalette() const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return QPalette();
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "standardPalette"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QStyle::standardPalette();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QPalette();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QPalette >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QStyle.standardPalette", Shiboken::SbkType<QPalette >()->tp_name, pyResult->ob_type->tp_name);
        return QPalette();
    }
    QPalette cppResult(Shiboken::Converter< ::QPalette >::toCpp(pyResult));
    return cppResult;
}

QPixmap QStyleWrapper::standardPixmap(QStyle::StandardPixmap standardPixmap, const QStyleOption * opt, const QWidget * widget) const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return QPixmap();
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "standardPixmap"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QStyle.standardPixmap()' not implemented.");
        return QPixmap();
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NNN)",
        Shiboken::Converter< ::QStyle::StandardPixmap >::toPython(standardPixmap),
        Shiboken::Converter< ::QStyleOption * >::toPython(opt),
        Shiboken::Converter< ::QWidget * >::toPython(widget)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QPixmap();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QPixmap >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QStyle.standardPixmap", Shiboken::SbkType<QPixmap >()->tp_name, pyResult->ob_type->tp_name);
        return QPixmap();
    }
    QPixmap cppResult(Shiboken::Converter< ::QPixmap >::toCpp(pyResult));
    return cppResult;
}

int QStyleWrapper::styleHint(QStyle::StyleHint stylehint, const QStyleOption * opt, const QWidget * widget, QStyleHintReturn * returnData) const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return int(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "styleHint"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QStyle.styleHint()' not implemented.");
        return int(0);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NNNN)",
        Shiboken::Converter< ::QStyle::StyleHint >::toPython(stylehint),
        Shiboken::Converter< ::QStyleOption * >::toPython(opt),
        Shiboken::Converter< ::QWidget * >::toPython(widget),
        Shiboken::Converter< ::QStyleHintReturn * >::toPython(returnData)
    ));
    bool invalidadeArg4 = PyTuple_GET_ITEM(pyargs, 3)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return int(0);
    }
    // Check return type
    bool typeIsValid = PyInt_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QStyle.styleHint", "int", pyResult->ob_type->tp_name);
        return int(0);
    }
    int cppResult(Shiboken::Converter< int >::toCpp(pyResult));
    if (invalidadeArg4)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 3));
    return cppResult;
}

QRect QStyleWrapper::subControlRect(QStyle::ComplexControl cc, const QStyleOptionComplex * opt, QStyle::SubControl sc, const QWidget * widget) const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return QRect();
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "subControlRect"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QStyle.subControlRect()' not implemented.");
        return QRect();
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NNNN)",
        Shiboken::Converter< ::QStyle::ComplexControl >::toPython(cc),
        Shiboken::Converter< ::QStyleOptionComplex * >::toPython(opt),
        Shiboken::Converter< ::QStyle::SubControl >::toPython(sc),
        Shiboken::Converter< ::QWidget * >::toPython(widget)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QRect();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QRect >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QStyle.subControlRect", Shiboken::SbkType<QRect >()->tp_name, pyResult->ob_type->tp_name);
        return QRect();
    }
    QRect cppResult(Shiboken::Converter< ::QRect >::toCpp(pyResult));
    return cppResult;
}

QRect QStyleWrapper::subElementRect(QStyle::SubElement subElement, const QStyleOption * option, const QWidget * widget) const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return QRect();
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "subElementRect"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QStyle.subElementRect()' not implemented.");
        return QRect();
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NNN)",
        Shiboken::Converter< ::QStyle::SubElement >::toPython(subElement),
        Shiboken::Converter< ::QStyleOption * >::toPython(option),
        Shiboken::Converter< ::QWidget * >::toPython(widget)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QRect();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QRect >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QStyle.subElementRect", Shiboken::SbkType<QRect >()->tp_name, pyResult->ob_type->tp_name);
        return QRect();
    }
    QRect cppResult(Shiboken::Converter< ::QRect >::toCpp(pyResult));
    return cppResult;
}

void QStyleWrapper::timerEvent(QTimerEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "timerEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::timerEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QTimerEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QStyleWrapper::unpolish(QApplication * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "unpolish"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QStyle::unpolish(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QApplication * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QStyleWrapper::unpolish(QWidget * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "unpolish"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QStyle::unpolish(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QWidget * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

const QMetaObject* QStyleWrapper::metaObject() const
{
    SbkObject* pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    return reinterpret_cast<QMetaObject*>(Shiboken::Object::getTypeUserData(pySelf));
}

int QStyleWrapper::qt_metacall(QMetaObject::Call call, int id, void** args)
{
    int result = QStyle::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

QStyleWrapper::~QStyleWrapper()
{
    SbkObject* wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QStyle_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QStyle >()))
        return -1;

    QStyleWrapper* cptr = 0;
    const char** argNames = 0;
    const QMetaObject* metaObject;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);
    SbkObjectType* type = reinterpret_cast<SbkObjectType*>(self->ob_type);
    SbkObjectType* myType = reinterpret_cast<SbkObjectType*>(SbkPySide_QtGuiTypes[SBK_QSTYLE_IDX]);
    if (type == myType) {
        PyErr_SetString(PyExc_NotImplementedError,
            "'QStyle' represents a C++ abstract class and cannot be instantiated");
        return -1;
    }


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // QStyle()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new QStyleWrapper();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QStyle >(), cptr)) {
        delete cptr;
        return -1;
    }
    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    metaObject = cptr->metaObject(); // <- init python qt properties
    if (kwds && !PySide::fillQtProperties(self, metaObject, kwds, argNames, 0))
        return -1;


    return 1;
}

static PyObject* Sbk_QStyleFunc_alignedRect(PyObject* self, PyObject* args)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "alignedRect", 4, 4, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: alignedRect(Qt::LayoutDirection,QFlags<Qt::AlignmentFlag>,QSize,QRect)
    if (numArgs == 4 && Shiboken::Converter< ::Qt::LayoutDirection >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QFlags<Qt::AlignmentFlag> >::isConvertible(pyargs[1]) && Shiboken::Converter< ::QSize >::isConvertible(pyargs[2]) && Shiboken::Converter< ::QRect >::isConvertible(pyargs[3])) {
        overloadId = 0; // alignedRect(Qt::LayoutDirection,QFlags<Qt::AlignmentFlag>,QSize,QRect)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QStyleFunc_alignedRect_TypeError;

    // Call function/method
    {
        {
            Qt::LayoutDirection cppArg0 = Shiboken::Converter<Qt::LayoutDirection >::toCpp(pyargs[0]);
            QFlags<Qt::AlignmentFlag> cppArg1 = Shiboken::Converter<QFlags<Qt::AlignmentFlag> >::toCpp(pyargs[1]);
            if (!Shiboken::Object::isValid(pyargs[2]))
                return 0;
            QSize cppArg2 = Shiboken::Converter<QSize >::toCpp(pyargs[2]);
            if (!Shiboken::Object::isValid(pyargs[3]))
                return 0;
            QRect cppArg3 = Shiboken::Converter<QRect >::toCpp(pyargs[3]);

            if(!PyErr_Occurred()) {
                // alignedRect(Qt::LayoutDirection,QFlags<Qt::AlignmentFlag>,QSize,QRect)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QRect cppResult = QStyle::alignedRect(cppArg0, cppArg1, cppArg2, cppArg3);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QRect >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QStyleFunc_alignedRect_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.LayoutDirection, PySide.QtCore.Qt.Alignment, PySide.QtCore.QSize, PySide.QtCore.QRect", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QStyle.alignedRect", overloads);
        return 0;
}

static PyObject* Sbk_QStyleFunc_combinedLayoutSpacing(PyObject* self, PyObject* args, PyObject* kwds)
{
    QStyle* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QStyle* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 5) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QStyle.combinedLayoutSpacing(): too many arguments");
        return 0;
    } else if (numArgs < 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QStyle.combinedLayoutSpacing(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOOOO:combinedLayoutSpacing", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4])))
        return 0;


    // Overloaded function decisor
    // 0: combinedLayoutSpacing(QFlags<QSizePolicy::ControlType>,QFlags<QSizePolicy::ControlType>,Qt::Orientation,QStyleOption*,QWidget*)const
    if (numArgs >= 3 && Shiboken::Converter< ::QFlags<QSizePolicy::ControlType> >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QFlags<QSizePolicy::ControlType> >::isConvertible(pyargs[1]) && Shiboken::Converter< ::Qt::Orientation >::isConvertible(pyargs[2])) {
        if (numArgs == 3) {
            overloadId = 0; // combinedLayoutSpacing(QFlags<QSizePolicy::ControlType>,QFlags<QSizePolicy::ControlType>,Qt::Orientation,QStyleOption*,QWidget*)const
        } else if (Shiboken::Converter< ::QStyleOption * >::isConvertible(pyargs[3])) {
            if (numArgs == 4) {
                overloadId = 0; // combinedLayoutSpacing(QFlags<QSizePolicy::ControlType>,QFlags<QSizePolicy::ControlType>,Qt::Orientation,QStyleOption*,QWidget*)const
            } else if (Shiboken::Converter< ::QWidget * >::isConvertible(pyargs[4])) {
                overloadId = 0; // combinedLayoutSpacing(QFlags<QSizePolicy::ControlType>,QFlags<QSizePolicy::ControlType>,Qt::Orientation,QStyleOption*,QWidget*)const
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QStyleFunc_combinedLayoutSpacing_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "option");
                if (value) {
                    if (pyargs[3])
                        errorArgName = "option";
                    else if (Shiboken::Converter< ::QStyleOption * >::isConvertible(value))
                        pyargs[3] = value;
                    else
                        goto Sbk_QStyleFunc_combinedLayoutSpacing_TypeError;
                }
                value = PyDict_GetItemString(kwds, "widget");
                if (value) {
                    if (pyargs[4])
                        errorArgName = "widget";
                    else if (Shiboken::Converter< ::QWidget * >::isConvertible(value))
                        pyargs[4] = value;
                    else
                        goto Sbk_QStyleFunc_combinedLayoutSpacing_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QStyle.combinedLayoutSpacing(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QFlags<QSizePolicy::ControlType> cppArg0 = Shiboken::Converter<QFlags<QSizePolicy::ControlType> >::toCpp(pyargs[0]);
            QFlags<QSizePolicy::ControlType> cppArg1 = Shiboken::Converter<QFlags<QSizePolicy::ControlType> >::toCpp(pyargs[1]);
            Qt::Orientation cppArg2 = Shiboken::Converter<Qt::Orientation >::toCpp(pyargs[2]);
            if (!Shiboken::Object::isValid(pyargs[3]))
                return 0;
            QStyleOption * cppArg3 = pyargs[3] ? Shiboken::Converter<QStyleOption * >::toCpp(pyargs[3]) : 0;
            if (!Shiboken::Object::isValid(pyargs[4]))
                return 0;
            QWidget * cppArg4 = pyargs[4] ? Shiboken::Converter<QWidget * >::toCpp(pyargs[4]) : 0;

            if(!PyErr_Occurred()) {
                // combinedLayoutSpacing(QFlags<QSizePolicy::ControlType>,QFlags<QSizePolicy::ControlType>,Qt::Orientation,QStyleOption*,QWidget*)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QStyle*>(cppSelf)->combinedLayoutSpacing(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QStyleFunc_combinedLayoutSpacing_TypeError:
        const char* overloads[] = {"PySide.QtGui.QSizePolicy.ControlTypes, PySide.QtGui.QSizePolicy.ControlTypes, PySide.QtCore.Qt.Orientation, PySide.QtGui.QStyleOption = None, PySide.QtGui.QWidget = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QStyle.combinedLayoutSpacing", overloads);
        return 0;
}

static PyObject* Sbk_QStyleFunc_drawComplexControl(PyObject* self, PyObject* args, PyObject* kwds)
{
    QStyle* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QStyle* >::toCpp(self);

    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 4) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QStyle.drawComplexControl(): too many arguments");
        return 0;
    } else if (numArgs < 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QStyle.drawComplexControl(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOOO:drawComplexControl", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: drawComplexControl(QStyle::ComplexControl,const QStyleOptionComplex*,QPainter*,const QWidget*)const
    if (numArgs >= 3 && Shiboken::Converter< ::QStyle::ComplexControl >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QStyleOptionComplex * >::isConvertible(pyargs[1]) && Shiboken::Converter< ::QPainter * >::isConvertible(pyargs[2])) {
        if (numArgs == 3) {
            overloadId = 0; // drawComplexControl(QStyle::ComplexControl,const QStyleOptionComplex*,QPainter*,const QWidget*)const
        } else if (Shiboken::Converter< ::QWidget * >::isConvertible(pyargs[3])) {
            overloadId = 0; // drawComplexControl(QStyle::ComplexControl,const QStyleOptionComplex*,QPainter*,const QWidget*)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QStyleFunc_drawComplexControl_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "widget");
                if (value) {
                    if (pyargs[3])
                        errorArgName = "widget";
                    else if (Shiboken::Converter< ::QWidget * >::isConvertible(value))
                        pyargs[3] = value;
                    else
                        goto Sbk_QStyleFunc_drawComplexControl_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QStyle.drawComplexControl(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QStyle::ComplexControl cppArg0 = Shiboken::Converter<QStyle::ComplexControl >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            QStyleOptionComplex * cppArg1 = Shiboken::Converter<QStyleOptionComplex * >::toCpp(pyargs[1]);
            if (!Shiboken::Object::isValid(pyargs[2]))
                return 0;
            QPainter * cppArg2 = Shiboken::Converter<QPainter * >::toCpp(pyargs[2]);
            if (!Shiboken::Object::isValid(pyargs[3]))
                return 0;
            QWidget * cppArg3 = pyargs[3] ? Shiboken::Converter<QWidget * >::toCpp(pyargs[3]) : 0;

            if(!PyErr_Occurred()) {
                // drawComplexControl(QStyle::ComplexControl,const QStyleOptionComplex*,QPainter*,const QWidget*)const
                if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self))) {
                    PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QStyle.drawComplexControl()' not implemented.");
                    return 0;
                }
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                const_cast<const QStyle*>(cppSelf)->drawComplexControl(cppArg0, cppArg1, cppArg2, cppArg3);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QStyleFunc_drawComplexControl_TypeError:
        const char* overloads[] = {"PySide.QtGui.QStyle.ComplexControl, PySide.QtGui.QStyleOptionComplex, PySide.QtGui.QPainter, PySide.QtGui.QWidget = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QStyle.drawComplexControl", overloads);
        return 0;
}

static PyObject* Sbk_QStyleFunc_drawControl(PyObject* self, PyObject* args, PyObject* kwds)
{
    QStyle* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QStyle* >::toCpp(self);

    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 4) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QStyle.drawControl(): too many arguments");
        return 0;
    } else if (numArgs < 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QStyle.drawControl(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOOO:drawControl", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: drawControl(QStyle::ControlElement,const QStyleOption*,QPainter*,const QWidget*)const
    if (numArgs >= 3 && Shiboken::Converter< ::QStyle::ControlElement >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QStyleOption * >::isConvertible(pyargs[1]) && Shiboken::Converter< ::QPainter * >::isConvertible(pyargs[2])) {
        if (numArgs == 3) {
            overloadId = 0; // drawControl(QStyle::ControlElement,const QStyleOption*,QPainter*,const QWidget*)const
        } else if (Shiboken::Converter< ::QWidget * >::isConvertible(pyargs[3])) {
            overloadId = 0; // drawControl(QStyle::ControlElement,const QStyleOption*,QPainter*,const QWidget*)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QStyleFunc_drawControl_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "w");
                if (value) {
                    if (pyargs[3])
                        errorArgName = "w";
                    else if (Shiboken::Converter< ::QWidget * >::isConvertible(value))
                        pyargs[3] = value;
                    else
                        goto Sbk_QStyleFunc_drawControl_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QStyle.drawControl(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QStyle::ControlElement cppArg0 = Shiboken::Converter<QStyle::ControlElement >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            QStyleOption * cppArg1 = Shiboken::Converter<QStyleOption * >::toCpp(pyargs[1]);
            if (!Shiboken::Object::isValid(pyargs[2]))
                return 0;
            QPainter * cppArg2 = Shiboken::Converter<QPainter * >::toCpp(pyargs[2]);
            if (!Shiboken::Object::isValid(pyargs[3]))
                return 0;
            QWidget * cppArg3 = pyargs[3] ? Shiboken::Converter<QWidget * >::toCpp(pyargs[3]) : 0;

            if(!PyErr_Occurred()) {
                // drawControl(QStyle::ControlElement,const QStyleOption*,QPainter*,const QWidget*)const
                if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self))) {
                    PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QStyle.drawControl()' not implemented.");
                    return 0;
                }
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                const_cast<const QStyle*>(cppSelf)->drawControl(cppArg0, cppArg1, cppArg2, cppArg3);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QStyleFunc_drawControl_TypeError:
        const char* overloads[] = {"PySide.QtGui.QStyle.ControlElement, PySide.QtGui.QStyleOption, PySide.QtGui.QPainter, PySide.QtGui.QWidget = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QStyle.drawControl", overloads);
        return 0;
}

static PyObject* Sbk_QStyleFunc_drawItemPixmap(PyObject* self, PyObject* args)
{
    QStyle* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QStyle* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "drawItemPixmap", 4, 4, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: drawItemPixmap(QPainter*,QRect,int,QPixmap)const
    if (numArgs == 4 && Shiboken::Converter< ::QPainter * >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QRect >::isConvertible(pyargs[1]) && SbkNumber_Check(pyargs[2]) && Shiboken::Converter< ::QPixmap >::isConvertible(pyargs[3])) {
        overloadId = 0; // drawItemPixmap(QPainter*,QRect,int,QPixmap)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QStyleFunc_drawItemPixmap_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QPainter * cppArg0 = Shiboken::Converter<QPainter * >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            QRect cppArg1 = Shiboken::Converter<QRect >::toCpp(pyargs[1]);
            int cppArg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);
            if (!Shiboken::Object::isValid(pyargs[3]))
                return 0;
            QPixmap cppArg3 = Shiboken::Converter<QPixmap >::toCpp(pyargs[3]);

            if(!PyErr_Occurred()) {
                // drawItemPixmap(QPainter*,QRect,int,QPixmap)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? const_cast<const QStyle*>(cppSelf)->::QStyle::drawItemPixmap(cppArg0, cppArg1, cppArg2, cppArg3) : const_cast<const QStyle*>(cppSelf)->drawItemPixmap(cppArg0, cppArg1, cppArg2, cppArg3));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QStyleFunc_drawItemPixmap_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPainter, PySide.QtCore.QRect, int, PySide.QtGui.QPixmap", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QStyle.drawItemPixmap", overloads);
        return 0;
}

static PyObject* Sbk_QStyleFunc_drawItemText(PyObject* self, PyObject* args, PyObject* kwds)
{
    QStyle* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QStyle* >::toCpp(self);

    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 7) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QStyle.drawItemText(): too many arguments");
        return 0;
    } else if (numArgs < 6) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QStyle.drawItemText(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOOOOOO:drawItemText", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4]), &(pyargs[5]), &(pyargs[6])))
        return 0;


    // Overloaded function decisor
    // 0: drawItemText(QPainter*,QRect,int,QPalette,bool,QString,QPalette::ColorRole)const
    if (numArgs >= 6 && Shiboken::Converter< ::QPainter * >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QRect >::isConvertible(pyargs[1]) && SbkNumber_Check(pyargs[2]) && Shiboken::Converter< ::QPalette >::isConvertible(pyargs[3]) && SbkNumber_Check(pyargs[4]) && Shiboken::Converter< QString >::isConvertible(pyargs[5])) {
        if (numArgs == 6) {
            overloadId = 0; // drawItemText(QPainter*,QRect,int,QPalette,bool,QString,QPalette::ColorRole)const
        } else if (Shiboken::Converter< ::QPalette::ColorRole >::isConvertible(pyargs[6])) {
            overloadId = 0; // drawItemText(QPainter*,QRect,int,QPalette,bool,QString,QPalette::ColorRole)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QStyleFunc_drawItemText_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "textRole");
                if (value) {
                    if (pyargs[6])
                        errorArgName = "textRole";
                    else if (Shiboken::Converter< ::QPalette::ColorRole >::isConvertible(value))
                        pyargs[6] = value;
                    else
                        goto Sbk_QStyleFunc_drawItemText_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QStyle.drawItemText(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QPainter * cppArg0 = Shiboken::Converter<QPainter * >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            QRect cppArg1 = Shiboken::Converter<QRect >::toCpp(pyargs[1]);
            int cppArg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);
            if (!Shiboken::Object::isValid(pyargs[3]))
                return 0;
            QPalette cppArg3 = Shiboken::Converter<QPalette >::toCpp(pyargs[3]);
            bool cppArg4 = Shiboken::Converter<bool >::toCpp(pyargs[4]);
            QString cppArg5 = Shiboken::Converter<QString >::toCpp(pyargs[5]);
            QPalette::ColorRole cppArg6 = pyargs[6] ? Shiboken::Converter<QPalette::ColorRole >::toCpp(pyargs[6]) : QPalette::NoRole;

            if(!PyErr_Occurred()) {
                // drawItemText(QPainter*,QRect,int,QPalette,bool,QString,QPalette::ColorRole)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? const_cast<const QStyle*>(cppSelf)->::QStyle::drawItemText(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5, cppArg6) : const_cast<const QStyle*>(cppSelf)->drawItemText(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5, cppArg6));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QStyleFunc_drawItemText_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPainter, PySide.QtCore.QRect, int, PySide.QtGui.QPalette, bool, QString, PySide.QtGui.QPalette.ColorRole = QPalette.NoRole", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QStyle.drawItemText", overloads);
        return 0;
}

static PyObject* Sbk_QStyleFunc_drawPrimitive(PyObject* self, PyObject* args, PyObject* kwds)
{
    QStyle* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QStyle* >::toCpp(self);

    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 4) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QStyle.drawPrimitive(): too many arguments");
        return 0;
    } else if (numArgs < 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QStyle.drawPrimitive(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOOO:drawPrimitive", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: drawPrimitive(QStyle::PrimitiveElement,const QStyleOption*,QPainter*,const QWidget*)const
    if (numArgs >= 3 && Shiboken::Converter< ::QStyle::PrimitiveElement >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QStyleOption * >::isConvertible(pyargs[1]) && Shiboken::Converter< ::QPainter * >::isConvertible(pyargs[2])) {
        if (numArgs == 3) {
            overloadId = 0; // drawPrimitive(QStyle::PrimitiveElement,const QStyleOption*,QPainter*,const QWidget*)const
        } else if (Shiboken::Converter< ::QWidget * >::isConvertible(pyargs[3])) {
            overloadId = 0; // drawPrimitive(QStyle::PrimitiveElement,const QStyleOption*,QPainter*,const QWidget*)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QStyleFunc_drawPrimitive_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "w");
                if (value) {
                    if (pyargs[3])
                        errorArgName = "w";
                    else if (Shiboken::Converter< ::QWidget * >::isConvertible(value))
                        pyargs[3] = value;
                    else
                        goto Sbk_QStyleFunc_drawPrimitive_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QStyle.drawPrimitive(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QStyle::PrimitiveElement cppArg0 = Shiboken::Converter<QStyle::PrimitiveElement >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            QStyleOption * cppArg1 = Shiboken::Converter<QStyleOption * >::toCpp(pyargs[1]);
            if (!Shiboken::Object::isValid(pyargs[2]))
                return 0;
            QPainter * cppArg2 = Shiboken::Converter<QPainter * >::toCpp(pyargs[2]);
            if (!Shiboken::Object::isValid(pyargs[3]))
                return 0;
            QWidget * cppArg3 = pyargs[3] ? Shiboken::Converter<QWidget * >::toCpp(pyargs[3]) : 0;

            if(!PyErr_Occurred()) {
                // drawPrimitive(QStyle::PrimitiveElement,const QStyleOption*,QPainter*,const QWidget*)const
                if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self))) {
                    PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QStyle.drawPrimitive()' not implemented.");
                    return 0;
                }
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                const_cast<const QStyle*>(cppSelf)->drawPrimitive(cppArg0, cppArg1, cppArg2, cppArg3);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QStyleFunc_drawPrimitive_TypeError:
        const char* overloads[] = {"PySide.QtGui.QStyle.PrimitiveElement, PySide.QtGui.QStyleOption, PySide.QtGui.QPainter, PySide.QtGui.QWidget = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QStyle.drawPrimitive", overloads);
        return 0;
}

static PyObject* Sbk_QStyleFunc_generatedIconPixmap(PyObject* self, PyObject* args)
{
    QStyle* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QStyle* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "generatedIconPixmap", 3, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: generatedIconPixmap(QIcon::Mode,QPixmap,const QStyleOption*)const
    if (numArgs == 3 && Shiboken::Converter< ::QIcon::Mode >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QPixmap >::isConvertible(pyargs[1]) && Shiboken::Converter< ::QStyleOption * >::isConvertible(pyargs[2])) {
        overloadId = 0; // generatedIconPixmap(QIcon::Mode,QPixmap,const QStyleOption*)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QStyleFunc_generatedIconPixmap_TypeError;

    // Call function/method
    {
        {
            QIcon::Mode cppArg0 = Shiboken::Converter<QIcon::Mode >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            QPixmap cppArg1 = Shiboken::Converter<QPixmap >::toCpp(pyargs[1]);
            if (!Shiboken::Object::isValid(pyargs[2]))
                return 0;
            QStyleOption * cppArg2 = Shiboken::Converter<QStyleOption * >::toCpp(pyargs[2]);

            if(!PyErr_Occurred()) {
                // generatedIconPixmap(QIcon::Mode,QPixmap,const QStyleOption*)const
                if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self))) {
                    PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QStyle.generatedIconPixmap()' not implemented.");
                    return 0;
                }
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QPixmap cppResult = const_cast<const QStyle*>(cppSelf)->generatedIconPixmap(cppArg0, cppArg1, cppArg2);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QPixmap >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QStyleFunc_generatedIconPixmap_TypeError:
        const char* overloads[] = {"PySide.QtGui.QIcon.Mode, PySide.QtGui.QPixmap, PySide.QtGui.QStyleOption", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QStyle.generatedIconPixmap", overloads);
        return 0;
}

static PyObject* Sbk_QStyleFunc_hitTestComplexControl(PyObject* self, PyObject* args, PyObject* kwds)
{
    QStyle* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QStyle* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 4) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QStyle.hitTestComplexControl(): too many arguments");
        return 0;
    } else if (numArgs < 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QStyle.hitTestComplexControl(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOOO:hitTestComplexControl", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: hitTestComplexControl(QStyle::ComplexControl,const QStyleOptionComplex*,QPoint,const QWidget*)const
    if (numArgs >= 3 && Shiboken::Converter< ::QStyle::ComplexControl >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QStyleOptionComplex * >::isConvertible(pyargs[1]) && Shiboken::Converter< ::QPoint >::isConvertible(pyargs[2])) {
        if (numArgs == 3) {
            overloadId = 0; // hitTestComplexControl(QStyle::ComplexControl,const QStyleOptionComplex*,QPoint,const QWidget*)const
        } else if (Shiboken::Converter< ::QWidget * >::isConvertible(pyargs[3])) {
            overloadId = 0; // hitTestComplexControl(QStyle::ComplexControl,const QStyleOptionComplex*,QPoint,const QWidget*)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QStyleFunc_hitTestComplexControl_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "widget");
                if (value) {
                    if (pyargs[3])
                        errorArgName = "widget";
                    else if (Shiboken::Converter< ::QWidget * >::isConvertible(value))
                        pyargs[3] = value;
                    else
                        goto Sbk_QStyleFunc_hitTestComplexControl_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QStyle.hitTestComplexControl(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QStyle::ComplexControl cppArg0 = Shiboken::Converter<QStyle::ComplexControl >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            QStyleOptionComplex * cppArg1 = Shiboken::Converter<QStyleOptionComplex * >::toCpp(pyargs[1]);
            if (!Shiboken::Object::isValid(pyargs[2]))
                return 0;
            QPoint cppArg2 = Shiboken::Converter<QPoint >::toCpp(pyargs[2]);
            if (!Shiboken::Object::isValid(pyargs[3]))
                return 0;
            QWidget * cppArg3 = pyargs[3] ? Shiboken::Converter<QWidget * >::toCpp(pyargs[3]) : 0;

            if(!PyErr_Occurred()) {
                // hitTestComplexControl(QStyle::ComplexControl,const QStyleOptionComplex*,QPoint,const QWidget*)const
                if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self))) {
                    PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QStyle.hitTestComplexControl()' not implemented.");
                    return 0;
                }
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QStyle::SubControl cppResult = const_cast<const QStyle*>(cppSelf)->hitTestComplexControl(cppArg0, cppArg1, cppArg2, cppArg3);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QStyle::SubControl >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QStyleFunc_hitTestComplexControl_TypeError:
        const char* overloads[] = {"PySide.QtGui.QStyle.ComplexControl, PySide.QtGui.QStyleOptionComplex, PySide.QtCore.QPoint, PySide.QtGui.QWidget = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QStyle.hitTestComplexControl", overloads);
        return 0;
}

static PyObject* Sbk_QStyleFunc_itemPixmapRect(PyObject* self, PyObject* args)
{
    QStyle* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QStyle* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "itemPixmapRect", 3, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: itemPixmapRect(QRect,int,QPixmap)const
    if (numArgs == 3 && Shiboken::Converter< ::QRect >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1]) && Shiboken::Converter< ::QPixmap >::isConvertible(pyargs[2])) {
        overloadId = 0; // itemPixmapRect(QRect,int,QPixmap)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QStyleFunc_itemPixmapRect_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QRect cppArg0 = Shiboken::Converter<QRect >::toCpp(pyargs[0]);
            int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
            if (!Shiboken::Object::isValid(pyargs[2]))
                return 0;
            QPixmap cppArg2 = Shiboken::Converter<QPixmap >::toCpp(pyargs[2]);

            if(!PyErr_Occurred()) {
                // itemPixmapRect(QRect,int,QPixmap)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QRect cppResult = (Shiboken::Object::isUserType(self) ? const_cast<const QStyle*>(cppSelf)->::QStyle::itemPixmapRect(cppArg0, cppArg1, cppArg2) : const_cast<const QStyle*>(cppSelf)->itemPixmapRect(cppArg0, cppArg1, cppArg2));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QRect >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QStyleFunc_itemPixmapRect_TypeError:
        const char* overloads[] = {"PySide.QtCore.QRect, int, PySide.QtGui.QPixmap", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QStyle.itemPixmapRect", overloads);
        return 0;
}

static PyObject* Sbk_QStyleFunc_layoutSpacing(PyObject* self, PyObject* args, PyObject* kwds)
{
    QStyle* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QStyle* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 5) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QStyle.layoutSpacing(): too many arguments");
        return 0;
    } else if (numArgs < 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QStyle.layoutSpacing(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOOOO:layoutSpacing", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4])))
        return 0;


    // Overloaded function decisor
    // 0: layoutSpacing(QSizePolicy::ControlType,QSizePolicy::ControlType,Qt::Orientation,const QStyleOption*,const QWidget*)const
    if (numArgs >= 3 && Shiboken::Converter< ::QSizePolicy::ControlType >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QSizePolicy::ControlType >::isConvertible(pyargs[1]) && Shiboken::Converter< ::Qt::Orientation >::isConvertible(pyargs[2])) {
        if (numArgs == 3) {
            overloadId = 0; // layoutSpacing(QSizePolicy::ControlType,QSizePolicy::ControlType,Qt::Orientation,const QStyleOption*,const QWidget*)const
        } else if (Shiboken::Converter< ::QStyleOption * >::isConvertible(pyargs[3])) {
            if (numArgs == 4) {
                overloadId = 0; // layoutSpacing(QSizePolicy::ControlType,QSizePolicy::ControlType,Qt::Orientation,const QStyleOption*,const QWidget*)const
            } else if (Shiboken::Converter< ::QWidget * >::isConvertible(pyargs[4])) {
                overloadId = 0; // layoutSpacing(QSizePolicy::ControlType,QSizePolicy::ControlType,Qt::Orientation,const QStyleOption*,const QWidget*)const
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QStyleFunc_layoutSpacing_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "option");
                if (value) {
                    if (pyargs[3])
                        errorArgName = "option";
                    else if (Shiboken::Converter< ::QStyleOption * >::isConvertible(value))
                        pyargs[3] = value;
                    else
                        goto Sbk_QStyleFunc_layoutSpacing_TypeError;
                }
                value = PyDict_GetItemString(kwds, "widget");
                if (value) {
                    if (pyargs[4])
                        errorArgName = "widget";
                    else if (Shiboken::Converter< ::QWidget * >::isConvertible(value))
                        pyargs[4] = value;
                    else
                        goto Sbk_QStyleFunc_layoutSpacing_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QStyle.layoutSpacing(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QSizePolicy::ControlType cppArg0 = Shiboken::Converter<QSizePolicy::ControlType >::toCpp(pyargs[0]);
            QSizePolicy::ControlType cppArg1 = Shiboken::Converter<QSizePolicy::ControlType >::toCpp(pyargs[1]);
            Qt::Orientation cppArg2 = Shiboken::Converter<Qt::Orientation >::toCpp(pyargs[2]);
            if (!Shiboken::Object::isValid(pyargs[3]))
                return 0;
            QStyleOption * cppArg3 = pyargs[3] ? Shiboken::Converter<QStyleOption * >::toCpp(pyargs[3]) : 0;
            if (!Shiboken::Object::isValid(pyargs[4]))
                return 0;
            QWidget * cppArg4 = pyargs[4] ? Shiboken::Converter<QWidget * >::toCpp(pyargs[4]) : 0;

            if(!PyErr_Occurred()) {
                // layoutSpacing(QSizePolicy::ControlType,QSizePolicy::ControlType,Qt::Orientation,const QStyleOption*,const QWidget*)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QStyle*>(cppSelf)->layoutSpacing(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QStyleFunc_layoutSpacing_TypeError:
        const char* overloads[] = {"PySide.QtGui.QSizePolicy.ControlType, PySide.QtGui.QSizePolicy.ControlType, PySide.QtCore.Qt.Orientation, PySide.QtGui.QStyleOption = None, PySide.QtGui.QWidget = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QStyle.layoutSpacing", overloads);
        return 0;
}

static PyObject* Sbk_QStyleFunc_layoutSpacingImplementation(PyObject* self, PyObject* args, PyObject* kwds)
{
    QStyle* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QStyle* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 5) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QStyle.layoutSpacingImplementation(): too many arguments");
        return 0;
    } else if (numArgs < 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QStyle.layoutSpacingImplementation(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOOOO:layoutSpacingImplementation", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4])))
        return 0;


    // Overloaded function decisor
    // 0: layoutSpacingImplementation(QSizePolicy::ControlType,QSizePolicy::ControlType,Qt::Orientation,const QStyleOption*,const QWidget*)const
    if (numArgs >= 3 && Shiboken::Converter< ::QSizePolicy::ControlType >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QSizePolicy::ControlType >::isConvertible(pyargs[1]) && Shiboken::Converter< ::Qt::Orientation >::isConvertible(pyargs[2])) {
        if (numArgs == 3) {
            overloadId = 0; // layoutSpacingImplementation(QSizePolicy::ControlType,QSizePolicy::ControlType,Qt::Orientation,const QStyleOption*,const QWidget*)const
        } else if (Shiboken::Converter< ::QStyleOption * >::isConvertible(pyargs[3])) {
            if (numArgs == 4) {
                overloadId = 0; // layoutSpacingImplementation(QSizePolicy::ControlType,QSizePolicy::ControlType,Qt::Orientation,const QStyleOption*,const QWidget*)const
            } else if (Shiboken::Converter< ::QWidget * >::isConvertible(pyargs[4])) {
                overloadId = 0; // layoutSpacingImplementation(QSizePolicy::ControlType,QSizePolicy::ControlType,Qt::Orientation,const QStyleOption*,const QWidget*)const
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QStyleFunc_layoutSpacingImplementation_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "option");
                if (value) {
                    if (pyargs[3])
                        errorArgName = "option";
                    else if (Shiboken::Converter< ::QStyleOption * >::isConvertible(value))
                        pyargs[3] = value;
                    else
                        goto Sbk_QStyleFunc_layoutSpacingImplementation_TypeError;
                }
                value = PyDict_GetItemString(kwds, "widget");
                if (value) {
                    if (pyargs[4])
                        errorArgName = "widget";
                    else if (Shiboken::Converter< ::QWidget * >::isConvertible(value))
                        pyargs[4] = value;
                    else
                        goto Sbk_QStyleFunc_layoutSpacingImplementation_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QStyle.layoutSpacingImplementation(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QSizePolicy::ControlType cppArg0 = Shiboken::Converter<QSizePolicy::ControlType >::toCpp(pyargs[0]);
            QSizePolicy::ControlType cppArg1 = Shiboken::Converter<QSizePolicy::ControlType >::toCpp(pyargs[1]);
            Qt::Orientation cppArg2 = Shiboken::Converter<Qt::Orientation >::toCpp(pyargs[2]);
            if (!Shiboken::Object::isValid(pyargs[3]))
                return 0;
            QStyleOption * cppArg3 = pyargs[3] ? Shiboken::Converter<QStyleOption * >::toCpp(pyargs[3]) : 0;
            if (!Shiboken::Object::isValid(pyargs[4]))
                return 0;
            QWidget * cppArg4 = pyargs[4] ? Shiboken::Converter<QWidget * >::toCpp(pyargs[4]) : 0;

            if(!PyErr_Occurred()) {
                // layoutSpacingImplementation(QSizePolicy::ControlType,QSizePolicy::ControlType,Qt::Orientation,const QStyleOption*,const QWidget*)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QStyle*>(cppSelf)->layoutSpacingImplementation(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QStyleFunc_layoutSpacingImplementation_TypeError:
        const char* overloads[] = {"PySide.QtGui.QSizePolicy.ControlType, PySide.QtGui.QSizePolicy.ControlType, PySide.QtCore.Qt.Orientation, PySide.QtGui.QStyleOption = None, PySide.QtGui.QWidget = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QStyle.layoutSpacingImplementation", overloads);
        return 0;
}

static PyObject* Sbk_QStyleFunc_pixelMetric(PyObject* self, PyObject* args, PyObject* kwds)
{
    QStyle* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QStyle* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QStyle.pixelMetric(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QStyle.pixelMetric(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOO:pixelMetric", &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: pixelMetric(QStyle::PixelMetric,const QStyleOption*,const QWidget*)const
    if (Shiboken::Converter< ::QStyle::PixelMetric >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // pixelMetric(QStyle::PixelMetric,const QStyleOption*,const QWidget*)const
        } else if (Shiboken::Converter< ::QStyleOption * >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 0; // pixelMetric(QStyle::PixelMetric,const QStyleOption*,const QWidget*)const
            } else if (Shiboken::Converter< ::QWidget * >::isConvertible(pyargs[2])) {
                overloadId = 0; // pixelMetric(QStyle::PixelMetric,const QStyleOption*,const QWidget*)const
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QStyleFunc_pixelMetric_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "option");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "option";
                    else if (Shiboken::Converter< ::QStyleOption * >::isConvertible(value))
                        pyargs[1] = value;
                    else
                        goto Sbk_QStyleFunc_pixelMetric_TypeError;
                }
                value = PyDict_GetItemString(kwds, "widget");
                if (value) {
                    if (pyargs[2])
                        errorArgName = "widget";
                    else if (Shiboken::Converter< ::QWidget * >::isConvertible(value))
                        pyargs[2] = value;
                    else
                        goto Sbk_QStyleFunc_pixelMetric_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QStyle.pixelMetric(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QStyle::PixelMetric cppArg0 = Shiboken::Converter<QStyle::PixelMetric >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            QStyleOption * cppArg1 = pyargs[1] ? Shiboken::Converter<QStyleOption * >::toCpp(pyargs[1]) : 0;
            if (!Shiboken::Object::isValid(pyargs[2]))
                return 0;
            QWidget * cppArg2 = pyargs[2] ? Shiboken::Converter<QWidget * >::toCpp(pyargs[2]) : 0;

            if(!PyErr_Occurred()) {
                // pixelMetric(QStyle::PixelMetric,const QStyleOption*,const QWidget*)const
                if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self))) {
                    PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QStyle.pixelMetric()' not implemented.");
                    return 0;
                }
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QStyle*>(cppSelf)->pixelMetric(cppArg0, cppArg1, cppArg2);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QStyleFunc_pixelMetric_TypeError:
        const char* overloads[] = {"PySide.QtGui.QStyle.PixelMetric, PySide.QtGui.QStyleOption = None, PySide.QtGui.QWidget = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QStyle.pixelMetric", overloads);
        return 0;
}

static PyObject* Sbk_QStyleFunc_polish(PyObject* self, PyObject* arg)
{
    QStyle* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QStyle* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: polish(QApplication*)
    // 1: polish(QPalette&)
    // 2: polish(QWidget*)
    if (Shiboken::Converter< ::QWidget * >::isConvertible(arg)) {
        overloadId = 2; // polish(QWidget*)
    } else if (Shiboken::Converter< ::QPalette & >::isConvertible(arg)) {
        overloadId = 1; // polish(QPalette&)
    } else if (Shiboken::Converter< ::QApplication * >::isConvertible(arg)) {
        overloadId = 0; // polish(QApplication*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QStyleFunc_polish_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // polish(QApplication*)
            {
                if (!Shiboken::Object::isValid(arg))
                    return 0;
                QApplication * cppArg0 = Shiboken::Converter<QApplication * >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // polish(QApplication*)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    (Shiboken::Object::isUserType(self) ? cppSelf->::QStyle::polish(cppArg0) : cppSelf->polish(cppArg0));
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // polish(QPalette&)
            {
                if (!Shiboken::Object::isValid(arg))
                    return 0;
                QPalette & cppArg0 = Shiboken::Converter<QPalette & >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // polish(QPalette&)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    (Shiboken::Object::isUserType(self) ? cppSelf->::QStyle::polish(cppArg0) : cppSelf->polish(cppArg0));
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 2: // polish(QWidget*)
            {
                if (!Shiboken::Object::isValid(arg))
                    return 0;
                QWidget * cppArg0 = Shiboken::Converter<QWidget * >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // polish(QWidget*)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    (Shiboken::Object::isUserType(self) ? cppSelf->::QStyle::polish(cppArg0) : cppSelf->polish(cppArg0));
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QStyleFunc_polish_TypeError:
        const char* overloads[] = {"PySide.QtGui.QApplication", "PySide.QtGui.QPalette", "PySide.QtGui.QWidget", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QStyle.polish", overloads);
        return 0;
}

static PyObject* Sbk_QStyleFunc_proxy(PyObject* self)
{
    QStyle* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QStyle* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // proxy()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                const QStyle * cppResult = const_cast<const QStyle*>(cppSelf)->proxy();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QStyle * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QStyleFunc_sizeFromContents(PyObject* self, PyObject* args, PyObject* kwds)
{
    QStyle* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QStyle* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 4) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QStyle.sizeFromContents(): too many arguments");
        return 0;
    } else if (numArgs < 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QStyle.sizeFromContents(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOOO:sizeFromContents", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: sizeFromContents(QStyle::ContentsType,const QStyleOption*,QSize,const QWidget*)const
    if (numArgs >= 3 && Shiboken::Converter< ::QStyle::ContentsType >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QStyleOption * >::isConvertible(pyargs[1]) && Shiboken::Converter< ::QSize >::isConvertible(pyargs[2])) {
        if (numArgs == 3) {
            overloadId = 0; // sizeFromContents(QStyle::ContentsType,const QStyleOption*,QSize,const QWidget*)const
        } else if (Shiboken::Converter< ::QWidget * >::isConvertible(pyargs[3])) {
            overloadId = 0; // sizeFromContents(QStyle::ContentsType,const QStyleOption*,QSize,const QWidget*)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QStyleFunc_sizeFromContents_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "w");
                if (value) {
                    if (pyargs[3])
                        errorArgName = "w";
                    else if (Shiboken::Converter< ::QWidget * >::isConvertible(value))
                        pyargs[3] = value;
                    else
                        goto Sbk_QStyleFunc_sizeFromContents_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QStyle.sizeFromContents(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QStyle::ContentsType cppArg0 = Shiboken::Converter<QStyle::ContentsType >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            QStyleOption * cppArg1 = Shiboken::Converter<QStyleOption * >::toCpp(pyargs[1]);
            if (!Shiboken::Object::isValid(pyargs[2]))
                return 0;
            QSize cppArg2 = Shiboken::Converter<QSize >::toCpp(pyargs[2]);
            if (!Shiboken::Object::isValid(pyargs[3]))
                return 0;
            QWidget * cppArg3 = pyargs[3] ? Shiboken::Converter<QWidget * >::toCpp(pyargs[3]) : 0;

            if(!PyErr_Occurred()) {
                // sizeFromContents(QStyle::ContentsType,const QStyleOption*,QSize,const QWidget*)const
                if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self))) {
                    PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QStyle.sizeFromContents()' not implemented.");
                    return 0;
                }
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QSize cppResult = const_cast<const QStyle*>(cppSelf)->sizeFromContents(cppArg0, cppArg1, cppArg2, cppArg3);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QSize >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QStyleFunc_sizeFromContents_TypeError:
        const char* overloads[] = {"PySide.QtGui.QStyle.ContentsType, PySide.QtGui.QStyleOption, PySide.QtCore.QSize, PySide.QtGui.QWidget = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QStyle.sizeFromContents", overloads);
        return 0;
}

static PyObject* Sbk_QStyleFunc_sliderPositionFromValue(PyObject* self, PyObject* args, PyObject* kwds)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 5) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QStyle.sliderPositionFromValue(): too many arguments");
        return 0;
    } else if (numArgs < 4) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QStyle.sliderPositionFromValue(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOOOO:sliderPositionFromValue", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4])))
        return 0;


    // Overloaded function decisor
    // 0: sliderPositionFromValue(int,int,int,int,bool)
    if (numArgs >= 4 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3])) {
        if (numArgs == 4) {
            overloadId = 0; // sliderPositionFromValue(int,int,int,int,bool)
        } else if (SbkNumber_Check(pyargs[4])) {
            overloadId = 0; // sliderPositionFromValue(int,int,int,int,bool)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QStyleFunc_sliderPositionFromValue_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "upsideDown");
                if (value) {
                    if (pyargs[4])
                        errorArgName = "upsideDown";
                    else if (SbkNumber_Check(value))
                        pyargs[4] = value;
                    else
                        goto Sbk_QStyleFunc_sliderPositionFromValue_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QStyle.sliderPositionFromValue(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
            int cppArg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);
            int cppArg3 = Shiboken::Converter<int >::toCpp(pyargs[3]);
            bool cppArg4 = pyargs[4] ? Shiboken::Converter<bool >::toCpp(pyargs[4]) : false;

            if(!PyErr_Occurred()) {
                // sliderPositionFromValue(int,int,int,int,bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = QStyle::sliderPositionFromValue(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QStyleFunc_sliderPositionFromValue_TypeError:
        const char* overloads[] = {"int, int, int, int, bool = false", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QStyle.sliderPositionFromValue", overloads);
        return 0;
}

static PyObject* Sbk_QStyleFunc_sliderValueFromPosition(PyObject* self, PyObject* args, PyObject* kwds)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 5) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QStyle.sliderValueFromPosition(): too many arguments");
        return 0;
    } else if (numArgs < 4) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QStyle.sliderValueFromPosition(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOOOO:sliderValueFromPosition", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4])))
        return 0;


    // Overloaded function decisor
    // 0: sliderValueFromPosition(int,int,int,int,bool)
    if (numArgs >= 4 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3])) {
        if (numArgs == 4) {
            overloadId = 0; // sliderValueFromPosition(int,int,int,int,bool)
        } else if (SbkNumber_Check(pyargs[4])) {
            overloadId = 0; // sliderValueFromPosition(int,int,int,int,bool)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QStyleFunc_sliderValueFromPosition_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "upsideDown");
                if (value) {
                    if (pyargs[4])
                        errorArgName = "upsideDown";
                    else if (SbkNumber_Check(value))
                        pyargs[4] = value;
                    else
                        goto Sbk_QStyleFunc_sliderValueFromPosition_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QStyle.sliderValueFromPosition(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
            int cppArg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);
            int cppArg3 = Shiboken::Converter<int >::toCpp(pyargs[3]);
            bool cppArg4 = pyargs[4] ? Shiboken::Converter<bool >::toCpp(pyargs[4]) : false;

            if(!PyErr_Occurred()) {
                // sliderValueFromPosition(int,int,int,int,bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = QStyle::sliderValueFromPosition(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QStyleFunc_sliderValueFromPosition_TypeError:
        const char* overloads[] = {"int, int, int, int, bool = false", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QStyle.sliderValueFromPosition", overloads);
        return 0;
}

static PyObject* Sbk_QStyleFunc_standardIcon(PyObject* self, PyObject* args, PyObject* kwds)
{
    QStyle* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QStyle* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QStyle.standardIcon(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QStyle.standardIcon(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOO:standardIcon", &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: standardIcon(QStyle::StandardPixmap,const QStyleOption*,const QWidget*)const
    if (Shiboken::Converter< ::QStyle::StandardPixmap >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // standardIcon(QStyle::StandardPixmap,const QStyleOption*,const QWidget*)const
        } else if (Shiboken::Converter< ::QStyleOption * >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 0; // standardIcon(QStyle::StandardPixmap,const QStyleOption*,const QWidget*)const
            } else if (Shiboken::Converter< ::QWidget * >::isConvertible(pyargs[2])) {
                overloadId = 0; // standardIcon(QStyle::StandardPixmap,const QStyleOption*,const QWidget*)const
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QStyleFunc_standardIcon_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "option");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "option";
                    else if (Shiboken::Converter< ::QStyleOption * >::isConvertible(value))
                        pyargs[1] = value;
                    else
                        goto Sbk_QStyleFunc_standardIcon_TypeError;
                }
                value = PyDict_GetItemString(kwds, "widget");
                if (value) {
                    if (pyargs[2])
                        errorArgName = "widget";
                    else if (Shiboken::Converter< ::QWidget * >::isConvertible(value))
                        pyargs[2] = value;
                    else
                        goto Sbk_QStyleFunc_standardIcon_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QStyle.standardIcon(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QStyle::StandardPixmap cppArg0 = Shiboken::Converter<QStyle::StandardPixmap >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            QStyleOption * cppArg1 = pyargs[1] ? Shiboken::Converter<QStyleOption * >::toCpp(pyargs[1]) : 0;
            if (!Shiboken::Object::isValid(pyargs[2]))
                return 0;
            QWidget * cppArg2 = pyargs[2] ? Shiboken::Converter<QWidget * >::toCpp(pyargs[2]) : 0;

            if(!PyErr_Occurred()) {
                // standardIcon(QStyle::StandardPixmap,const QStyleOption*,const QWidget*)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QIcon cppResult = const_cast<const QStyle*>(cppSelf)->standardIcon(cppArg0, cppArg1, cppArg2);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QIcon >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QStyleFunc_standardIcon_TypeError:
        const char* overloads[] = {"PySide.QtGui.QStyle.StandardPixmap, PySide.QtGui.QStyleOption = None, PySide.QtGui.QWidget = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QStyle.standardIcon", overloads);
        return 0;
}

static PyObject* Sbk_QStyleFunc_standardIconImplementation(PyObject* self, PyObject* args, PyObject* kwds)
{
    QStyle* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QStyle* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QStyle.standardIconImplementation(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QStyle.standardIconImplementation(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOO:standardIconImplementation", &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: standardIconImplementation(QStyle::StandardPixmap,const QStyleOption*,const QWidget*)const
    if (Shiboken::Converter< ::QStyle::StandardPixmap >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // standardIconImplementation(QStyle::StandardPixmap,const QStyleOption*,const QWidget*)const
        } else if (Shiboken::Converter< ::QStyleOption * >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 0; // standardIconImplementation(QStyle::StandardPixmap,const QStyleOption*,const QWidget*)const
            } else if (Shiboken::Converter< ::QWidget * >::isConvertible(pyargs[2])) {
                overloadId = 0; // standardIconImplementation(QStyle::StandardPixmap,const QStyleOption*,const QWidget*)const
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QStyleFunc_standardIconImplementation_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "opt");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "opt";
                    else if (Shiboken::Converter< ::QStyleOption * >::isConvertible(value))
                        pyargs[1] = value;
                    else
                        goto Sbk_QStyleFunc_standardIconImplementation_TypeError;
                }
                value = PyDict_GetItemString(kwds, "widget");
                if (value) {
                    if (pyargs[2])
                        errorArgName = "widget";
                    else if (Shiboken::Converter< ::QWidget * >::isConvertible(value))
                        pyargs[2] = value;
                    else
                        goto Sbk_QStyleFunc_standardIconImplementation_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QStyle.standardIconImplementation(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QStyle::StandardPixmap cppArg0 = Shiboken::Converter<QStyle::StandardPixmap >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            QStyleOption * cppArg1 = pyargs[1] ? Shiboken::Converter<QStyleOption * >::toCpp(pyargs[1]) : 0;
            if (!Shiboken::Object::isValid(pyargs[2]))
                return 0;
            QWidget * cppArg2 = pyargs[2] ? Shiboken::Converter<QWidget * >::toCpp(pyargs[2]) : 0;

            if(!PyErr_Occurred()) {
                // standardIconImplementation(QStyle::StandardPixmap,const QStyleOption*,const QWidget*)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QIcon cppResult = const_cast<const QStyle*>(cppSelf)->standardIconImplementation(cppArg0, cppArg1, cppArg2);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QIcon >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QStyleFunc_standardIconImplementation_TypeError:
        const char* overloads[] = {"PySide.QtGui.QStyle.StandardPixmap, PySide.QtGui.QStyleOption = None, PySide.QtGui.QWidget = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QStyle.standardIconImplementation", overloads);
        return 0;
}

static PyObject* Sbk_QStyleFunc_standardPalette(PyObject* self)
{
    QStyle* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QStyle* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // standardPalette()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QPalette cppResult = (Shiboken::Object::isUserType(self) ? const_cast<const QStyle*>(cppSelf)->::QStyle::standardPalette() : const_cast<const QStyle*>(cppSelf)->standardPalette());
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QPalette >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QStyleFunc_standardPixmap(PyObject* self, PyObject* args, PyObject* kwds)
{
    QStyle* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QStyle* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QStyle.standardPixmap(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QStyle.standardPixmap(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOO:standardPixmap", &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: standardPixmap(QStyle::StandardPixmap,const QStyleOption*,const QWidget*)const
    if (Shiboken::Converter< ::QStyle::StandardPixmap >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // standardPixmap(QStyle::StandardPixmap,const QStyleOption*,const QWidget*)const
        } else if (Shiboken::Converter< ::QStyleOption * >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 0; // standardPixmap(QStyle::StandardPixmap,const QStyleOption*,const QWidget*)const
            } else if (Shiboken::Converter< ::QWidget * >::isConvertible(pyargs[2])) {
                overloadId = 0; // standardPixmap(QStyle::StandardPixmap,const QStyleOption*,const QWidget*)const
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QStyleFunc_standardPixmap_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "opt");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "opt";
                    else if (Shiboken::Converter< ::QStyleOption * >::isConvertible(value))
                        pyargs[1] = value;
                    else
                        goto Sbk_QStyleFunc_standardPixmap_TypeError;
                }
                value = PyDict_GetItemString(kwds, "widget");
                if (value) {
                    if (pyargs[2])
                        errorArgName = "widget";
                    else if (Shiboken::Converter< ::QWidget * >::isConvertible(value))
                        pyargs[2] = value;
                    else
                        goto Sbk_QStyleFunc_standardPixmap_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QStyle.standardPixmap(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QStyle::StandardPixmap cppArg0 = Shiboken::Converter<QStyle::StandardPixmap >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            QStyleOption * cppArg1 = pyargs[1] ? Shiboken::Converter<QStyleOption * >::toCpp(pyargs[1]) : 0;
            if (!Shiboken::Object::isValid(pyargs[2]))
                return 0;
            QWidget * cppArg2 = pyargs[2] ? Shiboken::Converter<QWidget * >::toCpp(pyargs[2]) : 0;

            if(!PyErr_Occurred()) {
                // standardPixmap(QStyle::StandardPixmap,const QStyleOption*,const QWidget*)const
                if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self))) {
                    PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QStyle.standardPixmap()' not implemented.");
                    return 0;
                }
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QPixmap cppResult = const_cast<const QStyle*>(cppSelf)->standardPixmap(cppArg0, cppArg1, cppArg2);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QPixmap >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QStyleFunc_standardPixmap_TypeError:
        const char* overloads[] = {"PySide.QtGui.QStyle.StandardPixmap, PySide.QtGui.QStyleOption = None, PySide.QtGui.QWidget = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QStyle.standardPixmap", overloads);
        return 0;
}

static PyObject* Sbk_QStyleFunc_styleHint(PyObject* self, PyObject* args, PyObject* kwds)
{
    QStyle* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QStyle* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 4) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QStyle.styleHint(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QStyle.styleHint(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOOO:styleHint", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: styleHint(QStyle::StyleHint,const QStyleOption*,const QWidget*,QStyleHintReturn*)const
    if (Shiboken::Converter< ::QStyle::StyleHint >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // styleHint(QStyle::StyleHint,const QStyleOption*,const QWidget*,QStyleHintReturn*)const
        } else if (Shiboken::Converter< ::QStyleOption * >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 0; // styleHint(QStyle::StyleHint,const QStyleOption*,const QWidget*,QStyleHintReturn*)const
            } else if (Shiboken::Converter< ::QWidget * >::isConvertible(pyargs[2])) {
                if (numArgs == 3) {
                    overloadId = 0; // styleHint(QStyle::StyleHint,const QStyleOption*,const QWidget*,QStyleHintReturn*)const
                } else if (Shiboken::Converter< ::QStyleHintReturn * >::isConvertible(pyargs[3])) {
                    overloadId = 0; // styleHint(QStyle::StyleHint,const QStyleOption*,const QWidget*,QStyleHintReturn*)const
                }
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QStyleFunc_styleHint_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "opt");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "opt";
                    else if (Shiboken::Converter< ::QStyleOption * >::isConvertible(value))
                        pyargs[1] = value;
                    else
                        goto Sbk_QStyleFunc_styleHint_TypeError;
                }
                value = PyDict_GetItemString(kwds, "widget");
                if (value) {
                    if (pyargs[2])
                        errorArgName = "widget";
                    else if (Shiboken::Converter< ::QWidget * >::isConvertible(value))
                        pyargs[2] = value;
                    else
                        goto Sbk_QStyleFunc_styleHint_TypeError;
                }
                value = PyDict_GetItemString(kwds, "returnData");
                if (value) {
                    if (pyargs[3])
                        errorArgName = "returnData";
                    else if (Shiboken::Converter< ::QStyleHintReturn * >::isConvertible(value))
                        pyargs[3] = value;
                    else
                        goto Sbk_QStyleFunc_styleHint_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QStyle.styleHint(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QStyle::StyleHint cppArg0 = Shiboken::Converter<QStyle::StyleHint >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            QStyleOption * cppArg1 = pyargs[1] ? Shiboken::Converter<QStyleOption * >::toCpp(pyargs[1]) : 0;
            if (!Shiboken::Object::isValid(pyargs[2]))
                return 0;
            QWidget * cppArg2 = pyargs[2] ? Shiboken::Converter<QWidget * >::toCpp(pyargs[2]) : 0;
            if (!Shiboken::Object::isValid(pyargs[3]))
                return 0;
            QStyleHintReturn * cppArg3 = pyargs[3] ? Shiboken::Converter<QStyleHintReturn * >::toCpp(pyargs[3]) : 0;

            if(!PyErr_Occurred()) {
                // styleHint(QStyle::StyleHint,const QStyleOption*,const QWidget*,QStyleHintReturn*)const
                if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self))) {
                    PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QStyle.styleHint()' not implemented.");
                    return 0;
                }
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QStyle*>(cppSelf)->styleHint(cppArg0, cppArg1, cppArg2, cppArg3);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QStyleFunc_styleHint_TypeError:
        const char* overloads[] = {"PySide.QtGui.QStyle.StyleHint, PySide.QtGui.QStyleOption = None, PySide.QtGui.QWidget = None, PySide.QtGui.QStyleHintReturn = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QStyle.styleHint", overloads);
        return 0;
}

static PyObject* Sbk_QStyleFunc_subControlRect(PyObject* self, PyObject* args, PyObject* kwds)
{
    QStyle* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QStyle* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 4) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QStyle.subControlRect(): too many arguments");
        return 0;
    } else if (numArgs < 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QStyle.subControlRect(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOOO:subControlRect", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: subControlRect(QStyle::ComplexControl,const QStyleOptionComplex*,QStyle::SubControl,const QWidget*)const
    if (numArgs >= 3 && Shiboken::Converter< ::QStyle::ComplexControl >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QStyleOptionComplex * >::isConvertible(pyargs[1]) && Shiboken::Converter< ::QStyle::SubControl >::isConvertible(pyargs[2])) {
        if (numArgs == 3) {
            overloadId = 0; // subControlRect(QStyle::ComplexControl,const QStyleOptionComplex*,QStyle::SubControl,const QWidget*)const
        } else if (Shiboken::Converter< ::QWidget * >::isConvertible(pyargs[3])) {
            overloadId = 0; // subControlRect(QStyle::ComplexControl,const QStyleOptionComplex*,QStyle::SubControl,const QWidget*)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QStyleFunc_subControlRect_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "widget");
                if (value) {
                    if (pyargs[3])
                        errorArgName = "widget";
                    else if (Shiboken::Converter< ::QWidget * >::isConvertible(value))
                        pyargs[3] = value;
                    else
                        goto Sbk_QStyleFunc_subControlRect_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QStyle.subControlRect(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QStyle::ComplexControl cppArg0 = Shiboken::Converter<QStyle::ComplexControl >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            QStyleOptionComplex * cppArg1 = Shiboken::Converter<QStyleOptionComplex * >::toCpp(pyargs[1]);
            QStyle::SubControl cppArg2 = Shiboken::Converter<QStyle::SubControl >::toCpp(pyargs[2]);
            if (!Shiboken::Object::isValid(pyargs[3]))
                return 0;
            QWidget * cppArg3 = pyargs[3] ? Shiboken::Converter<QWidget * >::toCpp(pyargs[3]) : 0;

            if(!PyErr_Occurred()) {
                // subControlRect(QStyle::ComplexControl,const QStyleOptionComplex*,QStyle::SubControl,const QWidget*)const
                if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self))) {
                    PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QStyle.subControlRect()' not implemented.");
                    return 0;
                }
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QRect cppResult = const_cast<const QStyle*>(cppSelf)->subControlRect(cppArg0, cppArg1, cppArg2, cppArg3);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QRect >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QStyleFunc_subControlRect_TypeError:
        const char* overloads[] = {"PySide.QtGui.QStyle.ComplexControl, PySide.QtGui.QStyleOptionComplex, PySide.QtGui.QStyle.SubControl, PySide.QtGui.QWidget = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QStyle.subControlRect", overloads);
        return 0;
}

static PyObject* Sbk_QStyleFunc_subElementRect(PyObject* self, PyObject* args, PyObject* kwds)
{
    QStyle* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QStyle* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QStyle.subElementRect(): too many arguments");
        return 0;
    } else if (numArgs < 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QStyle.subElementRect(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOO:subElementRect", &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: subElementRect(QStyle::SubElement,const QStyleOption*,const QWidget*)const
    if (numArgs >= 2 && Shiboken::Converter< ::QStyle::SubElement >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QStyleOption * >::isConvertible(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 0; // subElementRect(QStyle::SubElement,const QStyleOption*,const QWidget*)const
        } else if (Shiboken::Converter< ::QWidget * >::isConvertible(pyargs[2])) {
            overloadId = 0; // subElementRect(QStyle::SubElement,const QStyleOption*,const QWidget*)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QStyleFunc_subElementRect_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "widget");
                if (value) {
                    if (pyargs[2])
                        errorArgName = "widget";
                    else if (Shiboken::Converter< ::QWidget * >::isConvertible(value))
                        pyargs[2] = value;
                    else
                        goto Sbk_QStyleFunc_subElementRect_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QStyle.subElementRect(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QStyle::SubElement cppArg0 = Shiboken::Converter<QStyle::SubElement >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            QStyleOption * cppArg1 = Shiboken::Converter<QStyleOption * >::toCpp(pyargs[1]);
            if (!Shiboken::Object::isValid(pyargs[2]))
                return 0;
            QWidget * cppArg2 = pyargs[2] ? Shiboken::Converter<QWidget * >::toCpp(pyargs[2]) : 0;

            if(!PyErr_Occurred()) {
                // subElementRect(QStyle::SubElement,const QStyleOption*,const QWidget*)const
                if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self))) {
                    PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QStyle.subElementRect()' not implemented.");
                    return 0;
                }
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QRect cppResult = const_cast<const QStyle*>(cppSelf)->subElementRect(cppArg0, cppArg1, cppArg2);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QRect >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QStyleFunc_subElementRect_TypeError:
        const char* overloads[] = {"PySide.QtGui.QStyle.SubElement, PySide.QtGui.QStyleOption, PySide.QtGui.QWidget = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QStyle.subElementRect", overloads);
        return 0;
}

static PyObject* Sbk_QStyleFunc_unpolish(PyObject* self, PyObject* arg)
{
    QStyle* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QStyle* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: unpolish(QApplication*)
    // 1: unpolish(QWidget*)
    if (Shiboken::Converter< ::QWidget * >::isConvertible(arg)) {
        overloadId = 1; // unpolish(QWidget*)
    } else if (Shiboken::Converter< ::QApplication * >::isConvertible(arg)) {
        overloadId = 0; // unpolish(QApplication*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QStyleFunc_unpolish_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // unpolish(QApplication*)
            {
                if (!Shiboken::Object::isValid(arg))
                    return 0;
                QApplication * cppArg0 = Shiboken::Converter<QApplication * >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // unpolish(QApplication*)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    (Shiboken::Object::isUserType(self) ? cppSelf->::QStyle::unpolish(cppArg0) : cppSelf->unpolish(cppArg0));
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // unpolish(QWidget*)
            {
                if (!Shiboken::Object::isValid(arg))
                    return 0;
                QWidget * cppArg0 = Shiboken::Converter<QWidget * >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // unpolish(QWidget*)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    (Shiboken::Object::isUserType(self) ? cppSelf->::QStyle::unpolish(cppArg0) : cppSelf->unpolish(cppArg0));
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QStyleFunc_unpolish_TypeError:
        const char* overloads[] = {"PySide.QtGui.QApplication", "PySide.QtGui.QWidget", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QStyle.unpolish", overloads);
        return 0;
}

static PyObject* Sbk_QStyleFunc_visualAlignment(PyObject* self, PyObject* args)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "visualAlignment", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: visualAlignment(Qt::LayoutDirection,QFlags<Qt::AlignmentFlag>)
    if (numArgs == 2 && Shiboken::Converter< ::Qt::LayoutDirection >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QFlags<Qt::AlignmentFlag> >::isConvertible(pyargs[1])) {
        overloadId = 0; // visualAlignment(Qt::LayoutDirection,QFlags<Qt::AlignmentFlag>)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QStyleFunc_visualAlignment_TypeError;

    // Call function/method
    {
        {
            Qt::LayoutDirection cppArg0 = Shiboken::Converter<Qt::LayoutDirection >::toCpp(pyargs[0]);
            QFlags<Qt::AlignmentFlag> cppArg1 = Shiboken::Converter<QFlags<Qt::AlignmentFlag> >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // visualAlignment(Qt::LayoutDirection,QFlags<Qt::AlignmentFlag>)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QFlags<Qt::AlignmentFlag> cppResult = QStyle::visualAlignment(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QFlags<Qt::AlignmentFlag> >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QStyleFunc_visualAlignment_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.LayoutDirection, PySide.QtCore.Qt.Alignment", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QStyle.visualAlignment", overloads);
        return 0;
}

static PyObject* Sbk_QStyleFunc_visualPos(PyObject* self, PyObject* args)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "visualPos", 3, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: visualPos(Qt::LayoutDirection,QRect,QPoint)
    if (numArgs == 3 && Shiboken::Converter< ::Qt::LayoutDirection >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QRect >::isConvertible(pyargs[1]) && Shiboken::Converter< ::QPoint >::isConvertible(pyargs[2])) {
        overloadId = 0; // visualPos(Qt::LayoutDirection,QRect,QPoint)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QStyleFunc_visualPos_TypeError;

    // Call function/method
    {
        {
            Qt::LayoutDirection cppArg0 = Shiboken::Converter<Qt::LayoutDirection >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            QRect cppArg1 = Shiboken::Converter<QRect >::toCpp(pyargs[1]);
            if (!Shiboken::Object::isValid(pyargs[2]))
                return 0;
            QPoint cppArg2 = Shiboken::Converter<QPoint >::toCpp(pyargs[2]);

            if(!PyErr_Occurred()) {
                // visualPos(Qt::LayoutDirection,QRect,QPoint)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QPoint cppResult = QStyle::visualPos(cppArg0, cppArg1, cppArg2);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QPoint >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QStyleFunc_visualPos_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.LayoutDirection, PySide.QtCore.QRect, PySide.QtCore.QPoint", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QStyle.visualPos", overloads);
        return 0;
}

static PyObject* Sbk_QStyleFunc_visualRect(PyObject* self, PyObject* args)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "visualRect", 3, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: visualRect(Qt::LayoutDirection,QRect,QRect)
    if (numArgs == 3 && Shiboken::Converter< ::Qt::LayoutDirection >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QRect >::isConvertible(pyargs[1]) && Shiboken::Converter< ::QRect >::isConvertible(pyargs[2])) {
        overloadId = 0; // visualRect(Qt::LayoutDirection,QRect,QRect)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QStyleFunc_visualRect_TypeError;

    // Call function/method
    {
        {
            Qt::LayoutDirection cppArg0 = Shiboken::Converter<Qt::LayoutDirection >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            QRect cppArg1 = Shiboken::Converter<QRect >::toCpp(pyargs[1]);
            if (!Shiboken::Object::isValid(pyargs[2]))
                return 0;
            QRect cppArg2 = Shiboken::Converter<QRect >::toCpp(pyargs[2]);

            if(!PyErr_Occurred()) {
                // visualRect(Qt::LayoutDirection,QRect,QRect)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QRect cppResult = QStyle::visualRect(cppArg0, cppArg1, cppArg2);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QRect >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QStyleFunc_visualRect_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.LayoutDirection, PySide.QtCore.QRect, PySide.QtCore.QRect", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QStyle.visualRect", overloads);
        return 0;
}

static PyMethodDef Sbk_QStyle_methods[] = {
    {"alignedRect", (PyCFunction)Sbk_QStyleFunc_alignedRect, METH_VARARGS|METH_STATIC},
    {"combinedLayoutSpacing", (PyCFunction)Sbk_QStyleFunc_combinedLayoutSpacing, METH_VARARGS|METH_KEYWORDS},
    {"drawComplexControl", (PyCFunction)Sbk_QStyleFunc_drawComplexControl, METH_VARARGS|METH_KEYWORDS},
    {"drawControl", (PyCFunction)Sbk_QStyleFunc_drawControl, METH_VARARGS|METH_KEYWORDS},
    {"drawItemPixmap", (PyCFunction)Sbk_QStyleFunc_drawItemPixmap, METH_VARARGS},
    {"drawItemText", (PyCFunction)Sbk_QStyleFunc_drawItemText, METH_VARARGS|METH_KEYWORDS},
    {"drawPrimitive", (PyCFunction)Sbk_QStyleFunc_drawPrimitive, METH_VARARGS|METH_KEYWORDS},
    {"generatedIconPixmap", (PyCFunction)Sbk_QStyleFunc_generatedIconPixmap, METH_VARARGS},
    {"hitTestComplexControl", (PyCFunction)Sbk_QStyleFunc_hitTestComplexControl, METH_VARARGS|METH_KEYWORDS},
    {"itemPixmapRect", (PyCFunction)Sbk_QStyleFunc_itemPixmapRect, METH_VARARGS},
    {"layoutSpacing", (PyCFunction)Sbk_QStyleFunc_layoutSpacing, METH_VARARGS|METH_KEYWORDS},
    {"layoutSpacingImplementation", (PyCFunction)Sbk_QStyleFunc_layoutSpacingImplementation, METH_VARARGS|METH_KEYWORDS},
    {"pixelMetric", (PyCFunction)Sbk_QStyleFunc_pixelMetric, METH_VARARGS|METH_KEYWORDS},
    {"polish", (PyCFunction)Sbk_QStyleFunc_polish, METH_O},
    {"proxy", (PyCFunction)Sbk_QStyleFunc_proxy, METH_NOARGS},
    {"sizeFromContents", (PyCFunction)Sbk_QStyleFunc_sizeFromContents, METH_VARARGS|METH_KEYWORDS},
    {"sliderPositionFromValue", (PyCFunction)Sbk_QStyleFunc_sliderPositionFromValue, METH_VARARGS|METH_KEYWORDS|METH_STATIC},
    {"sliderValueFromPosition", (PyCFunction)Sbk_QStyleFunc_sliderValueFromPosition, METH_VARARGS|METH_KEYWORDS|METH_STATIC},
    {"standardIcon", (PyCFunction)Sbk_QStyleFunc_standardIcon, METH_VARARGS|METH_KEYWORDS},
    {"standardIconImplementation", (PyCFunction)Sbk_QStyleFunc_standardIconImplementation, METH_VARARGS|METH_KEYWORDS},
    {"standardPalette", (PyCFunction)Sbk_QStyleFunc_standardPalette, METH_NOARGS},
    {"standardPixmap", (PyCFunction)Sbk_QStyleFunc_standardPixmap, METH_VARARGS|METH_KEYWORDS},
    {"styleHint", (PyCFunction)Sbk_QStyleFunc_styleHint, METH_VARARGS|METH_KEYWORDS},
    {"subControlRect", (PyCFunction)Sbk_QStyleFunc_subControlRect, METH_VARARGS|METH_KEYWORDS},
    {"subElementRect", (PyCFunction)Sbk_QStyleFunc_subElementRect, METH_VARARGS|METH_KEYWORDS},
    {"unpolish", (PyCFunction)Sbk_QStyleFunc_unpolish, METH_O},
    {"visualAlignment", (PyCFunction)Sbk_QStyleFunc_visualAlignment, METH_VARARGS|METH_STATIC},
    {"visualPos", (PyCFunction)Sbk_QStyleFunc_visualPos, METH_VARARGS|METH_STATIC},
    {"visualRect", (PyCFunction)Sbk_QStyleFunc_visualRect, METH_VARARGS|METH_STATIC},

    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QStyle_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QStyle",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QStyle_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QStyle_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern

static SbkObjectType* Sbk_QStyle_typeDiscovery(void* cptr, SbkObjectType* instanceType)
{
    if (instanceType == reinterpret_cast<SbkObjectType*>(Shiboken::SbkType<QObject >()) && dynamic_cast<QStyle*>(reinterpret_cast<QObject*>(cptr)))
        return &Sbk_QStyle_Type;
    return 0;
}

PyObject* SbkPySide_QtGui_QStyle_SubControl___and__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QStyle::SubControls >::toPython(
        Shiboken::Converter<QStyle::SubControls>::toCpp(self)
        & Shiboken::Converter< QStyle::SubControls >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtGui_QStyle_SubControl___or__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QStyle::SubControls >::toPython(
        Shiboken::Converter<QStyle::SubControls>::toCpp(self)
        | Shiboken::Converter< QStyle::SubControls >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtGui_QStyle_SubControl___xor__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QStyle::SubControls >::toPython(
        Shiboken::Converter<QStyle::SubControls>::toCpp(self)
        ^ Shiboken::Converter< QStyle::SubControls >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtGui_QStyle_SubControl___invert__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QStyle::SubControls >::toPython(
        ~Shiboken::Converter<QStyle::SubControls >::toCpp(self)
    );
}


static PyNumberMethods SbkPySide_QtGui_QStyle_SubControl_as_number = {
    /*nb_add*/                  0,
    /*nb_subtract*/             0,
    /*nb_multiply*/             0,
    /*nb_divide*/               0,
    /*nb_remainder*/            0,
    /*nb_divmod*/               0,
    /*nb_power*/                0,
    /*nb_negative*/             0,
    /*nb_positive*/             0,
    /*nb_absolute*/             0,
    /*nb_nonzero*/              0,
    /*nb_invert*/               (unaryfunc)SbkPySide_QtGui_QStyle_SubControl___invert__,
    /*nb_lshift*/               0,
    /*nb_rshift*/               0,
    /*nb_and*/                  (binaryfunc)SbkPySide_QtGui_QStyle_SubControl___and__,
    /*nb_xor*/                  (binaryfunc)SbkPySide_QtGui_QStyle_SubControl___xor__,
    /*nb_or*/                   (binaryfunc)SbkPySide_QtGui_QStyle_SubControl___or__,
    /*nb_coerce*/               0,
    /*nb_int*/                  0,
    /*nb_long*/                 0,
    /*nb_float*/                0,
    /*nb_oct*/                  0,
    /*nb_hex*/                  0,
    /*nb_inplace_add*/          0,
    /*nb_inplace_subtract*/     0,
    /*nb_inplace_multiply*/     0,
    /*nb_inplace_divide*/       0,
    /*nb_inplace_remainder*/    0,
    /*nb_inplace_power*/        0,
    /*nb_inplace_lshift*/       0,
    /*nb_inplace_rshift*/       0,
    /*nb_inplace_and*/          0,
    /*nb_inplace_xor*/          0,
    /*nb_inplace_or*/           0,
    /*nb_floor_divide*/         0,
    /*nb_true_divide*/          0,
    /*nb_inplace_floor_divide*/ 0,
    /*nb_inplace_true_divide*/  0,
    /*nb_index*/                0
};


// forward declaration of new function
static PyTypeObject SbkPySide_QtGui_QStyle_SubControls_Type = {
    PyObject_HEAD_INIT(&PyType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "SubControls",
    /*tp_basicsize*/        0,
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        &SbkPySide_QtGui_QStyle_SubControl_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT | Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              PyInt_Type.tp_new,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};


PyObject* SbkPySide_QtGui_QStyle_StateFlag___and__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QStyle::State >::toPython(
        Shiboken::Converter<QStyle::State>::toCpp(self)
        & Shiboken::Converter< QStyle::State >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtGui_QStyle_StateFlag___or__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QStyle::State >::toPython(
        Shiboken::Converter<QStyle::State>::toCpp(self)
        | Shiboken::Converter< QStyle::State >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtGui_QStyle_StateFlag___xor__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QStyle::State >::toPython(
        Shiboken::Converter<QStyle::State>::toCpp(self)
        ^ Shiboken::Converter< QStyle::State >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtGui_QStyle_StateFlag___invert__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QStyle::State >::toPython(
        ~Shiboken::Converter<QStyle::State >::toCpp(self)
    );
}


static PyNumberMethods SbkPySide_QtGui_QStyle_StateFlag_as_number = {
    /*nb_add*/                  0,
    /*nb_subtract*/             0,
    /*nb_multiply*/             0,
    /*nb_divide*/               0,
    /*nb_remainder*/            0,
    /*nb_divmod*/               0,
    /*nb_power*/                0,
    /*nb_negative*/             0,
    /*nb_positive*/             0,
    /*nb_absolute*/             0,
    /*nb_nonzero*/              0,
    /*nb_invert*/               (unaryfunc)SbkPySide_QtGui_QStyle_StateFlag___invert__,
    /*nb_lshift*/               0,
    /*nb_rshift*/               0,
    /*nb_and*/                  (binaryfunc)SbkPySide_QtGui_QStyle_StateFlag___and__,
    /*nb_xor*/                  (binaryfunc)SbkPySide_QtGui_QStyle_StateFlag___xor__,
    /*nb_or*/                   (binaryfunc)SbkPySide_QtGui_QStyle_StateFlag___or__,
    /*nb_coerce*/               0,
    /*nb_int*/                  0,
    /*nb_long*/                 0,
    /*nb_float*/                0,
    /*nb_oct*/                  0,
    /*nb_hex*/                  0,
    /*nb_inplace_add*/          0,
    /*nb_inplace_subtract*/     0,
    /*nb_inplace_multiply*/     0,
    /*nb_inplace_divide*/       0,
    /*nb_inplace_remainder*/    0,
    /*nb_inplace_power*/        0,
    /*nb_inplace_lshift*/       0,
    /*nb_inplace_rshift*/       0,
    /*nb_inplace_and*/          0,
    /*nb_inplace_xor*/          0,
    /*nb_inplace_or*/           0,
    /*nb_floor_divide*/         0,
    /*nb_true_divide*/          0,
    /*nb_inplace_floor_divide*/ 0,
    /*nb_inplace_true_divide*/  0,
    /*nb_index*/                0
};


// forward declaration of new function
static PyTypeObject SbkPySide_QtGui_QStyle_State_Type = {
    PyObject_HEAD_INIT(&PyType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "State",
    /*tp_basicsize*/        0,
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        &SbkPySide_QtGui_QStyle_StateFlag_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT | Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              PyInt_Type.tp_new,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};



void init_QStyle(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QSTYLE_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QStyle_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QStyle_Type);
    Shiboken::ObjectType::setSubTypeInitHook(&Sbk_QStyle_Type, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(&Sbk_QStyle_Type, &QStyle::staticMetaObject);    Sbk_QStyle_Type.super.ht_type.tp_base = SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX];
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QStyle_Type, &Shiboken::callCppDestructor<QStyle >);
    if (PyType_Ready((PyTypeObject*)&Sbk_QStyle_Type) < 0)
        return;

    // Fill type discovery information
    Shiboken::ObjectType::setTypeDiscoveryFunction(&Sbk_QStyle_Type, &Sbk_QStyle_typeDiscovery);
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkObjectType*>(SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX]), &Sbk_QStyle_Type);

    Shiboken::ObjectType::setOriginalName(&Sbk_QStyle_Type, "QStyle*");
    PyModule_AddObject(module, "QStyle",
        ((PyObject*)&Sbk_QStyle_Type));

    // Initialize enums
    PyObject* enumItem;

    // init enum: PixelMetric
    PyTypeObject* SbkPySide_QtGui_QStyle_PixelMetric = Shiboken::Enum::newType("PySide.QtGui.QStyle.PixelMetric");
    SbkPySide_QtGuiTypes[SBK_QSTYLE_PIXELMETRIC_IDX] = SbkPySide_QtGui_QStyle_PixelMetric;
    if (PyType_Ready(SbkPySide_QtGui_QStyle_PixelMetric) < 0)
        return;
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,
            "PixelMetric",((PyObject*)SbkPySide_QtGui_QStyle_PixelMetric));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PixelMetric,(long) QStyle::PM_ButtonMargin, "PM_ButtonMargin");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PM_ButtonMargin", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PixelMetric->tp_dict,"PM_ButtonMargin", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PixelMetric,(long) QStyle::PM_ButtonDefaultIndicator, "PM_ButtonDefaultIndicator");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PM_ButtonDefaultIndicator", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PixelMetric->tp_dict,"PM_ButtonDefaultIndicator", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PixelMetric,(long) QStyle::PM_MenuButtonIndicator, "PM_MenuButtonIndicator");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PM_MenuButtonIndicator", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PixelMetric->tp_dict,"PM_MenuButtonIndicator", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PixelMetric,(long) QStyle::PM_ButtonShiftHorizontal, "PM_ButtonShiftHorizontal");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PM_ButtonShiftHorizontal", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PixelMetric->tp_dict,"PM_ButtonShiftHorizontal", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PixelMetric,(long) QStyle::PM_ButtonShiftVertical, "PM_ButtonShiftVertical");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PM_ButtonShiftVertical", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PixelMetric->tp_dict,"PM_ButtonShiftVertical", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PixelMetric,(long) QStyle::PM_DefaultFrameWidth, "PM_DefaultFrameWidth");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PM_DefaultFrameWidth", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PixelMetric->tp_dict,"PM_DefaultFrameWidth", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PixelMetric,(long) QStyle::PM_SpinBoxFrameWidth, "PM_SpinBoxFrameWidth");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PM_SpinBoxFrameWidth", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PixelMetric->tp_dict,"PM_SpinBoxFrameWidth", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PixelMetric,(long) QStyle::PM_ComboBoxFrameWidth, "PM_ComboBoxFrameWidth");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PM_ComboBoxFrameWidth", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PixelMetric->tp_dict,"PM_ComboBoxFrameWidth", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PixelMetric,(long) QStyle::PM_MaximumDragDistance, "PM_MaximumDragDistance");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PM_MaximumDragDistance", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PixelMetric->tp_dict,"PM_MaximumDragDistance", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PixelMetric,(long) QStyle::PM_ScrollBarExtent, "PM_ScrollBarExtent");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PM_ScrollBarExtent", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PixelMetric->tp_dict,"PM_ScrollBarExtent", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PixelMetric,(long) QStyle::PM_ScrollBarSliderMin, "PM_ScrollBarSliderMin");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PM_ScrollBarSliderMin", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PixelMetric->tp_dict,"PM_ScrollBarSliderMin", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PixelMetric,(long) QStyle::PM_SliderThickness, "PM_SliderThickness");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PM_SliderThickness", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PixelMetric->tp_dict,"PM_SliderThickness", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PixelMetric,(long) QStyle::PM_SliderControlThickness, "PM_SliderControlThickness");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PM_SliderControlThickness", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PixelMetric->tp_dict,"PM_SliderControlThickness", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PixelMetric,(long) QStyle::PM_SliderLength, "PM_SliderLength");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PM_SliderLength", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PixelMetric->tp_dict,"PM_SliderLength", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PixelMetric,(long) QStyle::PM_SliderTickmarkOffset, "PM_SliderTickmarkOffset");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PM_SliderTickmarkOffset", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PixelMetric->tp_dict,"PM_SliderTickmarkOffset", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PixelMetric,(long) QStyle::PM_SliderSpaceAvailable, "PM_SliderSpaceAvailable");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PM_SliderSpaceAvailable", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PixelMetric->tp_dict,"PM_SliderSpaceAvailable", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PixelMetric,(long) QStyle::PM_DockWidgetSeparatorExtent, "PM_DockWidgetSeparatorExtent");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PM_DockWidgetSeparatorExtent", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PixelMetric->tp_dict,"PM_DockWidgetSeparatorExtent", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PixelMetric,(long) QStyle::PM_DockWidgetHandleExtent, "PM_DockWidgetHandleExtent");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PM_DockWidgetHandleExtent", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PixelMetric->tp_dict,"PM_DockWidgetHandleExtent", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PixelMetric,(long) QStyle::PM_DockWidgetFrameWidth, "PM_DockWidgetFrameWidth");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PM_DockWidgetFrameWidth", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PixelMetric->tp_dict,"PM_DockWidgetFrameWidth", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PixelMetric,(long) QStyle::PM_TabBarTabOverlap, "PM_TabBarTabOverlap");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PM_TabBarTabOverlap", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PixelMetric->tp_dict,"PM_TabBarTabOverlap", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PixelMetric,(long) QStyle::PM_TabBarTabHSpace, "PM_TabBarTabHSpace");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PM_TabBarTabHSpace", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PixelMetric->tp_dict,"PM_TabBarTabHSpace", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PixelMetric,(long) QStyle::PM_TabBarTabVSpace, "PM_TabBarTabVSpace");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PM_TabBarTabVSpace", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PixelMetric->tp_dict,"PM_TabBarTabVSpace", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PixelMetric,(long) QStyle::PM_TabBarBaseHeight, "PM_TabBarBaseHeight");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PM_TabBarBaseHeight", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PixelMetric->tp_dict,"PM_TabBarBaseHeight", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PixelMetric,(long) QStyle::PM_TabBarBaseOverlap, "PM_TabBarBaseOverlap");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PM_TabBarBaseOverlap", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PixelMetric->tp_dict,"PM_TabBarBaseOverlap", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PixelMetric,(long) QStyle::PM_ProgressBarChunkWidth, "PM_ProgressBarChunkWidth");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PM_ProgressBarChunkWidth", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PixelMetric->tp_dict,"PM_ProgressBarChunkWidth", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PixelMetric,(long) QStyle::PM_SplitterWidth, "PM_SplitterWidth");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PM_SplitterWidth", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PixelMetric->tp_dict,"PM_SplitterWidth", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PixelMetric,(long) QStyle::PM_TitleBarHeight, "PM_TitleBarHeight");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PM_TitleBarHeight", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PixelMetric->tp_dict,"PM_TitleBarHeight", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PixelMetric,(long) QStyle::PM_MenuScrollerHeight, "PM_MenuScrollerHeight");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PM_MenuScrollerHeight", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PixelMetric->tp_dict,"PM_MenuScrollerHeight", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PixelMetric,(long) QStyle::PM_MenuHMargin, "PM_MenuHMargin");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PM_MenuHMargin", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PixelMetric->tp_dict,"PM_MenuHMargin", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PixelMetric,(long) QStyle::PM_MenuVMargin, "PM_MenuVMargin");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PM_MenuVMargin", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PixelMetric->tp_dict,"PM_MenuVMargin", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PixelMetric,(long) QStyle::PM_MenuPanelWidth, "PM_MenuPanelWidth");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PM_MenuPanelWidth", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PixelMetric->tp_dict,"PM_MenuPanelWidth", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PixelMetric,(long) QStyle::PM_MenuTearoffHeight, "PM_MenuTearoffHeight");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PM_MenuTearoffHeight", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PixelMetric->tp_dict,"PM_MenuTearoffHeight", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PixelMetric,(long) QStyle::PM_MenuDesktopFrameWidth, "PM_MenuDesktopFrameWidth");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PM_MenuDesktopFrameWidth", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PixelMetric->tp_dict,"PM_MenuDesktopFrameWidth", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PixelMetric,(long) QStyle::PM_MenuBarPanelWidth, "PM_MenuBarPanelWidth");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PM_MenuBarPanelWidth", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PixelMetric->tp_dict,"PM_MenuBarPanelWidth", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PixelMetric,(long) QStyle::PM_MenuBarItemSpacing, "PM_MenuBarItemSpacing");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PM_MenuBarItemSpacing", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PixelMetric->tp_dict,"PM_MenuBarItemSpacing", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PixelMetric,(long) QStyle::PM_MenuBarVMargin, "PM_MenuBarVMargin");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PM_MenuBarVMargin", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PixelMetric->tp_dict,"PM_MenuBarVMargin", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PixelMetric,(long) QStyle::PM_MenuBarHMargin, "PM_MenuBarHMargin");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PM_MenuBarHMargin", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PixelMetric->tp_dict,"PM_MenuBarHMargin", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PixelMetric,(long) QStyle::PM_IndicatorWidth, "PM_IndicatorWidth");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PM_IndicatorWidth", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PixelMetric->tp_dict,"PM_IndicatorWidth", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PixelMetric,(long) QStyle::PM_IndicatorHeight, "PM_IndicatorHeight");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PM_IndicatorHeight", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PixelMetric->tp_dict,"PM_IndicatorHeight", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PixelMetric,(long) QStyle::PM_ExclusiveIndicatorWidth, "PM_ExclusiveIndicatorWidth");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PM_ExclusiveIndicatorWidth", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PixelMetric->tp_dict,"PM_ExclusiveIndicatorWidth", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PixelMetric,(long) QStyle::PM_ExclusiveIndicatorHeight, "PM_ExclusiveIndicatorHeight");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PM_ExclusiveIndicatorHeight", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PixelMetric->tp_dict,"PM_ExclusiveIndicatorHeight", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PixelMetric,(long) QStyle::PM_CheckListButtonSize, "PM_CheckListButtonSize");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PM_CheckListButtonSize", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PixelMetric->tp_dict,"PM_CheckListButtonSize", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PixelMetric,(long) QStyle::PM_CheckListControllerSize, "PM_CheckListControllerSize");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PM_CheckListControllerSize", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PixelMetric->tp_dict,"PM_CheckListControllerSize", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PixelMetric,(long) QStyle::PM_DialogButtonsSeparator, "PM_DialogButtonsSeparator");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PM_DialogButtonsSeparator", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PixelMetric->tp_dict,"PM_DialogButtonsSeparator", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PixelMetric,(long) QStyle::PM_DialogButtonsButtonWidth, "PM_DialogButtonsButtonWidth");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PM_DialogButtonsButtonWidth", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PixelMetric->tp_dict,"PM_DialogButtonsButtonWidth", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PixelMetric,(long) QStyle::PM_DialogButtonsButtonHeight, "PM_DialogButtonsButtonHeight");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PM_DialogButtonsButtonHeight", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PixelMetric->tp_dict,"PM_DialogButtonsButtonHeight", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PixelMetric,(long) QStyle::PM_MdiSubWindowFrameWidth, "PM_MdiSubWindowFrameWidth");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PM_MdiSubWindowFrameWidth", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PixelMetric->tp_dict,"PM_MdiSubWindowFrameWidth", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PixelMetric,(long) QStyle::PM_MDIFrameWidth, "PM_MDIFrameWidth");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PM_MDIFrameWidth", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PixelMetric->tp_dict,"PM_MDIFrameWidth", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PixelMetric,(long) QStyle::PM_MdiSubWindowMinimizedWidth, "PM_MdiSubWindowMinimizedWidth");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PM_MdiSubWindowMinimizedWidth", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PixelMetric->tp_dict,"PM_MdiSubWindowMinimizedWidth", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PixelMetric,(long) QStyle::PM_MDIMinimizedWidth, "PM_MDIMinimizedWidth");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PM_MDIMinimizedWidth", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PixelMetric->tp_dict,"PM_MDIMinimizedWidth", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PixelMetric,(long) QStyle::PM_HeaderMargin, "PM_HeaderMargin");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PM_HeaderMargin", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PixelMetric->tp_dict,"PM_HeaderMargin", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PixelMetric,(long) QStyle::PM_HeaderMarkSize, "PM_HeaderMarkSize");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PM_HeaderMarkSize", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PixelMetric->tp_dict,"PM_HeaderMarkSize", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PixelMetric,(long) QStyle::PM_HeaderGripMargin, "PM_HeaderGripMargin");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PM_HeaderGripMargin", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PixelMetric->tp_dict,"PM_HeaderGripMargin", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PixelMetric,(long) QStyle::PM_TabBarTabShiftHorizontal, "PM_TabBarTabShiftHorizontal");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PM_TabBarTabShiftHorizontal", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PixelMetric->tp_dict,"PM_TabBarTabShiftHorizontal", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PixelMetric,(long) QStyle::PM_TabBarTabShiftVertical, "PM_TabBarTabShiftVertical");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PM_TabBarTabShiftVertical", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PixelMetric->tp_dict,"PM_TabBarTabShiftVertical", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PixelMetric,(long) QStyle::PM_TabBarScrollButtonWidth, "PM_TabBarScrollButtonWidth");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PM_TabBarScrollButtonWidth", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PixelMetric->tp_dict,"PM_TabBarScrollButtonWidth", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PixelMetric,(long) QStyle::PM_ToolBarFrameWidth, "PM_ToolBarFrameWidth");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PM_ToolBarFrameWidth", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PixelMetric->tp_dict,"PM_ToolBarFrameWidth", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PixelMetric,(long) QStyle::PM_ToolBarHandleExtent, "PM_ToolBarHandleExtent");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PM_ToolBarHandleExtent", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PixelMetric->tp_dict,"PM_ToolBarHandleExtent", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PixelMetric,(long) QStyle::PM_ToolBarItemSpacing, "PM_ToolBarItemSpacing");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PM_ToolBarItemSpacing", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PixelMetric->tp_dict,"PM_ToolBarItemSpacing", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PixelMetric,(long) QStyle::PM_ToolBarItemMargin, "PM_ToolBarItemMargin");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PM_ToolBarItemMargin", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PixelMetric->tp_dict,"PM_ToolBarItemMargin", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PixelMetric,(long) QStyle::PM_ToolBarSeparatorExtent, "PM_ToolBarSeparatorExtent");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PM_ToolBarSeparatorExtent", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PixelMetric->tp_dict,"PM_ToolBarSeparatorExtent", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PixelMetric,(long) QStyle::PM_ToolBarExtensionExtent, "PM_ToolBarExtensionExtent");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PM_ToolBarExtensionExtent", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PixelMetric->tp_dict,"PM_ToolBarExtensionExtent", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PixelMetric,(long) QStyle::PM_SpinBoxSliderHeight, "PM_SpinBoxSliderHeight");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PM_SpinBoxSliderHeight", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PixelMetric->tp_dict,"PM_SpinBoxSliderHeight", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PixelMetric,(long) QStyle::PM_DefaultTopLevelMargin, "PM_DefaultTopLevelMargin");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PM_DefaultTopLevelMargin", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PixelMetric->tp_dict,"PM_DefaultTopLevelMargin", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PixelMetric,(long) QStyle::PM_DefaultChildMargin, "PM_DefaultChildMargin");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PM_DefaultChildMargin", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PixelMetric->tp_dict,"PM_DefaultChildMargin", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PixelMetric,(long) QStyle::PM_DefaultLayoutSpacing, "PM_DefaultLayoutSpacing");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PM_DefaultLayoutSpacing", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PixelMetric->tp_dict,"PM_DefaultLayoutSpacing", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PixelMetric,(long) QStyle::PM_ToolBarIconSize, "PM_ToolBarIconSize");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PM_ToolBarIconSize", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PixelMetric->tp_dict,"PM_ToolBarIconSize", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PixelMetric,(long) QStyle::PM_ListViewIconSize, "PM_ListViewIconSize");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PM_ListViewIconSize", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PixelMetric->tp_dict,"PM_ListViewIconSize", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PixelMetric,(long) QStyle::PM_IconViewIconSize, "PM_IconViewIconSize");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PM_IconViewIconSize", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PixelMetric->tp_dict,"PM_IconViewIconSize", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PixelMetric,(long) QStyle::PM_SmallIconSize, "PM_SmallIconSize");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PM_SmallIconSize", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PixelMetric->tp_dict,"PM_SmallIconSize", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PixelMetric,(long) QStyle::PM_LargeIconSize, "PM_LargeIconSize");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PM_LargeIconSize", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PixelMetric->tp_dict,"PM_LargeIconSize", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PixelMetric,(long) QStyle::PM_FocusFrameVMargin, "PM_FocusFrameVMargin");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PM_FocusFrameVMargin", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PixelMetric->tp_dict,"PM_FocusFrameVMargin", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PixelMetric,(long) QStyle::PM_FocusFrameHMargin, "PM_FocusFrameHMargin");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PM_FocusFrameHMargin", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PixelMetric->tp_dict,"PM_FocusFrameHMargin", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PixelMetric,(long) QStyle::PM_ToolTipLabelFrameWidth, "PM_ToolTipLabelFrameWidth");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PM_ToolTipLabelFrameWidth", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PixelMetric->tp_dict,"PM_ToolTipLabelFrameWidth", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PixelMetric,(long) QStyle::PM_CheckBoxLabelSpacing, "PM_CheckBoxLabelSpacing");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PM_CheckBoxLabelSpacing", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PixelMetric->tp_dict,"PM_CheckBoxLabelSpacing", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PixelMetric,(long) QStyle::PM_TabBarIconSize, "PM_TabBarIconSize");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PM_TabBarIconSize", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PixelMetric->tp_dict,"PM_TabBarIconSize", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PixelMetric,(long) QStyle::PM_SizeGripSize, "PM_SizeGripSize");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PM_SizeGripSize", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PixelMetric->tp_dict,"PM_SizeGripSize", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PixelMetric,(long) QStyle::PM_DockWidgetTitleMargin, "PM_DockWidgetTitleMargin");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PM_DockWidgetTitleMargin", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PixelMetric->tp_dict,"PM_DockWidgetTitleMargin", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PixelMetric,(long) QStyle::PM_MessageBoxIconSize, "PM_MessageBoxIconSize");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PM_MessageBoxIconSize", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PixelMetric->tp_dict,"PM_MessageBoxIconSize", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PixelMetric,(long) QStyle::PM_ButtonIconSize, "PM_ButtonIconSize");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PM_ButtonIconSize", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PixelMetric->tp_dict,"PM_ButtonIconSize", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PixelMetric,(long) QStyle::PM_DockWidgetTitleBarButtonMargin, "PM_DockWidgetTitleBarButtonMargin");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PM_DockWidgetTitleBarButtonMargin", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PixelMetric->tp_dict,"PM_DockWidgetTitleBarButtonMargin", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PixelMetric,(long) QStyle::PM_RadioButtonLabelSpacing, "PM_RadioButtonLabelSpacing");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PM_RadioButtonLabelSpacing", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PixelMetric->tp_dict,"PM_RadioButtonLabelSpacing", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PixelMetric,(long) QStyle::PM_LayoutLeftMargin, "PM_LayoutLeftMargin");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PM_LayoutLeftMargin", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PixelMetric->tp_dict,"PM_LayoutLeftMargin", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PixelMetric,(long) QStyle::PM_LayoutTopMargin, "PM_LayoutTopMargin");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PM_LayoutTopMargin", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PixelMetric->tp_dict,"PM_LayoutTopMargin", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PixelMetric,(long) QStyle::PM_LayoutRightMargin, "PM_LayoutRightMargin");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PM_LayoutRightMargin", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PixelMetric->tp_dict,"PM_LayoutRightMargin", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PixelMetric,(long) QStyle::PM_LayoutBottomMargin, "PM_LayoutBottomMargin");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PM_LayoutBottomMargin", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PixelMetric->tp_dict,"PM_LayoutBottomMargin", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PixelMetric,(long) QStyle::PM_LayoutHorizontalSpacing, "PM_LayoutHorizontalSpacing");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PM_LayoutHorizontalSpacing", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PixelMetric->tp_dict,"PM_LayoutHorizontalSpacing", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PixelMetric,(long) QStyle::PM_LayoutVerticalSpacing, "PM_LayoutVerticalSpacing");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PM_LayoutVerticalSpacing", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PixelMetric->tp_dict,"PM_LayoutVerticalSpacing", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PixelMetric,(long) QStyle::PM_TabBar_ScrollButtonOverlap, "PM_TabBar_ScrollButtonOverlap");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PM_TabBar_ScrollButtonOverlap", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PixelMetric->tp_dict,"PM_TabBar_ScrollButtonOverlap", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PixelMetric,(long) QStyle::PM_TextCursorWidth, "PM_TextCursorWidth");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PM_TextCursorWidth", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PixelMetric->tp_dict,"PM_TextCursorWidth", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PixelMetric,(long) QStyle::PM_TabCloseIndicatorWidth, "PM_TabCloseIndicatorWidth");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PM_TabCloseIndicatorWidth", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PixelMetric->tp_dict,"PM_TabCloseIndicatorWidth", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PixelMetric,(long) QStyle::PM_TabCloseIndicatorHeight, "PM_TabCloseIndicatorHeight");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PM_TabCloseIndicatorHeight", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PixelMetric->tp_dict,"PM_TabCloseIndicatorHeight", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PixelMetric,(long) QStyle::PM_ScrollView_ScrollBarSpacing, "PM_ScrollView_ScrollBarSpacing");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PM_ScrollView_ScrollBarSpacing", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PixelMetric->tp_dict,"PM_ScrollView_ScrollBarSpacing", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PixelMetric,(long) QStyle::PM_SubMenuOverlap, "PM_SubMenuOverlap");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PM_SubMenuOverlap", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PixelMetric->tp_dict,"PM_SubMenuOverlap", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PixelMetric,(long) QStyle::PM_CustomBase, "PM_CustomBase");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PM_CustomBase", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PixelMetric->tp_dict,"PM_CustomBase", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QStyle::PixelMetric");
    Shiboken::TypeResolver::createValueTypeResolver<int>("QStyle$ConcreteWrapper::PixelMetric");
    // end of enum PixelMetric

    // init enum: SubControl
    PyTypeObject* SbkPySide_QtGui_QStyle_SubControl = Shiboken::Enum::newType("PySide.QtGui.QStyle.SubControl");
    SbkPySide_QtGui_QStyle_SubControl->tp_as_number = &SbkPySide_QtGui_QStyle_SubControl_as_number;
    SbkPySide_QtGuiTypes[SBK_QSTYLE_SUBCONTROL_IDX] = SbkPySide_QtGui_QStyle_SubControl;
    if (PyType_Ready(SbkPySide_QtGui_QStyle_SubControl) < 0)
        return;
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,
            "SubControl",((PyObject*)SbkPySide_QtGui_QStyle_SubControl));

    // init flags class: QFlags<QStyle::SubControl>
    SbkPySide_QtGuiTypes[SBK_QFLAGS_QSTYLE_SUBCONTROL__IDX] = &SbkPySide_QtGui_QStyle_SubControls_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtGui_QStyle_SubControls_Type) < 0)
        return;
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,
            "SubControls",((PyObject*)&SbkPySide_QtGui_QStyle_SubControls_Type));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_SubControl,(long) QStyle::SC_None, "SC_None");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SC_None", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_SubControl->tp_dict,"SC_None", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_SubControl,(long) QStyle::SC_ScrollBarAddLine, "SC_ScrollBarAddLine");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SC_ScrollBarAddLine", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_SubControl->tp_dict,"SC_ScrollBarAddLine", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_SubControl,(long) QStyle::SC_ScrollBarSubLine, "SC_ScrollBarSubLine");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SC_ScrollBarSubLine", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_SubControl->tp_dict,"SC_ScrollBarSubLine", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_SubControl,(long) QStyle::SC_ScrollBarAddPage, "SC_ScrollBarAddPage");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SC_ScrollBarAddPage", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_SubControl->tp_dict,"SC_ScrollBarAddPage", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_SubControl,(long) QStyle::SC_ScrollBarSubPage, "SC_ScrollBarSubPage");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SC_ScrollBarSubPage", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_SubControl->tp_dict,"SC_ScrollBarSubPage", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_SubControl,(long) QStyle::SC_ScrollBarFirst, "SC_ScrollBarFirst");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SC_ScrollBarFirst", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_SubControl->tp_dict,"SC_ScrollBarFirst", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_SubControl,(long) QStyle::SC_ScrollBarLast, "SC_ScrollBarLast");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SC_ScrollBarLast", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_SubControl->tp_dict,"SC_ScrollBarLast", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_SubControl,(long) QStyle::SC_ScrollBarSlider, "SC_ScrollBarSlider");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SC_ScrollBarSlider", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_SubControl->tp_dict,"SC_ScrollBarSlider", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_SubControl,(long) QStyle::SC_ScrollBarGroove, "SC_ScrollBarGroove");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SC_ScrollBarGroove", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_SubControl->tp_dict,"SC_ScrollBarGroove", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_SubControl,(long) QStyle::SC_SpinBoxUp, "SC_SpinBoxUp");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SC_SpinBoxUp", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_SubControl->tp_dict,"SC_SpinBoxUp", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_SubControl,(long) QStyle::SC_SpinBoxDown, "SC_SpinBoxDown");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SC_SpinBoxDown", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_SubControl->tp_dict,"SC_SpinBoxDown", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_SubControl,(long) QStyle::SC_SpinBoxFrame, "SC_SpinBoxFrame");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SC_SpinBoxFrame", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_SubControl->tp_dict,"SC_SpinBoxFrame", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_SubControl,(long) QStyle::SC_SpinBoxEditField, "SC_SpinBoxEditField");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SC_SpinBoxEditField", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_SubControl->tp_dict,"SC_SpinBoxEditField", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_SubControl,(long) QStyle::SC_ComboBoxFrame, "SC_ComboBoxFrame");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SC_ComboBoxFrame", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_SubControl->tp_dict,"SC_ComboBoxFrame", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_SubControl,(long) QStyle::SC_ComboBoxEditField, "SC_ComboBoxEditField");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SC_ComboBoxEditField", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_SubControl->tp_dict,"SC_ComboBoxEditField", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_SubControl,(long) QStyle::SC_ComboBoxArrow, "SC_ComboBoxArrow");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SC_ComboBoxArrow", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_SubControl->tp_dict,"SC_ComboBoxArrow", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_SubControl,(long) QStyle::SC_ComboBoxListBoxPopup, "SC_ComboBoxListBoxPopup");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SC_ComboBoxListBoxPopup", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_SubControl->tp_dict,"SC_ComboBoxListBoxPopup", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_SubControl,(long) QStyle::SC_SliderGroove, "SC_SliderGroove");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SC_SliderGroove", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_SubControl->tp_dict,"SC_SliderGroove", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_SubControl,(long) QStyle::SC_SliderHandle, "SC_SliderHandle");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SC_SliderHandle", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_SubControl->tp_dict,"SC_SliderHandle", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_SubControl,(long) QStyle::SC_SliderTickmarks, "SC_SliderTickmarks");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SC_SliderTickmarks", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_SubControl->tp_dict,"SC_SliderTickmarks", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_SubControl,(long) QStyle::SC_ToolButton, "SC_ToolButton");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SC_ToolButton", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_SubControl->tp_dict,"SC_ToolButton", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_SubControl,(long) QStyle::SC_ToolButtonMenu, "SC_ToolButtonMenu");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SC_ToolButtonMenu", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_SubControl->tp_dict,"SC_ToolButtonMenu", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_SubControl,(long) QStyle::SC_TitleBarSysMenu, "SC_TitleBarSysMenu");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SC_TitleBarSysMenu", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_SubControl->tp_dict,"SC_TitleBarSysMenu", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_SubControl,(long) QStyle::SC_TitleBarMinButton, "SC_TitleBarMinButton");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SC_TitleBarMinButton", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_SubControl->tp_dict,"SC_TitleBarMinButton", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_SubControl,(long) QStyle::SC_TitleBarMaxButton, "SC_TitleBarMaxButton");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SC_TitleBarMaxButton", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_SubControl->tp_dict,"SC_TitleBarMaxButton", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_SubControl,(long) QStyle::SC_TitleBarCloseButton, "SC_TitleBarCloseButton");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SC_TitleBarCloseButton", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_SubControl->tp_dict,"SC_TitleBarCloseButton", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_SubControl,(long) QStyle::SC_TitleBarNormalButton, "SC_TitleBarNormalButton");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SC_TitleBarNormalButton", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_SubControl->tp_dict,"SC_TitleBarNormalButton", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_SubControl,(long) QStyle::SC_TitleBarShadeButton, "SC_TitleBarShadeButton");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SC_TitleBarShadeButton", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_SubControl->tp_dict,"SC_TitleBarShadeButton", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_SubControl,(long) QStyle::SC_TitleBarUnshadeButton, "SC_TitleBarUnshadeButton");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SC_TitleBarUnshadeButton", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_SubControl->tp_dict,"SC_TitleBarUnshadeButton", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_SubControl,(long) QStyle::SC_TitleBarContextHelpButton, "SC_TitleBarContextHelpButton");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SC_TitleBarContextHelpButton", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_SubControl->tp_dict,"SC_TitleBarContextHelpButton", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_SubControl,(long) QStyle::SC_TitleBarLabel, "SC_TitleBarLabel");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SC_TitleBarLabel", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_SubControl->tp_dict,"SC_TitleBarLabel", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_SubControl,(long) QStyle::SC_Q3ListView, "SC_Q3ListView");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SC_Q3ListView", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_SubControl->tp_dict,"SC_Q3ListView", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_SubControl,(long) QStyle::SC_Q3ListViewBranch, "SC_Q3ListViewBranch");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SC_Q3ListViewBranch", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_SubControl->tp_dict,"SC_Q3ListViewBranch", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_SubControl,(long) QStyle::SC_Q3ListViewExpand, "SC_Q3ListViewExpand");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SC_Q3ListViewExpand", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_SubControl->tp_dict,"SC_Q3ListViewExpand", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_SubControl,(long) QStyle::SC_DialGroove, "SC_DialGroove");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SC_DialGroove", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_SubControl->tp_dict,"SC_DialGroove", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_SubControl,(long) QStyle::SC_DialHandle, "SC_DialHandle");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SC_DialHandle", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_SubControl->tp_dict,"SC_DialHandle", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_SubControl,(long) QStyle::SC_DialTickmarks, "SC_DialTickmarks");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SC_DialTickmarks", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_SubControl->tp_dict,"SC_DialTickmarks", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_SubControl,(long) QStyle::SC_GroupBoxCheckBox, "SC_GroupBoxCheckBox");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SC_GroupBoxCheckBox", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_SubControl->tp_dict,"SC_GroupBoxCheckBox", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_SubControl,(long) QStyle::SC_GroupBoxLabel, "SC_GroupBoxLabel");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SC_GroupBoxLabel", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_SubControl->tp_dict,"SC_GroupBoxLabel", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_SubControl,(long) QStyle::SC_GroupBoxContents, "SC_GroupBoxContents");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SC_GroupBoxContents", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_SubControl->tp_dict,"SC_GroupBoxContents", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_SubControl,(long) QStyle::SC_GroupBoxFrame, "SC_GroupBoxFrame");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SC_GroupBoxFrame", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_SubControl->tp_dict,"SC_GroupBoxFrame", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_SubControl,(long) QStyle::SC_MdiMinButton, "SC_MdiMinButton");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SC_MdiMinButton", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_SubControl->tp_dict,"SC_MdiMinButton", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_SubControl,(long) QStyle::SC_MdiNormalButton, "SC_MdiNormalButton");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SC_MdiNormalButton", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_SubControl->tp_dict,"SC_MdiNormalButton", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_SubControl,(long) QStyle::SC_MdiCloseButton, "SC_MdiCloseButton");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SC_MdiCloseButton", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_SubControl->tp_dict,"SC_MdiCloseButton", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_SubControl,(long) QStyle::SC_CustomBase, "SC_CustomBase");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SC_CustomBase", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_SubControl->tp_dict,"SC_CustomBase", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_SubControl,(long) QStyle::SC_All, "SC_All");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SC_All", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_SubControl->tp_dict,"SC_All", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QStyle::SubControl");
    Shiboken::TypeResolver::createValueTypeResolver<int>("QStyle$ConcreteWrapper::SubControl");
    // end of enum SubControl

    // init enum: StandardPixmap
    PyTypeObject* SbkPySide_QtGui_QStyle_StandardPixmap = Shiboken::Enum::newType("PySide.QtGui.QStyle.StandardPixmap");
    SbkPySide_QtGuiTypes[SBK_QSTYLE_STANDARDPIXMAP_IDX] = SbkPySide_QtGui_QStyle_StandardPixmap;
    if (PyType_Ready(SbkPySide_QtGui_QStyle_StandardPixmap) < 0)
        return;
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,
            "StandardPixmap",((PyObject*)SbkPySide_QtGui_QStyle_StandardPixmap));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StandardPixmap,(long) QStyle::SP_TitleBarMenuButton, "SP_TitleBarMenuButton");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SP_TitleBarMenuButton", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StandardPixmap->tp_dict,"SP_TitleBarMenuButton", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StandardPixmap,(long) QStyle::SP_TitleBarMinButton, "SP_TitleBarMinButton");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SP_TitleBarMinButton", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StandardPixmap->tp_dict,"SP_TitleBarMinButton", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StandardPixmap,(long) QStyle::SP_TitleBarMaxButton, "SP_TitleBarMaxButton");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SP_TitleBarMaxButton", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StandardPixmap->tp_dict,"SP_TitleBarMaxButton", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StandardPixmap,(long) QStyle::SP_TitleBarCloseButton, "SP_TitleBarCloseButton");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SP_TitleBarCloseButton", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StandardPixmap->tp_dict,"SP_TitleBarCloseButton", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StandardPixmap,(long) QStyle::SP_TitleBarNormalButton, "SP_TitleBarNormalButton");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SP_TitleBarNormalButton", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StandardPixmap->tp_dict,"SP_TitleBarNormalButton", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StandardPixmap,(long) QStyle::SP_TitleBarShadeButton, "SP_TitleBarShadeButton");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SP_TitleBarShadeButton", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StandardPixmap->tp_dict,"SP_TitleBarShadeButton", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StandardPixmap,(long) QStyle::SP_TitleBarUnshadeButton, "SP_TitleBarUnshadeButton");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SP_TitleBarUnshadeButton", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StandardPixmap->tp_dict,"SP_TitleBarUnshadeButton", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StandardPixmap,(long) QStyle::SP_TitleBarContextHelpButton, "SP_TitleBarContextHelpButton");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SP_TitleBarContextHelpButton", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StandardPixmap->tp_dict,"SP_TitleBarContextHelpButton", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StandardPixmap,(long) QStyle::SP_DockWidgetCloseButton, "SP_DockWidgetCloseButton");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SP_DockWidgetCloseButton", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StandardPixmap->tp_dict,"SP_DockWidgetCloseButton", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StandardPixmap,(long) QStyle::SP_MessageBoxInformation, "SP_MessageBoxInformation");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SP_MessageBoxInformation", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StandardPixmap->tp_dict,"SP_MessageBoxInformation", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StandardPixmap,(long) QStyle::SP_MessageBoxWarning, "SP_MessageBoxWarning");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SP_MessageBoxWarning", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StandardPixmap->tp_dict,"SP_MessageBoxWarning", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StandardPixmap,(long) QStyle::SP_MessageBoxCritical, "SP_MessageBoxCritical");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SP_MessageBoxCritical", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StandardPixmap->tp_dict,"SP_MessageBoxCritical", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StandardPixmap,(long) QStyle::SP_MessageBoxQuestion, "SP_MessageBoxQuestion");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SP_MessageBoxQuestion", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StandardPixmap->tp_dict,"SP_MessageBoxQuestion", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StandardPixmap,(long) QStyle::SP_DesktopIcon, "SP_DesktopIcon");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SP_DesktopIcon", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StandardPixmap->tp_dict,"SP_DesktopIcon", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StandardPixmap,(long) QStyle::SP_TrashIcon, "SP_TrashIcon");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SP_TrashIcon", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StandardPixmap->tp_dict,"SP_TrashIcon", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StandardPixmap,(long) QStyle::SP_ComputerIcon, "SP_ComputerIcon");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SP_ComputerIcon", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StandardPixmap->tp_dict,"SP_ComputerIcon", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StandardPixmap,(long) QStyle::SP_DriveFDIcon, "SP_DriveFDIcon");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SP_DriveFDIcon", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StandardPixmap->tp_dict,"SP_DriveFDIcon", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StandardPixmap,(long) QStyle::SP_DriveHDIcon, "SP_DriveHDIcon");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SP_DriveHDIcon", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StandardPixmap->tp_dict,"SP_DriveHDIcon", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StandardPixmap,(long) QStyle::SP_DriveCDIcon, "SP_DriveCDIcon");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SP_DriveCDIcon", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StandardPixmap->tp_dict,"SP_DriveCDIcon", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StandardPixmap,(long) QStyle::SP_DriveDVDIcon, "SP_DriveDVDIcon");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SP_DriveDVDIcon", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StandardPixmap->tp_dict,"SP_DriveDVDIcon", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StandardPixmap,(long) QStyle::SP_DriveNetIcon, "SP_DriveNetIcon");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SP_DriveNetIcon", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StandardPixmap->tp_dict,"SP_DriveNetIcon", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StandardPixmap,(long) QStyle::SP_DirOpenIcon, "SP_DirOpenIcon");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SP_DirOpenIcon", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StandardPixmap->tp_dict,"SP_DirOpenIcon", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StandardPixmap,(long) QStyle::SP_DirClosedIcon, "SP_DirClosedIcon");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SP_DirClosedIcon", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StandardPixmap->tp_dict,"SP_DirClosedIcon", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StandardPixmap,(long) QStyle::SP_DirLinkIcon, "SP_DirLinkIcon");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SP_DirLinkIcon", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StandardPixmap->tp_dict,"SP_DirLinkIcon", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StandardPixmap,(long) QStyle::SP_FileIcon, "SP_FileIcon");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SP_FileIcon", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StandardPixmap->tp_dict,"SP_FileIcon", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StandardPixmap,(long) QStyle::SP_FileLinkIcon, "SP_FileLinkIcon");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SP_FileLinkIcon", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StandardPixmap->tp_dict,"SP_FileLinkIcon", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StandardPixmap,(long) QStyle::SP_ToolBarHorizontalExtensionButton, "SP_ToolBarHorizontalExtensionButton");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SP_ToolBarHorizontalExtensionButton", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StandardPixmap->tp_dict,"SP_ToolBarHorizontalExtensionButton", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StandardPixmap,(long) QStyle::SP_ToolBarVerticalExtensionButton, "SP_ToolBarVerticalExtensionButton");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SP_ToolBarVerticalExtensionButton", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StandardPixmap->tp_dict,"SP_ToolBarVerticalExtensionButton", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StandardPixmap,(long) QStyle::SP_FileDialogStart, "SP_FileDialogStart");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SP_FileDialogStart", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StandardPixmap->tp_dict,"SP_FileDialogStart", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StandardPixmap,(long) QStyle::SP_FileDialogEnd, "SP_FileDialogEnd");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SP_FileDialogEnd", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StandardPixmap->tp_dict,"SP_FileDialogEnd", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StandardPixmap,(long) QStyle::SP_FileDialogToParent, "SP_FileDialogToParent");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SP_FileDialogToParent", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StandardPixmap->tp_dict,"SP_FileDialogToParent", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StandardPixmap,(long) QStyle::SP_FileDialogNewFolder, "SP_FileDialogNewFolder");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SP_FileDialogNewFolder", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StandardPixmap->tp_dict,"SP_FileDialogNewFolder", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StandardPixmap,(long) QStyle::SP_FileDialogDetailedView, "SP_FileDialogDetailedView");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SP_FileDialogDetailedView", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StandardPixmap->tp_dict,"SP_FileDialogDetailedView", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StandardPixmap,(long) QStyle::SP_FileDialogInfoView, "SP_FileDialogInfoView");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SP_FileDialogInfoView", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StandardPixmap->tp_dict,"SP_FileDialogInfoView", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StandardPixmap,(long) QStyle::SP_FileDialogContentsView, "SP_FileDialogContentsView");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SP_FileDialogContentsView", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StandardPixmap->tp_dict,"SP_FileDialogContentsView", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StandardPixmap,(long) QStyle::SP_FileDialogListView, "SP_FileDialogListView");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SP_FileDialogListView", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StandardPixmap->tp_dict,"SP_FileDialogListView", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StandardPixmap,(long) QStyle::SP_FileDialogBack, "SP_FileDialogBack");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SP_FileDialogBack", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StandardPixmap->tp_dict,"SP_FileDialogBack", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StandardPixmap,(long) QStyle::SP_DirIcon, "SP_DirIcon");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SP_DirIcon", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StandardPixmap->tp_dict,"SP_DirIcon", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StandardPixmap,(long) QStyle::SP_DialogOkButton, "SP_DialogOkButton");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SP_DialogOkButton", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StandardPixmap->tp_dict,"SP_DialogOkButton", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StandardPixmap,(long) QStyle::SP_DialogCancelButton, "SP_DialogCancelButton");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SP_DialogCancelButton", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StandardPixmap->tp_dict,"SP_DialogCancelButton", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StandardPixmap,(long) QStyle::SP_DialogHelpButton, "SP_DialogHelpButton");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SP_DialogHelpButton", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StandardPixmap->tp_dict,"SP_DialogHelpButton", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StandardPixmap,(long) QStyle::SP_DialogOpenButton, "SP_DialogOpenButton");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SP_DialogOpenButton", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StandardPixmap->tp_dict,"SP_DialogOpenButton", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StandardPixmap,(long) QStyle::SP_DialogSaveButton, "SP_DialogSaveButton");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SP_DialogSaveButton", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StandardPixmap->tp_dict,"SP_DialogSaveButton", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StandardPixmap,(long) QStyle::SP_DialogCloseButton, "SP_DialogCloseButton");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SP_DialogCloseButton", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StandardPixmap->tp_dict,"SP_DialogCloseButton", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StandardPixmap,(long) QStyle::SP_DialogApplyButton, "SP_DialogApplyButton");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SP_DialogApplyButton", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StandardPixmap->tp_dict,"SP_DialogApplyButton", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StandardPixmap,(long) QStyle::SP_DialogResetButton, "SP_DialogResetButton");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SP_DialogResetButton", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StandardPixmap->tp_dict,"SP_DialogResetButton", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StandardPixmap,(long) QStyle::SP_DialogDiscardButton, "SP_DialogDiscardButton");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SP_DialogDiscardButton", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StandardPixmap->tp_dict,"SP_DialogDiscardButton", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StandardPixmap,(long) QStyle::SP_DialogYesButton, "SP_DialogYesButton");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SP_DialogYesButton", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StandardPixmap->tp_dict,"SP_DialogYesButton", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StandardPixmap,(long) QStyle::SP_DialogNoButton, "SP_DialogNoButton");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SP_DialogNoButton", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StandardPixmap->tp_dict,"SP_DialogNoButton", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StandardPixmap,(long) QStyle::SP_ArrowUp, "SP_ArrowUp");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SP_ArrowUp", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StandardPixmap->tp_dict,"SP_ArrowUp", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StandardPixmap,(long) QStyle::SP_ArrowDown, "SP_ArrowDown");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SP_ArrowDown", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StandardPixmap->tp_dict,"SP_ArrowDown", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StandardPixmap,(long) QStyle::SP_ArrowLeft, "SP_ArrowLeft");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SP_ArrowLeft", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StandardPixmap->tp_dict,"SP_ArrowLeft", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StandardPixmap,(long) QStyle::SP_ArrowRight, "SP_ArrowRight");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SP_ArrowRight", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StandardPixmap->tp_dict,"SP_ArrowRight", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StandardPixmap,(long) QStyle::SP_ArrowBack, "SP_ArrowBack");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SP_ArrowBack", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StandardPixmap->tp_dict,"SP_ArrowBack", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StandardPixmap,(long) QStyle::SP_ArrowForward, "SP_ArrowForward");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SP_ArrowForward", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StandardPixmap->tp_dict,"SP_ArrowForward", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StandardPixmap,(long) QStyle::SP_DirHomeIcon, "SP_DirHomeIcon");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SP_DirHomeIcon", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StandardPixmap->tp_dict,"SP_DirHomeIcon", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StandardPixmap,(long) QStyle::SP_CommandLink, "SP_CommandLink");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SP_CommandLink", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StandardPixmap->tp_dict,"SP_CommandLink", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StandardPixmap,(long) QStyle::SP_VistaShield, "SP_VistaShield");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SP_VistaShield", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StandardPixmap->tp_dict,"SP_VistaShield", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StandardPixmap,(long) QStyle::SP_BrowserReload, "SP_BrowserReload");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SP_BrowserReload", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StandardPixmap->tp_dict,"SP_BrowserReload", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StandardPixmap,(long) QStyle::SP_BrowserStop, "SP_BrowserStop");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SP_BrowserStop", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StandardPixmap->tp_dict,"SP_BrowserStop", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StandardPixmap,(long) QStyle::SP_MediaPlay, "SP_MediaPlay");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SP_MediaPlay", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StandardPixmap->tp_dict,"SP_MediaPlay", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StandardPixmap,(long) QStyle::SP_MediaStop, "SP_MediaStop");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SP_MediaStop", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StandardPixmap->tp_dict,"SP_MediaStop", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StandardPixmap,(long) QStyle::SP_MediaPause, "SP_MediaPause");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SP_MediaPause", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StandardPixmap->tp_dict,"SP_MediaPause", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StandardPixmap,(long) QStyle::SP_MediaSkipForward, "SP_MediaSkipForward");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SP_MediaSkipForward", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StandardPixmap->tp_dict,"SP_MediaSkipForward", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StandardPixmap,(long) QStyle::SP_MediaSkipBackward, "SP_MediaSkipBackward");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SP_MediaSkipBackward", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StandardPixmap->tp_dict,"SP_MediaSkipBackward", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StandardPixmap,(long) QStyle::SP_MediaSeekForward, "SP_MediaSeekForward");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SP_MediaSeekForward", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StandardPixmap->tp_dict,"SP_MediaSeekForward", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StandardPixmap,(long) QStyle::SP_MediaSeekBackward, "SP_MediaSeekBackward");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SP_MediaSeekBackward", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StandardPixmap->tp_dict,"SP_MediaSeekBackward", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StandardPixmap,(long) QStyle::SP_MediaVolume, "SP_MediaVolume");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SP_MediaVolume", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StandardPixmap->tp_dict,"SP_MediaVolume", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StandardPixmap,(long) QStyle::SP_MediaVolumeMuted, "SP_MediaVolumeMuted");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SP_MediaVolumeMuted", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StandardPixmap->tp_dict,"SP_MediaVolumeMuted", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StandardPixmap,(long) QStyle::SP_CustomBase, "SP_CustomBase");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SP_CustomBase", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StandardPixmap->tp_dict,"SP_CustomBase", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QStyle::StandardPixmap");
    Shiboken::TypeResolver::createValueTypeResolver<int>("QStyle$ConcreteWrapper::StandardPixmap");
    // end of enum StandardPixmap

    // init enum: StyleHint
    PyTypeObject* SbkPySide_QtGui_QStyle_StyleHint = Shiboken::Enum::newType("PySide.QtGui.QStyle.StyleHint");
    SbkPySide_QtGuiTypes[SBK_QSTYLE_STYLEHINT_IDX] = SbkPySide_QtGui_QStyle_StyleHint;
    if (PyType_Ready(SbkPySide_QtGui_QStyle_StyleHint) < 0)
        return;
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,
            "StyleHint",((PyObject*)SbkPySide_QtGui_QStyle_StyleHint));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StyleHint,(long) QStyle::SH_EtchDisabledText, "SH_EtchDisabledText");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SH_EtchDisabledText", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StyleHint->tp_dict,"SH_EtchDisabledText", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StyleHint,(long) QStyle::SH_DitherDisabledText, "SH_DitherDisabledText");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SH_DitherDisabledText", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StyleHint->tp_dict,"SH_DitherDisabledText", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StyleHint,(long) QStyle::SH_ScrollBar_MiddleClickAbsolutePosition, "SH_ScrollBar_MiddleClickAbsolutePosition");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SH_ScrollBar_MiddleClickAbsolutePosition", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StyleHint->tp_dict,"SH_ScrollBar_MiddleClickAbsolutePosition", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StyleHint,(long) QStyle::SH_ScrollBar_ScrollWhenPointerLeavesControl, "SH_ScrollBar_ScrollWhenPointerLeavesControl");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SH_ScrollBar_ScrollWhenPointerLeavesControl", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StyleHint->tp_dict,"SH_ScrollBar_ScrollWhenPointerLeavesControl", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StyleHint,(long) QStyle::SH_TabBar_SelectMouseType, "SH_TabBar_SelectMouseType");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SH_TabBar_SelectMouseType", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StyleHint->tp_dict,"SH_TabBar_SelectMouseType", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StyleHint,(long) QStyle::SH_TabBar_Alignment, "SH_TabBar_Alignment");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SH_TabBar_Alignment", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StyleHint->tp_dict,"SH_TabBar_Alignment", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StyleHint,(long) QStyle::SH_Header_ArrowAlignment, "SH_Header_ArrowAlignment");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SH_Header_ArrowAlignment", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StyleHint->tp_dict,"SH_Header_ArrowAlignment", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StyleHint,(long) QStyle::SH_Slider_SnapToValue, "SH_Slider_SnapToValue");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SH_Slider_SnapToValue", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StyleHint->tp_dict,"SH_Slider_SnapToValue", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StyleHint,(long) QStyle::SH_Slider_SloppyKeyEvents, "SH_Slider_SloppyKeyEvents");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SH_Slider_SloppyKeyEvents", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StyleHint->tp_dict,"SH_Slider_SloppyKeyEvents", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StyleHint,(long) QStyle::SH_ProgressDialog_CenterCancelButton, "SH_ProgressDialog_CenterCancelButton");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SH_ProgressDialog_CenterCancelButton", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StyleHint->tp_dict,"SH_ProgressDialog_CenterCancelButton", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StyleHint,(long) QStyle::SH_ProgressDialog_TextLabelAlignment, "SH_ProgressDialog_TextLabelAlignment");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SH_ProgressDialog_TextLabelAlignment", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StyleHint->tp_dict,"SH_ProgressDialog_TextLabelAlignment", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StyleHint,(long) QStyle::SH_PrintDialog_RightAlignButtons, "SH_PrintDialog_RightAlignButtons");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SH_PrintDialog_RightAlignButtons", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StyleHint->tp_dict,"SH_PrintDialog_RightAlignButtons", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StyleHint,(long) QStyle::SH_MainWindow_SpaceBelowMenuBar, "SH_MainWindow_SpaceBelowMenuBar");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SH_MainWindow_SpaceBelowMenuBar", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StyleHint->tp_dict,"SH_MainWindow_SpaceBelowMenuBar", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StyleHint,(long) QStyle::SH_FontDialog_SelectAssociatedText, "SH_FontDialog_SelectAssociatedText");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SH_FontDialog_SelectAssociatedText", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StyleHint->tp_dict,"SH_FontDialog_SelectAssociatedText", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StyleHint,(long) QStyle::SH_Menu_AllowActiveAndDisabled, "SH_Menu_AllowActiveAndDisabled");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SH_Menu_AllowActiveAndDisabled", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StyleHint->tp_dict,"SH_Menu_AllowActiveAndDisabled", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StyleHint,(long) QStyle::SH_Menu_SpaceActivatesItem, "SH_Menu_SpaceActivatesItem");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SH_Menu_SpaceActivatesItem", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StyleHint->tp_dict,"SH_Menu_SpaceActivatesItem", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StyleHint,(long) QStyle::SH_Menu_SubMenuPopupDelay, "SH_Menu_SubMenuPopupDelay");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SH_Menu_SubMenuPopupDelay", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StyleHint->tp_dict,"SH_Menu_SubMenuPopupDelay", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StyleHint,(long) QStyle::SH_ScrollView_FrameOnlyAroundContents, "SH_ScrollView_FrameOnlyAroundContents");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SH_ScrollView_FrameOnlyAroundContents", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StyleHint->tp_dict,"SH_ScrollView_FrameOnlyAroundContents", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StyleHint,(long) QStyle::SH_MenuBar_AltKeyNavigation, "SH_MenuBar_AltKeyNavigation");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SH_MenuBar_AltKeyNavigation", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StyleHint->tp_dict,"SH_MenuBar_AltKeyNavigation", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StyleHint,(long) QStyle::SH_ComboBox_ListMouseTracking, "SH_ComboBox_ListMouseTracking");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SH_ComboBox_ListMouseTracking", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StyleHint->tp_dict,"SH_ComboBox_ListMouseTracking", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StyleHint,(long) QStyle::SH_Menu_MouseTracking, "SH_Menu_MouseTracking");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SH_Menu_MouseTracking", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StyleHint->tp_dict,"SH_Menu_MouseTracking", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StyleHint,(long) QStyle::SH_MenuBar_MouseTracking, "SH_MenuBar_MouseTracking");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SH_MenuBar_MouseTracking", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StyleHint->tp_dict,"SH_MenuBar_MouseTracking", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StyleHint,(long) QStyle::SH_ItemView_ChangeHighlightOnFocus, "SH_ItemView_ChangeHighlightOnFocus");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SH_ItemView_ChangeHighlightOnFocus", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StyleHint->tp_dict,"SH_ItemView_ChangeHighlightOnFocus", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StyleHint,(long) QStyle::SH_Widget_ShareActivation, "SH_Widget_ShareActivation");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SH_Widget_ShareActivation", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StyleHint->tp_dict,"SH_Widget_ShareActivation", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StyleHint,(long) QStyle::SH_Workspace_FillSpaceOnMaximize, "SH_Workspace_FillSpaceOnMaximize");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SH_Workspace_FillSpaceOnMaximize", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StyleHint->tp_dict,"SH_Workspace_FillSpaceOnMaximize", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StyleHint,(long) QStyle::SH_ComboBox_Popup, "SH_ComboBox_Popup");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SH_ComboBox_Popup", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StyleHint->tp_dict,"SH_ComboBox_Popup", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StyleHint,(long) QStyle::SH_TitleBar_NoBorder, "SH_TitleBar_NoBorder");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SH_TitleBar_NoBorder", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StyleHint->tp_dict,"SH_TitleBar_NoBorder", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StyleHint,(long) QStyle::SH_Slider_StopMouseOverSlider, "SH_Slider_StopMouseOverSlider");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SH_Slider_StopMouseOverSlider", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StyleHint->tp_dict,"SH_Slider_StopMouseOverSlider", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StyleHint,(long) QStyle::SH_ScrollBar_StopMouseOverSlider, "SH_ScrollBar_StopMouseOverSlider");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SH_ScrollBar_StopMouseOverSlider", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StyleHint->tp_dict,"SH_ScrollBar_StopMouseOverSlider", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StyleHint,(long) QStyle::SH_BlinkCursorWhenTextSelected, "SH_BlinkCursorWhenTextSelected");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SH_BlinkCursorWhenTextSelected", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StyleHint->tp_dict,"SH_BlinkCursorWhenTextSelected", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StyleHint,(long) QStyle::SH_RichText_FullWidthSelection, "SH_RichText_FullWidthSelection");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SH_RichText_FullWidthSelection", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StyleHint->tp_dict,"SH_RichText_FullWidthSelection", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StyleHint,(long) QStyle::SH_Menu_Scrollable, "SH_Menu_Scrollable");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SH_Menu_Scrollable", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StyleHint->tp_dict,"SH_Menu_Scrollable", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StyleHint,(long) QStyle::SH_GroupBox_TextLabelVerticalAlignment, "SH_GroupBox_TextLabelVerticalAlignment");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SH_GroupBox_TextLabelVerticalAlignment", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StyleHint->tp_dict,"SH_GroupBox_TextLabelVerticalAlignment", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StyleHint,(long) QStyle::SH_GroupBox_TextLabelColor, "SH_GroupBox_TextLabelColor");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SH_GroupBox_TextLabelColor", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StyleHint->tp_dict,"SH_GroupBox_TextLabelColor", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StyleHint,(long) QStyle::SH_Menu_SloppySubMenus, "SH_Menu_SloppySubMenus");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SH_Menu_SloppySubMenus", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StyleHint->tp_dict,"SH_Menu_SloppySubMenus", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StyleHint,(long) QStyle::SH_Table_GridLineColor, "SH_Table_GridLineColor");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SH_Table_GridLineColor", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StyleHint->tp_dict,"SH_Table_GridLineColor", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StyleHint,(long) QStyle::SH_LineEdit_PasswordCharacter, "SH_LineEdit_PasswordCharacter");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SH_LineEdit_PasswordCharacter", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StyleHint->tp_dict,"SH_LineEdit_PasswordCharacter", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StyleHint,(long) QStyle::SH_DialogButtons_DefaultButton, "SH_DialogButtons_DefaultButton");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SH_DialogButtons_DefaultButton", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StyleHint->tp_dict,"SH_DialogButtons_DefaultButton", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StyleHint,(long) QStyle::SH_ToolBox_SelectedPageTitleBold, "SH_ToolBox_SelectedPageTitleBold");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SH_ToolBox_SelectedPageTitleBold", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StyleHint->tp_dict,"SH_ToolBox_SelectedPageTitleBold", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StyleHint,(long) QStyle::SH_TabBar_PreferNoArrows, "SH_TabBar_PreferNoArrows");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SH_TabBar_PreferNoArrows", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StyleHint->tp_dict,"SH_TabBar_PreferNoArrows", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StyleHint,(long) QStyle::SH_ScrollBar_LeftClickAbsolutePosition, "SH_ScrollBar_LeftClickAbsolutePosition");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SH_ScrollBar_LeftClickAbsolutePosition", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StyleHint->tp_dict,"SH_ScrollBar_LeftClickAbsolutePosition", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StyleHint,(long) QStyle::SH_Q3ListViewExpand_SelectMouseType, "SH_Q3ListViewExpand_SelectMouseType");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SH_Q3ListViewExpand_SelectMouseType", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StyleHint->tp_dict,"SH_Q3ListViewExpand_SelectMouseType", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StyleHint,(long) QStyle::SH_UnderlineShortcut, "SH_UnderlineShortcut");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SH_UnderlineShortcut", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StyleHint->tp_dict,"SH_UnderlineShortcut", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StyleHint,(long) QStyle::SH_SpinBox_AnimateButton, "SH_SpinBox_AnimateButton");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SH_SpinBox_AnimateButton", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StyleHint->tp_dict,"SH_SpinBox_AnimateButton", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StyleHint,(long) QStyle::SH_SpinBox_KeyPressAutoRepeatRate, "SH_SpinBox_KeyPressAutoRepeatRate");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SH_SpinBox_KeyPressAutoRepeatRate", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StyleHint->tp_dict,"SH_SpinBox_KeyPressAutoRepeatRate", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StyleHint,(long) QStyle::SH_SpinBox_ClickAutoRepeatRate, "SH_SpinBox_ClickAutoRepeatRate");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SH_SpinBox_ClickAutoRepeatRate", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StyleHint->tp_dict,"SH_SpinBox_ClickAutoRepeatRate", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StyleHint,(long) QStyle::SH_Menu_FillScreenWithScroll, "SH_Menu_FillScreenWithScroll");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SH_Menu_FillScreenWithScroll", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StyleHint->tp_dict,"SH_Menu_FillScreenWithScroll", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StyleHint,(long) QStyle::SH_ToolTipLabel_Opacity, "SH_ToolTipLabel_Opacity");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SH_ToolTipLabel_Opacity", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StyleHint->tp_dict,"SH_ToolTipLabel_Opacity", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StyleHint,(long) QStyle::SH_DrawMenuBarSeparator, "SH_DrawMenuBarSeparator");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SH_DrawMenuBarSeparator", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StyleHint->tp_dict,"SH_DrawMenuBarSeparator", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StyleHint,(long) QStyle::SH_TitleBar_ModifyNotification, "SH_TitleBar_ModifyNotification");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SH_TitleBar_ModifyNotification", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StyleHint->tp_dict,"SH_TitleBar_ModifyNotification", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StyleHint,(long) QStyle::SH_Button_FocusPolicy, "SH_Button_FocusPolicy");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SH_Button_FocusPolicy", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StyleHint->tp_dict,"SH_Button_FocusPolicy", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StyleHint,(long) QStyle::SH_MenuBar_DismissOnSecondClick, "SH_MenuBar_DismissOnSecondClick");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SH_MenuBar_DismissOnSecondClick", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StyleHint->tp_dict,"SH_MenuBar_DismissOnSecondClick", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StyleHint,(long) QStyle::SH_MessageBox_UseBorderForButtonSpacing, "SH_MessageBox_UseBorderForButtonSpacing");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SH_MessageBox_UseBorderForButtonSpacing", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StyleHint->tp_dict,"SH_MessageBox_UseBorderForButtonSpacing", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StyleHint,(long) QStyle::SH_TitleBar_AutoRaise, "SH_TitleBar_AutoRaise");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SH_TitleBar_AutoRaise", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StyleHint->tp_dict,"SH_TitleBar_AutoRaise", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StyleHint,(long) QStyle::SH_ToolButton_PopupDelay, "SH_ToolButton_PopupDelay");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SH_ToolButton_PopupDelay", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StyleHint->tp_dict,"SH_ToolButton_PopupDelay", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StyleHint,(long) QStyle::SH_FocusFrame_Mask, "SH_FocusFrame_Mask");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SH_FocusFrame_Mask", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StyleHint->tp_dict,"SH_FocusFrame_Mask", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StyleHint,(long) QStyle::SH_RubberBand_Mask, "SH_RubberBand_Mask");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SH_RubberBand_Mask", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StyleHint->tp_dict,"SH_RubberBand_Mask", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StyleHint,(long) QStyle::SH_WindowFrame_Mask, "SH_WindowFrame_Mask");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SH_WindowFrame_Mask", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StyleHint->tp_dict,"SH_WindowFrame_Mask", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StyleHint,(long) QStyle::SH_SpinControls_DisableOnBounds, "SH_SpinControls_DisableOnBounds");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SH_SpinControls_DisableOnBounds", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StyleHint->tp_dict,"SH_SpinControls_DisableOnBounds", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StyleHint,(long) QStyle::SH_Dial_BackgroundRole, "SH_Dial_BackgroundRole");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SH_Dial_BackgroundRole", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StyleHint->tp_dict,"SH_Dial_BackgroundRole", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StyleHint,(long) QStyle::SH_ComboBox_LayoutDirection, "SH_ComboBox_LayoutDirection");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SH_ComboBox_LayoutDirection", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StyleHint->tp_dict,"SH_ComboBox_LayoutDirection", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StyleHint,(long) QStyle::SH_ItemView_EllipsisLocation, "SH_ItemView_EllipsisLocation");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SH_ItemView_EllipsisLocation", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StyleHint->tp_dict,"SH_ItemView_EllipsisLocation", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StyleHint,(long) QStyle::SH_ItemView_ShowDecorationSelected, "SH_ItemView_ShowDecorationSelected");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SH_ItemView_ShowDecorationSelected", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StyleHint->tp_dict,"SH_ItemView_ShowDecorationSelected", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StyleHint,(long) QStyle::SH_ItemView_ActivateItemOnSingleClick, "SH_ItemView_ActivateItemOnSingleClick");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SH_ItemView_ActivateItemOnSingleClick", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StyleHint->tp_dict,"SH_ItemView_ActivateItemOnSingleClick", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StyleHint,(long) QStyle::SH_ScrollBar_ContextMenu, "SH_ScrollBar_ContextMenu");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SH_ScrollBar_ContextMenu", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StyleHint->tp_dict,"SH_ScrollBar_ContextMenu", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StyleHint,(long) QStyle::SH_ScrollBar_RollBetweenButtons, "SH_ScrollBar_RollBetweenButtons");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SH_ScrollBar_RollBetweenButtons", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StyleHint->tp_dict,"SH_ScrollBar_RollBetweenButtons", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StyleHint,(long) QStyle::SH_Slider_AbsoluteSetButtons, "SH_Slider_AbsoluteSetButtons");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SH_Slider_AbsoluteSetButtons", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StyleHint->tp_dict,"SH_Slider_AbsoluteSetButtons", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StyleHint,(long) QStyle::SH_Slider_PageSetButtons, "SH_Slider_PageSetButtons");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SH_Slider_PageSetButtons", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StyleHint->tp_dict,"SH_Slider_PageSetButtons", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StyleHint,(long) QStyle::SH_Menu_KeyboardSearch, "SH_Menu_KeyboardSearch");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SH_Menu_KeyboardSearch", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StyleHint->tp_dict,"SH_Menu_KeyboardSearch", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StyleHint,(long) QStyle::SH_TabBar_ElideMode, "SH_TabBar_ElideMode");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SH_TabBar_ElideMode", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StyleHint->tp_dict,"SH_TabBar_ElideMode", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StyleHint,(long) QStyle::SH_DialogButtonLayout, "SH_DialogButtonLayout");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SH_DialogButtonLayout", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StyleHint->tp_dict,"SH_DialogButtonLayout", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StyleHint,(long) QStyle::SH_ComboBox_PopupFrameStyle, "SH_ComboBox_PopupFrameStyle");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SH_ComboBox_PopupFrameStyle", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StyleHint->tp_dict,"SH_ComboBox_PopupFrameStyle", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StyleHint,(long) QStyle::SH_MessageBox_TextInteractionFlags, "SH_MessageBox_TextInteractionFlags");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SH_MessageBox_TextInteractionFlags", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StyleHint->tp_dict,"SH_MessageBox_TextInteractionFlags", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StyleHint,(long) QStyle::SH_DialogButtonBox_ButtonsHaveIcons, "SH_DialogButtonBox_ButtonsHaveIcons");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SH_DialogButtonBox_ButtonsHaveIcons", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StyleHint->tp_dict,"SH_DialogButtonBox_ButtonsHaveIcons", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StyleHint,(long) QStyle::SH_SpellCheckUnderlineStyle, "SH_SpellCheckUnderlineStyle");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SH_SpellCheckUnderlineStyle", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StyleHint->tp_dict,"SH_SpellCheckUnderlineStyle", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StyleHint,(long) QStyle::SH_MessageBox_CenterButtons, "SH_MessageBox_CenterButtons");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SH_MessageBox_CenterButtons", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StyleHint->tp_dict,"SH_MessageBox_CenterButtons", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StyleHint,(long) QStyle::SH_Menu_SelectionWrap, "SH_Menu_SelectionWrap");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SH_Menu_SelectionWrap", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StyleHint->tp_dict,"SH_Menu_SelectionWrap", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StyleHint,(long) QStyle::SH_ItemView_MovementWithoutUpdatingSelection, "SH_ItemView_MovementWithoutUpdatingSelection");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SH_ItemView_MovementWithoutUpdatingSelection", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StyleHint->tp_dict,"SH_ItemView_MovementWithoutUpdatingSelection", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StyleHint,(long) QStyle::SH_ToolTip_Mask, "SH_ToolTip_Mask");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SH_ToolTip_Mask", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StyleHint->tp_dict,"SH_ToolTip_Mask", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StyleHint,(long) QStyle::SH_FocusFrame_AboveWidget, "SH_FocusFrame_AboveWidget");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SH_FocusFrame_AboveWidget", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StyleHint->tp_dict,"SH_FocusFrame_AboveWidget", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StyleHint,(long) QStyle::SH_TextControl_FocusIndicatorTextCharFormat, "SH_TextControl_FocusIndicatorTextCharFormat");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SH_TextControl_FocusIndicatorTextCharFormat", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StyleHint->tp_dict,"SH_TextControl_FocusIndicatorTextCharFormat", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StyleHint,(long) QStyle::SH_WizardStyle, "SH_WizardStyle");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SH_WizardStyle", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StyleHint->tp_dict,"SH_WizardStyle", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StyleHint,(long) QStyle::SH_ItemView_ArrowKeysNavigateIntoChildren, "SH_ItemView_ArrowKeysNavigateIntoChildren");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SH_ItemView_ArrowKeysNavigateIntoChildren", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StyleHint->tp_dict,"SH_ItemView_ArrowKeysNavigateIntoChildren", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StyleHint,(long) QStyle::SH_Menu_Mask, "SH_Menu_Mask");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SH_Menu_Mask", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StyleHint->tp_dict,"SH_Menu_Mask", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StyleHint,(long) QStyle::SH_Menu_FlashTriggeredItem, "SH_Menu_FlashTriggeredItem");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SH_Menu_FlashTriggeredItem", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StyleHint->tp_dict,"SH_Menu_FlashTriggeredItem", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StyleHint,(long) QStyle::SH_Menu_FadeOutOnHide, "SH_Menu_FadeOutOnHide");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SH_Menu_FadeOutOnHide", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StyleHint->tp_dict,"SH_Menu_FadeOutOnHide", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StyleHint,(long) QStyle::SH_SpinBox_ClickAutoRepeatThreshold, "SH_SpinBox_ClickAutoRepeatThreshold");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SH_SpinBox_ClickAutoRepeatThreshold", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StyleHint->tp_dict,"SH_SpinBox_ClickAutoRepeatThreshold", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StyleHint,(long) QStyle::SH_ItemView_PaintAlternatingRowColorsForEmptyArea, "SH_ItemView_PaintAlternatingRowColorsForEmptyArea");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SH_ItemView_PaintAlternatingRowColorsForEmptyArea", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StyleHint->tp_dict,"SH_ItemView_PaintAlternatingRowColorsForEmptyArea", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StyleHint,(long) QStyle::SH_FormLayoutWrapPolicy, "SH_FormLayoutWrapPolicy");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SH_FormLayoutWrapPolicy", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StyleHint->tp_dict,"SH_FormLayoutWrapPolicy", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StyleHint,(long) QStyle::SH_TabWidget_DefaultTabPosition, "SH_TabWidget_DefaultTabPosition");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SH_TabWidget_DefaultTabPosition", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StyleHint->tp_dict,"SH_TabWidget_DefaultTabPosition", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StyleHint,(long) QStyle::SH_ToolBar_Movable, "SH_ToolBar_Movable");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SH_ToolBar_Movable", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StyleHint->tp_dict,"SH_ToolBar_Movable", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StyleHint,(long) QStyle::SH_FormLayoutFieldGrowthPolicy, "SH_FormLayoutFieldGrowthPolicy");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SH_FormLayoutFieldGrowthPolicy", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StyleHint->tp_dict,"SH_FormLayoutFieldGrowthPolicy", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StyleHint,(long) QStyle::SH_FormLayoutFormAlignment, "SH_FormLayoutFormAlignment");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SH_FormLayoutFormAlignment", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StyleHint->tp_dict,"SH_FormLayoutFormAlignment", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StyleHint,(long) QStyle::SH_FormLayoutLabelAlignment, "SH_FormLayoutLabelAlignment");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SH_FormLayoutLabelAlignment", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StyleHint->tp_dict,"SH_FormLayoutLabelAlignment", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StyleHint,(long) QStyle::SH_ItemView_DrawDelegateFrame, "SH_ItemView_DrawDelegateFrame");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SH_ItemView_DrawDelegateFrame", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StyleHint->tp_dict,"SH_ItemView_DrawDelegateFrame", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StyleHint,(long) QStyle::SH_TabBar_CloseButtonPosition, "SH_TabBar_CloseButtonPosition");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SH_TabBar_CloseButtonPosition", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StyleHint->tp_dict,"SH_TabBar_CloseButtonPosition", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StyleHint,(long) QStyle::SH_DockWidget_ButtonsHaveFrame, "SH_DockWidget_ButtonsHaveFrame");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SH_DockWidget_ButtonsHaveFrame", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StyleHint->tp_dict,"SH_DockWidget_ButtonsHaveFrame", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StyleHint,(long) QStyle::SH_ToolButtonStyle, "SH_ToolButtonStyle");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SH_ToolButtonStyle", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StyleHint->tp_dict,"SH_ToolButtonStyle", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StyleHint,(long) QStyle::SH_RequestSoftwareInputPanel, "SH_RequestSoftwareInputPanel");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SH_RequestSoftwareInputPanel", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StyleHint->tp_dict,"SH_RequestSoftwareInputPanel", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StyleHint,(long) QStyle::SH_CustomBase, "SH_CustomBase");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SH_CustomBase", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StyleHint->tp_dict,"SH_CustomBase", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QStyle::StyleHint");
    Shiboken::TypeResolver::createValueTypeResolver<int>("QStyle$ConcreteWrapper::StyleHint");
    // end of enum StyleHint

    // init enum: PrimitiveElement
    PyTypeObject* SbkPySide_QtGui_QStyle_PrimitiveElement = Shiboken::Enum::newType("PySide.QtGui.QStyle.PrimitiveElement");
    SbkPySide_QtGuiTypes[SBK_QSTYLE_PRIMITIVEELEMENT_IDX] = SbkPySide_QtGui_QStyle_PrimitiveElement;
    if (PyType_Ready(SbkPySide_QtGui_QStyle_PrimitiveElement) < 0)
        return;
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,
            "PrimitiveElement",((PyObject*)SbkPySide_QtGui_QStyle_PrimitiveElement));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PrimitiveElement,(long) QStyle::PE_Q3CheckListController, "PE_Q3CheckListController");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PE_Q3CheckListController", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PrimitiveElement->tp_dict,"PE_Q3CheckListController", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PrimitiveElement,(long) QStyle::PE_Q3CheckListExclusiveIndicator, "PE_Q3CheckListExclusiveIndicator");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PE_Q3CheckListExclusiveIndicator", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PrimitiveElement->tp_dict,"PE_Q3CheckListExclusiveIndicator", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PrimitiveElement,(long) QStyle::PE_Q3CheckListIndicator, "PE_Q3CheckListIndicator");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PE_Q3CheckListIndicator", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PrimitiveElement->tp_dict,"PE_Q3CheckListIndicator", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PrimitiveElement,(long) QStyle::PE_Q3DockWindowSeparator, "PE_Q3DockWindowSeparator");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PE_Q3DockWindowSeparator", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PrimitiveElement->tp_dict,"PE_Q3DockWindowSeparator", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PrimitiveElement,(long) QStyle::PE_Q3Separator, "PE_Q3Separator");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PE_Q3Separator", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PrimitiveElement->tp_dict,"PE_Q3Separator", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PrimitiveElement,(long) QStyle::PE_Frame, "PE_Frame");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PE_Frame", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PrimitiveElement->tp_dict,"PE_Frame", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PrimitiveElement,(long) QStyle::PE_FrameDefaultButton, "PE_FrameDefaultButton");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PE_FrameDefaultButton", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PrimitiveElement->tp_dict,"PE_FrameDefaultButton", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PrimitiveElement,(long) QStyle::PE_FrameDockWidget, "PE_FrameDockWidget");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PE_FrameDockWidget", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PrimitiveElement->tp_dict,"PE_FrameDockWidget", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PrimitiveElement,(long) QStyle::PE_FrameFocusRect, "PE_FrameFocusRect");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PE_FrameFocusRect", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PrimitiveElement->tp_dict,"PE_FrameFocusRect", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PrimitiveElement,(long) QStyle::PE_FrameGroupBox, "PE_FrameGroupBox");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PE_FrameGroupBox", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PrimitiveElement->tp_dict,"PE_FrameGroupBox", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PrimitiveElement,(long) QStyle::PE_FrameLineEdit, "PE_FrameLineEdit");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PE_FrameLineEdit", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PrimitiveElement->tp_dict,"PE_FrameLineEdit", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PrimitiveElement,(long) QStyle::PE_FrameMenu, "PE_FrameMenu");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PE_FrameMenu", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PrimitiveElement->tp_dict,"PE_FrameMenu", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PrimitiveElement,(long) QStyle::PE_FrameStatusBar, "PE_FrameStatusBar");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PE_FrameStatusBar", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PrimitiveElement->tp_dict,"PE_FrameStatusBar", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PrimitiveElement,(long) QStyle::PE_FrameStatusBarItem, "PE_FrameStatusBarItem");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PE_FrameStatusBarItem", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PrimitiveElement->tp_dict,"PE_FrameStatusBarItem", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PrimitiveElement,(long) QStyle::PE_FrameTabWidget, "PE_FrameTabWidget");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PE_FrameTabWidget", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PrimitiveElement->tp_dict,"PE_FrameTabWidget", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PrimitiveElement,(long) QStyle::PE_FrameWindow, "PE_FrameWindow");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PE_FrameWindow", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PrimitiveElement->tp_dict,"PE_FrameWindow", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PrimitiveElement,(long) QStyle::PE_FrameButtonBevel, "PE_FrameButtonBevel");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PE_FrameButtonBevel", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PrimitiveElement->tp_dict,"PE_FrameButtonBevel", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PrimitiveElement,(long) QStyle::PE_FrameButtonTool, "PE_FrameButtonTool");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PE_FrameButtonTool", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PrimitiveElement->tp_dict,"PE_FrameButtonTool", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PrimitiveElement,(long) QStyle::PE_FrameTabBarBase, "PE_FrameTabBarBase");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PE_FrameTabBarBase", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PrimitiveElement->tp_dict,"PE_FrameTabBarBase", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PrimitiveElement,(long) QStyle::PE_PanelButtonCommand, "PE_PanelButtonCommand");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PE_PanelButtonCommand", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PrimitiveElement->tp_dict,"PE_PanelButtonCommand", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PrimitiveElement,(long) QStyle::PE_PanelButtonBevel, "PE_PanelButtonBevel");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PE_PanelButtonBevel", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PrimitiveElement->tp_dict,"PE_PanelButtonBevel", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PrimitiveElement,(long) QStyle::PE_PanelButtonTool, "PE_PanelButtonTool");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PE_PanelButtonTool", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PrimitiveElement->tp_dict,"PE_PanelButtonTool", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PrimitiveElement,(long) QStyle::PE_PanelMenuBar, "PE_PanelMenuBar");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PE_PanelMenuBar", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PrimitiveElement->tp_dict,"PE_PanelMenuBar", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PrimitiveElement,(long) QStyle::PE_PanelToolBar, "PE_PanelToolBar");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PE_PanelToolBar", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PrimitiveElement->tp_dict,"PE_PanelToolBar", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PrimitiveElement,(long) QStyle::PE_PanelLineEdit, "PE_PanelLineEdit");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PE_PanelLineEdit", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PrimitiveElement->tp_dict,"PE_PanelLineEdit", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PrimitiveElement,(long) QStyle::PE_IndicatorArrowDown, "PE_IndicatorArrowDown");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PE_IndicatorArrowDown", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PrimitiveElement->tp_dict,"PE_IndicatorArrowDown", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PrimitiveElement,(long) QStyle::PE_IndicatorArrowLeft, "PE_IndicatorArrowLeft");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PE_IndicatorArrowLeft", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PrimitiveElement->tp_dict,"PE_IndicatorArrowLeft", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PrimitiveElement,(long) QStyle::PE_IndicatorArrowRight, "PE_IndicatorArrowRight");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PE_IndicatorArrowRight", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PrimitiveElement->tp_dict,"PE_IndicatorArrowRight", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PrimitiveElement,(long) QStyle::PE_IndicatorArrowUp, "PE_IndicatorArrowUp");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PE_IndicatorArrowUp", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PrimitiveElement->tp_dict,"PE_IndicatorArrowUp", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PrimitiveElement,(long) QStyle::PE_IndicatorBranch, "PE_IndicatorBranch");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PE_IndicatorBranch", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PrimitiveElement->tp_dict,"PE_IndicatorBranch", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PrimitiveElement,(long) QStyle::PE_IndicatorButtonDropDown, "PE_IndicatorButtonDropDown");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PE_IndicatorButtonDropDown", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PrimitiveElement->tp_dict,"PE_IndicatorButtonDropDown", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PrimitiveElement,(long) QStyle::PE_IndicatorViewItemCheck, "PE_IndicatorViewItemCheck");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PE_IndicatorViewItemCheck", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PrimitiveElement->tp_dict,"PE_IndicatorViewItemCheck", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PrimitiveElement,(long) QStyle::PE_IndicatorItemViewItemCheck, "PE_IndicatorItemViewItemCheck");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PE_IndicatorItemViewItemCheck", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PrimitiveElement->tp_dict,"PE_IndicatorItemViewItemCheck", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PrimitiveElement,(long) QStyle::PE_IndicatorCheckBox, "PE_IndicatorCheckBox");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PE_IndicatorCheckBox", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PrimitiveElement->tp_dict,"PE_IndicatorCheckBox", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PrimitiveElement,(long) QStyle::PE_IndicatorDockWidgetResizeHandle, "PE_IndicatorDockWidgetResizeHandle");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PE_IndicatorDockWidgetResizeHandle", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PrimitiveElement->tp_dict,"PE_IndicatorDockWidgetResizeHandle", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PrimitiveElement,(long) QStyle::PE_IndicatorHeaderArrow, "PE_IndicatorHeaderArrow");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PE_IndicatorHeaderArrow", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PrimitiveElement->tp_dict,"PE_IndicatorHeaderArrow", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PrimitiveElement,(long) QStyle::PE_IndicatorMenuCheckMark, "PE_IndicatorMenuCheckMark");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PE_IndicatorMenuCheckMark", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PrimitiveElement->tp_dict,"PE_IndicatorMenuCheckMark", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PrimitiveElement,(long) QStyle::PE_IndicatorProgressChunk, "PE_IndicatorProgressChunk");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PE_IndicatorProgressChunk", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PrimitiveElement->tp_dict,"PE_IndicatorProgressChunk", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PrimitiveElement,(long) QStyle::PE_IndicatorRadioButton, "PE_IndicatorRadioButton");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PE_IndicatorRadioButton", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PrimitiveElement->tp_dict,"PE_IndicatorRadioButton", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PrimitiveElement,(long) QStyle::PE_IndicatorSpinDown, "PE_IndicatorSpinDown");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PE_IndicatorSpinDown", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PrimitiveElement->tp_dict,"PE_IndicatorSpinDown", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PrimitiveElement,(long) QStyle::PE_IndicatorSpinMinus, "PE_IndicatorSpinMinus");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PE_IndicatorSpinMinus", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PrimitiveElement->tp_dict,"PE_IndicatorSpinMinus", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PrimitiveElement,(long) QStyle::PE_IndicatorSpinPlus, "PE_IndicatorSpinPlus");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PE_IndicatorSpinPlus", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PrimitiveElement->tp_dict,"PE_IndicatorSpinPlus", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PrimitiveElement,(long) QStyle::PE_IndicatorSpinUp, "PE_IndicatorSpinUp");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PE_IndicatorSpinUp", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PrimitiveElement->tp_dict,"PE_IndicatorSpinUp", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PrimitiveElement,(long) QStyle::PE_IndicatorToolBarHandle, "PE_IndicatorToolBarHandle");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PE_IndicatorToolBarHandle", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PrimitiveElement->tp_dict,"PE_IndicatorToolBarHandle", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PrimitiveElement,(long) QStyle::PE_IndicatorToolBarSeparator, "PE_IndicatorToolBarSeparator");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PE_IndicatorToolBarSeparator", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PrimitiveElement->tp_dict,"PE_IndicatorToolBarSeparator", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PrimitiveElement,(long) QStyle::PE_PanelTipLabel, "PE_PanelTipLabel");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PE_PanelTipLabel", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PrimitiveElement->tp_dict,"PE_PanelTipLabel", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PrimitiveElement,(long) QStyle::PE_IndicatorTabTear, "PE_IndicatorTabTear");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PE_IndicatorTabTear", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PrimitiveElement->tp_dict,"PE_IndicatorTabTear", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PrimitiveElement,(long) QStyle::PE_PanelScrollAreaCorner, "PE_PanelScrollAreaCorner");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PE_PanelScrollAreaCorner", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PrimitiveElement->tp_dict,"PE_PanelScrollAreaCorner", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PrimitiveElement,(long) QStyle::PE_Widget, "PE_Widget");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PE_Widget", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PrimitiveElement->tp_dict,"PE_Widget", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PrimitiveElement,(long) QStyle::PE_IndicatorColumnViewArrow, "PE_IndicatorColumnViewArrow");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PE_IndicatorColumnViewArrow", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PrimitiveElement->tp_dict,"PE_IndicatorColumnViewArrow", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PrimitiveElement,(long) QStyle::PE_IndicatorItemViewItemDrop, "PE_IndicatorItemViewItemDrop");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PE_IndicatorItemViewItemDrop", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PrimitiveElement->tp_dict,"PE_IndicatorItemViewItemDrop", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PrimitiveElement,(long) QStyle::PE_PanelItemViewItem, "PE_PanelItemViewItem");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PE_PanelItemViewItem", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PrimitiveElement->tp_dict,"PE_PanelItemViewItem", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PrimitiveElement,(long) QStyle::PE_PanelItemViewRow, "PE_PanelItemViewRow");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PE_PanelItemViewRow", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PrimitiveElement->tp_dict,"PE_PanelItemViewRow", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PrimitiveElement,(long) QStyle::PE_PanelStatusBar, "PE_PanelStatusBar");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PE_PanelStatusBar", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PrimitiveElement->tp_dict,"PE_PanelStatusBar", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PrimitiveElement,(long) QStyle::PE_IndicatorTabClose, "PE_IndicatorTabClose");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PE_IndicatorTabClose", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PrimitiveElement->tp_dict,"PE_IndicatorTabClose", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PrimitiveElement,(long) QStyle::PE_PanelMenu, "PE_PanelMenu");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PE_PanelMenu", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PrimitiveElement->tp_dict,"PE_PanelMenu", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_PrimitiveElement,(long) QStyle::PE_CustomBase, "PE_CustomBase");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"PE_CustomBase", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_PrimitiveElement->tp_dict,"PE_CustomBase", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QStyle::PrimitiveElement");
    Shiboken::TypeResolver::createValueTypeResolver<int>("QStyle$ConcreteWrapper::PrimitiveElement");
    // end of enum PrimitiveElement

    // init enum: ControlElement
    PyTypeObject* SbkPySide_QtGui_QStyle_ControlElement = Shiboken::Enum::newType("PySide.QtGui.QStyle.ControlElement");
    SbkPySide_QtGuiTypes[SBK_QSTYLE_CONTROLELEMENT_IDX] = SbkPySide_QtGui_QStyle_ControlElement;
    if (PyType_Ready(SbkPySide_QtGui_QStyle_ControlElement) < 0)
        return;
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,
            "ControlElement",((PyObject*)SbkPySide_QtGui_QStyle_ControlElement));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_ControlElement,(long) QStyle::CE_PushButton, "CE_PushButton");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"CE_PushButton", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_ControlElement->tp_dict,"CE_PushButton", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_ControlElement,(long) QStyle::CE_PushButtonBevel, "CE_PushButtonBevel");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"CE_PushButtonBevel", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_ControlElement->tp_dict,"CE_PushButtonBevel", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_ControlElement,(long) QStyle::CE_PushButtonLabel, "CE_PushButtonLabel");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"CE_PushButtonLabel", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_ControlElement->tp_dict,"CE_PushButtonLabel", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_ControlElement,(long) QStyle::CE_CheckBox, "CE_CheckBox");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"CE_CheckBox", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_ControlElement->tp_dict,"CE_CheckBox", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_ControlElement,(long) QStyle::CE_CheckBoxLabel, "CE_CheckBoxLabel");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"CE_CheckBoxLabel", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_ControlElement->tp_dict,"CE_CheckBoxLabel", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_ControlElement,(long) QStyle::CE_RadioButton, "CE_RadioButton");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"CE_RadioButton", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_ControlElement->tp_dict,"CE_RadioButton", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_ControlElement,(long) QStyle::CE_RadioButtonLabel, "CE_RadioButtonLabel");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"CE_RadioButtonLabel", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_ControlElement->tp_dict,"CE_RadioButtonLabel", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_ControlElement,(long) QStyle::CE_TabBarTab, "CE_TabBarTab");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"CE_TabBarTab", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_ControlElement->tp_dict,"CE_TabBarTab", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_ControlElement,(long) QStyle::CE_TabBarTabShape, "CE_TabBarTabShape");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"CE_TabBarTabShape", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_ControlElement->tp_dict,"CE_TabBarTabShape", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_ControlElement,(long) QStyle::CE_TabBarTabLabel, "CE_TabBarTabLabel");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"CE_TabBarTabLabel", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_ControlElement->tp_dict,"CE_TabBarTabLabel", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_ControlElement,(long) QStyle::CE_ProgressBar, "CE_ProgressBar");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"CE_ProgressBar", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_ControlElement->tp_dict,"CE_ProgressBar", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_ControlElement,(long) QStyle::CE_ProgressBarGroove, "CE_ProgressBarGroove");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"CE_ProgressBarGroove", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_ControlElement->tp_dict,"CE_ProgressBarGroove", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_ControlElement,(long) QStyle::CE_ProgressBarContents, "CE_ProgressBarContents");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"CE_ProgressBarContents", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_ControlElement->tp_dict,"CE_ProgressBarContents", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_ControlElement,(long) QStyle::CE_ProgressBarLabel, "CE_ProgressBarLabel");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"CE_ProgressBarLabel", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_ControlElement->tp_dict,"CE_ProgressBarLabel", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_ControlElement,(long) QStyle::CE_MenuItem, "CE_MenuItem");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"CE_MenuItem", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_ControlElement->tp_dict,"CE_MenuItem", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_ControlElement,(long) QStyle::CE_MenuScroller, "CE_MenuScroller");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"CE_MenuScroller", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_ControlElement->tp_dict,"CE_MenuScroller", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_ControlElement,(long) QStyle::CE_MenuVMargin, "CE_MenuVMargin");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"CE_MenuVMargin", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_ControlElement->tp_dict,"CE_MenuVMargin", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_ControlElement,(long) QStyle::CE_MenuHMargin, "CE_MenuHMargin");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"CE_MenuHMargin", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_ControlElement->tp_dict,"CE_MenuHMargin", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_ControlElement,(long) QStyle::CE_MenuTearoff, "CE_MenuTearoff");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"CE_MenuTearoff", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_ControlElement->tp_dict,"CE_MenuTearoff", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_ControlElement,(long) QStyle::CE_MenuEmptyArea, "CE_MenuEmptyArea");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"CE_MenuEmptyArea", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_ControlElement->tp_dict,"CE_MenuEmptyArea", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_ControlElement,(long) QStyle::CE_MenuBarItem, "CE_MenuBarItem");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"CE_MenuBarItem", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_ControlElement->tp_dict,"CE_MenuBarItem", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_ControlElement,(long) QStyle::CE_MenuBarEmptyArea, "CE_MenuBarEmptyArea");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"CE_MenuBarEmptyArea", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_ControlElement->tp_dict,"CE_MenuBarEmptyArea", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_ControlElement,(long) QStyle::CE_ToolButtonLabel, "CE_ToolButtonLabel");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"CE_ToolButtonLabel", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_ControlElement->tp_dict,"CE_ToolButtonLabel", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_ControlElement,(long) QStyle::CE_Header, "CE_Header");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"CE_Header", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_ControlElement->tp_dict,"CE_Header", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_ControlElement,(long) QStyle::CE_HeaderSection, "CE_HeaderSection");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"CE_HeaderSection", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_ControlElement->tp_dict,"CE_HeaderSection", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_ControlElement,(long) QStyle::CE_HeaderLabel, "CE_HeaderLabel");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"CE_HeaderLabel", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_ControlElement->tp_dict,"CE_HeaderLabel", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_ControlElement,(long) QStyle::CE_Q3DockWindowEmptyArea, "CE_Q3DockWindowEmptyArea");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"CE_Q3DockWindowEmptyArea", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_ControlElement->tp_dict,"CE_Q3DockWindowEmptyArea", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_ControlElement,(long) QStyle::CE_ToolBoxTab, "CE_ToolBoxTab");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"CE_ToolBoxTab", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_ControlElement->tp_dict,"CE_ToolBoxTab", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_ControlElement,(long) QStyle::CE_SizeGrip, "CE_SizeGrip");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"CE_SizeGrip", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_ControlElement->tp_dict,"CE_SizeGrip", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_ControlElement,(long) QStyle::CE_Splitter, "CE_Splitter");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"CE_Splitter", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_ControlElement->tp_dict,"CE_Splitter", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_ControlElement,(long) QStyle::CE_RubberBand, "CE_RubberBand");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"CE_RubberBand", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_ControlElement->tp_dict,"CE_RubberBand", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_ControlElement,(long) QStyle::CE_DockWidgetTitle, "CE_DockWidgetTitle");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"CE_DockWidgetTitle", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_ControlElement->tp_dict,"CE_DockWidgetTitle", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_ControlElement,(long) QStyle::CE_ScrollBarAddLine, "CE_ScrollBarAddLine");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"CE_ScrollBarAddLine", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_ControlElement->tp_dict,"CE_ScrollBarAddLine", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_ControlElement,(long) QStyle::CE_ScrollBarSubLine, "CE_ScrollBarSubLine");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"CE_ScrollBarSubLine", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_ControlElement->tp_dict,"CE_ScrollBarSubLine", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_ControlElement,(long) QStyle::CE_ScrollBarAddPage, "CE_ScrollBarAddPage");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"CE_ScrollBarAddPage", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_ControlElement->tp_dict,"CE_ScrollBarAddPage", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_ControlElement,(long) QStyle::CE_ScrollBarSubPage, "CE_ScrollBarSubPage");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"CE_ScrollBarSubPage", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_ControlElement->tp_dict,"CE_ScrollBarSubPage", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_ControlElement,(long) QStyle::CE_ScrollBarSlider, "CE_ScrollBarSlider");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"CE_ScrollBarSlider", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_ControlElement->tp_dict,"CE_ScrollBarSlider", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_ControlElement,(long) QStyle::CE_ScrollBarFirst, "CE_ScrollBarFirst");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"CE_ScrollBarFirst", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_ControlElement->tp_dict,"CE_ScrollBarFirst", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_ControlElement,(long) QStyle::CE_ScrollBarLast, "CE_ScrollBarLast");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"CE_ScrollBarLast", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_ControlElement->tp_dict,"CE_ScrollBarLast", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_ControlElement,(long) QStyle::CE_FocusFrame, "CE_FocusFrame");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"CE_FocusFrame", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_ControlElement->tp_dict,"CE_FocusFrame", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_ControlElement,(long) QStyle::CE_ComboBoxLabel, "CE_ComboBoxLabel");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"CE_ComboBoxLabel", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_ControlElement->tp_dict,"CE_ComboBoxLabel", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_ControlElement,(long) QStyle::CE_ToolBar, "CE_ToolBar");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"CE_ToolBar", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_ControlElement->tp_dict,"CE_ToolBar", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_ControlElement,(long) QStyle::CE_ToolBoxTabShape, "CE_ToolBoxTabShape");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"CE_ToolBoxTabShape", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_ControlElement->tp_dict,"CE_ToolBoxTabShape", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_ControlElement,(long) QStyle::CE_ToolBoxTabLabel, "CE_ToolBoxTabLabel");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"CE_ToolBoxTabLabel", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_ControlElement->tp_dict,"CE_ToolBoxTabLabel", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_ControlElement,(long) QStyle::CE_HeaderEmptyArea, "CE_HeaderEmptyArea");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"CE_HeaderEmptyArea", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_ControlElement->tp_dict,"CE_HeaderEmptyArea", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_ControlElement,(long) QStyle::CE_ColumnViewGrip, "CE_ColumnViewGrip");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"CE_ColumnViewGrip", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_ControlElement->tp_dict,"CE_ColumnViewGrip", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_ControlElement,(long) QStyle::CE_ItemViewItem, "CE_ItemViewItem");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"CE_ItemViewItem", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_ControlElement->tp_dict,"CE_ItemViewItem", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_ControlElement,(long) QStyle::CE_ShapedFrame, "CE_ShapedFrame");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"CE_ShapedFrame", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_ControlElement->tp_dict,"CE_ShapedFrame", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_ControlElement,(long) QStyle::CE_CustomBase, "CE_CustomBase");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"CE_CustomBase", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_ControlElement->tp_dict,"CE_CustomBase", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QStyle::ControlElement");
    Shiboken::TypeResolver::createValueTypeResolver<int>("QStyle$ConcreteWrapper::ControlElement");
    // end of enum ControlElement

    // init enum: ContentsType
    PyTypeObject* SbkPySide_QtGui_QStyle_ContentsType = Shiboken::Enum::newType("PySide.QtGui.QStyle.ContentsType");
    SbkPySide_QtGuiTypes[SBK_QSTYLE_CONTENTSTYPE_IDX] = SbkPySide_QtGui_QStyle_ContentsType;
    if (PyType_Ready(SbkPySide_QtGui_QStyle_ContentsType) < 0)
        return;
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,
            "ContentsType",((PyObject*)SbkPySide_QtGui_QStyle_ContentsType));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_ContentsType,(long) QStyle::CT_PushButton, "CT_PushButton");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"CT_PushButton", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_ContentsType->tp_dict,"CT_PushButton", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_ContentsType,(long) QStyle::CT_CheckBox, "CT_CheckBox");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"CT_CheckBox", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_ContentsType->tp_dict,"CT_CheckBox", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_ContentsType,(long) QStyle::CT_RadioButton, "CT_RadioButton");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"CT_RadioButton", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_ContentsType->tp_dict,"CT_RadioButton", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_ContentsType,(long) QStyle::CT_ToolButton, "CT_ToolButton");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"CT_ToolButton", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_ContentsType->tp_dict,"CT_ToolButton", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_ContentsType,(long) QStyle::CT_ComboBox, "CT_ComboBox");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"CT_ComboBox", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_ContentsType->tp_dict,"CT_ComboBox", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_ContentsType,(long) QStyle::CT_Splitter, "CT_Splitter");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"CT_Splitter", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_ContentsType->tp_dict,"CT_Splitter", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_ContentsType,(long) QStyle::CT_Q3DockWindow, "CT_Q3DockWindow");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"CT_Q3DockWindow", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_ContentsType->tp_dict,"CT_Q3DockWindow", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_ContentsType,(long) QStyle::CT_ProgressBar, "CT_ProgressBar");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"CT_ProgressBar", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_ContentsType->tp_dict,"CT_ProgressBar", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_ContentsType,(long) QStyle::CT_MenuItem, "CT_MenuItem");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"CT_MenuItem", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_ContentsType->tp_dict,"CT_MenuItem", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_ContentsType,(long) QStyle::CT_MenuBarItem, "CT_MenuBarItem");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"CT_MenuBarItem", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_ContentsType->tp_dict,"CT_MenuBarItem", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_ContentsType,(long) QStyle::CT_MenuBar, "CT_MenuBar");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"CT_MenuBar", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_ContentsType->tp_dict,"CT_MenuBar", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_ContentsType,(long) QStyle::CT_Menu, "CT_Menu");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"CT_Menu", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_ContentsType->tp_dict,"CT_Menu", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_ContentsType,(long) QStyle::CT_TabBarTab, "CT_TabBarTab");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"CT_TabBarTab", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_ContentsType->tp_dict,"CT_TabBarTab", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_ContentsType,(long) QStyle::CT_Slider, "CT_Slider");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"CT_Slider", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_ContentsType->tp_dict,"CT_Slider", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_ContentsType,(long) QStyle::CT_ScrollBar, "CT_ScrollBar");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"CT_ScrollBar", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_ContentsType->tp_dict,"CT_ScrollBar", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_ContentsType,(long) QStyle::CT_Q3Header, "CT_Q3Header");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"CT_Q3Header", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_ContentsType->tp_dict,"CT_Q3Header", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_ContentsType,(long) QStyle::CT_LineEdit, "CT_LineEdit");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"CT_LineEdit", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_ContentsType->tp_dict,"CT_LineEdit", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_ContentsType,(long) QStyle::CT_SpinBox, "CT_SpinBox");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"CT_SpinBox", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_ContentsType->tp_dict,"CT_SpinBox", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_ContentsType,(long) QStyle::CT_SizeGrip, "CT_SizeGrip");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"CT_SizeGrip", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_ContentsType->tp_dict,"CT_SizeGrip", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_ContentsType,(long) QStyle::CT_TabWidget, "CT_TabWidget");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"CT_TabWidget", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_ContentsType->tp_dict,"CT_TabWidget", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_ContentsType,(long) QStyle::CT_DialogButtons, "CT_DialogButtons");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"CT_DialogButtons", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_ContentsType->tp_dict,"CT_DialogButtons", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_ContentsType,(long) QStyle::CT_HeaderSection, "CT_HeaderSection");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"CT_HeaderSection", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_ContentsType->tp_dict,"CT_HeaderSection", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_ContentsType,(long) QStyle::CT_GroupBox, "CT_GroupBox");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"CT_GroupBox", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_ContentsType->tp_dict,"CT_GroupBox", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_ContentsType,(long) QStyle::CT_MdiControls, "CT_MdiControls");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"CT_MdiControls", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_ContentsType->tp_dict,"CT_MdiControls", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_ContentsType,(long) QStyle::CT_ItemViewItem, "CT_ItemViewItem");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"CT_ItemViewItem", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_ContentsType->tp_dict,"CT_ItemViewItem", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_ContentsType,(long) QStyle::CT_CustomBase, "CT_CustomBase");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"CT_CustomBase", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_ContentsType->tp_dict,"CT_CustomBase", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QStyle::ContentsType");
    Shiboken::TypeResolver::createValueTypeResolver<int>("QStyle$ConcreteWrapper::ContentsType");
    // end of enum ContentsType

    // init enum: StateFlag
    PyTypeObject* SbkPySide_QtGui_QStyle_StateFlag = Shiboken::Enum::newType("PySide.QtGui.QStyle.StateFlag");
    SbkPySide_QtGui_QStyle_StateFlag->tp_as_number = &SbkPySide_QtGui_QStyle_StateFlag_as_number;
    SbkPySide_QtGuiTypes[SBK_QSTYLE_STATEFLAG_IDX] = SbkPySide_QtGui_QStyle_StateFlag;
    if (PyType_Ready(SbkPySide_QtGui_QStyle_StateFlag) < 0)
        return;
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,
            "StateFlag",((PyObject*)SbkPySide_QtGui_QStyle_StateFlag));

    // init flags class: QFlags<QStyle::StateFlag>
    SbkPySide_QtGuiTypes[SBK_QFLAGS_QSTYLE_STATEFLAG__IDX] = &SbkPySide_QtGui_QStyle_State_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtGui_QStyle_State_Type) < 0)
        return;
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,
            "State",((PyObject*)&SbkPySide_QtGui_QStyle_State_Type));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StateFlag,(long) QStyle::State_None, "State_None");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"State_None", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StateFlag->tp_dict,"State_None", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StateFlag,(long) QStyle::State_Enabled, "State_Enabled");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"State_Enabled", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StateFlag->tp_dict,"State_Enabled", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StateFlag,(long) QStyle::State_Raised, "State_Raised");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"State_Raised", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StateFlag->tp_dict,"State_Raised", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StateFlag,(long) QStyle::State_Sunken, "State_Sunken");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"State_Sunken", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StateFlag->tp_dict,"State_Sunken", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StateFlag,(long) QStyle::State_Off, "State_Off");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"State_Off", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StateFlag->tp_dict,"State_Off", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StateFlag,(long) QStyle::State_NoChange, "State_NoChange");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"State_NoChange", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StateFlag->tp_dict,"State_NoChange", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StateFlag,(long) QStyle::State_On, "State_On");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"State_On", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StateFlag->tp_dict,"State_On", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StateFlag,(long) QStyle::State_DownArrow, "State_DownArrow");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"State_DownArrow", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StateFlag->tp_dict,"State_DownArrow", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StateFlag,(long) QStyle::State_Horizontal, "State_Horizontal");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"State_Horizontal", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StateFlag->tp_dict,"State_Horizontal", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StateFlag,(long) QStyle::State_HasFocus, "State_HasFocus");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"State_HasFocus", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StateFlag->tp_dict,"State_HasFocus", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StateFlag,(long) QStyle::State_Top, "State_Top");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"State_Top", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StateFlag->tp_dict,"State_Top", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StateFlag,(long) QStyle::State_Bottom, "State_Bottom");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"State_Bottom", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StateFlag->tp_dict,"State_Bottom", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StateFlag,(long) QStyle::State_FocusAtBorder, "State_FocusAtBorder");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"State_FocusAtBorder", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StateFlag->tp_dict,"State_FocusAtBorder", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StateFlag,(long) QStyle::State_AutoRaise, "State_AutoRaise");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"State_AutoRaise", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StateFlag->tp_dict,"State_AutoRaise", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StateFlag,(long) QStyle::State_MouseOver, "State_MouseOver");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"State_MouseOver", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StateFlag->tp_dict,"State_MouseOver", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StateFlag,(long) QStyle::State_UpArrow, "State_UpArrow");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"State_UpArrow", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StateFlag->tp_dict,"State_UpArrow", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StateFlag,(long) QStyle::State_Selected, "State_Selected");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"State_Selected", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StateFlag->tp_dict,"State_Selected", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StateFlag,(long) QStyle::State_Active, "State_Active");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"State_Active", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StateFlag->tp_dict,"State_Active", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StateFlag,(long) QStyle::State_Window, "State_Window");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"State_Window", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StateFlag->tp_dict,"State_Window", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StateFlag,(long) QStyle::State_Open, "State_Open");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"State_Open", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StateFlag->tp_dict,"State_Open", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StateFlag,(long) QStyle::State_Children, "State_Children");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"State_Children", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StateFlag->tp_dict,"State_Children", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StateFlag,(long) QStyle::State_Item, "State_Item");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"State_Item", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StateFlag->tp_dict,"State_Item", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StateFlag,(long) QStyle::State_Sibling, "State_Sibling");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"State_Sibling", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StateFlag->tp_dict,"State_Sibling", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StateFlag,(long) QStyle::State_Editing, "State_Editing");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"State_Editing", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StateFlag->tp_dict,"State_Editing", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StateFlag,(long) QStyle::State_KeyboardFocusChange, "State_KeyboardFocusChange");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"State_KeyboardFocusChange", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StateFlag->tp_dict,"State_KeyboardFocusChange", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StateFlag,(long) QStyle::State_ReadOnly, "State_ReadOnly");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"State_ReadOnly", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StateFlag->tp_dict,"State_ReadOnly", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StateFlag,(long) QStyle::State_Small, "State_Small");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"State_Small", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StateFlag->tp_dict,"State_Small", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_StateFlag,(long) QStyle::State_Mini, "State_Mini");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"State_Mini", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_StateFlag->tp_dict,"State_Mini", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QStyle::StateFlag");
    Shiboken::TypeResolver::createValueTypeResolver<int>("QStyle$ConcreteWrapper::StateFlag");
    // end of enum StateFlag

    // init enum: ComplexControl
    PyTypeObject* SbkPySide_QtGui_QStyle_ComplexControl = Shiboken::Enum::newType("PySide.QtGui.QStyle.ComplexControl");
    SbkPySide_QtGuiTypes[SBK_QSTYLE_COMPLEXCONTROL_IDX] = SbkPySide_QtGui_QStyle_ComplexControl;
    if (PyType_Ready(SbkPySide_QtGui_QStyle_ComplexControl) < 0)
        return;
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,
            "ComplexControl",((PyObject*)SbkPySide_QtGui_QStyle_ComplexControl));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_ComplexControl,(long) QStyle::CC_SpinBox, "CC_SpinBox");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"CC_SpinBox", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_ComplexControl->tp_dict,"CC_SpinBox", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_ComplexControl,(long) QStyle::CC_ComboBox, "CC_ComboBox");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"CC_ComboBox", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_ComplexControl->tp_dict,"CC_ComboBox", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_ComplexControl,(long) QStyle::CC_ScrollBar, "CC_ScrollBar");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"CC_ScrollBar", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_ComplexControl->tp_dict,"CC_ScrollBar", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_ComplexControl,(long) QStyle::CC_Slider, "CC_Slider");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"CC_Slider", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_ComplexControl->tp_dict,"CC_Slider", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_ComplexControl,(long) QStyle::CC_ToolButton, "CC_ToolButton");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"CC_ToolButton", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_ComplexControl->tp_dict,"CC_ToolButton", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_ComplexControl,(long) QStyle::CC_TitleBar, "CC_TitleBar");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"CC_TitleBar", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_ComplexControl->tp_dict,"CC_TitleBar", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_ComplexControl,(long) QStyle::CC_Q3ListView, "CC_Q3ListView");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"CC_Q3ListView", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_ComplexControl->tp_dict,"CC_Q3ListView", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_ComplexControl,(long) QStyle::CC_Dial, "CC_Dial");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"CC_Dial", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_ComplexControl->tp_dict,"CC_Dial", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_ComplexControl,(long) QStyle::CC_GroupBox, "CC_GroupBox");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"CC_GroupBox", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_ComplexControl->tp_dict,"CC_GroupBox", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_ComplexControl,(long) QStyle::CC_MdiControls, "CC_MdiControls");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"CC_MdiControls", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_ComplexControl->tp_dict,"CC_MdiControls", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_ComplexControl,(long) QStyle::CC_CustomBase, "CC_CustomBase");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"CC_CustomBase", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_ComplexControl->tp_dict,"CC_CustomBase", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QStyle::ComplexControl");
    Shiboken::TypeResolver::createValueTypeResolver<int>("QStyle$ConcreteWrapper::ComplexControl");
    // end of enum ComplexControl

    // init enum: RequestSoftwareInputPanel
    PyTypeObject* SbkPySide_QtGui_QStyle_RequestSoftwareInputPanel = Shiboken::Enum::newType("PySide.QtGui.QStyle.RequestSoftwareInputPanel");
    SbkPySide_QtGuiTypes[SBK_QSTYLE_REQUESTSOFTWAREINPUTPANEL_IDX] = SbkPySide_QtGui_QStyle_RequestSoftwareInputPanel;
    if (PyType_Ready(SbkPySide_QtGui_QStyle_RequestSoftwareInputPanel) < 0)
        return;
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,
            "RequestSoftwareInputPanel",((PyObject*)SbkPySide_QtGui_QStyle_RequestSoftwareInputPanel));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_RequestSoftwareInputPanel,(long) QStyle::RSIP_OnMouseClickAndAlreadyFocused, "RSIP_OnMouseClickAndAlreadyFocused");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"RSIP_OnMouseClickAndAlreadyFocused", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_RequestSoftwareInputPanel->tp_dict,"RSIP_OnMouseClickAndAlreadyFocused", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_RequestSoftwareInputPanel,(long) QStyle::RSIP_OnMouseClick, "RSIP_OnMouseClick");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"RSIP_OnMouseClick", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_RequestSoftwareInputPanel->tp_dict,"RSIP_OnMouseClick", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QStyle::RequestSoftwareInputPanel");
    Shiboken::TypeResolver::createValueTypeResolver<int>("QStyle$ConcreteWrapper::RequestSoftwareInputPanel");
    // end of enum RequestSoftwareInputPanel

    // init enum: SubElement
    PyTypeObject* SbkPySide_QtGui_QStyle_SubElement = Shiboken::Enum::newType("PySide.QtGui.QStyle.SubElement");
    SbkPySide_QtGuiTypes[SBK_QSTYLE_SUBELEMENT_IDX] = SbkPySide_QtGui_QStyle_SubElement;
    if (PyType_Ready(SbkPySide_QtGui_QStyle_SubElement) < 0)
        return;
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,
            "SubElement",((PyObject*)SbkPySide_QtGui_QStyle_SubElement));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_SubElement,(long) QStyle::SE_PushButtonContents, "SE_PushButtonContents");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SE_PushButtonContents", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_SubElement->tp_dict,"SE_PushButtonContents", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_SubElement,(long) QStyle::SE_PushButtonFocusRect, "SE_PushButtonFocusRect");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SE_PushButtonFocusRect", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_SubElement->tp_dict,"SE_PushButtonFocusRect", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_SubElement,(long) QStyle::SE_CheckBoxIndicator, "SE_CheckBoxIndicator");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SE_CheckBoxIndicator", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_SubElement->tp_dict,"SE_CheckBoxIndicator", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_SubElement,(long) QStyle::SE_CheckBoxContents, "SE_CheckBoxContents");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SE_CheckBoxContents", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_SubElement->tp_dict,"SE_CheckBoxContents", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_SubElement,(long) QStyle::SE_CheckBoxFocusRect, "SE_CheckBoxFocusRect");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SE_CheckBoxFocusRect", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_SubElement->tp_dict,"SE_CheckBoxFocusRect", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_SubElement,(long) QStyle::SE_CheckBoxClickRect, "SE_CheckBoxClickRect");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SE_CheckBoxClickRect", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_SubElement->tp_dict,"SE_CheckBoxClickRect", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_SubElement,(long) QStyle::SE_RadioButtonIndicator, "SE_RadioButtonIndicator");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SE_RadioButtonIndicator", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_SubElement->tp_dict,"SE_RadioButtonIndicator", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_SubElement,(long) QStyle::SE_RadioButtonContents, "SE_RadioButtonContents");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SE_RadioButtonContents", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_SubElement->tp_dict,"SE_RadioButtonContents", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_SubElement,(long) QStyle::SE_RadioButtonFocusRect, "SE_RadioButtonFocusRect");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SE_RadioButtonFocusRect", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_SubElement->tp_dict,"SE_RadioButtonFocusRect", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_SubElement,(long) QStyle::SE_RadioButtonClickRect, "SE_RadioButtonClickRect");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SE_RadioButtonClickRect", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_SubElement->tp_dict,"SE_RadioButtonClickRect", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_SubElement,(long) QStyle::SE_ComboBoxFocusRect, "SE_ComboBoxFocusRect");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SE_ComboBoxFocusRect", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_SubElement->tp_dict,"SE_ComboBoxFocusRect", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_SubElement,(long) QStyle::SE_SliderFocusRect, "SE_SliderFocusRect");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SE_SliderFocusRect", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_SubElement->tp_dict,"SE_SliderFocusRect", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_SubElement,(long) QStyle::SE_Q3DockWindowHandleRect, "SE_Q3DockWindowHandleRect");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SE_Q3DockWindowHandleRect", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_SubElement->tp_dict,"SE_Q3DockWindowHandleRect", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_SubElement,(long) QStyle::SE_ProgressBarGroove, "SE_ProgressBarGroove");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SE_ProgressBarGroove", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_SubElement->tp_dict,"SE_ProgressBarGroove", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_SubElement,(long) QStyle::SE_ProgressBarContents, "SE_ProgressBarContents");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SE_ProgressBarContents", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_SubElement->tp_dict,"SE_ProgressBarContents", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_SubElement,(long) QStyle::SE_ProgressBarLabel, "SE_ProgressBarLabel");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SE_ProgressBarLabel", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_SubElement->tp_dict,"SE_ProgressBarLabel", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_SubElement,(long) QStyle::SE_DialogButtonAccept, "SE_DialogButtonAccept");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SE_DialogButtonAccept", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_SubElement->tp_dict,"SE_DialogButtonAccept", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_SubElement,(long) QStyle::SE_DialogButtonReject, "SE_DialogButtonReject");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SE_DialogButtonReject", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_SubElement->tp_dict,"SE_DialogButtonReject", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_SubElement,(long) QStyle::SE_DialogButtonApply, "SE_DialogButtonApply");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SE_DialogButtonApply", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_SubElement->tp_dict,"SE_DialogButtonApply", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_SubElement,(long) QStyle::SE_DialogButtonHelp, "SE_DialogButtonHelp");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SE_DialogButtonHelp", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_SubElement->tp_dict,"SE_DialogButtonHelp", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_SubElement,(long) QStyle::SE_DialogButtonAll, "SE_DialogButtonAll");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SE_DialogButtonAll", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_SubElement->tp_dict,"SE_DialogButtonAll", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_SubElement,(long) QStyle::SE_DialogButtonAbort, "SE_DialogButtonAbort");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SE_DialogButtonAbort", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_SubElement->tp_dict,"SE_DialogButtonAbort", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_SubElement,(long) QStyle::SE_DialogButtonIgnore, "SE_DialogButtonIgnore");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SE_DialogButtonIgnore", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_SubElement->tp_dict,"SE_DialogButtonIgnore", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_SubElement,(long) QStyle::SE_DialogButtonRetry, "SE_DialogButtonRetry");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SE_DialogButtonRetry", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_SubElement->tp_dict,"SE_DialogButtonRetry", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_SubElement,(long) QStyle::SE_DialogButtonCustom, "SE_DialogButtonCustom");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SE_DialogButtonCustom", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_SubElement->tp_dict,"SE_DialogButtonCustom", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_SubElement,(long) QStyle::SE_ToolBoxTabContents, "SE_ToolBoxTabContents");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SE_ToolBoxTabContents", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_SubElement->tp_dict,"SE_ToolBoxTabContents", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_SubElement,(long) QStyle::SE_HeaderLabel, "SE_HeaderLabel");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SE_HeaderLabel", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_SubElement->tp_dict,"SE_HeaderLabel", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_SubElement,(long) QStyle::SE_HeaderArrow, "SE_HeaderArrow");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SE_HeaderArrow", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_SubElement->tp_dict,"SE_HeaderArrow", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_SubElement,(long) QStyle::SE_TabWidgetTabBar, "SE_TabWidgetTabBar");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SE_TabWidgetTabBar", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_SubElement->tp_dict,"SE_TabWidgetTabBar", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_SubElement,(long) QStyle::SE_TabWidgetTabPane, "SE_TabWidgetTabPane");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SE_TabWidgetTabPane", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_SubElement->tp_dict,"SE_TabWidgetTabPane", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_SubElement,(long) QStyle::SE_TabWidgetTabContents, "SE_TabWidgetTabContents");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SE_TabWidgetTabContents", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_SubElement->tp_dict,"SE_TabWidgetTabContents", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_SubElement,(long) QStyle::SE_TabWidgetLeftCorner, "SE_TabWidgetLeftCorner");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SE_TabWidgetLeftCorner", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_SubElement->tp_dict,"SE_TabWidgetLeftCorner", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_SubElement,(long) QStyle::SE_TabWidgetRightCorner, "SE_TabWidgetRightCorner");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SE_TabWidgetRightCorner", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_SubElement->tp_dict,"SE_TabWidgetRightCorner", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_SubElement,(long) QStyle::SE_ViewItemCheckIndicator, "SE_ViewItemCheckIndicator");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SE_ViewItemCheckIndicator", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_SubElement->tp_dict,"SE_ViewItemCheckIndicator", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_SubElement,(long) QStyle::SE_ItemViewItemCheckIndicator, "SE_ItemViewItemCheckIndicator");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SE_ItemViewItemCheckIndicator", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_SubElement->tp_dict,"SE_ItemViewItemCheckIndicator", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_SubElement,(long) QStyle::SE_TabBarTearIndicator, "SE_TabBarTearIndicator");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SE_TabBarTearIndicator", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_SubElement->tp_dict,"SE_TabBarTearIndicator", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_SubElement,(long) QStyle::SE_TreeViewDisclosureItem, "SE_TreeViewDisclosureItem");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SE_TreeViewDisclosureItem", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_SubElement->tp_dict,"SE_TreeViewDisclosureItem", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_SubElement,(long) QStyle::SE_LineEditContents, "SE_LineEditContents");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SE_LineEditContents", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_SubElement->tp_dict,"SE_LineEditContents", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_SubElement,(long) QStyle::SE_FrameContents, "SE_FrameContents");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SE_FrameContents", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_SubElement->tp_dict,"SE_FrameContents", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_SubElement,(long) QStyle::SE_DockWidgetCloseButton, "SE_DockWidgetCloseButton");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SE_DockWidgetCloseButton", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_SubElement->tp_dict,"SE_DockWidgetCloseButton", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_SubElement,(long) QStyle::SE_DockWidgetFloatButton, "SE_DockWidgetFloatButton");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SE_DockWidgetFloatButton", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_SubElement->tp_dict,"SE_DockWidgetFloatButton", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_SubElement,(long) QStyle::SE_DockWidgetTitleBarText, "SE_DockWidgetTitleBarText");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SE_DockWidgetTitleBarText", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_SubElement->tp_dict,"SE_DockWidgetTitleBarText", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_SubElement,(long) QStyle::SE_DockWidgetIcon, "SE_DockWidgetIcon");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SE_DockWidgetIcon", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_SubElement->tp_dict,"SE_DockWidgetIcon", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_SubElement,(long) QStyle::SE_CheckBoxLayoutItem, "SE_CheckBoxLayoutItem");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SE_CheckBoxLayoutItem", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_SubElement->tp_dict,"SE_CheckBoxLayoutItem", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_SubElement,(long) QStyle::SE_ComboBoxLayoutItem, "SE_ComboBoxLayoutItem");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SE_ComboBoxLayoutItem", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_SubElement->tp_dict,"SE_ComboBoxLayoutItem", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_SubElement,(long) QStyle::SE_DateTimeEditLayoutItem, "SE_DateTimeEditLayoutItem");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SE_DateTimeEditLayoutItem", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_SubElement->tp_dict,"SE_DateTimeEditLayoutItem", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_SubElement,(long) QStyle::SE_DialogButtonBoxLayoutItem, "SE_DialogButtonBoxLayoutItem");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SE_DialogButtonBoxLayoutItem", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_SubElement->tp_dict,"SE_DialogButtonBoxLayoutItem", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_SubElement,(long) QStyle::SE_LabelLayoutItem, "SE_LabelLayoutItem");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SE_LabelLayoutItem", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_SubElement->tp_dict,"SE_LabelLayoutItem", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_SubElement,(long) QStyle::SE_ProgressBarLayoutItem, "SE_ProgressBarLayoutItem");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SE_ProgressBarLayoutItem", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_SubElement->tp_dict,"SE_ProgressBarLayoutItem", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_SubElement,(long) QStyle::SE_PushButtonLayoutItem, "SE_PushButtonLayoutItem");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SE_PushButtonLayoutItem", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_SubElement->tp_dict,"SE_PushButtonLayoutItem", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_SubElement,(long) QStyle::SE_RadioButtonLayoutItem, "SE_RadioButtonLayoutItem");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SE_RadioButtonLayoutItem", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_SubElement->tp_dict,"SE_RadioButtonLayoutItem", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_SubElement,(long) QStyle::SE_SliderLayoutItem, "SE_SliderLayoutItem");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SE_SliderLayoutItem", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_SubElement->tp_dict,"SE_SliderLayoutItem", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_SubElement,(long) QStyle::SE_SpinBoxLayoutItem, "SE_SpinBoxLayoutItem");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SE_SpinBoxLayoutItem", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_SubElement->tp_dict,"SE_SpinBoxLayoutItem", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_SubElement,(long) QStyle::SE_ToolButtonLayoutItem, "SE_ToolButtonLayoutItem");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SE_ToolButtonLayoutItem", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_SubElement->tp_dict,"SE_ToolButtonLayoutItem", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_SubElement,(long) QStyle::SE_FrameLayoutItem, "SE_FrameLayoutItem");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SE_FrameLayoutItem", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_SubElement->tp_dict,"SE_FrameLayoutItem", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_SubElement,(long) QStyle::SE_GroupBoxLayoutItem, "SE_GroupBoxLayoutItem");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SE_GroupBoxLayoutItem", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_SubElement->tp_dict,"SE_GroupBoxLayoutItem", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_SubElement,(long) QStyle::SE_TabWidgetLayoutItem, "SE_TabWidgetLayoutItem");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SE_TabWidgetLayoutItem", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_SubElement->tp_dict,"SE_TabWidgetLayoutItem", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_SubElement,(long) QStyle::SE_ItemViewItemDecoration, "SE_ItemViewItemDecoration");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SE_ItemViewItemDecoration", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_SubElement->tp_dict,"SE_ItemViewItemDecoration", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_SubElement,(long) QStyle::SE_ItemViewItemText, "SE_ItemViewItemText");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SE_ItemViewItemText", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_SubElement->tp_dict,"SE_ItemViewItemText", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_SubElement,(long) QStyle::SE_ItemViewItemFocusRect, "SE_ItemViewItemFocusRect");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SE_ItemViewItemFocusRect", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_SubElement->tp_dict,"SE_ItemViewItemFocusRect", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_SubElement,(long) QStyle::SE_TabBarTabLeftButton, "SE_TabBarTabLeftButton");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SE_TabBarTabLeftButton", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_SubElement->tp_dict,"SE_TabBarTabLeftButton", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_SubElement,(long) QStyle::SE_TabBarTabRightButton, "SE_TabBarTabRightButton");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SE_TabBarTabRightButton", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_SubElement->tp_dict,"SE_TabBarTabRightButton", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_SubElement,(long) QStyle::SE_TabBarTabText, "SE_TabBarTabText");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SE_TabBarTabText", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_SubElement->tp_dict,"SE_TabBarTabText", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_SubElement,(long) QStyle::SE_ShapedFrameContents, "SE_ShapedFrameContents");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SE_ShapedFrameContents", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_SubElement->tp_dict,"SE_ShapedFrameContents", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_SubElement,(long) QStyle::SE_ToolBarHandle, "SE_ToolBarHandle");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SE_ToolBarHandle", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_SubElement->tp_dict,"SE_ToolBarHandle", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyle_SubElement,(long) QStyle::SE_CustomBase, "SE_CustomBase");
    PyDict_SetItemString(Sbk_QStyle_Type.super.ht_type.tp_dict,"SE_CustomBase", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyle_SubElement->tp_dict,"SE_CustomBase", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QStyle::SubElement");
    Shiboken::TypeResolver::createValueTypeResolver<int>("QStyle$ConcreteWrapper::SubElement");
    // end of enum SubElement


    Shiboken::TypeResolver::createObjectTypeResolver<QStyle >("QStyle*");
    Shiboken::TypeResolver::createObjectTypeResolver<QStyle >("QStyle$ConcreteWrapper*");
    Shiboken::TypeResolver::createObjectTypeResolver<QStyle >(typeid(QStyle).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QStyle >(typeid(QStyleWrapper).name());
    PySide::initQtMetaType< ::QStyle* >();
    qRegisterMetaType< ::QStyle::PixelMetric >("QStyle::PixelMetric");
    qRegisterMetaType< ::QStyle::SubControl >("QStyle::SubControl");
    qRegisterMetaType< ::QStyle::SubControls >("QStyle::SubControls");
    qRegisterMetaType< ::QStyle::StandardPixmap >("QStyle::StandardPixmap");
    qRegisterMetaType< ::QStyle::StyleHint >("QStyle::StyleHint");
    qRegisterMetaType< ::QStyle::PrimitiveElement >("QStyle::PrimitiveElement");
    qRegisterMetaType< ::QStyle::ControlElement >("QStyle::ControlElement");
    qRegisterMetaType< ::QStyle::ContentsType >("QStyle::ContentsType");
    qRegisterMetaType< ::QStyle::StateFlag >("QStyle::StateFlag");
    qRegisterMetaType< ::QStyle::State >("QStyle::State");
    qRegisterMetaType< ::QStyle::ComplexControl >("QStyle::ComplexControl");
    qRegisterMetaType< ::QStyle::RequestSoftwareInputPanel >("QStyle::RequestSoftwareInputPanel");
    qRegisterMetaType< ::QStyle::SubElement >("QStyle::SubElement");
}

