/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <set>
#include "pyside_qtgui_python.h"

#include "qtreewidget_wrapper.h"

// Extra includes
#include <QList>
#include <QStringList>
#include <qabstractitemdelegate.h>
#include <qabstractitemmodel.h>
#include <qaction.h>
#include <qbitmap.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qcursor.h>
#include <qevent.h>
#include <qfont.h>
#include <qfontinfo.h>
#include <qfontmetrics.h>
#include <qgraphicseffect.h>
#include <qgraphicsproxywidget.h>
#include <qheaderview.h>
#include <qicon.h>
#include <qinputcontext.h>
#include <qitemselectionmodel.h>
#include <qkeysequence.h>
#include <qlayout.h>
#include <qlocale.h>
#include <qmargins.h>
#include <qmimedata.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qpaintdevice.h>
#include <qpaintengine.h>
#include <qpainter.h>
#include <qpalette.h>
#include <qpoint.h>
#include <qrect.h>
#include <qregion.h>
#include <qscrollbar.h>
#include <qsize.h>
#include <qsizepolicy.h>
#include <qstyle.h>
#include <qstyleoption.h>
#include <qtreewidget.h>
#include <qwidget.h>
#include <qx11info_x11.h>


// Native ---------------------------------------------------------

QTreeWidgetWrapper::QTreeWidgetWrapper(QWidget * parent) : QTreeWidget(parent) {
    // ... middle
}

void QTreeWidgetWrapper::actionEvent(QActionEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "actionEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::actionEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QActionEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QTreeWidgetWrapper::changeEvent(QEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "changeEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QFrame::changeEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QTreeWidgetWrapper::childEvent(QChildEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "childEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::childEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QChildEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QTreeWidgetWrapper::closeEditor(QWidget * editor, QAbstractItemDelegate::EndEditHint hint)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "closeEditor"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractItemView::closeEditor(editor, hint);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter< ::QWidget * >::toPython(editor),
        Shiboken::Converter< ::QAbstractItemDelegate::EndEditHint >::toPython(hint)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QTreeWidgetWrapper::closeEvent(QCloseEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "closeEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::closeEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QCloseEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QTreeWidgetWrapper::commitData(QWidget * editor)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "commitData"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractItemView::commitData(editor);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QWidget * >::toPython(editor)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QTreeWidgetWrapper::connectNotify(const char * signal)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "connectNotify"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QTreeWidgetWrapper::contextMenuEvent(QContextMenuEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "contextMenuEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractScrollArea::contextMenuEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QContextMenuEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QTreeWidgetWrapper::currentChanged(const QModelIndex & current, const QModelIndex & previous)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "currentChanged"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QTreeView::currentChanged(current, previous);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter< ::QModelIndex >::toPython(current),
        Shiboken::Converter< ::QModelIndex >::toPython(previous)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QTreeWidgetWrapper::customEvent(QEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "customEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::customEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QTreeWidgetWrapper::dataChanged(const QModelIndex & topLeft, const QModelIndex & bottomRight)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "dataChanged"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QTreeView::dataChanged(topLeft, bottomRight);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter< ::QModelIndex >::toPython(topLeft),
        Shiboken::Converter< ::QModelIndex >::toPython(bottomRight)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

int QTreeWidgetWrapper::devType() const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return int(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "devType"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::devType();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return int(0);
    }
    // Check return type
    bool typeIsValid = PyInt_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QTreeWidget.devType", "int", pyResult->ob_type->tp_name);
        return int(0);
    }
    int cppResult(Shiboken::Converter< int >::toCpp(pyResult));
    return cppResult;
}

void QTreeWidgetWrapper::disconnectNotify(const char * signal)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "disconnectNotify"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QTreeWidgetWrapper::doItemsLayout()
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "doItemsLayout"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QTreeView::doItemsLayout();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QTreeWidgetWrapper::dragEnterEvent(QDragEnterEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "dragEnterEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractItemView::dragEnterEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QDragEnterEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QTreeWidgetWrapper::dragLeaveEvent(QDragLeaveEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "dragLeaveEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractItemView::dragLeaveEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QDragLeaveEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QTreeWidgetWrapper::dragMoveEvent(QDragMoveEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "dragMoveEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QTreeView::dragMoveEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QDragMoveEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QTreeWidgetWrapper::drawBranches(QPainter * painter, const QRect & rect, const QModelIndex & index) const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "drawBranches"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QTreeView::drawBranches(painter, rect, index);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NNN)",
        Shiboken::Converter< ::QPainter * >::toPython(painter),
        Shiboken::Converter< ::QRect >::toPython(rect),
        Shiboken::Converter< ::QModelIndex >::toPython(index)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QTreeWidgetWrapper::drawRow(QPainter * painter, const QStyleOptionViewItem & options, const QModelIndex & index) const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "drawRow"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QTreeView::drawRow(painter, options, index);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NNN)",
        Shiboken::Converter< ::QPainter * >::toPython(painter),
        Shiboken::Converter< ::QStyleOptionViewItem >::toPython(options),
        Shiboken::Converter< ::QModelIndex >::toPython(index)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QTreeWidgetWrapper::dropEvent(QDropEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "dropEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QTreeWidget::dropEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QDropEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

bool QTreeWidgetWrapper::dropMimeData(QTreeWidgetItem * parent, int index, const QMimeData * data, Qt::DropAction action)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return bool(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "dropMimeData"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QTreeWidget::dropMimeData(parent, index, data, action);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NiNN)",
        Shiboken::Converter< ::QTreeWidgetItem * >::toPython(parent),
        index,
        Shiboken::Converter< ::QMimeData * >::toPython(data),
        Shiboken::Converter< ::Qt::DropAction >::toPython(action)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QTreeWidget.dropMimeData", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
    return cppResult;
}

bool QTreeWidgetWrapper::edit(const QModelIndex & index, QAbstractItemView::EditTrigger trigger, QEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return bool(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "edit"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractItemView::edit(index, trigger, event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NNN)",
        Shiboken::Converter< ::QModelIndex >::toPython(index),
        Shiboken::Converter< ::QAbstractItemView::EditTrigger >::toPython(trigger),
        Shiboken::Converter< ::QEvent * >::toPython(event)
    ));
    bool invalidadeArg3 = PyTuple_GET_ITEM(pyargs, 2)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QTreeWidget.edit", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    if (invalidadeArg3)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 2));
    return cppResult;
}

void QTreeWidgetWrapper::editorDestroyed(QObject * editor)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "editorDestroyed"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractItemView::editorDestroyed(editor);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QObject * >::toPython(editor)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QTreeWidgetWrapper::enterEvent(QEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "enterEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::enterEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

bool QTreeWidgetWrapper::event(QEvent * e)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return bool(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "event"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QTreeWidget::event(e);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(e)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QTreeWidget.event", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    return cppResult;
}

bool QTreeWidgetWrapper::eventFilter(QObject * arg__1, QEvent * arg__2)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return bool(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "eventFilter"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::eventFilter(arg__1, arg__2);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter< ::QObject * >::toPython(arg__1),
        Shiboken::Converter< ::QEvent * >::toPython(arg__2)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QTreeWidget.eventFilter", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    return cppResult;
}

void QTreeWidgetWrapper::focusInEvent(QFocusEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "focusInEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractItemView::focusInEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QFocusEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

bool QTreeWidgetWrapper::focusNextPrevChild(bool next)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return bool(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "focusNextPrevChild"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractItemView::focusNextPrevChild(next);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< bool >::toPython(next)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QTreeWidget.focusNextPrevChild", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    return cppResult;
}

void QTreeWidgetWrapper::focusOutEvent(QFocusEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "focusOutEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractItemView::focusOutEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QFocusEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

int QTreeWidgetWrapper::heightForWidth(int arg__1) const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return int(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "heightForWidth"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::heightForWidth(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(i)",
        arg__1
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return int(0);
    }
    // Check return type
    bool typeIsValid = PyInt_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QTreeWidget.heightForWidth", "int", pyResult->ob_type->tp_name);
        return int(0);
    }
    int cppResult(Shiboken::Converter< int >::toCpp(pyResult));
    return cppResult;
}

void QTreeWidgetWrapper::hideEvent(QHideEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "hideEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::hideEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QHideEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

int QTreeWidgetWrapper::horizontalOffset() const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return int(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "horizontalOffset"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QTreeView::horizontalOffset();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return int(0);
    }
    // Check return type
    bool typeIsValid = PyInt_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QTreeWidget.horizontalOffset", "int", pyResult->ob_type->tp_name);
        return int(0);
    }
    int cppResult(Shiboken::Converter< int >::toCpp(pyResult));
    return cppResult;
}

void QTreeWidgetWrapper::horizontalScrollbarAction(int action)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "horizontalScrollbarAction"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QTreeView::horizontalScrollbarAction(action);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(i)",
        action
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QTreeWidgetWrapper::horizontalScrollbarValueChanged(int value)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "horizontalScrollbarValueChanged"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractItemView::horizontalScrollbarValueChanged(value);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(i)",
        value
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

QModelIndex QTreeWidgetWrapper::indexAt(const QPoint & p) const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return QModelIndex();
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "indexAt"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QTreeView::indexAt(p);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QPoint >::toPython(p)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QModelIndex();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QModelIndex >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QTreeWidget.indexAt", Shiboken::SbkType<QModelIndex >()->tp_name, pyResult->ob_type->tp_name);
        return QModelIndex();
    }
    QModelIndex cppResult(Shiboken::Converter< ::QModelIndex >::toCpp(pyResult));
    return cppResult;
}

void QTreeWidgetWrapper::inputMethodEvent(QInputMethodEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "inputMethodEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractItemView::inputMethodEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QInputMethodEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

QVariant QTreeWidgetWrapper::inputMethodQuery(Qt::InputMethodQuery query) const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return QVariant(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "inputMethodQuery"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractItemView::inputMethodQuery(query);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::Qt::InputMethodQuery >::toPython(query)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QVariant(0);
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< QVariant >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QTreeWidget.inputMethodQuery", "QVariant", pyResult->ob_type->tp_name);
        return QVariant(0);
    }
    QVariant cppResult(Shiboken::Converter< QVariant >::toCpp(pyResult));
    return cppResult;
}

bool QTreeWidgetWrapper::isIndexHidden(const QModelIndex & index) const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return bool(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "isIndexHidden"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QTreeView::isIndexHidden(index);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QModelIndex >::toPython(index)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QTreeWidget.isIndexHidden", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    return cppResult;
}

void QTreeWidgetWrapper::keyPressEvent(QKeyEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "keyPressEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QTreeView::keyPressEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QKeyEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QTreeWidgetWrapper::keyReleaseEvent(QKeyEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "keyReleaseEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::keyReleaseEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QKeyEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QTreeWidgetWrapper::keyboardSearch(const QString & search)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "keyboardSearch"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QTreeView::keyboardSearch(search);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< QString >::toPython(search)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QTreeWidgetWrapper::languageChange()
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "languageChange"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::languageChange();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QTreeWidgetWrapper::leaveEvent(QEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "leaveEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::leaveEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

int QTreeWidgetWrapper::metric(QPaintDevice::PaintDeviceMetric arg__1) const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return int(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "metric"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::metric(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QPaintDevice::PaintDeviceMetric >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return int(0);
    }
    // Check return type
    bool typeIsValid = PyInt_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QTreeWidget.metric", "int", pyResult->ob_type->tp_name);
        return int(0);
    }
    int cppResult(Shiboken::Converter< int >::toCpp(pyResult));
    return cppResult;
}

QMimeData * QTreeWidgetWrapper::mimeData(const QList<QTreeWidgetItem * > items) const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return 0;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "mimeData"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QTreeWidget::mimeData(items);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QList<QTreeWidgetItem * > >::toPython(items)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return 0;
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QMimeData * >::isConvertible(pyResult);
    typeIsValid = typeIsValid || (pyResult == Py_None);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QTreeWidget.mimeData", Shiboken::SbkType<QMimeData >()->tp_name, pyResult->ob_type->tp_name);
        return 0;
    }
    QMimeData * cppResult(Shiboken::Converter< ::QMimeData * >::toCpp(pyResult));
    return cppResult;
}

QStringList QTreeWidgetWrapper::mimeTypes() const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return QStringList();
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "mimeTypes"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QTreeWidget::mimeTypes();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QStringList();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QStringList >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QTreeWidget.mimeTypes", "list", pyResult->ob_type->tp_name);
        return QStringList();
    }
    QStringList cppResult(Shiboken::Converter< ::QStringList >::toCpp(pyResult));
    return cppResult;
}

QSize QTreeWidgetWrapper::minimumSizeHint() const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return QSize();
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "minimumSizeHint"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractScrollArea::minimumSizeHint();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QSize();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QSize >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QTreeWidget.minimumSizeHint", Shiboken::SbkType<QSize >()->tp_name, pyResult->ob_type->tp_name);
        return QSize();
    }
    QSize cppResult(Shiboken::Converter< ::QSize >::toCpp(pyResult));
    return cppResult;
}

void QTreeWidgetWrapper::mouseDoubleClickEvent(QMouseEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "mouseDoubleClickEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QTreeView::mouseDoubleClickEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QMouseEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QTreeWidgetWrapper::mouseMoveEvent(QMouseEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "mouseMoveEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QTreeView::mouseMoveEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QMouseEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QTreeWidgetWrapper::mousePressEvent(QMouseEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "mousePressEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QTreeView::mousePressEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QMouseEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QTreeWidgetWrapper::mouseReleaseEvent(QMouseEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "mouseReleaseEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QTreeView::mouseReleaseEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QMouseEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QTreeWidgetWrapper::moveEvent(QMoveEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "moveEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::moveEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QMoveEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

QPaintEngine * QTreeWidgetWrapper::paintEngine() const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return 0;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "paintEngine"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::paintEngine();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return 0;
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QPaintEngine * >::isConvertible(pyResult);
    typeIsValid = typeIsValid || (pyResult == Py_None);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QTreeWidget.paintEngine", Shiboken::SbkType<QPaintEngine >()->tp_name, pyResult->ob_type->tp_name);
        return 0;
    }
    QPaintEngine * cppResult(Shiboken::Converter< ::QPaintEngine * >::toCpp(pyResult));
    return cppResult;
}

void QTreeWidgetWrapper::paintEvent(QPaintEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "paintEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QTreeView::paintEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QPaintEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QTreeWidgetWrapper::reset()
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "reset"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QTreeView::reset();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QTreeWidgetWrapper::resizeEvent(QResizeEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "resizeEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractItemView::resizeEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QResizeEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QTreeWidgetWrapper::rowsAboutToBeRemoved(const QModelIndex & parent, int start, int end)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "rowsAboutToBeRemoved"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QTreeView::rowsAboutToBeRemoved(parent, start, end);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(Nii)",
        Shiboken::Converter< ::QModelIndex >::toPython(parent),
        start,
        end
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QTreeWidgetWrapper::rowsInserted(const QModelIndex & parent, int start, int end)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "rowsInserted"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QTreeView::rowsInserted(parent, start, end);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(Nii)",
        Shiboken::Converter< ::QModelIndex >::toPython(parent),
        start,
        end
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QTreeWidgetWrapper::scrollContentsBy(int dx, int dy)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "scrollContentsBy"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QTreeView::scrollContentsBy(dx, dy);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(ii)",
        dx,
        dy
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QTreeWidgetWrapper::scrollTo(const QModelIndex & index, QAbstractItemView::ScrollHint hint)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "scrollTo"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QTreeView::scrollTo(index, hint);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter< ::QModelIndex >::toPython(index),
        Shiboken::Converter< ::QAbstractItemView::ScrollHint >::toPython(hint)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QTreeWidgetWrapper::selectAll()
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "selectAll"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QTreeView::selectAll();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

QList<QModelIndex > QTreeWidgetWrapper::selectedIndexes() const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return QList<QModelIndex >();
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "selectedIndexes"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QTreeView::selectedIndexes();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QList<QModelIndex >();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QList<QModelIndex > >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QTreeWidget.selectedIndexes", "list", pyResult->ob_type->tp_name);
        return QList<QModelIndex >();
    }
    QList<QModelIndex > cppResult(Shiboken::Converter< ::QList<QModelIndex > >::toCpp(pyResult));
    return cppResult;
}

void QTreeWidgetWrapper::selectionChanged(const QItemSelection & selected, const QItemSelection & deselected)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "selectionChanged"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QTreeView::selectionChanged(selected, deselected);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter< ::QItemSelection >::toPython(selected),
        Shiboken::Converter< ::QItemSelection >::toPython(deselected)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

QFlags<QItemSelectionModel::SelectionFlag> QTreeWidgetWrapper::selectionCommand(const QModelIndex & index, const QEvent * event) const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return QFlags<QItemSelectionModel::SelectionFlag>();
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "selectionCommand"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractItemView::selectionCommand(index, event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter< ::QModelIndex >::toPython(index),
        Shiboken::Converter< ::QEvent * >::toPython(event)
    ));
    bool invalidadeArg2 = PyTuple_GET_ITEM(pyargs, 1)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QFlags<QItemSelectionModel::SelectionFlag>();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QFlags<QItemSelectionModel::SelectionFlag> >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QTreeWidget.selectionCommand", Shiboken::SbkType<QFlags<QItemSelectionModel::SelectionFlag> >()->tp_name, pyResult->ob_type->tp_name);
        return QFlags<QItemSelectionModel::SelectionFlag>();
    }
    QFlags<QItemSelectionModel::SelectionFlag> cppResult(Shiboken::Converter< ::QFlags<QItemSelectionModel::SelectionFlag> >::toCpp(pyResult));
    if (invalidadeArg2)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 1));
    return cppResult;
}

void QTreeWidgetWrapper::setRootIndex(const QModelIndex & index)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "setRootIndex"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QTreeView::setRootIndex(index);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QModelIndex >::toPython(index)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QTreeWidgetWrapper::setSelection(const QRect & rect, QFlags<QItemSelectionModel::SelectionFlag> command)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "setSelection"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QTreeView::setSelection(rect, command);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter< ::QRect >::toPython(rect),
        Shiboken::Converter< ::QFlags<QItemSelectionModel::SelectionFlag> >::toPython(command)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QTreeWidgetWrapper::setSelectionModel(QItemSelectionModel * selectionModel)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "setSelectionModel"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QTreeWidget::setSelectionModel(selectionModel);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QItemSelectionModel * >::toPython(selectionModel)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QTreeWidgetWrapper::setVisible(bool visible)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "setVisible"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::setVisible(visible);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< bool >::toPython(visible)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QTreeWidgetWrapper::showEvent(QShowEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "showEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::showEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QShowEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

QSize QTreeWidgetWrapper::sizeHint() const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return QSize();
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "sizeHint"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractScrollArea::sizeHint();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QSize();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QSize >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QTreeWidget.sizeHint", Shiboken::SbkType<QSize >()->tp_name, pyResult->ob_type->tp_name);
        return QSize();
    }
    QSize cppResult(Shiboken::Converter< ::QSize >::toCpp(pyResult));
    return cppResult;
}

int QTreeWidgetWrapper::sizeHintForColumn(int column) const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return int(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "sizeHintForColumn"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QTreeView::sizeHintForColumn(column);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(i)",
        column
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return int(0);
    }
    // Check return type
    bool typeIsValid = PyInt_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QTreeWidget.sizeHintForColumn", "int", pyResult->ob_type->tp_name);
        return int(0);
    }
    int cppResult(Shiboken::Converter< int >::toCpp(pyResult));
    return cppResult;
}

int QTreeWidgetWrapper::sizeHintForRow(int row) const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return int(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "sizeHintForRow"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractItemView::sizeHintForRow(row);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(i)",
        row
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return int(0);
    }
    // Check return type
    bool typeIsValid = PyInt_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QTreeWidget.sizeHintForRow", "int", pyResult->ob_type->tp_name);
        return int(0);
    }
    int cppResult(Shiboken::Converter< int >::toCpp(pyResult));
    return cppResult;
}

void QTreeWidgetWrapper::startDrag(QFlags<Qt::DropAction> supportedActions)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "startDrag"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractItemView::startDrag(supportedActions);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QFlags<Qt::DropAction> >::toPython(supportedActions)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

QFlags<Qt::DropAction> QTreeWidgetWrapper::supportedDropActions() const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return QFlags<Qt::DropAction>();
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "supportedDropActions"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QTreeWidget::supportedDropActions();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QFlags<Qt::DropAction>();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QFlags<Qt::DropAction> >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QTreeWidget.supportedDropActions", Shiboken::SbkType<QFlags<Qt::DropAction> >()->tp_name, pyResult->ob_type->tp_name);
        return QFlags<Qt::DropAction>();
    }
    QFlags<Qt::DropAction> cppResult(Shiboken::Converter< ::QFlags<Qt::DropAction> >::toCpp(pyResult));
    return cppResult;
}

void QTreeWidgetWrapper::tabletEvent(QTabletEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "tabletEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::tabletEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QTabletEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QTreeWidgetWrapper::timerEvent(QTimerEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "timerEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QTreeView::timerEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QTimerEvent * >::toPython(event)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QTreeWidgetWrapper::updateEditorData()
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "updateEditorData"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractItemView::updateEditorData();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QTreeWidgetWrapper::updateEditorGeometries()
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "updateEditorGeometries"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractItemView::updateEditorGeometries();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QTreeWidgetWrapper::updateGeometries()
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "updateGeometries"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QTreeView::updateGeometries();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

int QTreeWidgetWrapper::verticalOffset() const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return int(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "verticalOffset"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QTreeView::verticalOffset();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return int(0);
    }
    // Check return type
    bool typeIsValid = PyInt_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QTreeWidget.verticalOffset", "int", pyResult->ob_type->tp_name);
        return int(0);
    }
    int cppResult(Shiboken::Converter< int >::toCpp(pyResult));
    return cppResult;
}

void QTreeWidgetWrapper::verticalScrollbarAction(int action)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "verticalScrollbarAction"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractItemView::verticalScrollbarAction(action);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(i)",
        action
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QTreeWidgetWrapper::verticalScrollbarValueChanged(int value)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "verticalScrollbarValueChanged"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractItemView::verticalScrollbarValueChanged(value);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(i)",
        value
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

QStyleOptionViewItem QTreeWidgetWrapper::viewOptions() const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return QStyleOptionViewItem();
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "viewOptions"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractItemView::viewOptions();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QStyleOptionViewItem();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QStyleOptionViewItem >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QTreeWidget.viewOptions", Shiboken::SbkType<QStyleOptionViewItem >()->tp_name, pyResult->ob_type->tp_name);
        return QStyleOptionViewItem();
    }
    QStyleOptionViewItem cppResult(Shiboken::Converter< ::QStyleOptionViewItem >::toCpp(pyResult));
    return cppResult;
}

bool QTreeWidgetWrapper::viewportEvent(QEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return bool(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "viewportEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QTreeView::viewportEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QTreeWidget.viewportEvent", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
    return cppResult;
}

QRect QTreeWidgetWrapper::visualRect(const QModelIndex & index) const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return QRect();
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "visualRect"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QTreeView::visualRect(index);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QModelIndex >::toPython(index)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QRect();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QRect >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QTreeWidget.visualRect", Shiboken::SbkType<QRect >()->tp_name, pyResult->ob_type->tp_name);
        return QRect();
    }
    QRect cppResult(Shiboken::Converter< ::QRect >::toCpp(pyResult));
    return cppResult;
}

QRegion QTreeWidgetWrapper::visualRegionForSelection(const QItemSelection & selection) const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return QRegion();
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "visualRegionForSelection"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QTreeView::visualRegionForSelection(selection);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QItemSelection >::toPython(selection)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QRegion();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QRegion >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QTreeWidget.visualRegionForSelection", Shiboken::SbkType<QRegion >()->tp_name, pyResult->ob_type->tp_name);
        return QRegion();
    }
    QRegion cppResult(Shiboken::Converter< ::QRegion >::toCpp(pyResult));
    return cppResult;
}

void QTreeWidgetWrapper::wheelEvent(QWheelEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "wheelEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractScrollArea::wheelEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QWheelEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

const QMetaObject* QTreeWidgetWrapper::metaObject() const
{
    SbkObject* pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    return reinterpret_cast<QMetaObject*>(Shiboken::Object::getTypeUserData(pySelf));
}

int QTreeWidgetWrapper::qt_metacall(QMetaObject::Call call, int id, void** args)
{
    int result = QTreeWidget::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

QTreeWidgetWrapper::~QTreeWidgetWrapper()
{
    SbkObject* wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QTreeWidget_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QTreeWidget >()))
        return -1;

    QTreeWidgetWrapper* cptr = 0;
    int overloadId = -1;
    const char* argNames[] = {"parent"};
    const QMetaObject* metaObject;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths


    if (!PyArg_ParseTuple(args, "|O:QTreeWidget", &(pyargs[0])))
        return -1;

    // Overloaded function decisor
    // 0: QTreeWidget(QWidget*)
    if (numArgs == 0) {
        overloadId = 0; // QTreeWidget(QWidget*)
    } else if (Shiboken::Converter< ::QWidget * >::isConvertible(pyargs[0])) {
        overloadId = 0; // QTreeWidget(QWidget*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTreeWidget_Init_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "parent");
                if (value) {
                    if (pyargs[0])
                        errorArgName = "parent";
                    else if (Shiboken::Converter< ::QWidget * >::isConvertible(value))
                        pyargs[0] = value;
                    else
                        goto Sbk_QTreeWidget_Init_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QTreeWidget(): got multiple values for keyword argument '%s'", errorArgName);
                    return -1;
                }
            }
            if (!Shiboken::Object::isValid(pyargs[0]))
                return -1;
            QWidget * cppArg0 = pyargs[0] ? Shiboken::Converter<QWidget * >::toCpp(pyargs[0]) : 0;

            if(!PyErr_Occurred()) {
                // QTreeWidget(QWidget*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new QTreeWidgetWrapper(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                Shiboken::Object::setParent(pyargs[0], self);
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QTreeWidget >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QTreeWidget_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    metaObject = cptr->metaObject(); // <- init python qt properties
    if (kwds && !PySide::fillQtProperties(self, metaObject, kwds, argNames, 1))
        return -1;


    return 1;

    Sbk_QTreeWidget_Init_TypeError:
        const char* overloads[] = {"PySide.QtGui.QWidget = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTreeWidget", overloads);
        return -1;
}

static PyObject* Sbk_QTreeWidgetFunc_addTopLevelItem(PyObject* self, PyObject* arg)
{
    QTreeWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTreeWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: addTopLevelItem(QTreeWidgetItem*)
    if (Shiboken::Converter< ::QTreeWidgetItem * >::isConvertible(arg)) {
        overloadId = 0; // addTopLevelItem(QTreeWidgetItem*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTreeWidgetFunc_addTopLevelItem_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QTreeWidgetItem * cppArg0 = Shiboken::Converter<QTreeWidgetItem * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // addTopLevelItem(QTreeWidgetItem*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->addTopLevelItem(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                Shiboken::Object::setParent(self, arg);
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTreeWidgetFunc_addTopLevelItem_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTreeWidgetItem", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTreeWidget.addTopLevelItem", overloads);
        return 0;
}

static PyObject* Sbk_QTreeWidgetFunc_addTopLevelItems(PyObject* self, PyObject* arg)
{
    QTreeWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTreeWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: addTopLevelItems(QList<QTreeWidgetItem*>)
    if (Shiboken::Converter< ::QList<QTreeWidgetItem * > >::isConvertible(arg)) {
        overloadId = 0; // addTopLevelItems(QList<QTreeWidgetItem*>)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTreeWidgetFunc_addTopLevelItems_TypeError;

    // Call function/method
    {
        {
            QList<QTreeWidgetItem * > cppArg0 = Shiboken::Converter<QList<QTreeWidgetItem * > >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // addTopLevelItems(QList<QTreeWidgetItem*>)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->addTopLevelItems(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                Shiboken::Object::setParent(self, arg);
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTreeWidgetFunc_addTopLevelItems_TypeError:
        const char* overloads[] = {"list", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTreeWidget.addTopLevelItems", overloads);
        return 0;
}

static PyObject* Sbk_QTreeWidgetFunc_clear(PyObject* self)
{
    QTreeWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTreeWidget* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // clear()
                // Begin code injection

                QTreeWidgetItem *rootItem = cppSelf->invisibleRootItem();
                Shiboken::BindingManager &bm = Shiboken::BindingManager::instance();
                for (int i = 0; i < rootItem->childCount(); ++i) {
                    QTreeWidgetItem *item = rootItem->child(i);
                    SbkObject* wrapper = bm.retrieveWrapper(item);
                    if (wrapper)
                        Shiboken::Object::setParent(0, reinterpret_cast<PyObject*>(wrapper));
                }

                // End of code injection

                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->clear();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS

            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QTreeWidgetFunc_closePersistentEditor(PyObject* self, PyObject* args, PyObject* kwds)
{
    QTreeWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTreeWidget* >::toCpp(self);

    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QTreeWidget.closePersistentEditor(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QTreeWidget.closePersistentEditor(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:closePersistentEditor", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: closePersistentEditor(QTreeWidgetItem*,int)
    if (Shiboken::Converter< ::QTreeWidgetItem * >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // closePersistentEditor(QTreeWidgetItem*,int)
        } else if (SbkNumber_Check(pyargs[1])) {
            overloadId = 0; // closePersistentEditor(QTreeWidgetItem*,int)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTreeWidgetFunc_closePersistentEditor_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "column");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "column";
                    else if (SbkNumber_Check(value))
                        pyargs[1] = value;
                    else
                        goto Sbk_QTreeWidgetFunc_closePersistentEditor_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QTreeWidget.closePersistentEditor(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QTreeWidgetItem * cppArg0 = Shiboken::Converter<QTreeWidgetItem * >::toCpp(pyargs[0]);
            int cppArg1 = pyargs[1] ? Shiboken::Converter<int >::toCpp(pyargs[1]) : 0;

            if(!PyErr_Occurred()) {
                // closePersistentEditor(QTreeWidgetItem*,int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->closePersistentEditor(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTreeWidgetFunc_closePersistentEditor_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTreeWidgetItem, int = 0", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTreeWidget.closePersistentEditor", overloads);
        return 0;
}

static PyObject* Sbk_QTreeWidgetFunc_collapseItem(PyObject* self, PyObject* arg)
{
    QTreeWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTreeWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: collapseItem(const QTreeWidgetItem*)
    if (Shiboken::Converter< ::QTreeWidgetItem * >::isConvertible(arg)) {
        overloadId = 0; // collapseItem(const QTreeWidgetItem*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTreeWidgetFunc_collapseItem_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QTreeWidgetItem * cppArg0 = Shiboken::Converter<QTreeWidgetItem * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // collapseItem(const QTreeWidgetItem*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->collapseItem(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTreeWidgetFunc_collapseItem_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTreeWidgetItem", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTreeWidget.collapseItem", overloads);
        return 0;
}

static PyObject* Sbk_QTreeWidgetFunc_columnCount(PyObject* self)
{
    QTreeWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTreeWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // columnCount()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QTreeWidget*>(cppSelf)->columnCount();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTreeWidgetFunc_currentColumn(PyObject* self)
{
    QTreeWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTreeWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // currentColumn()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QTreeWidget*>(cppSelf)->currentColumn();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTreeWidgetFunc_currentItem(PyObject* self)
{
    QTreeWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTreeWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // currentItem()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QTreeWidgetItem * cppResult = const_cast<const QTreeWidget*>(cppSelf)->currentItem();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QTreeWidgetItem * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTreeWidgetFunc_dropEvent(PyObject* self, PyObject* arg)
{
    QTreeWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTreeWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: dropEvent(QDropEvent*)
    if (Shiboken::Converter< ::QDropEvent * >::isConvertible(arg)) {
        overloadId = 0; // dropEvent(QDropEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTreeWidgetFunc_dropEvent_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QDropEvent * cppArg0 = Shiboken::Converter<QDropEvent * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // dropEvent(QDropEvent*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QTreeWidget::dropEvent(cppArg0) : cppSelf->dropEvent(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTreeWidgetFunc_dropEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QDropEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTreeWidget.dropEvent", overloads);
        return 0;
}

static PyObject* Sbk_QTreeWidgetFunc_dropMimeData(PyObject* self, PyObject* args)
{
    QTreeWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTreeWidget* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "dropMimeData", 4, 4, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: dropMimeData(QTreeWidgetItem*,int,const QMimeData*,Qt::DropAction)
    if (numArgs == 4 && Shiboken::Converter< ::QTreeWidgetItem * >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1]) && Shiboken::Converter< ::QMimeData * >::isConvertible(pyargs[2]) && Shiboken::Converter< ::Qt::DropAction >::isConvertible(pyargs[3])) {
        overloadId = 0; // dropMimeData(QTreeWidgetItem*,int,const QMimeData*,Qt::DropAction)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTreeWidgetFunc_dropMimeData_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QTreeWidgetItem * cppArg0 = Shiboken::Converter<QTreeWidgetItem * >::toCpp(pyargs[0]);
            int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
            if (!Shiboken::Object::isValid(pyargs[2]))
                return 0;
            QMimeData * cppArg2 = Shiboken::Converter<QMimeData * >::toCpp(pyargs[2]);
            Qt::DropAction cppArg3 = Shiboken::Converter<Qt::DropAction >::toCpp(pyargs[3]);

            if(!PyErr_Occurred()) {
                // dropMimeData(QTreeWidgetItem*,int,const QMimeData*,Qt::DropAction)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = (Shiboken::Object::isUserType(self) ? cppSelf->::QTreeWidget::dropMimeData(cppArg0, cppArg1, cppArg2, cppArg3) : cppSelf->dropMimeData(cppArg0, cppArg1, cppArg2, cppArg3));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QTreeWidgetFunc_dropMimeData_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTreeWidgetItem, int, PySide.QtCore.QMimeData, PySide.QtCore.Qt.DropAction", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTreeWidget.dropMimeData", overloads);
        return 0;
}

static PyObject* Sbk_QTreeWidgetFunc_editItem(PyObject* self, PyObject* args, PyObject* kwds)
{
    QTreeWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTreeWidget* >::toCpp(self);

    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QTreeWidget.editItem(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QTreeWidget.editItem(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:editItem", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: editItem(QTreeWidgetItem*,int)
    if (Shiboken::Converter< ::QTreeWidgetItem * >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // editItem(QTreeWidgetItem*,int)
        } else if (SbkNumber_Check(pyargs[1])) {
            overloadId = 0; // editItem(QTreeWidgetItem*,int)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTreeWidgetFunc_editItem_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "column");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "column";
                    else if (SbkNumber_Check(value))
                        pyargs[1] = value;
                    else
                        goto Sbk_QTreeWidgetFunc_editItem_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QTreeWidget.editItem(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QTreeWidgetItem * cppArg0 = Shiboken::Converter<QTreeWidgetItem * >::toCpp(pyargs[0]);
            int cppArg1 = pyargs[1] ? Shiboken::Converter<int >::toCpp(pyargs[1]) : 0;

            if(!PyErr_Occurred()) {
                // editItem(QTreeWidgetItem*,int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->editItem(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTreeWidgetFunc_editItem_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTreeWidgetItem, int = 0", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTreeWidget.editItem", overloads);
        return 0;
}

static PyObject* Sbk_QTreeWidgetFunc_event(PyObject* self, PyObject* arg)
{
    QTreeWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTreeWidget* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: event(QEvent*)
    if (Shiboken::Converter< ::QEvent * >::isConvertible(arg)) {
        overloadId = 0; // event(QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTreeWidgetFunc_event_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QEvent * cppArg0 = Shiboken::Converter<QEvent * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // event(QEvent*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = (Shiboken::Object::isUserType(self) ? cppSelf->::QTreeWidget::event(cppArg0) : cppSelf->event(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QTreeWidgetFunc_event_TypeError:
        const char* overloads[] = {"PySide.QtCore.QEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTreeWidget.event", overloads);
        return 0;
}

static PyObject* Sbk_QTreeWidgetFunc_expandItem(PyObject* self, PyObject* arg)
{
    QTreeWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTreeWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: expandItem(const QTreeWidgetItem*)
    if (Shiboken::Converter< ::QTreeWidgetItem * >::isConvertible(arg)) {
        overloadId = 0; // expandItem(const QTreeWidgetItem*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTreeWidgetFunc_expandItem_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QTreeWidgetItem * cppArg0 = Shiboken::Converter<QTreeWidgetItem * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // expandItem(const QTreeWidgetItem*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->expandItem(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTreeWidgetFunc_expandItem_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTreeWidgetItem", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTreeWidget.expandItem", overloads);
        return 0;
}

static PyObject* Sbk_QTreeWidgetFunc_findItems(PyObject* self, PyObject* args, PyObject* kwds)
{
    QTreeWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTreeWidget* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QTreeWidget.findItems(): too many arguments");
        return 0;
    } else if (numArgs < 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QTreeWidget.findItems(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOO:findItems", &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: findItems(QString,QFlags<Qt::MatchFlag>,int)const
    if (numArgs >= 2 && Shiboken::Converter< QString >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QFlags<Qt::MatchFlag> >::isConvertible(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 0; // findItems(QString,QFlags<Qt::MatchFlag>,int)const
        } else if (SbkNumber_Check(pyargs[2])) {
            overloadId = 0; // findItems(QString,QFlags<Qt::MatchFlag>,int)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTreeWidgetFunc_findItems_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "column");
                if (value) {
                    if (pyargs[2])
                        errorArgName = "column";
                    else if (SbkNumber_Check(value))
                        pyargs[2] = value;
                    else
                        goto Sbk_QTreeWidgetFunc_findItems_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QTreeWidget.findItems(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            QFlags<Qt::MatchFlag> cppArg1 = Shiboken::Converter<QFlags<Qt::MatchFlag> >::toCpp(pyargs[1]);
            int cppArg2 = pyargs[2] ? Shiboken::Converter<int >::toCpp(pyargs[2]) : 0;

            if(!PyErr_Occurred()) {
                // findItems(QString,QFlags<Qt::MatchFlag>,int)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QList<QTreeWidgetItem * > cppResult = const_cast<const QTreeWidget*>(cppSelf)->findItems(cppArg0, cppArg1, cppArg2);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QList<QTreeWidgetItem * > >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QTreeWidgetFunc_findItems_TypeError:
        const char* overloads[] = {"QString, PySide.QtCore.Qt.MatchFlags, int = 0", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTreeWidget.findItems", overloads);
        return 0;
}

static PyObject* Sbk_QTreeWidgetFunc_headerItem(PyObject* self)
{
    QTreeWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTreeWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // headerItem()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QTreeWidgetItem * cppResult = const_cast<const QTreeWidget*>(cppSelf)->headerItem();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QTreeWidgetItem * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTreeWidgetFunc_indexFromItem(PyObject* self, PyObject* args, PyObject* kwds)
{
    QTreeWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTreeWidget* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QTreeWidget.indexFromItem(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QTreeWidget.indexFromItem(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:indexFromItem", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: indexFromItem(QTreeWidgetItem*,int)const
    if (Shiboken::Converter< ::QTreeWidgetItem * >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // indexFromItem(QTreeWidgetItem*,int)const
        } else if (SbkNumber_Check(pyargs[1])) {
            overloadId = 0; // indexFromItem(QTreeWidgetItem*,int)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTreeWidgetFunc_indexFromItem_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "column");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "column";
                    else if (SbkNumber_Check(value))
                        pyargs[1] = value;
                    else
                        goto Sbk_QTreeWidgetFunc_indexFromItem_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QTreeWidget.indexFromItem(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QTreeWidgetItem * cppArg0 = Shiboken::Converter<QTreeWidgetItem * >::toCpp(pyargs[0]);
            int cppArg1 = pyargs[1] ? Shiboken::Converter<int >::toCpp(pyargs[1]) : 0;

            if(!PyErr_Occurred()) {
                // indexFromItem(QTreeWidgetItem*,int)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QModelIndex cppResult = const_cast<const QTreeWidget*>(cppSelf)->indexFromItem(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QModelIndex >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QTreeWidgetFunc_indexFromItem_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTreeWidgetItem, int = 0", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTreeWidget.indexFromItem", overloads);
        return 0;
}

static PyObject* Sbk_QTreeWidgetFunc_indexOfTopLevelItem(PyObject* self, PyObject* arg)
{
    QTreeWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTreeWidget* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: indexOfTopLevelItem(QTreeWidgetItem*)const
    if (Shiboken::Converter< ::QTreeWidgetItem * >::isConvertible(arg)) {
        overloadId = 0; // indexOfTopLevelItem(QTreeWidgetItem*)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTreeWidgetFunc_indexOfTopLevelItem_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QTreeWidgetItem * cppArg0 = Shiboken::Converter<QTreeWidgetItem * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // indexOfTopLevelItem(QTreeWidgetItem*)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QTreeWidget*>(cppSelf)->indexOfTopLevelItem(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QTreeWidgetFunc_indexOfTopLevelItem_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTreeWidgetItem", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTreeWidget.indexOfTopLevelItem", overloads);
        return 0;
}

static PyObject* Sbk_QTreeWidgetFunc_insertTopLevelItem(PyObject* self, PyObject* args)
{
    QTreeWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTreeWidget* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "insertTopLevelItem", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: insertTopLevelItem(int,QTreeWidgetItem*)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && Shiboken::Converter< ::QTreeWidgetItem * >::isConvertible(pyargs[1])) {
        overloadId = 0; // insertTopLevelItem(int,QTreeWidgetItem*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTreeWidgetFunc_insertTopLevelItem_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            QTreeWidgetItem * cppArg1 = Shiboken::Converter<QTreeWidgetItem * >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // insertTopLevelItem(int,QTreeWidgetItem*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->insertTopLevelItem(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                Shiboken::Object::setParent(self, pyargs[1]);
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTreeWidgetFunc_insertTopLevelItem_TypeError:
        const char* overloads[] = {"int, PySide.QtGui.QTreeWidgetItem", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTreeWidget.insertTopLevelItem", overloads);
        return 0;
}

static PyObject* Sbk_QTreeWidgetFunc_insertTopLevelItems(PyObject* self, PyObject* args)
{
    QTreeWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTreeWidget* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "insertTopLevelItems", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: insertTopLevelItems(int,QList<QTreeWidgetItem*>)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && Shiboken::Converter< ::QList<QTreeWidgetItem * > >::isConvertible(pyargs[1])) {
        overloadId = 0; // insertTopLevelItems(int,QList<QTreeWidgetItem*>)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTreeWidgetFunc_insertTopLevelItems_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            QList<QTreeWidgetItem * > cppArg1 = Shiboken::Converter<QList<QTreeWidgetItem * > >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // insertTopLevelItems(int,QList<QTreeWidgetItem*>)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->insertTopLevelItems(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                Shiboken::Object::setParent(self, pyargs[1]);
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTreeWidgetFunc_insertTopLevelItems_TypeError:
        const char* overloads[] = {"int, list", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTreeWidget.insertTopLevelItems", overloads);
        return 0;
}

static PyObject* Sbk_QTreeWidgetFunc_invisibleRootItem(PyObject* self)
{
    QTreeWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTreeWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // invisibleRootItem()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QTreeWidgetItem * cppResult = const_cast<const QTreeWidget*>(cppSelf)->invisibleRootItem();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QTreeWidgetItem * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTreeWidgetFunc_isFirstItemColumnSpanned(PyObject* self, PyObject* arg)
{
    QTreeWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTreeWidget* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: isFirstItemColumnSpanned(const QTreeWidgetItem*)const
    if (Shiboken::Converter< ::QTreeWidgetItem * >::isConvertible(arg)) {
        overloadId = 0; // isFirstItemColumnSpanned(const QTreeWidgetItem*)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTreeWidgetFunc_isFirstItemColumnSpanned_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QTreeWidgetItem * cppArg0 = Shiboken::Converter<QTreeWidgetItem * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // isFirstItemColumnSpanned(const QTreeWidgetItem*)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QTreeWidget*>(cppSelf)->isFirstItemColumnSpanned(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QTreeWidgetFunc_isFirstItemColumnSpanned_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTreeWidgetItem", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTreeWidget.isFirstItemColumnSpanned", overloads);
        return 0;
}

static PyObject* Sbk_QTreeWidgetFunc_isItemExpanded(PyObject* self, PyObject* arg)
{
    QTreeWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTreeWidget* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: isItemExpanded(const QTreeWidgetItem*)const
    if (Shiboken::Converter< ::QTreeWidgetItem * >::isConvertible(arg)) {
        overloadId = 0; // isItemExpanded(const QTreeWidgetItem*)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTreeWidgetFunc_isItemExpanded_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QTreeWidgetItem * cppArg0 = Shiboken::Converter<QTreeWidgetItem * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // isItemExpanded(const QTreeWidgetItem*)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QTreeWidget*>(cppSelf)->isItemExpanded(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QTreeWidgetFunc_isItemExpanded_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTreeWidgetItem", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTreeWidget.isItemExpanded", overloads);
        return 0;
}

static PyObject* Sbk_QTreeWidgetFunc_isItemHidden(PyObject* self, PyObject* arg)
{
    QTreeWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTreeWidget* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: isItemHidden(const QTreeWidgetItem*)const
    if (Shiboken::Converter< ::QTreeWidgetItem * >::isConvertible(arg)) {
        overloadId = 0; // isItemHidden(const QTreeWidgetItem*)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTreeWidgetFunc_isItemHidden_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QTreeWidgetItem * cppArg0 = Shiboken::Converter<QTreeWidgetItem * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // isItemHidden(const QTreeWidgetItem*)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QTreeWidget*>(cppSelf)->isItemHidden(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QTreeWidgetFunc_isItemHidden_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTreeWidgetItem", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTreeWidget.isItemHidden", overloads);
        return 0;
}

static PyObject* Sbk_QTreeWidgetFunc_isItemSelected(PyObject* self, PyObject* arg)
{
    QTreeWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTreeWidget* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: isItemSelected(const QTreeWidgetItem*)const
    if (Shiboken::Converter< ::QTreeWidgetItem * >::isConvertible(arg)) {
        overloadId = 0; // isItemSelected(const QTreeWidgetItem*)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTreeWidgetFunc_isItemSelected_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QTreeWidgetItem * cppArg0 = Shiboken::Converter<QTreeWidgetItem * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // isItemSelected(const QTreeWidgetItem*)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QTreeWidget*>(cppSelf)->isItemSelected(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QTreeWidgetFunc_isItemSelected_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTreeWidgetItem", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTreeWidget.isItemSelected", overloads);
        return 0;
}

static PyObject* Sbk_QTreeWidgetFunc_isSortingEnabled(PyObject* self)
{
    QTreeWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTreeWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isSortingEnabled()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QTreeWidget*>(cppSelf)->isSortingEnabled();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTreeWidgetFunc_itemAbove(PyObject* self, PyObject* arg)
{
    QTreeWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTreeWidget* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: itemAbove(const QTreeWidgetItem*)const
    if (Shiboken::Converter< ::QTreeWidgetItem * >::isConvertible(arg)) {
        overloadId = 0; // itemAbove(const QTreeWidgetItem*)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTreeWidgetFunc_itemAbove_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QTreeWidgetItem * cppArg0 = Shiboken::Converter<QTreeWidgetItem * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // itemAbove(const QTreeWidgetItem*)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QTreeWidgetItem * cppResult = const_cast<const QTreeWidget*>(cppSelf)->itemAbove(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QTreeWidgetItem * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QTreeWidgetFunc_itemAbove_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTreeWidgetItem", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTreeWidget.itemAbove", overloads);
        return 0;
}

static PyObject* Sbk_QTreeWidgetFunc_itemAt(PyObject* self, PyObject* args)
{
    QTreeWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTreeWidget* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "itemAt", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: itemAt(QPoint)const
    // 1: itemAt(int,int)const
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 1; // itemAt(int,int)const
    } else if (numArgs == 1 && Shiboken::Converter< ::QPoint >::isConvertible(pyargs[0])) {
        overloadId = 0; // itemAt(QPoint)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTreeWidgetFunc_itemAt_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // itemAt(QPoint)const
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QPoint cppArg0 = Shiboken::Converter<QPoint >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // itemAt(QPoint)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QTreeWidgetItem * cppResult = const_cast<const QTreeWidget*>(cppSelf)->itemAt(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QTreeWidgetItem * >::toPython(cppResult);
                    Shiboken::Object::setParent(self, pyResult);
                }
                break;
            }
            case 1: // itemAt(int,int)const
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // itemAt(int,int)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QTreeWidgetItem * cppResult = const_cast<const QTreeWidget*>(cppSelf)->itemAt(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QTreeWidgetItem * >::toPython(cppResult);
                    Shiboken::Object::setParent(self, pyResult);
                }
                break;
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QTreeWidgetFunc_itemAt_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPoint", "int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTreeWidget.itemAt", overloads);
        return 0;
}

static PyObject* Sbk_QTreeWidgetFunc_itemBelow(PyObject* self, PyObject* arg)
{
    QTreeWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTreeWidget* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: itemBelow(const QTreeWidgetItem*)const
    if (Shiboken::Converter< ::QTreeWidgetItem * >::isConvertible(arg)) {
        overloadId = 0; // itemBelow(const QTreeWidgetItem*)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTreeWidgetFunc_itemBelow_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QTreeWidgetItem * cppArg0 = Shiboken::Converter<QTreeWidgetItem * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // itemBelow(const QTreeWidgetItem*)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QTreeWidgetItem * cppResult = const_cast<const QTreeWidget*>(cppSelf)->itemBelow(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QTreeWidgetItem * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QTreeWidgetFunc_itemBelow_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTreeWidgetItem", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTreeWidget.itemBelow", overloads);
        return 0;
}

static PyObject* Sbk_QTreeWidgetFunc_itemFromIndex(PyObject* self, PyObject* arg)
{
    QTreeWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTreeWidget* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: itemFromIndex(QModelIndex)const
    if (Shiboken::Converter< ::QModelIndex >::isConvertible(arg)) {
        overloadId = 0; // itemFromIndex(QModelIndex)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTreeWidgetFunc_itemFromIndex_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QModelIndex cppArg0 = Shiboken::Converter<QModelIndex >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // itemFromIndex(QModelIndex)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QTreeWidgetItem * cppResult = const_cast<const QTreeWidget*>(cppSelf)->itemFromIndex(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QTreeWidgetItem * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QTreeWidgetFunc_itemFromIndex_TypeError:
        const char* overloads[] = {"PySide.QtCore.QModelIndex", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTreeWidget.itemFromIndex", overloads);
        return 0;
}

static PyObject* Sbk_QTreeWidgetFunc_itemWidget(PyObject* self, PyObject* args)
{
    QTreeWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTreeWidget* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "itemWidget", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: itemWidget(QTreeWidgetItem*,int)const
    if (numArgs == 2 && Shiboken::Converter< ::QTreeWidgetItem * >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 0; // itemWidget(QTreeWidgetItem*,int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTreeWidgetFunc_itemWidget_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QTreeWidgetItem * cppArg0 = Shiboken::Converter<QTreeWidgetItem * >::toCpp(pyargs[0]);
            int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // itemWidget(QTreeWidgetItem*,int)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QWidget * cppResult = const_cast<const QTreeWidget*>(cppSelf)->itemWidget(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QWidget * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QTreeWidgetFunc_itemWidget_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTreeWidgetItem, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTreeWidget.itemWidget", overloads);
        return 0;
}

static PyObject* Sbk_QTreeWidgetFunc_mimeData(PyObject* self, PyObject* arg)
{
    QTreeWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTreeWidget* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: mimeData(QList<QTreeWidgetItem*>)const
    if (Shiboken::Converter< ::QList<QTreeWidgetItem * > >::isConvertible(arg)) {
        overloadId = 0; // mimeData(QList<QTreeWidgetItem*>)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTreeWidgetFunc_mimeData_TypeError;

    // Call function/method
    {
        {
            QList<QTreeWidgetItem * > cppArg0 = Shiboken::Converter<QList<QTreeWidgetItem * > >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // mimeData(QList<QTreeWidgetItem*>)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QMimeData * cppResult = (Shiboken::Object::isUserType(self) ? const_cast<const QTreeWidget*>(cppSelf)->::QTreeWidget::mimeData(cppArg0) : const_cast<const QTreeWidget*>(cppSelf)->mimeData(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QMimeData * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QTreeWidgetFunc_mimeData_TypeError:
        const char* overloads[] = {"list", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTreeWidget.mimeData", overloads);
        return 0;
}

static PyObject* Sbk_QTreeWidgetFunc_mimeTypes(PyObject* self)
{
    QTreeWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTreeWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // mimeTypes()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QStringList cppResult = (Shiboken::Object::isUserType(self) ? const_cast<const QTreeWidget*>(cppSelf)->::QTreeWidget::mimeTypes() : const_cast<const QTreeWidget*>(cppSelf)->mimeTypes());
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QStringList >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTreeWidgetFunc_openPersistentEditor(PyObject* self, PyObject* args, PyObject* kwds)
{
    QTreeWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTreeWidget* >::toCpp(self);

    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QTreeWidget.openPersistentEditor(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QTreeWidget.openPersistentEditor(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:openPersistentEditor", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: openPersistentEditor(QTreeWidgetItem*,int)
    if (Shiboken::Converter< ::QTreeWidgetItem * >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // openPersistentEditor(QTreeWidgetItem*,int)
        } else if (SbkNumber_Check(pyargs[1])) {
            overloadId = 0; // openPersistentEditor(QTreeWidgetItem*,int)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTreeWidgetFunc_openPersistentEditor_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "column");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "column";
                    else if (SbkNumber_Check(value))
                        pyargs[1] = value;
                    else
                        goto Sbk_QTreeWidgetFunc_openPersistentEditor_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QTreeWidget.openPersistentEditor(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QTreeWidgetItem * cppArg0 = Shiboken::Converter<QTreeWidgetItem * >::toCpp(pyargs[0]);
            int cppArg1 = pyargs[1] ? Shiboken::Converter<int >::toCpp(pyargs[1]) : 0;

            if(!PyErr_Occurred()) {
                // openPersistentEditor(QTreeWidgetItem*,int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->openPersistentEditor(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTreeWidgetFunc_openPersistentEditor_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTreeWidgetItem, int = 0", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTreeWidget.openPersistentEditor", overloads);
        return 0;
}

static PyObject* Sbk_QTreeWidgetFunc_removeItemWidget(PyObject* self, PyObject* args)
{
    QTreeWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTreeWidget* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "removeItemWidget", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: removeItemWidget(QTreeWidgetItem*,int)
    if (numArgs == 2 && Shiboken::Converter< ::QTreeWidgetItem * >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 0; // removeItemWidget(QTreeWidgetItem*,int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTreeWidgetFunc_removeItemWidget_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QTreeWidgetItem * cppArg0 = Shiboken::Converter<QTreeWidgetItem * >::toCpp(pyargs[0]);
            int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // removeItemWidget(QTreeWidgetItem*,int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->removeItemWidget(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTreeWidgetFunc_removeItemWidget_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTreeWidgetItem, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTreeWidget.removeItemWidget", overloads);
        return 0;
}

static PyObject* Sbk_QTreeWidgetFunc_scrollToItem(PyObject* self, PyObject* args, PyObject* kwds)
{
    QTreeWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTreeWidget* >::toCpp(self);

    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QTreeWidget.scrollToItem(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QTreeWidget.scrollToItem(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:scrollToItem", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: scrollToItem(const QTreeWidgetItem*,QAbstractItemView::ScrollHint)
    if (Shiboken::Converter< ::QTreeWidgetItem * >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // scrollToItem(const QTreeWidgetItem*,QAbstractItemView::ScrollHint)
        } else if (Shiboken::Converter< ::QAbstractItemView::ScrollHint >::isConvertible(pyargs[1])) {
            overloadId = 0; // scrollToItem(const QTreeWidgetItem*,QAbstractItemView::ScrollHint)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTreeWidgetFunc_scrollToItem_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "hint");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "hint";
                    else if (Shiboken::Converter< ::QAbstractItemView::ScrollHint >::isConvertible(value))
                        pyargs[1] = value;
                    else
                        goto Sbk_QTreeWidgetFunc_scrollToItem_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QTreeWidget.scrollToItem(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QTreeWidgetItem * cppArg0 = Shiboken::Converter<QTreeWidgetItem * >::toCpp(pyargs[0]);
            QAbstractItemView::ScrollHint cppArg1 = pyargs[1] ? Shiboken::Converter<QAbstractItemView::ScrollHint >::toCpp(pyargs[1]) : QAbstractItemView::EnsureVisible;

            if(!PyErr_Occurred()) {
                // scrollToItem(const QTreeWidgetItem*,QAbstractItemView::ScrollHint)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->scrollToItem(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTreeWidgetFunc_scrollToItem_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTreeWidgetItem, PySide.QtGui.QAbstractItemView.ScrollHint = EnsureVisible", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTreeWidget.scrollToItem", overloads);
        return 0;
}

static PyObject* Sbk_QTreeWidgetFunc_selectedItems(PyObject* self)
{
    QTreeWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTreeWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // selectedItems()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QList<QTreeWidgetItem * > cppResult = const_cast<const QTreeWidget*>(cppSelf)->selectedItems();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QList<QTreeWidgetItem * > >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTreeWidgetFunc_setColumnCount(PyObject* self, PyObject* arg)
{
    QTreeWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTreeWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setColumnCount(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setColumnCount(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTreeWidgetFunc_setColumnCount_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setColumnCount(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setColumnCount(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTreeWidgetFunc_setColumnCount_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTreeWidget.setColumnCount", overloads);
        return 0;
}

static PyObject* Sbk_QTreeWidgetFunc_setCurrentItem(PyObject* self, PyObject* args)
{
    QTreeWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTreeWidget* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setCurrentItem", 1, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: setCurrentItem(QTreeWidgetItem*)
    // 1: setCurrentItem(QTreeWidgetItem*,int)
    // 2: setCurrentItem(QTreeWidgetItem*,int,QFlags<QItemSelectionModel::SelectionFlag>)
    if (Shiboken::Converter< ::QTreeWidgetItem * >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // setCurrentItem(QTreeWidgetItem*)
        } else if (SbkNumber_Check(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 1; // setCurrentItem(QTreeWidgetItem*,int)
            } else if (numArgs == 3 && Shiboken::Converter< ::QFlags<QItemSelectionModel::SelectionFlag> >::isConvertible(pyargs[2])) {
                overloadId = 2; // setCurrentItem(QTreeWidgetItem*,int,QFlags<QItemSelectionModel::SelectionFlag>)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTreeWidgetFunc_setCurrentItem_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // setCurrentItem(QTreeWidgetItem*)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QTreeWidgetItem * cppArg0 = Shiboken::Converter<QTreeWidgetItem * >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // setCurrentItem(QTreeWidgetItem*)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setCurrentItem(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // setCurrentItem(QTreeWidgetItem*,int)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QTreeWidgetItem * cppArg0 = Shiboken::Converter<QTreeWidgetItem * >::toCpp(pyargs[0]);
                int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // setCurrentItem(QTreeWidgetItem*,int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setCurrentItem(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 2: // setCurrentItem(QTreeWidgetItem*,int,QFlags<QItemSelectionModel::SelectionFlag>)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QTreeWidgetItem * cppArg0 = Shiboken::Converter<QTreeWidgetItem * >::toCpp(pyargs[0]);
                int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                QFlags<QItemSelectionModel::SelectionFlag> cppArg2 = Shiboken::Converter<QFlags<QItemSelectionModel::SelectionFlag> >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                    // setCurrentItem(QTreeWidgetItem*,int,QFlags<QItemSelectionModel::SelectionFlag>)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setCurrentItem(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTreeWidgetFunc_setCurrentItem_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTreeWidgetItem", "PySide.QtGui.QTreeWidgetItem, int", "PySide.QtGui.QTreeWidgetItem, int, PySide.QtGui.QItemSelectionModel.SelectionFlags", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTreeWidget.setCurrentItem", overloads);
        return 0;
}

static PyObject* Sbk_QTreeWidgetFunc_setFirstItemColumnSpanned(PyObject* self, PyObject* args)
{
    QTreeWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTreeWidget* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setFirstItemColumnSpanned", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setFirstItemColumnSpanned(const QTreeWidgetItem*,bool)
    if (numArgs == 2 && Shiboken::Converter< ::QTreeWidgetItem * >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 0; // setFirstItemColumnSpanned(const QTreeWidgetItem*,bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTreeWidgetFunc_setFirstItemColumnSpanned_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QTreeWidgetItem * cppArg0 = Shiboken::Converter<QTreeWidgetItem * >::toCpp(pyargs[0]);
            bool cppArg1 = Shiboken::Converter<bool >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // setFirstItemColumnSpanned(const QTreeWidgetItem*,bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setFirstItemColumnSpanned(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTreeWidgetFunc_setFirstItemColumnSpanned_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTreeWidgetItem, bool", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTreeWidget.setFirstItemColumnSpanned", overloads);
        return 0;
}

static PyObject* Sbk_QTreeWidgetFunc_setHeaderItem(PyObject* self, PyObject* arg)
{
    QTreeWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTreeWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setHeaderItem(QTreeWidgetItem*)
    if (Shiboken::Converter< ::QTreeWidgetItem * >::isConvertible(arg)) {
        overloadId = 0; // setHeaderItem(QTreeWidgetItem*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTreeWidgetFunc_setHeaderItem_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QTreeWidgetItem * cppArg0 = Shiboken::Converter<QTreeWidgetItem * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setHeaderItem(QTreeWidgetItem*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setHeaderItem(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                Shiboken::Object::setParent(self, arg);
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTreeWidgetFunc_setHeaderItem_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTreeWidgetItem", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTreeWidget.setHeaderItem", overloads);
        return 0;
}

static PyObject* Sbk_QTreeWidgetFunc_setHeaderLabel(PyObject* self, PyObject* arg)
{
    QTreeWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTreeWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setHeaderLabel(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // setHeaderLabel(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTreeWidgetFunc_setHeaderLabel_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setHeaderLabel(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setHeaderLabel(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTreeWidgetFunc_setHeaderLabel_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTreeWidget.setHeaderLabel", overloads);
        return 0;
}

static PyObject* Sbk_QTreeWidgetFunc_setHeaderLabels(PyObject* self, PyObject* arg)
{
    QTreeWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTreeWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setHeaderLabels(QStringList)
    if (Shiboken::Converter< ::QStringList >::isConvertible(arg)) {
        overloadId = 0; // setHeaderLabels(QStringList)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTreeWidgetFunc_setHeaderLabels_TypeError;

    // Call function/method
    {
        {
            QStringList cppArg0 = Shiboken::Converter<QStringList >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setHeaderLabels(QStringList)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setHeaderLabels(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTreeWidgetFunc_setHeaderLabels_TypeError:
        const char* overloads[] = {"list", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTreeWidget.setHeaderLabels", overloads);
        return 0;
}

static PyObject* Sbk_QTreeWidgetFunc_setItemExpanded(PyObject* self, PyObject* args)
{
    QTreeWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTreeWidget* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setItemExpanded", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setItemExpanded(const QTreeWidgetItem*,bool)
    if (numArgs == 2 && Shiboken::Converter< ::QTreeWidgetItem * >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 0; // setItemExpanded(const QTreeWidgetItem*,bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTreeWidgetFunc_setItemExpanded_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QTreeWidgetItem * cppArg0 = Shiboken::Converter<QTreeWidgetItem * >::toCpp(pyargs[0]);
            bool cppArg1 = Shiboken::Converter<bool >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // setItemExpanded(const QTreeWidgetItem*,bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setItemExpanded(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTreeWidgetFunc_setItemExpanded_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTreeWidgetItem, bool", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTreeWidget.setItemExpanded", overloads);
        return 0;
}

static PyObject* Sbk_QTreeWidgetFunc_setItemHidden(PyObject* self, PyObject* args)
{
    QTreeWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTreeWidget* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setItemHidden", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setItemHidden(const QTreeWidgetItem*,bool)
    if (numArgs == 2 && Shiboken::Converter< ::QTreeWidgetItem * >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 0; // setItemHidden(const QTreeWidgetItem*,bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTreeWidgetFunc_setItemHidden_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QTreeWidgetItem * cppArg0 = Shiboken::Converter<QTreeWidgetItem * >::toCpp(pyargs[0]);
            bool cppArg1 = Shiboken::Converter<bool >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // setItemHidden(const QTreeWidgetItem*,bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setItemHidden(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTreeWidgetFunc_setItemHidden_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTreeWidgetItem, bool", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTreeWidget.setItemHidden", overloads);
        return 0;
}

static PyObject* Sbk_QTreeWidgetFunc_setItemSelected(PyObject* self, PyObject* args)
{
    QTreeWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTreeWidget* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setItemSelected", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setItemSelected(const QTreeWidgetItem*,bool)
    if (numArgs == 2 && Shiboken::Converter< ::QTreeWidgetItem * >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 0; // setItemSelected(const QTreeWidgetItem*,bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTreeWidgetFunc_setItemSelected_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QTreeWidgetItem * cppArg0 = Shiboken::Converter<QTreeWidgetItem * >::toCpp(pyargs[0]);
            bool cppArg1 = Shiboken::Converter<bool >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // setItemSelected(const QTreeWidgetItem*,bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setItemSelected(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTreeWidgetFunc_setItemSelected_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTreeWidgetItem, bool", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTreeWidget.setItemSelected", overloads);
        return 0;
}

static PyObject* Sbk_QTreeWidgetFunc_setItemWidget(PyObject* self, PyObject* args)
{
    QTreeWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTreeWidget* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setItemWidget", 3, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: setItemWidget(QTreeWidgetItem*,int,QWidget*)
    if (numArgs == 3 && Shiboken::Converter< ::QTreeWidgetItem * >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1]) && Shiboken::Converter< ::QWidget * >::isConvertible(pyargs[2])) {
        overloadId = 0; // setItemWidget(QTreeWidgetItem*,int,QWidget*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTreeWidgetFunc_setItemWidget_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QTreeWidgetItem * cppArg0 = Shiboken::Converter<QTreeWidgetItem * >::toCpp(pyargs[0]);
            int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
            if (!Shiboken::Object::isValid(pyargs[2]))
                return 0;
            QWidget * cppArg2 = Shiboken::Converter<QWidget * >::toCpp(pyargs[2]);

            if(!PyErr_Occurred()) {
                // setItemWidget(QTreeWidgetItem*,int,QWidget*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setItemWidget(cppArg0, cppArg1, cppArg2);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTreeWidgetFunc_setItemWidget_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTreeWidgetItem, int, PySide.QtGui.QWidget", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTreeWidget.setItemWidget", overloads);
        return 0;
}

static PyObject* Sbk_QTreeWidgetFunc_setModel(PyObject* self, PyObject* arg)
{
    QTreeWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTreeWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setModel(QAbstractItemModel*)
    if (Shiboken::Converter< ::QAbstractItemModel * >::isConvertible(arg)) {
        overloadId = 0; // setModel(QAbstractItemModel*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTreeWidgetFunc_setModel_TypeError;

    // Call function/method
    {
        {
            PyErr_Format(PyExc_TypeError, "%s is a private method.", "setModel(QAbstractItemModel * model)");
            return 0;
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTreeWidgetFunc_setModel_TypeError:
        const char* overloads[] = {"PySide.QtCore.QAbstractItemModel", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTreeWidget.setModel", overloads);
        return 0;
}

static PyObject* Sbk_QTreeWidgetFunc_setSelectionModel(PyObject* self, PyObject* arg)
{
    QTreeWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTreeWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setSelectionModel(QItemSelectionModel*)
    if (Shiboken::Converter< ::QItemSelectionModel * >::isConvertible(arg)) {
        overloadId = 0; // setSelectionModel(QItemSelectionModel*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTreeWidgetFunc_setSelectionModel_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QItemSelectionModel * cppArg0 = Shiboken::Converter<QItemSelectionModel * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setSelectionModel(QItemSelectionModel*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QTreeWidget::setSelectionModel(cppArg0) : cppSelf->setSelectionModel(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                Shiboken::Object::keepReference(reinterpret_cast<SbkObject*>(self), "setSelectionModel(QItemSelectionModel*)1", arg);
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTreeWidgetFunc_setSelectionModel_TypeError:
        const char* overloads[] = {"PySide.QtGui.QItemSelectionModel", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTreeWidget.setSelectionModel", overloads);
        return 0;
}

static PyObject* Sbk_QTreeWidgetFunc_setSortingEnabled(PyObject* self, PyObject* arg)
{
    QTreeWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTreeWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setSortingEnabled(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setSortingEnabled(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTreeWidgetFunc_setSortingEnabled_TypeError;

    // Call function/method
    {
        {
            bool cppArg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setSortingEnabled(bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setSortingEnabled(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTreeWidgetFunc_setSortingEnabled_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTreeWidget.setSortingEnabled", overloads);
        return 0;
}

static PyObject* Sbk_QTreeWidgetFunc_sortColumn(PyObject* self)
{
    QTreeWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTreeWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // sortColumn()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QTreeWidget*>(cppSelf)->sortColumn();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTreeWidgetFunc_sortItems(PyObject* self, PyObject* args)
{
    QTreeWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTreeWidget* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "sortItems", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: sortItems(int,Qt::SortOrder)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && Shiboken::Converter< ::Qt::SortOrder >::isConvertible(pyargs[1])) {
        overloadId = 0; // sortItems(int,Qt::SortOrder)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTreeWidgetFunc_sortItems_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            Qt::SortOrder cppArg1 = Shiboken::Converter<Qt::SortOrder >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // sortItems(int,Qt::SortOrder)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->sortItems(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTreeWidgetFunc_sortItems_TypeError:
        const char* overloads[] = {"int, PySide.QtCore.Qt.SortOrder", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTreeWidget.sortItems", overloads);
        return 0;
}

static PyObject* Sbk_QTreeWidgetFunc_supportedDropActions(PyObject* self)
{
    QTreeWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTreeWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // supportedDropActions()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QFlags<Qt::DropAction> cppResult = (Shiboken::Object::isUserType(self) ? const_cast<const QTreeWidget*>(cppSelf)->::QTreeWidget::supportedDropActions() : const_cast<const QTreeWidget*>(cppSelf)->supportedDropActions());
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QFlags<Qt::DropAction> >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTreeWidgetFunc_takeTopLevelItem(PyObject* self, PyObject* arg)
{
    QTreeWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTreeWidget* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: takeTopLevelItem(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // takeTopLevelItem(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTreeWidgetFunc_takeTopLevelItem_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // takeTopLevelItem(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QTreeWidgetItem * cppResult = cppSelf->takeTopLevelItem(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QTreeWidgetItem * >::toPython(cppResult);

                // Ownership transferences.
                Shiboken::Object::setParent(Py_None, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QTreeWidgetFunc_takeTopLevelItem_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTreeWidget.takeTopLevelItem", overloads);
        return 0;
}

static PyObject* Sbk_QTreeWidgetFunc_topLevelItem(PyObject* self, PyObject* arg)
{
    QTreeWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTreeWidget* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: topLevelItem(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // topLevelItem(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTreeWidgetFunc_topLevelItem_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // topLevelItem(int)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QTreeWidgetItem * cppResult = const_cast<const QTreeWidget*>(cppSelf)->topLevelItem(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QTreeWidgetItem * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QTreeWidgetFunc_topLevelItem_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTreeWidget.topLevelItem", overloads);
        return 0;
}

static PyObject* Sbk_QTreeWidgetFunc_topLevelItemCount(PyObject* self)
{
    QTreeWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTreeWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // topLevelItemCount()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QTreeWidget*>(cppSelf)->topLevelItemCount();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTreeWidgetFunc_visualItemRect(PyObject* self, PyObject* arg)
{
    QTreeWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTreeWidget* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: visualItemRect(const QTreeWidgetItem*)const
    if (Shiboken::Converter< ::QTreeWidgetItem * >::isConvertible(arg)) {
        overloadId = 0; // visualItemRect(const QTreeWidgetItem*)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTreeWidgetFunc_visualItemRect_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QTreeWidgetItem * cppArg0 = Shiboken::Converter<QTreeWidgetItem * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // visualItemRect(const QTreeWidgetItem*)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QRect cppResult = const_cast<const QTreeWidget*>(cppSelf)->visualItemRect(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QRect >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QTreeWidgetFunc_visualItemRect_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTreeWidgetItem", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTreeWidget.visualItemRect", overloads);
        return 0;
}

static PyMethodDef Sbk_QTreeWidget_methods[] = {
    {"addTopLevelItem", (PyCFunction)Sbk_QTreeWidgetFunc_addTopLevelItem, METH_O},
    {"addTopLevelItems", (PyCFunction)Sbk_QTreeWidgetFunc_addTopLevelItems, METH_O},
    {"clear", (PyCFunction)Sbk_QTreeWidgetFunc_clear, METH_NOARGS},
    {"closePersistentEditor", (PyCFunction)Sbk_QTreeWidgetFunc_closePersistentEditor, METH_VARARGS|METH_KEYWORDS},
    {"collapseItem", (PyCFunction)Sbk_QTreeWidgetFunc_collapseItem, METH_O},
    {"columnCount", (PyCFunction)Sbk_QTreeWidgetFunc_columnCount, METH_NOARGS},
    {"currentColumn", (PyCFunction)Sbk_QTreeWidgetFunc_currentColumn, METH_NOARGS},
    {"currentItem", (PyCFunction)Sbk_QTreeWidgetFunc_currentItem, METH_NOARGS},
    {"dropEvent", (PyCFunction)Sbk_QTreeWidgetFunc_dropEvent, METH_O},
    {"dropMimeData", (PyCFunction)Sbk_QTreeWidgetFunc_dropMimeData, METH_VARARGS},
    {"editItem", (PyCFunction)Sbk_QTreeWidgetFunc_editItem, METH_VARARGS|METH_KEYWORDS},
    {"event", (PyCFunction)Sbk_QTreeWidgetFunc_event, METH_O},
    {"expandItem", (PyCFunction)Sbk_QTreeWidgetFunc_expandItem, METH_O},
    {"findItems", (PyCFunction)Sbk_QTreeWidgetFunc_findItems, METH_VARARGS|METH_KEYWORDS},
    {"headerItem", (PyCFunction)Sbk_QTreeWidgetFunc_headerItem, METH_NOARGS},
    {"indexFromItem", (PyCFunction)Sbk_QTreeWidgetFunc_indexFromItem, METH_VARARGS|METH_KEYWORDS},
    {"indexOfTopLevelItem", (PyCFunction)Sbk_QTreeWidgetFunc_indexOfTopLevelItem, METH_O},
    {"insertTopLevelItem", (PyCFunction)Sbk_QTreeWidgetFunc_insertTopLevelItem, METH_VARARGS},
    {"insertTopLevelItems", (PyCFunction)Sbk_QTreeWidgetFunc_insertTopLevelItems, METH_VARARGS},
    {"invisibleRootItem", (PyCFunction)Sbk_QTreeWidgetFunc_invisibleRootItem, METH_NOARGS},
    {"isFirstItemColumnSpanned", (PyCFunction)Sbk_QTreeWidgetFunc_isFirstItemColumnSpanned, METH_O},
    {"isItemExpanded", (PyCFunction)Sbk_QTreeWidgetFunc_isItemExpanded, METH_O},
    {"isItemHidden", (PyCFunction)Sbk_QTreeWidgetFunc_isItemHidden, METH_O},
    {"isItemSelected", (PyCFunction)Sbk_QTreeWidgetFunc_isItemSelected, METH_O},
    {"isSortingEnabled", (PyCFunction)Sbk_QTreeWidgetFunc_isSortingEnabled, METH_NOARGS},
    {"itemAbove", (PyCFunction)Sbk_QTreeWidgetFunc_itemAbove, METH_O},
    {"itemAt", (PyCFunction)Sbk_QTreeWidgetFunc_itemAt, METH_VARARGS},
    {"itemBelow", (PyCFunction)Sbk_QTreeWidgetFunc_itemBelow, METH_O},
    {"itemFromIndex", (PyCFunction)Sbk_QTreeWidgetFunc_itemFromIndex, METH_O},
    {"itemWidget", (PyCFunction)Sbk_QTreeWidgetFunc_itemWidget, METH_VARARGS},
    {"mimeData", (PyCFunction)Sbk_QTreeWidgetFunc_mimeData, METH_O},
    {"mimeTypes", (PyCFunction)Sbk_QTreeWidgetFunc_mimeTypes, METH_NOARGS},
    {"openPersistentEditor", (PyCFunction)Sbk_QTreeWidgetFunc_openPersistentEditor, METH_VARARGS|METH_KEYWORDS},
    {"removeItemWidget", (PyCFunction)Sbk_QTreeWidgetFunc_removeItemWidget, METH_VARARGS},
    {"scrollToItem", (PyCFunction)Sbk_QTreeWidgetFunc_scrollToItem, METH_VARARGS|METH_KEYWORDS},
    {"selectedItems", (PyCFunction)Sbk_QTreeWidgetFunc_selectedItems, METH_NOARGS},
    {"setColumnCount", (PyCFunction)Sbk_QTreeWidgetFunc_setColumnCount, METH_O},
    {"setCurrentItem", (PyCFunction)Sbk_QTreeWidgetFunc_setCurrentItem, METH_VARARGS},
    {"setFirstItemColumnSpanned", (PyCFunction)Sbk_QTreeWidgetFunc_setFirstItemColumnSpanned, METH_VARARGS},
    {"setHeaderItem", (PyCFunction)Sbk_QTreeWidgetFunc_setHeaderItem, METH_O},
    {"setHeaderLabel", (PyCFunction)Sbk_QTreeWidgetFunc_setHeaderLabel, METH_O},
    {"setHeaderLabels", (PyCFunction)Sbk_QTreeWidgetFunc_setHeaderLabels, METH_O},
    {"setItemExpanded", (PyCFunction)Sbk_QTreeWidgetFunc_setItemExpanded, METH_VARARGS},
    {"setItemHidden", (PyCFunction)Sbk_QTreeWidgetFunc_setItemHidden, METH_VARARGS},
    {"setItemSelected", (PyCFunction)Sbk_QTreeWidgetFunc_setItemSelected, METH_VARARGS},
    {"setItemWidget", (PyCFunction)Sbk_QTreeWidgetFunc_setItemWidget, METH_VARARGS},
    {"setModel", (PyCFunction)Sbk_QTreeWidgetFunc_setModel, METH_O},
    {"setSelectionModel", (PyCFunction)Sbk_QTreeWidgetFunc_setSelectionModel, METH_O},
    {"setSortingEnabled", (PyCFunction)Sbk_QTreeWidgetFunc_setSortingEnabled, METH_O},
    {"sortColumn", (PyCFunction)Sbk_QTreeWidgetFunc_sortColumn, METH_NOARGS},
    {"sortItems", (PyCFunction)Sbk_QTreeWidgetFunc_sortItems, METH_VARARGS},
    {"supportedDropActions", (PyCFunction)Sbk_QTreeWidgetFunc_supportedDropActions, METH_NOARGS},
    {"takeTopLevelItem", (PyCFunction)Sbk_QTreeWidgetFunc_takeTopLevelItem, METH_O},
    {"topLevelItem", (PyCFunction)Sbk_QTreeWidgetFunc_topLevelItem, METH_O},
    {"topLevelItemCount", (PyCFunction)Sbk_QTreeWidgetFunc_topLevelItemCount, METH_NOARGS},
    {"visualItemRect", (PyCFunction)Sbk_QTreeWidgetFunc_visualItemRect, METH_O},

    {0} // Sentinel
};

} // extern "C"

static void* Sbk_QTreeWidgetSpecialCastFunction(void* obj, SbkObjectType* desiredType)
{
    QTreeWidget* me = reinterpret_cast<QTreeWidget*>(obj);
    if (desiredType == reinterpret_cast<SbkObjectType*>(SbkPySide_QtGuiTypes[SBK_QTREEVIEW_IDX]))
        return static_cast<QTreeView*>(me);
    else if (desiredType == reinterpret_cast<SbkObjectType*>(SbkPySide_QtGuiTypes[SBK_QABSTRACTITEMVIEW_IDX]))
        return static_cast<QAbstractItemView*>(me);
    else if (desiredType == reinterpret_cast<SbkObjectType*>(SbkPySide_QtGuiTypes[SBK_QABSTRACTSCROLLAREA_IDX]))
        return static_cast<QAbstractScrollArea*>(me);
    else if (desiredType == reinterpret_cast<SbkObjectType*>(SbkPySide_QtGuiTypes[SBK_QFRAME_IDX]))
        return static_cast<QFrame*>(me);
    else if (desiredType == reinterpret_cast<SbkObjectType*>(SbkPySide_QtGuiTypes[SBK_QWIDGET_IDX]))
        return static_cast<QWidget*>(me);
    else if (desiredType == reinterpret_cast<SbkObjectType*>(SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX]))
        return static_cast<QObject*>(me);
    else if (desiredType == reinterpret_cast<SbkObjectType*>(SbkPySide_QtGuiTypes[SBK_QPAINTDEVICE_IDX]))
        return static_cast<QPaintDevice*>(me);
    return me;
}


// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QTreeWidget_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QTreeWidget",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QTreeWidget_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QTreeWidget_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern

static SbkObjectType* Sbk_QTreeWidget_typeDiscovery(void* cptr, SbkObjectType* instanceType)
{
    if (instanceType == reinterpret_cast<SbkObjectType*>(Shiboken::SbkType<QObject >()) && dynamic_cast<QTreeWidget*>(reinterpret_cast<QObject*>(cptr)))
        return &Sbk_QTreeWidget_Type;
    if (instanceType == reinterpret_cast<SbkObjectType*>(Shiboken::SbkType<QPaintDevice >()) && dynamic_cast<QTreeWidget*>(reinterpret_cast<QPaintDevice*>(cptr)))
        return &Sbk_QTreeWidget_Type;
    return 0;
}


void init_QTreeWidget(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QTREEWIDGET_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QTreeWidget_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QTreeWidget_Type);
    Shiboken::ObjectType::setSubTypeInitHook(&Sbk_QTreeWidget_Type, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(&Sbk_QTreeWidget_Type, &QTreeWidget::staticMetaObject);    Sbk_QTreeWidget_Type.super.ht_type.tp_base = SbkPySide_QtGuiTypes[SBK_QTREEVIEW_IDX];
    MultipleInheritanceInitFunction func;
    func = Shiboken::ObjectType::getMultipleIheritanceFunction(reinterpret_cast<SbkObjectType*>(SbkPySide_QtGuiTypes[SBK_QWIDGET_IDX]));
    Shiboken::ObjectType::setMultipleIheritanceFunction(&Sbk_QTreeWidget_Type, func);
    Shiboken::ObjectType::setCastFunction(&Sbk_QTreeWidget_Type, &Sbk_QTreeWidgetSpecialCastFunction);
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QTreeWidget_Type, &Shiboken::callCppDestructor<QTreeWidget >);
    if (PyType_Ready((PyTypeObject*)&Sbk_QTreeWidget_Type) < 0)
        return;

    // Fill type discovery information
    Shiboken::ObjectType::setTypeDiscoveryFunction(&Sbk_QTreeWidget_Type, &Sbk_QTreeWidget_typeDiscovery);
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkObjectType*>(SbkPySide_QtGuiTypes[SBK_QTREEVIEW_IDX]), &Sbk_QTreeWidget_Type);

    Shiboken::ObjectType::setOriginalName(&Sbk_QTreeWidget_Type, "QTreeWidget*");
    PyModule_AddObject(module, "QTreeWidget",
        ((PyObject*)&Sbk_QTreeWidget_Type));

    // Initialize signals
    PySideSignal* signal_item;

    signal_item = PySide::Signal::newObject("currentItemChanged", "QTreeWidgetItem*,QTreeWidgetItem*", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QTreeWidget_Type, "currentItemChanged", signal_item);
    Py_DECREF((PyObject*) signal_item);
    signal_item = PySide::Signal::newObject("itemChanged", "QTreeWidgetItem*,int", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QTreeWidget_Type, "itemChanged", signal_item);
    Py_DECREF((PyObject*) signal_item);
    signal_item = PySide::Signal::newObject("itemDoubleClicked", "QTreeWidgetItem*,int", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QTreeWidget_Type, "itemDoubleClicked", signal_item);
    Py_DECREF((PyObject*) signal_item);
    signal_item = PySide::Signal::newObject("itemClicked", "QTreeWidgetItem*,int", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QTreeWidget_Type, "itemClicked", signal_item);
    Py_DECREF((PyObject*) signal_item);
    signal_item = PySide::Signal::newObject("itemActivated", "QTreeWidgetItem*,int", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QTreeWidget_Type, "itemActivated", signal_item);
    Py_DECREF((PyObject*) signal_item);
    signal_item = PySide::Signal::newObject("itemCollapsed", "QTreeWidgetItem*", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QTreeWidget_Type, "itemCollapsed", signal_item);
    Py_DECREF((PyObject*) signal_item);
    signal_item = PySide::Signal::newObject("itemPressed", "QTreeWidgetItem*,int", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QTreeWidget_Type, "itemPressed", signal_item);
    Py_DECREF((PyObject*) signal_item);
    signal_item = PySide::Signal::newObject("itemSelectionChanged", "void", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QTreeWidget_Type, "itemSelectionChanged", signal_item);
    Py_DECREF((PyObject*) signal_item);
    signal_item = PySide::Signal::newObject("itemExpanded", "QTreeWidgetItem*", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QTreeWidget_Type, "itemExpanded", signal_item);
    Py_DECREF((PyObject*) signal_item);
    signal_item = PySide::Signal::newObject("itemEntered", "QTreeWidgetItem*,int", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QTreeWidget_Type, "itemEntered", signal_item);
    Py_DECREF((PyObject*) signal_item);


    Shiboken::TypeResolver::createObjectTypeResolver<QTreeWidget >("QTreeWidget*");
    Shiboken::TypeResolver::createObjectTypeResolver<QTreeWidget >(typeid(QTreeWidget).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QTreeWidget >(typeid(QTreeWidgetWrapper).name());
    PySide::initQtMetaType< ::QTreeWidget* >();
}

